/**
 * PRESENTATION STYLESHEET
 * ----------------------------------------------------------------------------
 */

/*


       PLEASE NOTE: 
       ============

       THIS FILE IS NOT PART OF THE *REQUIRED FONT ICON FILES* 
       THIS FILE IS USED TO STYLE THE ICON DEMO TEMPLATE FOUND AT DEMO.HTML



*/

*,
*:before,
*:after {
	border: 0 none;
	margin: 0;
	padding: 0;
	font-size: 100%;

	-webkit-box-sizing: border-box;
	   -moz-box-sizing: border-box;
	        box-sizing: border-box;
}

::-webkit-scrollbar {
	width: 12px;
	height: 12px;
}
::-webkit-scrollbar-track {
	background-color: rgba(255, 255, 255, 0.1);
	-webkit-border-radius: 5px;
}
::-webkit-scrollbar-thumb {
	background-color: rgba(0, 0, 0, 0.4);
	-webkit-border-radius: 6px;
}
::-webkit-scrollbar-thumb:hover {
	background-color: rgba(0, 0, 0, 0.6);
}

section, 
header, 
footer {
	display: block;
	position: relative;
}

body {
	background-color: #fff;
	color: #0e8a65;
	font-family: "Helvetica Neue", Helvetica, "DejaVu Sans", Arial, sans-serif;
	line-height: 1.5;
	font-size: 1em;
}


section:after,
.masthead:after {
	content: '';
	pointer-events: none;
	position: absolute;
		bottom: -1.5em;
		left: 50%;
		z-index: 10;
	width: 3em;
	height: 3em;

	background: inherit;
	-webkit-transform: translateX(-50%) rotate(45deg);
	transform: translateX(-50%) rotate(45deg);
}

section header {
	position: relative;
}

section header:after {
	background-color: transparent;
	border-bottom-width: 1px;
	border-bottom-style: solid;
	border-bottom-color: inherit;
	content: '';
	position: absolute;
		left: 40%;
		bottom: 0;
	width: 20%;
	height: 0;
}

.masthead {
	background-color: #fff;
	padding: 3em;
	position: relative;
	text-align: center;
}

.colophon {
	padding: 4.5em 3em;
	position: relative;
}
.colophon .group {
	padding: 3em;
	text-align: center;
}

.masthead hgroup,
.colophon .group {
	margin: auto;
	padding: 0 10%;
	position: absolute;
	top: 50%;
	left: 0%;
	right: 0%;
	-webkit-transform: translate(0%,-50%);
	    -ms-transform: translate(0%,-50%);
	        transform: translate(0%,-50%);
}

.masthead h1 {
	font-size: 2.25em;
	font-weight: bolder;
	line-height: 1.5;
	margin-bottom: 1em;
	text-transform: uppercase;
}

.masthead h2 {
	font-size: 1em;
	font-weight: lighter;
	letter-spacing: 6px;
	text-transform: uppercase;
}

.glyphs, 
.classes {
	margin-left: -1.5em;
	padding: 4.5em 3em;
}

.glyphs header,
.classes header {
	margin-bottom: 2.25em;
	padding-bottom: 2.25em;
	text-align: center;
	text-transform: uppercase;
}

.glyphs h1,
.classes h1 {
	font-size: 2.25em;
	font-weight: bolder;
	line-height: 1.5;
}

.glyphs h2,
.classes h2 {
	font-size: 1em;
	font-weight: normal;
	letter-spacing: 3px;
	text-transform: uppercase;
}

h2 code {
	text-transform: lowercase;
}


.glyphs {
	background-color: #74f3c8;
	color: #0e8a65;
}

.classes {
	background-color: #33383e;
	color: #fff;
}

.glyph {
	cursor: pointer;
	display: inline-block;
	font-size: 1em;
	margin: 0 -0.21em 3em 0;
	padding: 1.5em 0 0 1.5em;
	text-align: center;
	width: 50%;
}

.glyph-item {
	border-radius: 8px;
	display: inline-block;
	width: 1.5em;
	height: 1.5em;
	line-height: 1;
	padding: 0.25em;
	position: relative;
}
.glyph:hover .glyph-item {
	background-color: #0e8a65;
	color: #fff;
} 

.mega {
	font-size: 3em;
}

a, 
a:visited {
	color: #74f3c8;
	text-decoration: none;
}

a:hover, 
a:focus {
		color: #0e8a65;
}

.item-box {
	display: inline-block;
	font-family: consolas, monospace;
	font-size: 1.2em;
	margin: 0 -0.22em 1em 0;
	padding-left: 1em;
	width: 100%;

}

.item {
	background-color: #fff;
	color: #33383e;
	border-radius: 8px;
	display: inline-block;
	padding: 0.5em;
	width: 100%;
}


.colophon .group {
	font-size: 1.5em;
	text-transform: uppercase;
}

.group em {
	font-weight: bold;
	font-style: normal;
}


#wH {
	width: 0;
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
}



@media only screen and (min-width: 768px) {
	section:after,
	.masthead:after {
		bottom: -3em;
		width: 6em;
		height: 6em;
	}

	section header {
		position: relative;
	}

	.masthead {
		padding: 6em;
	}

	.colophon {
		padding: 9em 6em;
	}

	.masthead h1 {
		font-size: 4.5em;
	}

	.glyphs, 
	.classes {
		padding: 9em 6em;
	}

	.glyphs header,
	.classes header {
		margin-bottom: 4.5em;
		padding-bottom: 4.5em;
	}

	.glyphs h1,
	.classes h1 {
		font-size: 4.5em;
	}


	.mega {
		font-size: 6em;
	}

    
    .glyph {
		width: 16.66666666666667%;
    }

    .item-box {
		width: 33.333%;
    }
    
    .colophon .group {
    	padding: 6em;
    }
}

