/*Import custom_hover_effect.css*/
@import url(hover.css);

.link-effects .tag-box a {
  margin: 0 10px 10px 0;
}

.link-effects .tag-box h2.heading-sm {
  font-size: 18px;
  line-height: 26px;
}

/*custom_hover_effect*/
.link-effects .button {
  margin: 10px;
  padding: 10px;
  cursor: pointer;
}

.link-effects a.button:hover {
  text-decoration: none;
}

.link-effects .border-fade,
.link-effects .hollow,
.link-effects .trim,
.link-effects .outline-outward,
.link-effects .outline-inward,
.link-effects .round-corners {
	color: #fff !important;
}

.link-effects .hollow:hover {
  background: #fff !important;
  color: #555 !important;
}

.link-effects .round-corners:hover {
  border-radius: 1em !important;
}

.bubble-float-top, 
.bubble-float-right, 
.bubble-float-left, 
.bubble-float-bottom {
  transform: inherit;
}

.bubble-float-top, 
.bubble-float-right, 
.bubble-float-left, 
.bubble-float-bottom:hover {
  color: #555 !important;
}

.link-effects .curl-top-left:before {
  background: -webkit-linear-gradient(315deg, white 45%, #eee 50%, #eee 56%, white 80%);
  background: linear-gradient(135deg, white 45%, #eee 50%, #eee 56%, white 80%);
  filter: progid:DXImageTransform.Microsoft.gradient(GradientType=0,startColorstr='#ffffff', endColorstr='#000000');
}

.link-effects .curl-top-right:before {
  background: -webkit-linear-gradient(225deg, white 45%, #eee 50%, #eee 56%, white 80%);
  background: linear-gradient(225deg, white 45%, #eee 50%, #eee 56%, white 80%);
}

.link-effects .curl-bottom-right:before  {
  background: -webkit-linear-gradient(135deg, white 45%, #eee 50%, #eee 56%, white 80%);
  background: linear-gradient(315deg, white 45%, #eee 50%, #eee 56%, white 80%);
}

.link-effects .curl-bottom-left:before {
  background: -webkit-linear-gradient(45deg, white 45%, #eee 50%, #eee 56%, white 80%);
  background: linear-gradient(45deg, white 45%, #eee 50%, #eee 56%, white 80%);
}