{% load i18n %}
<!-- Import New Scheme Modal Data Entry Form -->
<form action="" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="labelmodal" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content no-corners">
            
            <!-- Form Header -->
            <div class="modal-header arches-modal-header">
                <button aria-hidden="true" data-dismiss="modal" class="close" type="button">×</button>
                <h4 id="" class="modal-title">{% trans "Import New Concept Scheme" %}</h4>
            </div>
            <!-- End Form Header -->
            
            <!-- Form -->
            <div class="modal-body">
                <div class="row">
                    <div class="col-md-6">
                        <h5 class="arches-modal-section">{% trans "Select an existing group, or add your own" %}</h5>
                        <p> 
                            {% include 'views/concept-scheme-group-dd.htm' %}  
                        </p>
                    </div>
                    <div class="col-md-6">
                        <h5 class="arches-modal-section">{% trans "Language" %}</h5>
                        <p> 
                            <select style="width:100%" class="select2" name="language_dd" required>
                                {% for language in languages %}
                                  <option value="{{language.languageid}}" {% if language.isdefault %} selected="selected" {% endif %}>{{language.languageid}} ({{language.languagename}})</option>
                                {% endfor %}
                            </select>
                        </p>
                    </div>
                </div>

                <div class="row">
                    <div class="col-xs-12">
                        
                        <form class="form-inline" role="form">
                            
                            <div class="form-group arches-modal-form-group">

                                <h5 class="arches-modal-section">{% trans "SKOS File" %}</h5>
                                <input type="file" class="form-control" style="width: 100%;" name="skosfile">
                            </div>
                        </form>
                    </div>
                </div>
            </div>
            <!-- End Form (modal body) -->

            <div class="modal-footer">
                <button data-dismiss="modal" class="btn-u btn-u-default" type="button">Cancel</button>
                <button type="submit" class="btn-u btn-u-primary">{% trans "Save changes" %}</button>
            </div>
          </div>
    </div>
</form>
<!-- End Import New Scheme Data Entry Form -->