/*
 * Template Name: Unify - Responsive Bootstrap Template
 * Description: Business, Corporate, Portfolio and Blog Theme.
 * Version: 1.4
 * Author: @htmlstream
 * Website: http://htmlstream.com
*/

/*Import Global Compulsory CSS Files*/
@import url(app.css);
@import url(plugins.css);

/*Import CSS Plugins*/
@import url(plugins/animate.css);
@import url(plugins/box-shadows.css);

/*Boxed Layout
------------------------------------*/
.wrapper {
  background: #fff;
}

.boxed-layout {
  padding: 0;
  box-shadow: 0 0 5px #ccc;
  margin-left: auto !important;
  margin-right: auto !important;
  background: url(../img/patterns/15.png) repeat;
}

/*Parallax Backgrounds
------------------------------------*/
.parallax-bg {
    background: url(../img/blur/img1.jpg) 50% 0 repeat fixed;       
}

/*Parallax Counter Block*/
.parallax-counter {
    padding: 60px 0;
    background: url(../img/bg/9.jpg) 50% 0 no-repeat fixed; 
}

.parallax-counter h4 {
    color: #fff;
    font-size: 18px;
}

.parallax-counter .counters {
    color: #fff;
    padding: 20px 0;
    font-weight: 200;
    background: rgba(0,0,0,0.6);
}

/*Parallax Team*/
.parallax-team {
    background: url(../img/team/faces.jpg) 50% 0 repeat fixed;  
}

.parallax-team,
.parallax-team .title-box-v2 {
    position: relative;
}

.parallax-team:before {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; 
    content: " ";
    position: absolute;
    background: rgba(255,255,255,0.9);
}

/*Top Bar (login, search etc.)
------------------------------------*/
.topbar {
    z-index: 12;
    padding: 8px 0;
    position: relative;
}

.topbar ul.loginbar {
    margin: 0;
}

.topbar ul.loginbar > li {
    display: inline;
    list-style: none;
    position: relative;
    padding-bottom: 15px;
}

.topbar ul.loginbar > li > a, 
.topbar ul.loginbar > li > a:hover {
    color: #7c8082;
    font-size: 11px;
    text-transform: uppercase;
}

.topbar ul.loginbar li i.fa { 
    color: #bbb;
}

.topbar ul.loginbar li.topbar-devider { 
    top: -1px;
    padding: 0;
    font-size: 8px;
    position: relative;
    margin: 0 9px 0 5px;
    font-family: Tahoma;
    border-right: solid 1px #bbb;
}

/*Lenguages*/
.topbar ul.lenguages {
    top: 25px;
    left: -5px;
    display: none;
    padding: 4px 0;
    padding-left: 0; 
    list-style: none;
    min-width: 100px;
    position: absolute;
    background: #f0f0f0;
}

.topbar li:hover ul.lenguages {
    display: block;
}

.topbar ul.lenguages:after {
    top: -4px;
    width: 0; 
    height: 0;
    left: 8px;
    content: " "; 
    display: block; 
    position: absolute;
    border-bottom: 6px solid #f0f0f0;   
    border-left: 6px solid transparent;
    border-right: 6px solid transparent;
    border-left-style: inset; /*FF fixes*/
    border-right-style: inset; /*FF fixes*/
}

.topbar ul.lenguages li a {
    color: #555;
    display: block;
    font-size: 10px;
    padding: 2px 12px;
    margin-bottom: 1px;
    text-transform: uppercase; 
}

.topbar ul.lenguages li.active a i {
    color: #999;
    float: right;
    margin-top: 2px;
}

.topbar ul.lenguages li a:hover, 
.topbar ul.lenguages li.active a {
    background: #fafafa;
}

.topbar ul.lenguages li a:hover {
    text-decoration: none; 
}

/*Top Bar v1 (login, search etc.)
------------------------------------*/
.topbar-v1 {
    background: #fdfdfd;
    border-bottom: solid 1px #f0f0f0;
}

/*Top Contacts*/
.topbar-v1 ul {
    margin: 0;
}

.topbar-v1 .top-v1-contacts li {
    color: #666;
    padding: 5px 0;
    font-size: 12px;
    margin-right: 15px;
    display: inline-block;
}

.topbar-v1 .top-v1-contacts i {
    color: #999;
    font-size: 13px;
    margin-right: 3px;
}

/*Top Data*/
.topbar-v1 .top-v1-data {
    text-align: right;
}

.topbar-v1 .top-v1-data li {
    padding: 5px 11px;
    display: inline-block;  
    border-right: solid 1px #eee;
}

.topbar-v1 .top-v1-data li:first-child {
    border-left: solid 1px #eee;
}

.topbar-v1 .top-v1-data li a {
    font-size: 12px; 
}

.topbar-v1 .top-v1-data li a:hover {
    text-decoration: none;
}

.topbar-v1 .top-v1-data li i {
    color: #777;
    font-size: 13px; 
}

.topbar-v1 .top-v1-data li a:hover i {
    color: #72c02c;
}

/*Responsive Topbar v1*/
@media (max-width: 992px) {
    .topbar-v1 ul {
        text-align: center !important;
    }

    .topbar-v1 .top-v1-contacts {
        margin: 10px 0;
    }

    .topbar-v1 .top-v1-data li {
        top: 1px;
        padding: 6px 16px;
        margin-left: -5px;
        position: relative;
        border: solid 1px #eee;
    }       
}

/*Header Default
------------------------------------*/
.header {
    z-index: 99;
    position: relative;
    border-bottom: solid 2px #eee;
}

.header .navbar {
    margin: 0 0 0px 0;
    min-height: inherit;
}

.header .navbar-default {
    border: none;
    background: none;
}

.header .navbar-collapse {
    position: relative;
    /*max-height: inherit;*/
}

/*Brand*/
.header .navbar-brand { 
    z-index: 1;
    top: -10px;
    position: relative;
    padding: 0 10px 10px;
}

@media (max-width: 992px) {
    .header .navbar-brand { 
        top: 0;
        height: 40px;
    }
}

/*Navbar*/
@media (min-width: 992px) {
    .header .navbar-nav {
        float: right;
    }   
}

.header .navbar-default .navbar-nav > li > a {
    color: #687074;
    font-size: 15px;
    font-weight:400;
    text-transform: uppercase;
}

.header .navbar-default .navbar-nav > .active > a {
    color: #72c02c;
}

/*Dropdown*/
.header .navbar-right .dropdown-menu {
    right: inherit;
}

/*Navbar Toggle*/
.navbar-toggle,
.navbar-default .navbar-toggle:hover, 
.navbar-default .navbar-toggle:focus {
    background: #72c02c;
    padding: 6px 10px 2px;
}

.navbar-default .navbar-toggle {
    border-color: #5fb611;
}

.navbar-default .navbar-toggle:hover {
    background: #5fb611;
}

.navbar-default .navbar-toggle .fa {
    color: #fff;
    font-size: 19px;
}

/*Responsive Navbar*/
@media (max-width: 767px) {
    .header .navbar-default .navbar-nav > li > a {
        font-size: 14px;
        padding: 9px 10px;
    }

    .header .navbar-default .navbar-nav > li a {
        /*margin-bottom: 1px;*/
        border-bottom: solid 1px #eee;
    }

    .header .navbar-default .navbar-nav > li > a:focus {
        background: none;
    }

    .header .navbar-default .navbar-nav > li > a:hover {
        color: #72c02c;
    }

    .header .navbar-default .navbar-nav > .active > a,
    .header .navbar-default .navbar-nav > .active > a:hover,
    .header .navbar-default .navbar-nav > .active > a:focus {
        color: #fff;
        background: #72c02c;
        /*border-bottom: solid 2px #72c02c;*/
    }

    .header .dropdown-submenu li a { 
        font-size: 12px;
    }   
}

@media (min-width: 767px) {
    /*Navbar Collapse*/
    .header .navbar-collapse {
        padding: 0;
    }

    /*Navbar*/
    .header .navbar-nav {
        top: 2px;
        position: relative;
    }

    .header .navbar-default .navbar-nav > li > a {
        padding: 9px 30px 9px 20px;     
    }

    .header .navbar-default .navbar-nav > li > a,
    .header .navbar-default .navbar-nav > li > a:focus {    
        border-bottom: solid 2px transparent;
    }

    .header .navbar-default .navbar-nav > li > a:hover,
    .header .navbar-default .navbar-nav > .active > a {
        border-bottom: solid 2px #72c02c;
    }
    
    .header .navbar-default .navbar-nav > li > a,
    .header .navbar-default .navbar-nav > li > a:hover,
    .header .navbar-default .navbar-nav > li > a:focus, 
    .header .navbar-default .navbar-nav > .active > a, 
    .header .navbar-default .navbar-nav > .active > a:hover, 
    .header .navbar-default .navbar-nav > .active > a:focus {
        background: none;
    }
    

    .header .navbar-default .navbar-nav > .open > a,
    .header .navbar-default .navbar-nav > .open > a:hover,
    .header .navbar-default .navbar-nav > .open > a:focus {
        color: #687074;
    }

    /*Dropdown Menu*/
    .header .dropdown-menu { 
        padding: 0;
        border: none;
        min-width: 200px;
        border-radius: 0; 
        z-index: 9999 !important;
        margin-top: -2px !important; 
        border-top: solid 2px #72c02c; 
        border-bottom: solid 2px #687074; 
    }

    .header .dropdown-menu li a { 
        color: #687074; 
        font-size: 13px; 
        font-weight: 400; 
        padding: 6px 15px; 
        border-bottom: solid 1px #eee;
    }

    .header .dropdown-menu .active > a,
    .header .dropdown-menu li > a:hover {
        color: #fff;
        filter: none !important;
        background: #687074 !important;
        -webkit-transition: all 0.1s ease-in-out;
        -moz-transition: all 0.1s ease-in-out;
        -o-transition: all 0.1s ease-in-out;
        transition: all 0.1s ease-in-out;
    }

    .header .dropdown-menu li > a:focus {
        background: none;
        filter: none !important;
    }

    .header .navbar-nav > li.dropdown:hover > .dropdown-menu {
        display: block;
    }   
}

/*Search Box*/
.header .navbar .nav > li > .search {
    color: #aaa;
    cursor: pointer;
    min-width: 35px;
    font-size: 15px;
    text-align: center;
    background: #f7f7f7;
    padding: 11px 0 12px;
    display: inline-block;
    border-bottom: solid 2px #aaa;
}

.header .navbar .nav > li > .search:hover {
    color: #72c02c;
    background: #f7f7f7;
    border-bottom-color: #72c02c;
}

.header .navbar .search-open {
    right: 0; 
    top: 38px; 
    display: none;
    padding: 14px; 
    position: absolute;
    background: #fcfcfc; 
    border-top: solid 2px #eee;
    box-shadow: 0 1px 3px #ddd; 
}

.header .navbar .search-open form {
    margin: 0;  
}

@media (min-width: 767px) {
    .header .navbar .search-open {
        width: 330px;
    }

    .header .open > .dropdown-menu,
    .header-v1 .open > .dropdown-menu {
        display: none;
    }
}

@media (max-width: 767px) {
    .header .navbar .nav > li > .search {
        color: #999;
        width: 35px;
        height: 34px;
        line-height: 12px;
        text-align: left;
        text-align: center;
        margin: 5px 10px 0;
        background: #eee;
        border-bottom: none;
    }

    .header .navbar .nav > li > .search:hover {
        background: #5fb611;
        color: #fff !important;
    }

    .header .navbar .search-open {
        top: 5px;
        padding: 0;
        left: 48px;
        border-top: none;
        box-shadow: none;
        background: none; 
        margin-right: 10px;
    }
}

/*Header v1
------------------------------------*/
.header-v1 {
    border-bottom: none; 
}

/*Brand*/
.header-v1 .navbar-brand {
    top: 2px;
    padding: 0 10px 10px;
}

/*Search Box*/
.header-v1 .navbar .search-open {
    background: #f8f8f8; 
}

@media (max-width: 767px) {
    .header-v1 .navbar .search-open {
        bottom: -6px; 
    }   
}

.header-v1 .navbar .nav > li > .search {
    padding: 11px;
    border: none;
    min-width: 37px;
}

.header-v1 .navbar .nav > li > .search:hover {
    background: #72c02c;
    color: #fff !important;
}

/*Toggle*/
.header-v1 .navbar-toggle {
    margin-top: 3px;
}

/*Responsive Header v1*/
@media (min-width: 767px) and (max-width: 992px) {
    /*Brand*/
    .header-v1 .navbar-brand {
        margin-bottom: 15px;
    }
}

@media (min-width: 767px) {
    /*Navbar*/
    .header-v1 .navbar-default .navbar-nav > li {
        margin-left: 1px;
    }

    .header-v1 .navbar-default .navbar-nav > li > a {
        padding: 9px 30px 6px 20px;     
    }

    .header-v1 .navbar-default .navbar-nav > .active > a,
    .header-v1 .navbar-default .navbar-nav > li > a:hover,
    .header-v1 .navbar-default .navbar-nav > li > a:focus {
        color: #fff !important;
        background: #72c02c !important;
    }

    .header-v1 .navbar-default .navbar-nav > .open > a,
    .header-v1 .navbar-default .navbar-nav > .open > a:hover,
    .header-v1 .navbar-default .navbar-nav > .open > a:focus {
        color: #fff;
        background: #72c02c;        
    }

    /*Dropdown Menu*/
    .header-v1 .dropdown-menu { 
        background: #fafafa;
    }
}

/*Header Fixed
------------------------------------*/
/*Header*/
.header-fixed .header {
    height: 58px;
}

.header-fixed .header.header-fixed-shrink {
    top: 0;
    left: 0;
    width: 100%;
    /*height: 95px;*/
    z-index: 9999;
    position: fixed;
    margin-top: -35px;
    background: rgba(255,255,255, 0.9);
    border-bottom-color: #f5f5f5;
    /*-webkit-transition: height 0.6s;
    -moz-transition: height 0.6s;
    transition: height 0.6s;*/
}

/*Brand*/
.header-fixed .header.header-fixed-shrink .navbar-brand { 
    top: 10px;
    z-index: 1;
    position: relative;
    padding: 0 10px 10px;
}

.header-fixed .header.header-fixed-shrink .navbar-brand img {
    width: 90%;
}

.header-fixed .header.header-fixed-shrink .search,
.header-fixed .header.header-fixed-shrink .active a {
    border-bottom: none !important;
}

.header-fixed .header.header-fixed-shrink .dropdown > a:after {
    top: 19px;
}

/*Toggle*/
.header-fixed .navbar-toggle {
    margin-top: 5px;
}

/*Search Bar*/
.header-fixed .header.header-fixed-shrink .search {
    margin-top: 12px;
    padding: 8px !important;
    color: #585f69 !important;
    background: none !important;
}

.header-fixed .header.header-fixed-shrink .search-open {
    border-top: none;
    background: rgba(255,255,255, 0.9); 
}

/*Responsive Fixed Header*/
@media (max-width: 992px) {
    /*Header*/
    .header-fixed .header {
        height: 118px;
    }

    .header-fixed .header.header-fixed-shrink {
        height: 135px;
    }
}

@media (max-width: 767px) {
    /*Header*/
    .header-fixed .header,
    .header-fixed .header.header-fixed-shrink {
        height: 88px;
    }

    /*Navbar*/
    .header-fixed .header .navbar-nav {
        background: #fff;
        padding: 6px 0;
        margin-top: 0px;
        border: solid 1px #eee;
    }
    
    .header-fixed .header .navbar-default .navbar-collapse, 
    .header-fixed .header .navbar-default .navbar-form {
        border: none;
    }

    /*Toggle*/
    .header-fixed .navbar-toggle {
        margin-top: 9px;
    }

    /*Search*/
    .header-fixed .header.header-fixed-shrink .navbar .nav > li > .search {
        top: 5px;
        position: relative;
    }   
}

@media (min-width: 767px) {
    /*Navbar*/
    .header-fixed .header.header-fixed-shrink .navbar-nav > li > a {
        padding: 19px 30px 18px 20px;
        border-bottom: solid 1px transparent !important;
    }

    /*Search Bar*/
    .header-fixed .header.header-fixed-shrink .search-open {
        top: 56px;
    }   
}

/*Dropdown Submenu for BS3
------------------------------------*/
.dropdown-submenu { 
   position: relative; 
}

.dropdown > a:after,
.dropdown-submenu > a:after {
    top: 8px;
    right: 9px;
    font-size: 11px;
    content: "\f105";
    position: absolute;
    font-weight: normal;
    display: inline-block;
    font-family: FontAwesome;
}

@media (max-width: 767px) {
  .dropdown-submenu > a:after {
      content: " ";
  }
}

.dropdown > a:after {
    top: 9px;
    right: 15px;
    content: "\f107";
}

.dropdown-submenu > .dropdown-menu { 
   top: 0; 
   left: 100%; 
   margin-top: -5px; 
   margin-left: 0px; 
}

.dropdown-submenu:hover > .dropdown-menu {  
   display: block;
}

@media (max-width: 767px) {
  .dropdown-submenu > .dropdown-menu {  
     display: block;
     margin-left: 15px;
  }
}

.dropdown-submenu.pull-left {
   float: none;
}

.dropdown-submenu.pull-left > .dropdown-menu {
   left: -100%;
   margin-left: 10px;
}

.dropdown-menu li [class^="fa-"],
.dropdown-menu li [class*=" fa-"] {
  left: -3px;
  width: 1.25em;
  margin-right: 1px;
  position: relative;
  text-align: center;
  display: inline-block;
}
.dropdown-menu li [class^="fa-"].fa-lg,
.dropdown-menu li [class*=" fa-"].fa-lg {
  /* increased font size for fa-lg */
  width: 1.5625em;
}

/*Menu Icons*/
.menu-icon {
   margin-right: 10px;
   font-weight: 200;
}

/*Dropdown Show*/
.dropdown-show {
  position: relative;
  display: inline-block;
  box-shadow: 0 0 4px #eee;
}

/*Main Styles
------------------------------------*/
/*Purchase Block*/
.purchase {
    padding: 25px 0 30px;
    border-bottom: solid 1px #eee;
    background: url(../img/breadcrumbs.png) repeat;
}
.purchase p {
    margin-bottom: 0;
}
.purchase span {
    color: #666;
    display: block;
    font-size: 24px;
    line-height: 35px;
    font-weight: normal;
    margin-bottom: 12px;
    font-family: 'Open Sans', sans-serif;   
}

.purchase .btn-buy {
    text-align: center;
}

.purchase .btn-buy a {
    margin-top: 27px;
}

.purchase .btn-buy a i {
    margin-right: 5px;
}

@media (max-width: 992px) {
    .purchase {
        text-align: center;
    }

    .purchase span {
        font-size: 22px;
        line-height: 29px;
    }

    .purchase .btn-buy a {
        margin-top: 25px;
        font-size: 16px;
    }
}

/*Service*/
.service {
    overflow: hidden; 
    margin-bottom: 10px;
    padding: 15px 15px 10px;
}
.service:hover {
    background: #fcfcfc;
    box-shadow: 0 0 5px #ddd;
    -webkit-transition: box-shadow 0.2s ease-in-out;
    -moz-transition: box-shadow 0.2s ease-in-out;
    -o-transition: box-shadow 0.2s ease-in-out;
    transition: box-shadow 0.2s ease-in-out;
}
.service:hover i {
    color: #656565;
}

.service .desc {
    padding: 0 15px; 
    overflow: hidden;
}
.service .desc h4 {
    font-size: 22px;
    line-height: 25px;
}

.service .service-icon {
    float: left;
    padding: 10px;
    color: #72c02c;
    font-size: 35px;  
    text-align: center;
    -webkit-transition: all 0.4s ease-in-out;
    -moz-transition: all 0.4s ease-in-out;
    -o-transition: all 0.4s ease-in-out;
    transition: all 0.4s ease-in-out;
}
.service .service-icon.icon-cogs {
    font-size: 37px;
}
.service .service-icon.icon-plane {
    font-size: 43px;
}

/* Recent Work  */
.recent-work a {
    text-align: center;
    background: #fcfcfc;
    display: inline-block;
}

.recent-work a:hover {
    text-decoration: none;
}

.recent-work a:hover strong {
    color: #555;
}

.recent-work em.overflow-hidden {
    display: block;
}

.recent-work a span {
    display: block;
    padding: 10px;
    border-bottom: solid 2px #eee;
}

.recent-work a strong {
    color: #555;
    display: block;
}

.recent-work a i {
    color: #777;
}

.recent-work a img {
   -webkit-transition: all 0.8s ease-in-out;
   -moz-transition: all 0.8s ease-in-out;
   -o-transition: all 0.8s ease-in-out;
   -ms-transition: all 0.8s ease-in-out;
   transition: all 0.8s ease-in-out;
}

.recent-work a:hover img {
    opacity: 0.8;
   -webkit-transform: scale(1.2) rotate(3deg);
   -moz-transform: scale(1.2) rotate(3deg);
   -o-transform: scale(1.0) rotate(3deg);
   -ms-transform: scale(1.2) rotate(3deg);
   transform: scale(1.2) rotate(3deg);
}

.recent-work a:hover span {
    border-bottom: solid 2px #72c02c;
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.3s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    transition: all 0.3s ease-in-out;
}

/* Work */
.work {
    margin-top: 6px;
}
.work .details {
    padding: 10px;
}
.work .caption {
    display: block;
    padding-top: 5px;
    color: #585f69 !important;
    font-size: 18px !important;
}
.work .caption:hover {
    cursor: pointer;
    color: #444 !important;
    text-decoration: underline;
}

/*Footer*/
.footer {
    color: #dadada;
    background: #585f69;
    padding: 20px 0 30px;
}

.footer.margin-top-0 {
    margin-top: 0;
}

.footer p,
.footer a {
    font-size: 14px;
} 
.footer p {
    color: #dadada;
} 

.footer a {
    color: #72c02c;
}
.footer a:hover {
    color: #a8f85f;
    -webkit-transition: all 0.4s ease-in-out;
    -moz-transition: all 0.4s ease-in-out;
    -o-transition: all 0.4s ease-in-out;
    transition: all 0.4s ease-in-out;
}

.footer h2, 
.footer h3,
.footer h4 {
    color: #e4e4e4;
    background: none;
    text-shadow: none;
}

/*Footer Subsribe*/
.footer .footer-subsribe {
    width: 85%;
}

/*Footer Blog Posts*/
.footer .blog-list {
    margin: 0;
    padding: 0;
    color: #dadada;
    list-style: none;
}

.footer .blog-list li {
    padding: 0 0;
    margin-bottom: 7px; 
}
.footer .blog-list li span {
    color: #818488;
}

.footer .dl-horizontal,
.footer .dl-horizontal:hover {
    border: none !important;
    background: none !important;
}
.footer .posts .dl-horizontal a {
    color: #dadada;
}
.footer .dl-horizontal a:hover {
    color: #a8f85f !important;
}
.footer .dl-horizontal img {
    border-color: #888 !important;
}

/*Copyright*/
.copyright {
    font-size: 12px;
    padding: 11px 0 7px;
    background: #3e4753;
    border-top: solid 1px #777; 
}

.copyright p {
    color: #dadada;
    margin-top: 12px;
}

.copyright a {
    margin: 0 5px;
    color: #72c02c;
}
.copyright a:hover {
    color: #a8f85f;
}

.copyright a img {
    margin-top: 5px;
}

/*Breadcrumbs
------------------------------------*/ 
/*Default Breadcrumbs*/
.breadcrumbs {
    overflow: hidden;
    padding: 10px 0 6px;
    border-bottom: solid 1px #eee;
    background: url(../img/breadcrumbs.png) repeat;
}
.breadcrumbs h1 {
    color: #666;
    font-size: 22px;
    margin-top: 8px;
}

.breadcrumb { 
    top: 10px;
    padding-right: 0;
    background: none;
    position: relative;
}
.breadcrumb a {
    color: #777;
}
.breadcrumb li.active,
.breadcrumb li a:hover {
    color: #72c02c;
    text-decoration: none;
}

@media (max-width: 550px) {
    .breadcrumbs h1.pull-left,
    .breadcrumbs ul.pull-right {
        width: 100%;
        text-align: center;
    }

    .breadcrumbs h1.pull-left {
        margin-bottom: 0;
    }

    .breadcrumbs .breadcrumb {
        top: 0;
        margin-bottom: 10px;
    }
}

/*Thumbnails
------------------------------------*/
a.thumbnail {
    padding: 0;
    border: none;
    margin-bottom: 15px;
}

.thumbnail-style { 
    padding: 7px;
    margin-bottom: 20px; 
}
.thumbnail-style:hover { 
    box-shadow: 0 0 8px #ddd; 
    -webkit-transition: box-shadow 0.2s ease-in-out;
    -moz-transition: box-shadow 0.2s ease-in-out;
    -o-transition: box-shadow 0.2s ease-in-out;
    transition: box-shadow 0.2s ease-in-out;
}

.thumbnail h3,
.thumbnail-style h3 {
    margin: 6px 0 8px 0;
}

.thumbnail h3 a,
.thumbnail-style h3 a {
    color: #585f69;
    font-size: 20px;
}

.thumbnail h3 a:hover,
.thumbnail-style h3 a:hover {
    color: #72c02c;
    text-decoration: none;
}

.thumbnail-style .thumbnail-img {
    position: relative;
    margin-bottom: 11px;
}

.thumbnail-style a.btn-more {
    right: -10px;
    bottom: 10px;
    color: #fff;
    padding: 1px 6px;
    position: absolute;
    background: #72c02c;
    display: inline-block; 
}
.thumbnail-style a.btn-more:hover {
    text-decoration: none;
    box-shadow: 0 0 0 2px #377500;
}
.thumbnail-style:hover a.btn-more {
    right: 10px;
}

.thumbnail-kenburn img {
    left: 10px;
    margin-left: -10px;
    position: relative;
   -webkit-transition: all 0.8s ease-in-out;
   -moz-transition: all 0.8s ease-in-out;
   -o-transition: all 0.8s ease-in-out;
   -ms-transition: all 0.8s ease-in-out;
   transition: all 0.8s ease-in-out;
}
.thumbnail-kenburn:hover img {
   -webkit-transform: scale(1.2) rotate(2deg);
   -moz-transform: scale(1.2) rotate(2deg);
   -o-transform: scale(1.2) rotate(2deg);
   -ms-transform: scale(1.2) rotate(2deg);
   transform: scale(1.2) rotate(2deg);
}
 
/*Servive Blocks
------------------------------------*/
/*Service Alternative Block*/
.service-alternative .service:hover { 
    background: #76ca2c;
    -webkit-transition: all 0.4s ease-in-out;
    -moz-transition: all 0.4s ease-in-out;
    -o-transition: all 0.4s ease-in-out;
    transition: all 0.4s ease-in-out;
}
.service-alternative .service:hover i,
.service-alternative .service:hover p,
.service-alternative .service:hover h4 { 
    color: #fff;
}

/*Servive Block Versions*/
.service-v1 h2 {
    margin: 15px 0 10px;
    font-size: 20px;
    line-height: 28px;
}

.service-v1 p {
    text-align: justify;
}

/*Blog Posts
------------------------------------*/ 
.posts .dl-horizontal a {
    color: #555;
}

.posts .dl-horizontal { 
    margin-bottom: 15px;
    overflow: hidden;
}

.posts .dl-horizontal dt { 
    width: 60px; 
    float: left;
}

.posts .dl-horizontal dt img { 
    width: 60px; 
    height: 60px;
    padding: 2px;
    margin-top: 2px; 
    border: solid 1px #ddd;
}

.posts .dl-horizontal dd { 
    margin-left: 70px;
}

.posts .dl-horizontal dd p { 
    margin: 0;
}

.posts .dl-horizontal dd a {
    font-size: 14px;
    line-height: 16px !important; 
}

.posts .dl-horizontal dd a:hover { 
    color: #72c02c; 
    text-decoration: none;
}

.posts .dl-horizontal:hover dt img,
.posts .dl-horizontal:hover dd a { 
    color: #72c02c;
    border-color: #72c02c !important;
    -webkit-transition: all 0.4s ease-in-out;
    -moz-transition: all 0.4s ease-in-out;
    -o-transition: all 0.4s ease-in-out;
    transition: all 0.4s ease-in-out;
}

/*About Page
------------------------------------*/
.team ul.team-socail { 
    text-align: right;
}

.team ul.team-socail li {
    padding: 0 !important;
    margin: 0 !important;
}

.team ul.team-socail li a,
.team ul.team-socail li a:hover {
    text-decoration: none;
}

.team ul.team-socail li i {
    color: #aaa;
    padding: 3px;
    min-width: 30px;
    font-size: 20px;
    text-align: center;
    background: #f7f7f7;
    display: inline-block;
}

.team ul.team-socail li i:hover {
    color: #fff;
    background: #72c02c;
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.team .thumbnail-style {
    padding: 12px;
}

.team .thumbnail-style img {
    margin-bottom: 7px;
}

.team .thumbnail-style h3 {
    margin-bottom-bottom: 5px;
}

.team .thumbnail-style:hover h3 a {
    color: #72c02c !important;
}

.team .thumbnail-style small {
    display: block;
    margin-top: 5px;
    font-size: 12px;
}

/*About Me Page
------------------------------------*/
.about-me {
    overflow: hidden;
}

.about-me h2 {
    margin: 0;
    font-size: 20px;
    text-transform: uppercase;
}

.about-me span {
    color: #999;
    display: block;
    font-size: 14px;
    margin-bottom: 10px;
}

.about-me .social-icons {
    margin-top: 7px;
}

/*About My Goals*/
.about-my-goals h2 {
    text-transform: uppercase;
}

/*About Skills*/
.about-skills {
    padding: 40px 0;    
    border-top: 1px solid #eee;
    border-bottom: 1px solid #eee;
    background: url(../img/breadcrumbs.png) repeat;
}

/*Gallery Page
------------------------------------*/
.gallery-page .thumbnail,
.gallery-page .thumbnail:hover {
    padding: 0;
    border: none;
    box-shadow: none;
}
.gallery-page .thumbnails {
    margin-bottom:6px;
}

/*Privacy Page
------------------------------------*/
.privacy a {
    text-decoration: underline;
}
.privacy a:hover {
    color: #72c02c;
    text-decoration: none;
}

/*Portfolio Item Page v1
------------------------------------*/
.portfolio-item h2 {
    color: #555;
    font-size: 24px;
    margin: 0 0 15px;
}
.portfolio-item li {
    padding: 3px 0;
} 
.portfolio-item p a {
    text-decoration: underline;
}
.portfolio-item p a:hover {
    text-decoration: none;
}

/*Portfolio Item v1*/
.portfolio-item1 ul {
    margin: 10px 0 20px;
}

.portfolio-item1 li {
    font-size: 16px;
    margin-bottom: 3px;
}

.portfolio-item1 li i {
    font-size: 18px;
    margin-right: 4px;
}

/*Sidebar Features
------------------------------------*/
/*Blog Tags*/
ul.blog-tags li {
    display: inline-block;
}

ul.blog-tags a {
    font-size :13px;
    padding: 2px 7px;
    background: #f7f7f7;
    margin: 0 3px 6px 0;
    display: inline-block;
}

ul.blog-tags a i {
    color: #666;
}

ul.blog-tags a:hover {
    background: #72c02c;
}

ul.blog-tags a:hover,
ul.blog-tags a:hover i {
    color: #fff !important;
    text-decoration: none;
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

/*Blog Photo Stream*/
.blog-photos li {
    display: inline;
}
.blog-photos li img {
    opacity: 0.6;
    width: 58px;
    height: 58px;
    margin: 0 2px 8px;
}
.blog-photos li img:hover {
    opacity: 1;
    box-shadow: 0 0 0 2px #72c02c;
}

/*Blog Latest Tweets*/
.blog-twitter .blog-twitter-inner {
    padding: 10px;
    background: #f7f7f7;
    position: relative;
    margin-bottom: 10px;
    /*border-top: solid 2px #eee;*/
}

.blog-twitter .blog-twitter-inner,
.blog-twitter .blog-twitter-inner:after,
.blog-twitter .blog-twitter-inner:before {
    transition: all 0.3s ease-in-out;
    -o-transition: all 0.3s ease-in-out;
    -ms-transition: all 0.3s ease-in-out;
    -moz-transition: all 0.3s ease-in-out;
    -webkit-transition: all 0.3s ease-in-out;   
}

.blog-twitter .blog-twitter-inner:after,
.blog-twitter .blog-twitter-inner:before {
    width: 0; 
    height: 0;
    right: 0px;
    bottom: 0px;
    content: " "; 
    display: block; 
    position: absolute;
}

.blog-twitter .blog-twitter-inner:after {
    border-top: 15px solid #eee;    
    border-right: 15px solid transparent;
    border-left: 0px solid transparent;
    border-left-style: inset; /*FF fixes*/
    border-right-style: inset; /*FF fixes*/
}
.blog-twitter .blog-twitter-inner:before {
    border-bottom: 15px solid #fff; 
    border-right: 0 solid transparent;
    border-left: 15px solid transparent;
    border-left-style: inset; /*FF fixes*/
    border-bottom-style: inset; /*FF fixes*/
}

.blog-twitter .blog-twitter-inner:hover {
    border-color: #72c02c;
    border-top-color: #72c02c;  
}
.blog-twitter .blog-twitter-inner:hover:after {
    border-top-color: #72c02c;  
}

.blog-twitter .blog-twitter-inner span.twitter-time {
    color: #777;
    display: block;
    font-size: 11px; 
}

.blog-twitter .blog-twitter-inner a {
    color: #72c02c;
    text-decoration: none;
}
.blog-twitter .blog-twitter-inner a:hover {
    text-decoration: underline;
}

.blog-twitter .blog-twitter-inner i.fa {
    top: 2px;
    color: #bbb;
    font-size: 18px;
    position: relative;
}

/*Choose Block*/
.who li { 
    margin-bottom: 6px;
}
.who li i { 
    color: #72c02c; 
    font-size: 13px;
    margin-right: 8px;
    position: relative; 
}
.who li:hover i, 
.who li:hover a { 
    color: #777;
}
.who li:hover a:hover {
    text-decoration: none;
}

/*Promo Page
------------------------------------*/
/*Slider Part*/
.fullwidthbanner-container.slider-promo {
    max-height: 460px !important;
}

.slider-promo-info-bg {
    padding: 25px 20px 20px;
    background: url(../img/bg-black.png) repeat;
}

.slider-promo-info span.big-size { 
    color: #fff;
    display: block;
    font-size: 30px;
    margin-bottom: 25px;
    text-shadow: 0 !important;
}

.slider-promo-info p {
    color: #fff;
    font-size: 16px;
    margin-bottom: 0;
}

/*Promo Box*/
.promo-box {
    padding: 20px;
    margin: 25px 0 20px;
    text-align: center;
}

.promo-box i {
    display: block;
    font-size: 50px;
}

.promo-box p {
    font-size: 14px;
    margin-bottom: 0;
}

.promo-box strong,
.promo-box strong a {
    color: #555;
    display: block;
    font-size: 20px;
    font-weight: 200; 
    margin: 20px 0 15px;
}

.promo-box:hover strong, 
.promo-box:hover strong a {
    color: #72c02c;
}

/*Promo Service*/
.promo-service {
    margin-bottom: 20px;
}

.promo-service li {
    margin-bottom: 5px;
}

.promo-service a.btn-u {
    margin: 0 20px 10px 0;
}

/*Promo Elements*/
.title-box {
    font-size: 16px;
    text-align: center;
    padding: 10px 0 30px;
    border-bottom: solid 1px #eee;
}

.title-box .title-box-text {
    color: #555;
    display: block;
    font-size: 35px;
    font-weight: 200;
}

@media (max-width: 768px) {
    .title-box .title-box-text {
        font-size: 26px;
        line-height: 34px;
        margin-bottom: 10px;
    }
    .title-box p {
        font-size: 15px;
    }
}

.block-blockquote {
    margin: 20px 0; 
    text-align: center;
    border: dashed 1px #ccc;
}

.block-blockquote-inner {
    padding: 15px; 
}

.block-blockquote p {
    font-size: 26px;
    margin-bottom: 0;
}

/*Info Blocks*/
.info-blocks {
    margin-bottom: 15px;
}

.info-blocks:hover i.icon-info-blocks {
    color: #72c02c;
    -webkit-transition:all 0.2s ease-in-out;
    -moz-transition:all 0.2s ease-in-out;
    -o-transition:all 0.2s ease-in-out;
    transition:all 0.2s ease-in-out;    
}

.info-blocks i.icon-info-blocks {
    float: left;
    color: #777;
    font-size: 30px;
    min-width: 50px;
    margin-top: 10px;
    text-align: center;
}

.info-blocks .info-blocks-in {
    padding: 0 10px;
    overflow: hidden;
}

.info-blocks .info-blocks-in h3 {
    color: #555;
    font-size: 20px;
    line-height: 28px;
}

.info-blocks .info-blocks-in p {
    font-size: 12px;
}

/*Brand Page
------------------------------------*/
.brand-page .btn {
    margin-bottom: 10px;
}

/*Form Pages
------------------------------------*/
.form-page input,
.form-page select {
    margin-bottom: 10px;
}

/*Labels and Badges Page
------------------------------------*/
ul.labels-demo {
  margin: 5px 0;
}

ul.labels-demo li {
  list-style: none;
  display: inline-block;
  margin: 0 5px 2px 0;
}

.badge-sidebar {
    border-left: solid 1px #eee;
}

@media (max-width: 991px) {
    .badge-sidebar {
        border-left: none;
    }
}

/*Line Icon Page
------------------------------------*/
.line-icon-page .item-box {
    width: 25%;
    float: left;
    height: 90px;
    text-align: center;
    padding: 20px 10px;
    margin: 0 -1px -1px 0;
    border: 1px solid #ddd;
    word-wrap: break-word;
}

@media (max-width: 768px) {
    .line-icon-page .item-box {
        height: 115px;    
  }
}

@media (max-width: 450px) {
    .line-icon-page .item-box {
        height: 130px;    
  }
}

.line-icon-page .item-box:hover {
    background: #fafafa;
}

.line-icon-page .item span {
    display: block;
    font-size: 28px;
    margin-bottom: 10px;
}

.line-icon-page .item:hover {
    color: #72c02c;
}

/*GLYPHICONS Icons Page
------------------------------------*/
/*Special styles for displaying the icons and their classes*/
.bs-glyphicons {
    padding-left: 0;
    list-style: none;
    overflow: hidden;
    padding-bottom: 1px;
    margin-bottom: 20px;
}

.bs-glyphicons li {
    width: 25%;
    float: left;
    height: 115px;
    padding: 10px;
    font-size: 12px;
    line-height: 1.4;
    text-align: center;
    margin: 0 -1px -1px 0;
    border: 1px solid #ddd;
}

.bs-glyphicons .glyphicon {
    display: block;
    font-size: 24px;
    margin: 5px auto 10px;
}

.bs-glyphicons li:hover {
    color: #72c02c;
    background-color: #fafafa;
}

@media (min-width: 768px) {
    .bs-glyphicons li {
      width: 12.5%;
    }
}

/*Contact Pages
------------------------------------*/
.map {
    width: 100%; 
    height: 350px;
    border-top: solid 1px #eee;
    border-bottom: solid 1px #eee;
}

.gm-style-iw {
    /*overflow: inherit !important;*/
}

.map-box {
    height: 250px;
}

.map-box-space {
    margin-top: 15px;
}

.map-box-space1 {
    margin-top: 7px;
}

/*Background Opacity
------------------------------------*/
.service-or {
    overflow: hidden;
    position: relative;
}

.service-bg {
    background-color: rgba(255,255,255,0.1);
    width: 250px;
    padding: 60px;
    position: absolute;
    top: -10px;
    right: -100px;
    transform: rotate(55deg);   
    -o-transform: rotate(55deg);
    -ms-transform: rotate(55deg);
    -moz-transform: rotate(55deg);
    -webkit-transform: rotate(55deg);
}

/*Service Block v2
------------------------------------*/
.servive-block-v2 .servive-block-in {
    padding: 20px 30px;
    text-align: center;
    margin-bottom: 15px;
    background: rgba(255,255,255,0.2);
}

.servive-block-v2 .servive-block-in img {
    width: 100%;
    margin-bottom: 15px;
}

.servive-block-v2 .servive-block-in i {
    font-size: 40px;
}

.servive-block-v2 .servive-block-in h4 {
    line-height: 25px;
}

.servive-block-v2 .servive-block-in p {
    margin-bottom: 20px;
}

.servive-block-v2 .servive-block-in i,
.servive-block-v2 .servive-block-in h4,
.servive-block-v2 .servive-block-in p {
    color: #fff;
}

/*Easy Block
------------------------------------*/
.easy-block-v1 {
    position: relative;
}

.easy-block-v1 img {
    width: 100%;
}

.easy-block-v1 .overflow-h h3 {
    width: 60%; 
    float: left;
    font-size: 18px;
    line-height: 24px;
    margin-bottom: 5px;
}

.easy-block-v1 .easy-block-v1-badge {
    left: 0px;
    top: 10px;
    z-index: 1;
    color: #fff;
    padding: 4px 10px;
    position: absolute;
}

/*Easy Block v2
------------------------------------*/
.easy-block-v2 {
    overflow: hidden;
    position: relative;
    margin-bottom: 20px;
}

.easy-block-v2 img {
    width: 100%;
}

.easy-bg-v2 {
    top: 5px;
    color: #fff;
    width: 100px;
    padding: 5px;
    right: -32px;
    font-size: 13px;
    position: absolute;
    text-align: center;
    letter-spacing: 2px;
    transform: rotate(45deg);   
    -o-transform: rotate(45deg);
    -ms-transform: rotate(45deg);
    -moz-transform: rotate(45deg);
    -webkit-transform: rotate(45deg);
}

.rgba-red { background-color: rgba(231,76,60,0.8);}
.rgba-blue{ background-color: rgba(52,152,219,0.8);}
.rgba-default { background-color: rgba(114,192,44,0.8);}
.rgba-purple { background-color: rgba(155,107,204,0.8);}

/*Easy Block v3
------------------------------------*/
.easy-block-v3 {
    text-align: left;
    background: #585f69;
    margin-bottom: 10px;
    padding: 30px 20px 20px;
}

.easy-block-v3.first { 
    background: #696f77; 
}
.easy-block-v3.second { 
    background: #707780; 
}
.easy-block-v3.third { 
    background: #787f88; 
}

.easy-block-v3 i {
    color: #fff;
    float: left;
    font-size: 30px;
    min-width: 45px;
    padding-top: 10px;
}

.easy-block-v3 .inner-faq-b {
    overflow: hidden;
}

.easy-block-v3 .inner-faq-b h2,
.easy-block-v3 .inner-faq-b h3 {
    font-size: 21px;
    margin-bottom: 8px;
}

.easy-block-v3 .inner-faq-b h4 {
    color: #fff;
    font-size: 17px;
    margin-bottom: 2px;
}

.easy-block-v3 .inner-faq-b h2,
.easy-block-v3 .inner-faq-b h3,
.easy-block-v3 .inner-faq-b p {
    color: #fff;
}

/*Full Width Block
------------------------------------*/
.full-w-block {
    padding: 30px 0;
    background: #282828;
}

.full-w-block .info-blocks i,
.full-w-block .info-blocks-in h3 {
    color: #fff;
}

.full-w-block .info-blocks-in p {
    color: #ccc;
}

.full-w-block .info-blocks:hover i.icon-info-blocks {
    color: #fff;
}

/*Team v2
------------------------------------*/
.team-v2 {
    position: relative;
    margin-bottom: 20px;
}

.team-v2 img {
    width: 100%;
}

.team-v2 .inner-team {
    padding: 20px;
    background: #fff;
    text-align: center;
}

.team-v2 .inner-team h3 {
    margin: 0;
}

.team-v2 .inner-team small {
    display: block;
    font-size: 12px;
    margin-bottom: 7px;
}

.team-v2 .inner-team p {
    font-size: 13px;
}

.team-v2 .inner-team hr {
    margin: 10px 0 15px;
}

/*Team-Social ---- Temporary*/
.team-social {
    margin-bottom: 0;
}

.team-social li {
    padding: 0 2px;
}

.team-social li a {
    font-size: 14px;
    padding: 6px 4px;
    border-radius: 50% !important;
}

.team-social li i {
    min-width: 20px;
}

.team-social li a.fb {
    color: #4862a3;
    border: 1px solid #4862a3;
}

.team-social li a.tw {
    color: #159ceb;
    border: 1px solid #159ceb;
}

.team-social li a.gp {
    color: #dc4a38;
    border: 1px solid #dc4a38;
}

.team-social li a:hover {
    text-decoration: none;
}

.team-social li a.fb:hover {
    color: #fff;
    background: #4862a3;
}

.team-social li a.tw:hover {
    color: #fff;
    background: #159ceb;
}

.team-social li a.gp:hover {
    color: #fff;
    background: #dc4a38;
}

/*Simple Block
------------------------------------*/
.simple-block {
    margin-bottom: 20px;
}   

.simple-block img {
    width: 100%;
}

.simple-block p {
    text-align: center;
}

.simple-block .carousel-indicators {
    top: 10px;
    left: 65%;
    text-align: right;
}

.simple-block .carousel-indicators .active {
    background: #555;
}

.simple-block .carousel-indicators li {
    border-color: #555;
}

.simple-block .carousel-inner > .item {
    margin: 0;
}

/*Two Blocks
------------------------------------*/
.two-blocks {
    text-align: center;
}

.two-blocks-in {
    margin-bottom: 30px;
}

.two-blocks-in i {
    color: #fff;
    padding: 11px;
    font-size: 30px;
    min-width: 50px;
    text-align: center;
    background: #585f69;
    margin-bottom: 10px;
    display: inline-block;
}

/*Three Blocks
------------------------------------*/
.three-blocks {
    text-align: center;
}

.three-blocks-in {
    margin-bottom: 30px;
}

.three-blocks-in i {
    color: #777;
    padding: 9px 6px;
    font-size: 20px;
    min-width: 40px;
    margin-bottom: 10px;
    border: 1px solid #777;
}

.three-blocks-in h3 {
    font-size: 20px;    
    margin-bottom: 7px;
}

/*Temperory Classes
------------------------------------*/
/*Banner-info*/
.banner-info {
    margin-bottom: 10px;
}

.banner-info i {
    float: left;
    color: #fff;
    padding: 11px;
    /*min-width works with line-icon*/
    min-width: 40px;
    font-size: 22px;
    text-align: center;
    margin: 7px 20px 0 0;
}

/*min-width works with FontAwesome*/
.banner-info i.fa {
    min-width: 46px;
}

.banner-info.light i {
    border: 1px solid #fff;
}

.banner-info.dark i { 
    background: #585f69;
}

.banner-info h3 {
    font-size: 21px;
    margin-bottom: 5px;
}

.banner-info.light h3 { color: #fff; }
.banner-info.light p { color: #eee; }

/*Breadcrumb-V2*/
.breadcrumbs-v2 {
    text-align: center;
    position: relative;
    background: url(../img/bg/11.jpg) no-repeat center;
}

.breadcrumbs-v2-in {
    padding: 60px 0;
    position: relative;
}

.breadcrumbs-v2 h1 {
    color: #fff;
    text-transform: uppercase;
}

.breadcrumb-v2 li a,
.breadcrumb-v2 li.active {
    color: #fff;
}

.breadcrumb-v2 li i {
    color: #fff;
    min-width: 19px;
    padding: 3px 7px;
    margin-right: 5px;
    text-align: center;
    border: 1px solid #fff;
}

/*Breadcrumbs-v3*/
.breadcrumbs-v3 {
    padding: 10px 0;
    background: #585f69;
    border-bottom: 1px solid #eee;
}

.breadcrumbs-v3 h1 {
    color: #fff;
    margin: 3px 0;
    font-size: 22px;
    font-weight: 200;
}

.breadcrumbs-v3 .breadcrumb {
    padding: 0;
    margin-top: 2px;
    margin-bottom: 0;
}

.breadcrumbs-v3 .breadcrumb li a {
    color: #fff;
}

/*Title-Box-V2*/
.title-box-v2 {
    text-align: center;
    margin-bottom: 40px;
}

.title-box-v2 h2 {
    font-size: 25px;
    text-transform: uppercase;
}

.title-box-v2 p {
    font-size: 13px;
}

/*remove padding from "Col-"*/
.no-space {
    padding: 0;
}

/*List Style v1*/
.list-style-v1 li {
    margin-bottom: 7px;
}

.list-style-v1 i {
    margin-right: 5px;
}

/*
 * Template Name: Arches - Historic Inventory Package (HIP) 
 * Description: Package to support Cultural Heritage Inventory
 * Version: 0.1
 * Date: June 7, 2014
 * Author: @farallon
 * Website: http://www.archesproject.org
*/


/*General Positioning Classes
------------------------------------*/
.margin-0 {
    .margin: 0px;
}

.margin-10 {
    margin-top: 10px;
    margin-bottom: 10px;
}

.margin-15 {
    margin-top: 15px;
    margin-bottom: 15px;
}

.margin-top-30 {
    margin-top: 30px;
}

.margin-top-20 {
    margin-top: 20px;
}

.margin-top-15 {
    margin-top: 15px;
}

.margin-top-10 {
    margin-top: 10px;
}

.margin-top-5 {
    margin-top: 5px;
}

.margin-top-0 {
    margin-top: 0px;
}

.margin-top-minus-5 {
    margin-top: -5px;
}

.margin-top-minus-10 {
    margin-top: -10px;
}

.margin-top-minus-15 {
    margin-top: -15px;
}

.margin-top-minus-20 {
    margin-top: -20px;
}

.margin-top-minus-22 {
    margin-top: -22px;
}

.margin-top-minus-28 {
    margin-top: -28px;
}

.margin-top-minus-35 {
    margin-top: -40px;
}

.margin-top-minus-40 {
    margin-top: -40px;
}

.margin-bottom-0 {
    margin-bottom: 0px;
}

.margin-bottom-5 {
    margin-bottom: 5px;
}

.margin-bottom-10 {
    margin-bottom: 10px;
}

.margin-bottom-20 {
    margin-bottom: 20px;
}

.margin-bottom-30 {
    margin-bottom: 30px;
}

.margin-bottom-40 {
    margin-bottom: 40px;
}

.margin-bottom-minus-30 {
    margin-bottom: -30px;
}

.margin-left-0 {
    margin-left: 0px;
}

.margin-left-5 {
    margin-left: 5px;
}

.margin-left-10 {
    margin-left: 10px;
}

.margin-left-15 {
    margin-left: 15px;
}

.margin-left-30 {
    margin-left: 30px;
}

.margin-left-35 {
    margin-left: 35px;
}

.margin-left-60 {
    margin-left: 60px;
}

.margin-left-70 {
    margin-left: 70px;
}

.margin-left-minus-5 {
    margin-left: -5px;
}

.margin-right-0 {
    margin-right: 0px;
}

.margin-right-10 {
    margin-right: 10px;
}

.margin-right-15 {
    margin-right: 15px;
}

.italic {
    font-style: italic;
}

.padding-15 {
    padding-top: 15px;
    padding-bottom: 15px;
}

.padding-all-20 {
    padding-top: 20px;
    padding-bottom: 20px;
    padding-left: 20px;
    padding-right: 20px;
}

.padding-30 {
    padding-top: 30px;
    padding-bottom: 30px;
}

.padding-bottom-0 {
    padding-bottom: 0px;
}

.padding-top-0 {
    padding-top: 0px;
}

.padding-top-20 {
    padding-top: 20px;
}

.padding-right-0 {
    padding-right: 0px;
}

.padding-left-0 {
    padding-left: 0px;
}

.padding-left-5 {
    padding-left: 5px;
}

.padding-left-10 {
    padding-left: 10px;
}

.padding-left-20 {
    padding-left: 20px;
}

.spacer-20 {
    maring-left: 20px;
}

.scroll-y {
    overflow: visible;
}

.centered {
    position: fixed;
    top: 50%;
    left: 50%;
}

.arches-logo {
    height: 28px;
    margin-top: 13px;
}


/*Arches Form Classes
------------------------------------*/
.arches-section {
    margin-bottom: 10px;
    padding-left: 10px;
}

.arches-form {
    margin-left: 13px;
}

.arches-form-input {
    height: 32px;
}


/*Additional Font Colors
------------------------------------*/
.txt-color-blue {
    color: #57889c;
}

.txt-color-white {
    color: #ffffff;
}

.arches-selected {
    font-weight: 600;
    color: #4765a0;
}



/*Additional Styling Classes
------------------------------------*/
.no-border {
    border-width: 0px;
}

.background-light-grey {
    background: #f9f9f9;
}


/*Addition to Unify loginbar
------------------------------------*/
.arches-loginbar a {
    color: #7c8082;
    font-size: 11px;
    margin-bottom: 8px;
    text-transform: uppercase;
}

.arches-loginbar-title {
    padding: 0px;
    margin-top: -10px;
    margin-left: -2px;
    width: 300px;
    font-weight: 200;
}



/*Addition to Unify breadcrumbs
------------------------------------*/
.arches-breadcrumbs {
    background: #cdcdcd;
}

.arches-breadcrumb-title {
    font-weight: 200;
    margin-bottom: 15px;
}

.arches-secondary-header {
    background: #f4f4f4;
    padding-top: 10px;
}

/*Search Block*/
.arches-search-block {
    height: 400px;
    padding: 80px 0;
    text-align: center;
    position: relative;
    margin-bottom: 20px;
    background: url(../img/bg/Coast.jpg);
    background-size: 101%;
    background-position: 50% -80px;
    background-repeat: no-repeat;       
}

.arches-search-block:before {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; 
    content: " ";
    position: absolute;
    background: rgba(0,0,0,0.3);
}

.arches-search-block h1 {
    color: #fff;
    font-size: 30px;
    font-weight: 200;
    text-align: center;
    margin-bottom: 10px;
    text-transform: uppercase;
}

.arches-search-block-tagline {
    color: #dfdfdf;
    font-weight: 100;
    margin-top: -20px;
}

.padding-bottom-40 {
    padding-bottom: 40px;
}

.arches-search-block .input-group {
    margin-bottom: 10px;
}


.arches-block {
    height: 220px;
}

.arches-forms-container {
    padding-top: 10px;
}

/*Counter
------------------------------------*/
.arches-counters {
  color: #555;
  text-align: center;
  margin-top: 10px;
}


.arches-counters span {
  font-size: 25px;
  font-weight: 200;
}

.arches-counters h4 {
    margin-top: -7px;
    color: #bcbcbc;
}

.arches-counter-category {
    font-weight: 100;
}

/*Search Filters
------------------------------------*/
.arches-date-filter {
    padding-top: 0px;
    padding-left: 0px;
    padding-right: 15px;
    border-width: 0px;
}

.arches-filter-style {
    font-style: normal;
    font-size: 14px;
}

.arches-search-item {
    margin-top: -10px; 
    margin-bottom: -10px; 
    padding-left: 3px;
}

.arches-search-item:hover {
    background: #f9f9f9;
}

.arches-search-item-selected {
    background: #f9f9f9;
}

.arches-search-term-button {
    font-size: 15px;
    margin-top: 2px;
}

.arches-search-filter {
    text-align: left; 
    white-space: inherit;
    box-shadow: none;
    background: inherit;
    margin-bottom: 5px;
}

.arches-search-filter-font {
    font-size: 14px;
}


/* Report CLasses
------------------------------------*/
::-webkit-input-placeholder { 
    color: red; 
    text-overflow: ellipsis; 
}

:-moz-placeholder { 
    color: #acacac !important; 
    text-overflow: ellipsis; 
}

::-moz-placeholder { 
    color: #acacac !important; 
    text-overflow: ellipsis; 
} 

/* for the future */
:-ms-input-placeholder { 
    color: #acacac !important; 
    text-overflow: ellipsis; 
}



/* Data Entry (CRUD) classes
------------------------------------*/
.arches-record {
    margin-left: 35px;
}

.arches-child-record {
    margin-left: 35px;
    margin-top: -27px;
}

.arches-panel-header {
    background: #f5f5f5;
}

.arches-panel-footer {
    background: #f5f5f5;
}

.arches-report-date {
    font-size: 19px;
    font-weight: 200;
    margin-top: -15px;
    margin-bottom: 20px;
    color: #57889c
}

.arches-report-grey-block {
    background: #fcfcfc;
    padding: 20px;
    border-color: #dcdcdc;
    border: 1px solid rgba(0,0,0,.1);
    border-radius: 2em 1em 4em / 0.5em 3em;
}

.arches-box-grey-border {
    border-color: #dcdcdc; 
    border: 1px solid rgba(0,0,0,.1);
    padding-left: 20px;
    background: #ffffff;
}

.arches-scrollable {
    height: 500px;
    overflow-y: scroll-y;
}


.arches-toolbar {   
    border: 1px solid rgba(200,200,200,0.5);
    background: #f9f9f9; /* rgba(71,101,160,0.15);  alternate background: #065D88 or #dedede;  */
    margin-top: -20px;
    margin-bottom: 10px;
    margin-left: 0px;
    margin-right: 0px;
    padding-top: 15px;
    padding-left: 10px;
    padding-right: 10px;
}

.arches-map-footer {
    margin-top: -74px;
    height: 75px; 
    opacity: .80;
    background: steelblue;
}

.arches-form-toggle {
    margin-top: -35px;
    margin-bottom: 10px;
    margin-left: -45px;
    margin-right: 10px;
}

.arches-toggle-label {
    color: steelblue; 
    font-weight: 400;
}

.arches-crud-buttons {
    height: 60px;
    background: #ededed;
    border: 1px solid rgba(0,0,0,.1);
    padding-top: 10px;
    margin-left: 0px;
    margin-right: 0px;
    width: 100%;
}

.arches-report-map {
    height: 500px;
    margin-top: 150px;
    border-width: 0px 1px 1px 1px; 
    border-color: #cfcfcf; 
    border-style: solid;
}

.arches-map-info-panel {
    margin-top: -446px;
    margin-right: 0px;
    box-shadow: 0 5px 15px rgba(0,0,0,0.3);
}

.arches-basemap-panel {
    margin-top: -446px;     
    z-index: 100;
    height: 250px;
    overflow-y: scroll;
    box-shadow: 0 5px 15px rgba(0,0,0,0.3);
}

.arches-basemap-thumbnail {
    border: 1px solid rgba(0,10,0,.3);
    width: 68px;
    height: 64px;
    border-radius: 3px 0px 0px 3px;
}

.arches-basemap-entry {
    background-color: #f9f9f9;
    border-radius: 3px 3px 3px 3px;
}

.arches-basemap-entry:active {
    background-color: #f0f0f0;
}

.arches-basemap-caption {
    font-size: 18px;
    margin-left: 15px;
}

.caption-text {
    color: #999;
    font-weight: 300;
}

.caption-text:active {
    color: #555;
    font-weight: 400;
}

.arches-basemap-caption-search {
    font-size: 18px;
    margin-left: 5px;
    width: 150px;
    overflow: hidden;
    float: right;
    margin-bottom: 0;
    display: block;
    height: 64px;
    line-height: 64px;
}

.caption-text-search {
    color: #999;
    font-weight: 300;
}

.caption-text-search.basemap {
    display: inline-block;
    vertical-align: middle;
    line-height: normal;
}

.arches-layer-icon {
    -webkit-text-stroke: white 0.05em;
    font-size: 33px;
}

.arches-form-inline {
    display: inline;
}

.arches-form-group {
    display: inline-block;
    margin-bottom: 0px;
    vertical-align: middle;
}

.arches-info-theme {
    list-style-type: none;
    margin-top: 2px;
    margin-left: -40px;
    margin-right: -5px;
    font-size: 15px;
    padding-left: 17px;

}

.arches-info-theme:hover {
    background: #f5f5f5;
}

.arches-info-theme:hover > .arches-theme-menu {
    color: #4765a0;
}

.arches-crud-title-block {
    background: #fdfdfd;
}

.arches-crud-title {
    font-size: 18px;
    font-style: normal;
    font-weight: 300;
}

.arches-CRUD-child {
    font-size: 15px;
    font-style: normal;
}

.arches-CRUD-child-title {
    font-size: 16px;
    font-style: normal;
    font-weight: 300;
    color: #999;
    margin-left: 5px;
}

.arches-crud-child-section {
    margin-top: -10px;
    padding-left: 10px;
}

.arches-CRUD-delete {
    font-size: 16px;
    color: #e74c3c;
}

.arches-crud-record {
    font-size: 15px;
    display: block;
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 1px;
    padding-bottom: 1px;
}

.arches-crud-record:hover {
    background: #f5f5f5;
}


a.disabled {
   pointer-events: none;
   cursor: default;
   color: #777;
}


/* Resource Report
------------------------------------*/
.arches-report-nav {
    position: fixed;
    z-index: 900;
    width: 100%;
    top: 0px;
}

.arches-topnav {
    background: #ffffff;
    margin-top: -150px;
}

.arches-report-header {
    font-size: 15px;
    font-weight: 500;
    margin-bottom: -2px;
    color: #585f69;
}

.arches-report-content {
    font-size: 15px;
    color: #57889c;
    line-height: 17px;
}

/*Extend Search wigdet
------------------------------------*/
.arches-search {
    width: 500px;
}

.arches-search-terms-panel {
    background: #ffffff;
    margin-left: 0px;
    margin-top: -80px;
    margin-right: 0px;
    padding-left: 15px;
    padding-top: 5px;
    padding-bottom: 15px;
    height: 150px;
    overflow-y: scroll;
}

.arches-search-stats {
    font-size: 14px;
}

.arches-search-term {
    font-size: 15px;
    font-weight: 500;
    color: steelblue;
}


/*Form classes
------------------------------------*/
.arches-theme-menu:hover {
    color: #4765a0;
}


/*RDM classes
------------------------------------*/
.arches-RDM-URI {
    color: #494949;
    margin-top: 5px;
}

.arches-RDM-label-highlighted {
    font-size: 15px;
    display: block;
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 1px;
    padding-bottom: 1px;    
}

.arches-RDM-label-highlighted:hover {
    background-color: #f9f9f9;
}

.arches-RDM-label {
    font-size: 15px;
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 1px;
    padding-bottom: 2px;
}

.arches-RDM-link {
    font-size: 15px;
    font-weight: 500;
    padding-left: 5px;
    padding-right: 5px;
    display: block-inline;
    /*background-color: #f5f5f5;*/
}

.arches-RDM-note {
    font-size: 15px;
    padding-left: 10px;
    padding-right: 10px;
    padding-bottom: 10px;
    color: #555;
}

.arches-RDM-note:hover {
    background-color: #f9f9f9;
}

.arches-RDM-divider {
    margin-top: 10px;
    margin-bottom: 5px;
    margin-left: 10px;
}

.arches-concept-heirarchy {
    font-size: 15px;
    display: block;
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 1px;
    padding-bottom: 1px;
}

.arches-concept-heirarchy:hover {
    background-color: #f9f9f9;
}

.selected-concept {
    font-weight: 600;
    background-color: #f0f0f0;
}

.arches-RDM-map-container {
    padding-left: 15px;
    padding-top: 10px;
    padding-bottom: 20px;
    padding-right: 20px;
}

.arches-RDM-map {
    height: 600px;
    border: 1px solid #cfcfcf;
}

.section-headline {
    margin-top: 0px;
    margin-bottom: 0px;
    font-size: 17px;
    font-weight: 400;
}

.arches-RDM-headline {
    margin-bottom: 10px;
    padding-left: 10px;
}

.arches-RDM-Concept {
    font-weight: 300;
}

.arches-RDM-button {
    margin-top: -8px;
}

.arches-RDM-button-xs {
    margin-top: 5px;
    margin-bottom: 5px;
}

.map-toggle {

}



/*Inventory classes
------------------------------------*/
.arches-inventory-map {
    height: 650px;
}

.arches-map-panel-list {
    margin-bottom: 5px;
}

.arches-map-inventory-panel {
    margin-top: -642px;
    margin-right: 0px;
    box-shadow: 0 5px 15px rgba(0,0,0,0.3);
    border-radius: 3px;
}

.arches-map-inventory-header {
    height: 55px;
    opacity: .90;
    margin-top: -650px;
}

.arches-map-inventory-footer {
    margin-top: 535px;
    height: 60px; 
    opacity: .50;
    background: #eaeaea;
}

.arches-map-inventory-footer-text {
    font-size: 15px;
    font-weight: 400;
    margin-top: 10px;
    color: #000000;
}


/*
 * NESTABLES
 */
.arches-dd {
  position: relative;
  display: block;
  margin: 0;
  padding: 0;
  max-width: 400px;
  list-style: none;
  font-size: 13px;
  line-height: 20px;
}

.arches-dd-list {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  list-style: none;
}

.arches-dd-list .arches-dd-list {
  padding-left: 25px;
}

.arches-dd-hover > .arches-dd-handle {
  background: #065D88 !important;
}

.arches-dd-handle {
  display: block;
  font-size: 13px;
  margin: 5px 0;
  padding: 5px 15px;
  color: #333333;
  text-decoration: none;
  border: 1px solid #cfcfcf;
  background: #fbfbfb;
}

.arches-dd-handle:hover {
  color: #2ea8e5;
  font-weight: 400;
  background: #ffffff;
}

.arches-dd-item,
.arches-dd-empty,
.arches-dd-placeholder {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  min-height: 20px;
  font-size: 13px;
  line-height: 20px;
}

.arches-dd-item > button {
  position: relative;
  cursor: pointer;
  float: left;
  width: 25px;
  height: 20px;
  margin: 7px 10px;
  line-height: 22px !important;
  padding: 0;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden;
  border: 0;
  background: rgba(0, 0, 0, 0);
  text-align: center;
}

.arches-dd-item > button {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 18px;
}

.arches-dd-item > button:before {
  content: '\f055';
  display: block;
  position: absolute;
  width: 100%;
  text-align: center;
  text-indent: 0;
  color: #0091d9;
}

.arches-dd-item > button[data-action="collapse"]:before {
  content: '\f056';
  color: #a90329;
}


/*hover effect for neested conepts */
.arches-dd-handle:hover + .arches-dd-list .arches-dd-handle,
.arches-dd-handle:hover {
  background: #428bca !important;
  opacity: .5;
  border: 1px solid #065D88;
  color: #fff !important;
}
.arches-dd-handle > span {
  font-size: 13px;
  color: #777;
}

.arches-dd-handle:hover + .arches-dd-list .arches-dd-handle, 
.arches-dd-handle:hover i {
    color: #ffffff;
}



/*Device Screen Size Mods
------------------------------------*/
@media (max-width: 767px) {
  .arches-loginbar-title {
    margin-left: 13px;
  }

    .header .navbar .search-open {
        width: 500px;
    }

}

@media (max-width: 550px) {
    .header .navbar .search-open {
        width: 350px;
    }
}

@media (min-width: 540px) {
    .arches-search {
        width: 250px;
    }
}


/*Modals
------------------------------------*/
.arches-modal-header {
    background: #f7f7f7;
}

.arches-modal-section {
    margin-left: 0px;
    margin-bottom: 5px;
    font-weight: 300;
    color: #555;
}

.arches-modal-form-group {
    margin-top: 5px;
    padding-bottom: 10px;
    width: 100%;
}

.arches-html-editor {
    padding: 0px;
    border: 1px solid rgba(200, 2000, 200, .25);
}

.arches-graph-container {
    background: #fdfdfd;
     border: 1px solid #dedede;
}

.explanation {
    font-size: 15px;
    line-height: 1.4;
    color: #555;
}

.arches-concept-label {
    font-size: 15px;
    padding-left: 10px;
    font-weight: 500;
    color: #555;
}

.arches-resource-label {
    font-size: 15px;
    padding-left: 10px;
    font-weight: 300;
    color: #555;
}

.warning {
    font-size: 16px;
    padding-left: 10px;
    padding-right: 10px;
    line-height: 1.4;
    color: #555;
}

.arches-RDM-image:hover {
    cursor: auto;
    opacity: 1.0 !important; 
}

.arches-report-options {
   /*right: 0px;*/
   top: 135px;
   min-width: 160px;
   display: none;
   z-index: 555555;
   position: fixed;
   background: #fff;
   border: 1px solid rgba(0,0,0,.15);
   box-shadow: 0 6px 12px rgba(0,0,0,.175);
   padding: 5px 0;
   background-clip: padding-box;
   float: left;
   border-radius: 2px 2px 2px 2px !important;
   margin: 2px 0 0;
}

.arches-menu {
    list-style: none;
    padding: 1px 0;
    margin-top: 2px;
    margin-left: 0px;
    margin-bottom: 0px;
    font-size: 13px;
    font-weight: 400px;
}

.arches-menu-item {
    color: #333;
    font-size: 14px;
    font-weight: 400;
    padding: 3px 13px;
    line-height: 1.6;
    text-decoration: none;
    white-space: nowrap;
    clear: both;
    display: block;
}

.arches-menu-record {
    text-decoration: none;
    margin-top: 3px;
    margin-bottom: 3px;
}

.arches-menu-divider {
    height: 1px;
    background-color: #e5e5e5;
    margin-top: 9px;
    margin-bottom: 3px;
}

.arches-menu-item:hover {
    background-color: #f4f4f4;
}

.arches-menu >li > a:hover, .arches-menu > li > a:focus {
    background-color: #f4f4f4;
    width: 100%;
    display: block;
    text-decoration: none;
    color: #333;
}


/*Sidebar Navigation Overrides
------------------------------------*/
.arches-sidebar-nav {
    font-size: 14px;
}

.arches-list-group-item {
    font-size: 15px;
    background: #f0f0f0;
}

.arches-list-item {
    font-size: 15px;
}

.sidebar-nav-v1 > li.active.arches-list-group-item,
.sidebar-nav-v1 > li.active:hover {
  background: #b8b8b8; /*#428bca*/
} 

.sidebar-nav-v1 li ul .arches-list-group-item,
.sidebar-nav-v1 li.active ul a {
  background: #ffffff;
}

.sidebar-nav-v1 li ul a.arches-list-item{
  color: #585f69;
  font-size: 14px;
  border-top: solid 1px #ddd;
  padding: 6px 30px 6px 17px; 
}

.sidebar-nav-v1 li ul a.arches-list-item:hover {
  background-color: #f9f9f9; 
  color: #357ebd;
}


/*.sticky {
    position: fixed!important;
    width: 100%;
    margin-top: -62px;
    z-index: 400;
    margin-bottom: 20px;
    overflow-x: hidden;
    overflow-y: auto;
}
*/

.sticky {
    z-index: 200;
    padding-top: 0px;
    padding-bottom: 10px; 
    padding-top: 30px;
}

.fixed {
  position: fixed;
  top: 0px;
  width: 100%;
  padding-bottom: 10px; 
}

.fixed-menu {
    margin-top: 15px;
    position: fixed;
}

.fixed-spacer {
    margin-top: 95px;
}

.menu-top {
    margin-top: 15px;
}

.menu-spacer {
    margin-top: 90px;
}

.scrolling-spacer {
    margin-top: 15px;
}

/*
.sidebar-nav-v1 > li.active > a {
  color: #333;
}
*/

/*Scroll bar mods for Chrome/Safari
------------------------------------*/
/*
::-webkit-scrollbar {
    width: 5px;
    background: #ededed;
}

::-webkit-scrollbar-thumb 
    background: #a3a3a3;
    -webkit-border-radius: 1ex;
    -webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.5);
}

::-webkit-scrollbar-corner {
    background: #ededed;
}
*/

a {
   color: #4765a0;
}

a:focus, 
a:hover, 
a:active {
    color: #4765a0;
}

.color-green {
    color: #4765a0;
}

a.read-more:hover { 
    color:#4765a0; 
}

.linked:hover {
    color:#4765a0;
}

/*Header v1
------------------------------------*/
/*Navber*/
.header .navbar-default .navbar-nav > .active > a {
    color: #4765a0;
}

/*Navbar Toggle*/
.navbar-toggle,
.navbar-default .navbar-toggle:hover, 
.navbar-default .navbar-toggle:focus {
    background: #4765a0;
}

.navbar-default .navbar-toggle {
    border-color: #324c80;
}

.navbar-default .navbar-toggle:hover {
    background: #324c80;
}

/*Responsive Navbar*/
@media (max-width: 767px) {
    .header .navbar-default .navbar-nav > li > a:hover {
        color: #4765a0;
    }

    .header .navbar-default .navbar-nav > .active > a,
    .header .navbar-default .navbar-nav > .active > a:hover,
    .header .navbar-default .navbar-nav > .active > a:focus {
        color: #fff;
        background: #4765a0;
    }
}

@media (min-width: 767px) {
    /*Navbar*/
    .header .navbar-default .navbar-nav > li > a:hover,
    .header .navbar-default .navbar-nav > .active > a {
        border-bottom: solid 2px #4765a0;
    }

    .header .navbar-default .navbar-nav > .open > a,
    .header .navbar-default .navbar-nav > .open > a:hover,
    .header .navbar-default .navbar-nav > .open > a:focus {
        color: #4765a0;
    }

    /*Dropdown Menu*/
    .header .dropdown-menu { 
        border-top: solid 2px #4765a0; 
    }   
}

/*Search Box*/
.header .navbar .nav > li > .search:hover {
    color: #4765a0;
    border-bottom-color: #4765a0;
}

@media (max-width: 767px) {
    .header .navbar .nav > li > .search:hover {
        background: #324c80;
    }
}

/*Header v2
------------------------------------*/
/*Topbar*/
.topbar-v1 .top-v1-data li a:hover i {
    color: #4765a0;
}

/*Search Box*/
.header-v1 .navbar .nav > li > .search:hover {
    background: #4765a0;
}

/*Responsive Navbar*/
@media (min-width: 767px) {
    .header-v1 .navbar-default .navbar-nav > li > a:hover,
    .header-v1 .navbar-default .navbar-nav > .active > a {
        color: #fff;
        background: #4765a0 !important;
    }

    .header-v1 .navbar-default .navbar-nav > .open > a,
    .header-v1 .navbar-default .navbar-nav > .open > a:hover,
    .header-v1 .navbar-default .navbar-nav > .open > a:focus {
        background: #4765a0;        
    }
}   

/*Sliders
------------------------------------*/
/*Main Parallax Sldier*/
.da-slide h2 i {
    background:url(../../plugins/parallax-slider/img/bg-heading-dark-blue.png) repeat;
}

/*Sequence Parallax Sldier*/
.sequence-inner {
  background: -webkit-gradient(linear, 0 0, 0 bottom, from(#fff), to(#cad9f6));
  background: -webkit-linear-gradient(#fff, #cad9f6);
  background: -moz-linear-gradient(#fff, #cad9f6);
  background: -ms-linear-gradient(#fff, #cad9f6);
  background: -o-linear-gradient(#fff, #cad9f6);
  background: linear-gradient(#fff, #cad9f6)
}

#sequence-theme h2 {
    background:rgba(71, 101, 160, 0.8);
}

#sequence-theme .info p {
    background:rgba(71, 101, 160, 0.8);
}

/*Buttons
------------------------------------*/
.btn-u {
    background: #4765a0;
}

.btn-u:hover, 
.btn-u:focus, 
.btn-u:active, 
.btn-u.active, 
.open .dropdown-toggle.btn-u {
    background: #324c80;
}

/*Buttons Color*/
.btn-u-split.dropdown-toggle {
   border-left: solid 1px #324c80;
}

/*Bordered Buttons*/
.btn-u.btn-brd {
  border-color: #4765a0;
}
.btn-u.btn-brd:hover {
  color: #324c80;
  border-color: #324c80;
}
.btn-u.btn-brd.btn-brd-hover:hover {
   background: #324c80;   
}

/*Service
------------------------------------*/
.service .service-icon {
    color:#4765a0;  
}

/*Service Blocks*/
.service-alternative .service:hover { 
    background:#4765a0;
} 

/*Thumbnail (Recent Work)
------------------------------------*/
.thumbnail-style h3 a:hover {
    color:#4765a0;
}

.thumbnail-style a.btn-more {
    background:#4765a0;
}
.thumbnail-style a.btn-more:hover {
    box-shadow:0 0 0 2px #324c80;
}

/*Carousel (Recent Work)*/
.recent-work a:hover span {
    border-bottom:solid 2px #4765a0;
}

.bx-wrapper .bx-prev {
    background-image: url(../../plugins/bxslider/images/controls-dark-blue.png);
}
.bx-wrapper .bx-next {
    background-image: url(../../plugins/bxslider/images/controls-dark-blue.png);
}

/*Typography
------------------------------------*/
/*Heading*/
.headline h2, 
.headline h3, 
.headline h4 {
    border-bottom:2px solid #4765a0;
}

/*Blockquote*/
blockquote:hover {
    border-left-color:#4765a0; 
}

.hero {
    border-left-color: #4765a0;
}

/*Carousel
------------------------------------*/
.carousel-arrow a.carousel-control:hover {
    color: #4765a0;
}

/*Footer
------------------------------------*/
.footer a,
.copyright a,
.footer a:hover,
.copyright a:hover {
    color: #f9f9f9;
}

/*Footer Blog*/
.footer .dl-horizontal a:hover {
    color:#4765a0 !important;
}

/*Blog Posts
------------------------------------*/
.posts .dl-horizontal a:hover { 
    color:#4765a0; 
}

.posts .dl-horizontal:hover dt img,
.posts .dl-horizontal:hover dd a { 
    color: #4765a0;
    border-color: #4765a0 !important;
}

/*Post Comment*/
.post-comment h3, 
.blog-item .media h3,
.blog-item .media h4.media-heading span a {
    color: #4765a0;
}

/*Tabs
------------------------------------*/
/*Tabs v1*/
.tab-v1 .nav-tabs { 
    border-bottom: solid 2px #4765a0;   
}

.tab-v1 .nav-tabs > .active > a, 
.tab-v1 .nav-tabs > .active > a:hover, 
.tab-v1 .nav-tabs > .active > a:focus { 
    background: #4765a0; 
}

.tab-v1 .nav-tabs > li > a:hover { 
    background: #4765a0; 
}

/*Tabs v2*/
.tab-v2 .nav-tabs li.active a {
    border-top: solid 2px #4765a0;
}

/*Tabs v3*/
.tab-v3 .nav-pills li a:hover,
.tab-v3 .nav-pills li.active a {
    background: #4765a0;
    border: solid 1px #324c80;
}

/*Accardion
------------------------------------*/
.acc-home a.active,
.acc-home a.accordion-toggle:hover { 
    color:#4765a0; 
}
.acc-home .collapse.in { 
    border-bottom:solid 1px #4765a0; 
}

/*Testimonials
------------------------------------*/
.testimonials .testimonial-info {
    color: #4765a0;
}

.testimonials .carousel-arrow i:hover {
    background: #4765a0;
}

/*Info Blocks
------------------------------------*/
.info-blocks:hover i.icon-info-blocks {
    color: #4765a0;
}

/*Breadcrumb
------------------------------------*/
.breadcrumb li.active,
.breadcrumb li a:hover {
    color:#4765a0;
}

/*About Page
------------------------------------*/
.team .thumbnail-style:hover h3 a {
    color:#4765a0 !important;
}

/*Social Icons*/
.team ul.team-socail li i:hover {
    background: #4765a0;
}

/*Right Sidebar
------------------------------------*/
/*Right Sidebar*/
.who li i,
.who li:hover i, 
.who li:hover a { 
    color:#4765a0; 
}

/*Privacy Page
------------------------------------*/
.privacy a:hover {
    color:#4765a0; 
}

/*Portfolio Page
------------------------------------*/
/*Portfolio v1*/
.view a.info:hover {
    background: #4765a0;
}

/*Portfolio v2*/
.sorting-block .sorting-nav li.active {
    color: #4765a0;
    border-bottom: solid 1px #4765a0;
}

.sorting-block .sorting-grid li a:hover span.sorting-cover {
    background: #4765a0;
}

/*Blog Page
------------------------------------*/
.blog h3 {
    color:#4765a0;
}
.blog li a:hover {
    color:#4765a0;
}

/*Blog Tags*/
ul.blog-tags a:hover {
    background: #4765a0;
}

.blog-post-tags ul.blog-tags a:hover {
    background: none repeat scroll 0 0 #4765a0;
}

/*Blog Photos*/
.blog-photos li img:hover {
    box-shadow: 0 0 0 2px #4765a0;
}

/*Blog Latest Tweets*/
.blog-twitter .blog-twitter-inner:hover {
    border-color: #4765a0;
    border-top-color: #4765a0;  
}
.blog-twitter .blog-twitter-inner:hover:after {
    border-top-color: #4765a0;  
}

.blog-twitter .blog-twitter-inner a {
    color: #4765a0;
}

/*Blog Item Page
------------------------------------*/
.blog-item h4.media-heading span a {
    color:#4765a0;
}

/*Coming Soon Page
------------------------------------*/
.coming-soon-border {
    border-top: solid 3px #4765a0;
}

/*Search Page
------------------------------------*/
.booking-blocks p a {
    color: #4765a0;
}

/*Icons Page
------------------------------------*/
.icon-page li:hover { 
    color:#4765a0;
}

/*Glyphicons*/
.glyphicons-demo a:hover {
    color: #4765a0;
    text-decoration: none;
}

/*Magazine Page
------------------------------------*/
/*Magazine News*/
.magazine-news .by-author strong {
    color: #4765a0;
}

.magazine-news a.read-more {
    color: #4765a0;
}

/*Magazine Mini News*/
.magazine-mini-news .post-author strong {
    color: #4765a0;
}

.news-read-more i {
    background: #4765a0;
}

/*Sidebar Features*/
.magazine-page h3 a:hover {
    color: #4765a0;
}

/*Page Features
------------------------------------*/
/*Tag Boxes v1*/
.tag-box-v1 {
    border-top: solid 2px #4765a0;
}

/*Tag Boxes v2*/
.tag-box-v2 {
    border-left: solid 2px #4765a0;
}

/*Tag Boxes v7*/
.tag-box-v7 {
    border-bottom: solid 2px #4765a0;
}

/*Font Awesome Icon Page Style*/
.fa-icons li:hover { 
   color: #4765a0;
}

.fa-icons li:hover i {
   background: #4765a0; 
}

/*GLYPHICONS Icons Page Style*/
.bs-glyphicons li:hover {
   color: #4765a0;
}

/*Navigation
------------------------------------*/
/*Pagination*/
.pagination > .active > a, 
.pagination > .active > span, 
.pagination > .active > a:hover, 
.pagination > .active > span:hover, 
.pagination > .active > a:focus, 
.pagination > .active > span:focus {
   background-color: #4765a0;
   border-color: #4765a0;
}

.pagination li a:hover {
   background: #324c80;
   border-color: #324c80;   
}

/*Pager*/
.pager li > a:hover, 
.pager li > a:focus {
   background: #324c80;
   border-color: #324c80;   
}

/*Registration and Login Page v2
------------------------------------*/
.reg-block {
    border-top: solid 2px #4765a0;
}

/*Image Hover
------------------------------------*/
/*Image-hover*/
#effect-2 figure .img-hover {
    background: #4765a0;
}

/*Blog Large Page
------------------------------------*/
.blog h2 a:hover {
    color: #4765a0;
}

/*Timeline v1 Page
------------------------------------*/
.timeline-v1 > li > .timeline-badge i:hover {
    color: #4765a0;
}

.timeline-v1 .timeline-footer .likes:hover i {
    color: #4765a0;
}

/*Timeline v2 Page
------------------------------------*/
/* The icons */
.timeline-v2 > li .cbp_tmicon {
    background: #4765a0;
}

/*Progress Bar
------------------------------------*/
.progress-bar-u {
  background: #4765a0;
}

/*Job Inner Page
------------------------------------*/
.job-description .save-job a:hover,
.block-description .save-job a:hover {
    color: #4765a0;
}

.job-description .p-chart .overflow-h li i,
.job-description .p-chart .overflow-h li a,
.block-description .p-chart .overflow-h li i,
.block-description .p-chart .overflow-h li a {
    color: #4765a0;
}

/*Colorful-ul*/
.job-description .colorful-ul li a {
    color: #4765a0;
}

/*Search Inner Page
------------------------------------*/
.s-results .related-search a:hover {
    color: #4765a0;
}

.s-results .inner-results h3 a:hover {
    color: #4765a0;
}

.s-results .up-ul li a:hover {
    color: #4765a0;
}

.s-results .down-ul li a {
    color: #4765a0;
}

/*Funny Boxes
------------------------------------*/
.funny-boxes p a {
  color: #4765a0;
}

.funny-boxes .funny-boxes-img li i {
  color: #4765a0;
}

/*Sidebar Sub Navigation
------------------------------------*/
.sidebar-nav-v1 ul li:hover a,
.sidebar-nav-v1 ul li.active a {
  color: #4765a0;
}

/*Blockquote
------------------------------------*/
blockquote.bq-green {
  border-color: #4765a0;
}

blockquote:hover,
blockquote.text-right:hover {
   border-color: #4765a0;
}

/*Green Left Bordered Funny Box**/
.funny-boxes-left-green {
  border-left: solid 2px #4765a0;
}

.funny-boxes-left-green:hover {
  border-left-color: #4765a0;
}

/*Testimonials Default
------------------------------------*/
/*Testimonials*/
.testimonials .carousel-arrow i:hover {
  background: #4765a0;
}

/*Testimonials Default*/
.testimonials-bg-default .item p {
  background: #4765a0;
}

.testimonials.testimonials-bg-default .item p:after,
.testimonials.testimonials-bg-default .item p:after {
  border-top-color: #4765a0;
}

.testimonials-bg-default .carousel-arrow i {
  background: #4765a0;
}

.testimonials.testimonials-bg-default .carousel-arrow i:hover {
  background: #324c80;
}

/*Promo Page
------------------------------------*/
/*Promo Box*/
.promo-box:hover strong, 
.promo-box:hover strong a {
    color: #4765a0;
}

/*Typography
------------------------------------*/
.dropcap {
    color: #4765a0;
}

.dropcap-bg {
    color: #fff;
    background: #4765a0;
}

/*Breadcrumbs
------------------------------------*/ 
span.label-u,
span.badge-u {
  background: #4765a0;
}

/*Icons
------------------------------------*/
/*Icon Link*/
.link-icon:hover i {
  color: #4765a0;
  border: solid 1px #4765a0;
}

.link-bg-icon:hover i {
  color: #4765a0;
  background: #4765a0 !important;
  border-color: #4765a0;
}

/*Icons Backgroun Color
------------------------------------*/ 
i.icon-color-u {
   color: #4765a0;
   border: solid 1px #4765a0;
}

i.icon-bg-u {
   background: #4765a0;
}

/*Line Icon Page
------------------------------------*/
.line-icon-page .item:hover {
    color: #4765a0;
}

/*Colored Content Boxes
------------------------------------*/
.servive-block-u {
  background: #4765a0;
}

/*Panels (Portlets)
------------------------------------*/
.panel-u > .panel-heading {
   background: #4765a0;
}

/*Owl Carousel
------------------------------------*/
.owl-btn:hover {
  background: #4765a0;
}

/*Counter
------------------------------------*/
.counters span.counter-icon i {
    background: #4765a0;
}

.counters span.counter-icon i:after {
    border-top: 7px solid #4765a0;
}

/*SKy-Forms
------------------------------------*/
/*Buttons*/
.sky-form .button {
    background: #4765a0;
}

/*Rating*/
.sky-form .rating input:checked ~ label {
    color: #4765a0;
}

/*Pricing Page
------------------------------------*/
/*Pricing Head*/
.pricing:hover h4 {
    color:#4765a0;
}

.pricing-head h3 {
    background:#4765a0;
    text-shadow: 0 1px 0 #324c80;   
}

.pricing-head h4 {
    color:#999;
    background:#fcfcfc;
    border-bottom:solid 1px #cad9f6;
}
    
/*Pricing Content*/
.pricing-content li {
    border-bottom:solid 1px #cad9f6;
}
.pricing-content li i {
    color:#4765a0;
}

/*Pricing Extra*/
.sticker-left {
    background: #4765a0;
}

/*Pricing Footer*/
.pricing-footer a,
.pricing-footer button {
    background:#4765a0;
}
.pricing-footer a:hover,
.pricing-footer button:hover {
    background:#324c80;
}

/*Priceing Active*/
.price-active h4 {
    color:#4765a0;
}

.no-space-pricing .price-active .pricing-head h4,
.no-space-pricing .pricing:hover .pricing-head h4 {
    color:#4765a0;
}


/*Mega Pricing Tables 
------------------------------------*/
.pricing-mega-v1 .pricing-head h3,
.pricing-mega-v2 .pricing-head h3,
.pricing-mega-v3 .pricing-head h3 {
    text-shadow: 0 1px 0 #324c80;
}

/*Pricing Table Mega v1 Version
------------------------------------*/
.pricing-mega-v1 .pricing:hover h4 i {
    color:#4765a0;
}
.pricing-mega-v1 .pricing-content li i {
    color: #4765a0; 
}

/*Pricing Table Colored Background Version
------------------------------------*/
.pricing-bg-colored .pricing:hover {    
    background: #4765a0;
}

.pricing-bg-colored .pricing-head i {
    color:#4765a0;
}

/*Pricing Table Mega v2 
------------------------------------*/
.pricing-mega-v2 .block:hover .bg-color {
    background: #4765a0;
}
.pricing-mega-v2 .block:hover h3,
.pricing-mega-v2 .block:hover h4, 
.pricing-mega-v2 .block:hover li, 
.pricing-mega-v2 .block:hover li i,
.pricing-mega-v2 .block:hover h4 i {
    background: #4765a0;
}

/*Pricing Table Mega v3 
------------------------------------*/
.pricing-mega-v1 .btn-group .dropdown-menu,
.pricing-mega-v3 .btn-group .dropdown-menu {
    background: #4765a0 !important;
}

.pricing-mega-v1 .btn-group .dropdown-menu li a:hover,
.pricing-mega-v3 .btn-group .dropdown-menu li a:hover {
    background: #324c80;
}