.btn:hover {
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}

.btn-amazon-inversed {
  background-color: #f29e37;
  border-color: #f29e37;
  color: white; }
  .btn-amazon-inversed:hover {
    background-color: transparent;
    color: #f29e37; }

.btn-delicious-inversed {
  background-color: #3271cb;
  border-color: #3271cb;
  color: white; }
  .btn-delicious-inversed:hover {
    background-color: transparent;
    color: #3271cb; }

.btn-digg-inversed {
  background-color: #164673;
  border-color: #164673;
  color: white; }
  .btn-digg-inversed:hover {
    background-color: transparent;
    color: #164673; }

.btn-disqus-inversed {
  background-color: #2e9fff;
  border-color: #2e9fff;
  color: white; }
  .btn-disqus-inversed:hover {
    background-color: transparent;
    color: #2e9fff; }

.btn-eventbrite-inversed {
  background-color: #ff5616;
  border-color: #ff5616;
  color: white; }
  .btn-eventbrite-inversed:hover {
    background-color: transparent;
    color: #ff5616; }

.btn-eventful-inversed {
  background-color: #376095;
  border-color: #376095;
  color: white; }
  .btn-eventful-inversed:hover {
    background-color: transparent;
    color: #376095; }

.btn-intensedebate-inversed {
  background-color: #0099e1;
  border-color: #0099e1;
  color: white; }
  .btn-intensedebate-inversed:hover {
    background-color: transparent;
    color: #0099e1; }

.btn-lanyrd-inversed {
  background-color: #2e6ac2;
  border-color: #2e6ac2;
  color: white; }
  .btn-lanyrd-inversed:hover {
    background-color: transparent;
    color: #2e6ac2; }

.btn-pinboard-inversed {
  background-color: #0000ff;
  border-color: #0000ff;
  color: white; }
  .btn-pinboard-inversed:hover {
    background-color: transparent;
    color: #0000ff; }

.btn-songkick-inversed {
  background-color: #ff0050;
  border-color: #ff0050;
  color: white; }
  .btn-songkick-inversed:hover {
    background-color: transparent;
    color: #ff0050; }

.btn-stumbleupon-inversed {
  background-color: #eb4924;
  border-color: #eb4924;
  color: white; }
  .btn-stumbleupon-inversed:hover {
    background-color: transparent;
    color: #eb4924; }

.btn-gmail-inversed {
  background-color: #db4038;
  border-color: #db4038;
  color: white; }
  .btn-gmail-inversed:hover {
    background-color: transparent;
    color: #db4038; }

.btn-google-inversed {
  background-color: #4e6cf7;
  border-color: #4e6cf7;
  color: white; }
  .btn-google-inversed:hover {
    background-color: transparent;
    color: #4e6cf7; }

.btn-evernote-inversed {
  background-color: #6bb130;
  border-color: #6bb130;
  color: white; }
  .btn-evernote-inversed:hover {
    background-color: transparent;
    color: #6bb130; }

.btn-grooveshark-inversed {
  background-color: #e97a2f;
  border-color: #e97a2f;
  color: white; }
  .btn-grooveshark-inversed:hover {
    background-color: transparent;
    color: #e97a2f; }

.btn-instapaper-inversed {
  background-color: #222222;
  border-color: #222222;
  color: white; }
  .btn-instapaper-inversed:hover {
    background-color: transparent;
    color: #222222; }

.btn-itunes-inversed {
  background-color: #525152;
  border-color: #525152;
  color: white; }
  .btn-itunes-inversed:hover {
    background-color: transparent;
    color: #525152; }

.btn-opentable-inversed {
  background-color: #990000;
  border-color: #990000;
  color: white; }
  .btn-opentable-inversed:hover {
    background-color: transparent;
    color: #990000; }

.btn-logmein-inversed {
  background-color: #000000;
  border-color: #000000;
  color: white; }
  .btn-logmein-inversed:hover {
    background-color: transparent;
    color: #000000; }

.btn-ninetyninedesigns-inversed {
  background-color: #072243;
  border-color: #072243;
  color: white; }
  .btn-ninetyninedesigns-inversed:hover {
    background-color: transparent;
    color: #072243; }

.btn-paypal-inversed {
  background-color: #32689a;
  border-color: #32689a;
  color: white; }
  .btn-paypal-inversed:hover {
    background-color: transparent;
    color: #32689a; }

.btn-pocket-inversed {
  background-color: #de5a5f;
  border-color: #de5a5f;
  color: white; }
  .btn-pocket-inversed:hover {
    background-color: transparent;
    color: #de5a5f; }

.btn-scribd-inversed {
  background-color: #231c1a;
  border-color: #231c1a;
  color: white; }
  .btn-scribd-inversed:hover {
    background-color: transparent;
    color: #231c1a; }

.btn-spotify-inversed {
  background-color: #60af00;
  border-color: #60af00;
  color: white; }
  .btn-spotify-inversed:hover {
    background-color: transparent;
    color: #60af00; }

.btn-statusnet-inversed {
  background-color: #829d25;
  border-color: #829d25;
  color: white; }
  .btn-statusnet-inversed:hover {
    background-color: transparent;
    color: #829d25; }

.btn-stripe-inversed {
  background-color: #2f7ed6;
  border-color: #2f7ed6;
  color: white; }
  .btn-stripe-inversed:hover {
    background-color: transparent;
    color: #2f7ed6; }

.btn-yahoo-inversed {
  background-color: #a200c2;
  border-color: #a200c2;
  color: white; }
  .btn-yahoo-inversed:hover {
    background-color: transparent;
    color: #a200c2; }

.btn-yelp-inversed {
  background-color: #e60010;
  border-color: #e60010;
  color: white; }
  .btn-yelp-inversed:hover {
    background-color: transparent;
    color: #e60010; }

.btn-wikipedia-inversed {
  background-color: #111111;
  border-color: #111111;
  color: white; }
  .btn-wikipedia-inversed:hover {
    background-color: transparent;
    color: #111111; }

.btn-wordpress-inversed {
  background-color: #464646;
  border-color: #464646;
  color: white; }
  .btn-wordpress-inversed:hover {
    background-color: transparent;
    color: #464646; }

.btn-ycombinator-inversed {
  background-color: #ff6600;
  border-color: #ff6600;
  color: white; }
  .btn-ycombinator-inversed:hover {
    background-color: transparent;
    color: #ff6600; }

.btn-bitcoin-inversed {
  background-color: #eb9737;
  border-color: #eb9737;
  color: white; }
  .btn-bitcoin-inversed:hover {
    background-color: transparent;
    color: #eb9737; }

.btn-cloudapp-inversed {
  background-color: #312c2a;
  border-color: #312c2a;
  color: white; }
  .btn-cloudapp-inversed:hover {
    background-color: transparent;
    color: #312c2a; }

.btn-creativecommons-inversed {
  background-color: #000000;
  border-color: #000000;
  color: white; }
  .btn-creativecommons-inversed:hover {
    background-color: transparent;
    color: #000000; }

.btn-dropbox-inversed {
  background-color: #007ee5;
  border-color: #007ee5;
  color: white; }
  .btn-dropbox-inversed:hover {
    background-color: transparent;
    color: #007ee5; }

.btn-html5-inversed {
  background-color: #ff3617;
  border-color: #ff3617;
  color: white; }
  .btn-html5-inversed:hover {
    background-color: transparent;
    color: #ff3617; }

.btn-ie-inversed {
  background-color: #00a1d9;
  border-color: #00a1d9;
  color: white; }
  .btn-ie-inversed:hover {
    background-color: transparent;
    color: #00a1d9; }

.btn-podcast-inversed {
  background-color: #9365ce;
  border-color: #9365ce;
  color: white; }
  .btn-podcast-inversed:hover {
    background-color: transparent;
    color: #9365ce; }

.btn-rss-inversed {
  background-color: #ff7f25;
  border-color: #ff7f25;
  color: white; }
  .btn-rss-inversed:hover {
    background-color: transparent;
    color: #ff7f25; }

.btn-skype-inversed {
  background-color: #00a2ed;
  border-color: #00a2ed;
  color: white; }
  .btn-skype-inversed:hover {
    background-color: transparent;
    color: #00a2ed; }

.btn-steam-inversed {
  background-color: #000000;
  border-color: #000000;
  color: white; }
  .btn-steam-inversed:hover {
    background-color: transparent;
    color: #000000; }

.btn-windows-inversed {
  background-color: #48bbef;
  border-color: #48bbef;
  color: white; }
  .btn-windows-inversed:hover {
    background-color: transparent;
    color: #48bbef; }

.btn-android-inversed {
  background-color: #a4c639;
  border-color: #a4c639;
  color: white; }
  .btn-android-inversed:hover {
    background-color: transparent;
    color: #a4c639; }

.btn-appstore-inversed {
  background-color: #000000;
  border-color: #000000;
  color: white; }
  .btn-appstore-inversed:hover {
    background-color: transparent;
    color: #000000; }

.btn-googleplay-inversed {
  background-color: #b9c13e;
  border-color: #b9c13e;
  color: white; }
  .btn-googleplay-inversed:hover {
    background-color: transparent;
    color: #b9c13e; }

.btn-macstore-inversed {
  background-color: #007dcb;
  border-color: #007dcb;
  color: white; }
  .btn-macstore-inversed:hover {
    background-color: transparent;
    color: #007dcb; }

.btn-appnet-inversed {
  background-color: #3178bd;
  border-color: #3178bd;
  color: white; }
  .btn-appnet-inversed:hover {
    background-color: transparent;
    color: #3178bd; }

.btn-blogger-inversed {
  background-color: #ee5a22;
  border-color: #ee5a22;
  color: white; }
  .btn-blogger-inversed:hover {
    background-color: transparent;
    color: #ee5a22; }

.btn-bitbucket-inversed {
  background-color: #205081;
  border-color: #205081;
  color: white; }
  .btn-bitbucket-inversed:hover {
    background-color: transparent;
    color: #205081; }

.btn-dribbble-inversed {
  background-color: #ea4c89;
  border-color: #ea4c89;
  color: white; }
  .btn-dribbble-inversed:hover {
    background-color: transparent;
    color: #ea4c89; }

.btn-facebook-inversed {
  background-color: #4863ae;
  border-color: #4863ae;
  color: white; }
  .btn-facebook-inversed:hover {
    background-color: transparent;
    color: #4863ae; }

.btn-flattr-inversed {
  background-color: #8aba42;
  border-color: #8aba42;
  color: white; }
  .btn-flattr-inversed:hover {
    background-color: transparent;
    color: #8aba42; }

.btn-flickr-inversed {
  background-color: #ff0084;
  border-color: #ff0084;
  color: white; }
  .btn-flickr-inversed:hover {
    background-color: transparent;
    color: #ff0084; }

.btn-foursquare-inversed {
  background-color: #0072b1;
  border-color: #0072b1;
  color: white; }
  .btn-foursquare-inversed:hover {
    background-color: transparent;
    color: #0072b1; }

.btn-github-inversed {
  background-color: #171515;
  border-color: #171515;
  color: white; }
  .btn-github-inversed:hover {
    background-color: transparent;
    color: #171515; }

.btn-googleplus-inversed {
  background-color: #dd4a38;
  border-color: #dd4a38;
  color: white; }
  .btn-googleplus-inversed:hover {
    background-color: transparent;
    color: #dd4a38; }

.btn-gowalla-inversed {
  background-color: #ff720a;
  border-color: #ff720a;
  color: white; }
  .btn-gowalla-inversed:hover {
    background-color: transparent;
    color: #ff720a; }

.btn-instagram-inversed {
  background-color: #3f729b;
  border-color: #3f729b;
  color: white; }
  .btn-instagram-inversed:hover {
    background-color: transparent;
    color: #3f729b; }

.btn-klout-inversed {
  background-color: #e34a25;
  border-color: #e34a25;
  color: white; }
  .btn-klout-inversed:hover {
    background-color: transparent;
    color: #e34a25; }

.btn-lastfm-inversed {
  background-color: #dc1a23;
  border-color: #dc1a23;
  color: white; }
  .btn-lastfm-inversed:hover {
    background-color: transparent;
    color: #dc1a23; }

.btn-linkedin-inversed {
  background-color: #0083a8;
  border-color: #0083a8;
  color: white; }
  .btn-linkedin-inversed:hover {
    background-color: transparent;
    color: #0083a8; }

.btn-meetup-inversed {
  background-color: #ff0026;
  border-color: #ff0026;
  color: white; }
  .btn-meetup-inversed:hover {
    background-color: transparent;
    color: #ff0026; }

.btn-myspace-inversed {
  background-color: #000000;
  border-color: #000000;
  color: white; }
  .btn-myspace-inversed:hover {
    background-color: transparent;
    color: #000000; }

.btn-pinterest-inversed {
  background-color: #c91618;
  border-color: #c91618;
  color: white; }
  .btn-pinterest-inversed:hover {
    background-color: transparent;
    color: #c91618; }

.btn-quora-inversed {
  background-color: #a82400;
  border-color: #a82400;
  color: white; }
  .btn-quora-inversed:hover {
    background-color: transparent;
    color: #a82400; }

.btn-reddit-inversed {
  background-color: #ff5700;
  border-color: #ff5700;
  color: white; }
  .btn-reddit-inversed:hover {
    background-color: transparent;
    color: #ff5700; }

.btn-plurk-inversed {
  background-color: #cf682f;
  border-color: #cf682f;
  color: white; }
  .btn-plurk-inversed:hover {
    background-color: transparent;
    color: #cf682f; }

.btn-smashing-inversed {
  background-color: #ff4f27;
  border-color: #ff4f27;
  color: white; }
  .btn-smashing-inversed:hover {
    background-color: transparent;
    color: #ff4f27; }

.btn-soundcloud-inversed {
  background-color: #ff4500;
  border-color: #ff4500;
  color: white; }
  .btn-soundcloud-inversed:hover {
    background-color: transparent;
    color: #ff4500; }

.btn-stackoverflow-inversed {
  background-color: #f18436;
  border-color: #f18436;
  color: white; }
  .btn-stackoverflow-inversed:hover {
    background-color: transparent;
    color: #f18436; }

.btn-tumblr-inversed {
  background-color: #374a61;
  border-color: #374a61;
  color: white; }
  .btn-tumblr-inversed:hover {
    background-color: transparent;
    color: #374a61; }

.btn-twitter-inversed {
  background-color: #46c0fb;
  border-color: #46c0fb;
  color: white; }
  .btn-twitter-inversed:hover {
    background-color: transparent;
    color: #46c0fb; }

.btn-viadeo-inversed {
  background-color: #e7732e;
  border-color: #e7732e;
  color: white; }
  .btn-viadeo-inversed:hover {
    background-color: transparent;
    color: #e7732e; }

.btn-vimeo-inversed {
  background-color: #00a2cd;
  border-color: #00a2cd;
  color: white; }
  .btn-vimeo-inversed:hover {
    background-color: transparent;
    color: #00a2cd; }

.btn-vk-inversed {
  background-color: #45688e;
  border-color: #45688e;
  color: white; }
  .btn-vk-inversed:hover {
    background-color: transparent;
    color: #45688e; }

.btn-weibo-inversed {
  background-color: #d7584d;
  border-color: #d7584d;
  color: white; }
  .btn-weibo-inversed:hover {
    background-color: transparent;
    color: #d7584d; }

.btn-xing-inversed {
  background-color: #0a5d5e;
  border-color: #0a5d5e;
  color: white; }
  .btn-xing-inversed:hover {
    background-color: transparent;
    color: #0a5d5e; }

.btn-youtube-inversed {
  background-color: #ff0000;
  border-color: #ff0000;
  color: white; }
  .btn-youtube-inversed:hover {
    background-color: transparent;
    color: #ff0000; }

.btn-csgo-inversed {
  background-color: #b67300;
  border-color: #b67300;
  color: white; }
  .btn-csgo-inversed:hover {
    background-color: transparent;
    color: #b67300; }

.btn-dota2-inversed {
  background-color: #c33d2b;
  border-color: #c33d2b;
  color: white; }
  .btn-dota2-inversed:hover {
    background-color: transparent;
    color: #c33d2b; }

.btn-gm-inversed {
  background-color: #1194f0;
  border-color: #1194f0;
  color: white; }
  .btn-gm-inversed:hover {
    background-color: transparent;
    color: #1194f0; }

.btn-lol-inversed {
  background-color: #d79922;
  border-color: #d79922;
  color: white; }
  .btn-lol-inversed:hover {
    background-color: transparent;
    color: #d79922; }

.btn-minecraft-inversed {
  background-color: #94c864;
  border-color: #94c864;
  color: white; }
  .btn-minecraft-inversed:hover {
    background-color: transparent;
    color: #94c864; }

.btn-tf2-inversed {
  background-color: #b35215;
  border-color: #b35215;
  color: white; }
  .btn-tf2-inversed:hover {
    background-color: transparent;
    color: #b35215; }

.btn-quake-inversed {
  background-color: #cd1800;
  border-color: #cd1800;
  color: white; }
  .btn-quake-inversed:hover {
    background-color: transparent;
    color: #cd1800; }

.btn-wot-inversed {
  background-color: #ff4005;
  border-color: #ff4005;
  color: white; }
  .btn-wot-inversed:hover {
    background-color: transparent;
    color: #ff4005; }
