<!-- Service Blocks -->
<div class="row margin-bottom-40">
    <div class="col-sm-4">
        <div class="servive-block servive-block-default">
            <i class="icon-custom rounded-x icon-bg-dark fa fa-trophy"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Designated  Resources</h2></a>
            <p>Buildings, bridges or other historic objects that are super important</p>                        
        </div>
    </div>

    <div class="col-sm-4">
        <div class="servive-block servive-block-default">            
            <i class="icon-custom rounded-x icon-bg-dark fa fa-bookmark-o"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Historic Districts</h2></a>
            <p>Groups of man-made objects designated as historically significant</p>
        </div>
    </div> 

    <div class="col-sm-4">
        <div class="servive-block servive-block-default">            
            <i class="icon-custom rounded-x icon-bg-dark fa fa-tasks"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Craftsmen Houses</h2></a>
            <p>Significant buildings in the Craftsman architectural style</p>
        </div>
    </div>
</div>

<div class="row margin-bottom-40">
    <div class="col-sm-4">
        <div class="servive-block servive-block-default">
            <i class="icon-custom rounded-x icon-bg-dark fa fa-calendar-o"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Historic Events</h2></a>
            <p>Are culturally significant happenings that occurred in the past and may be related to other resources</p>
        </div>
    </div>

    <div class="col-sm-4">
        <div class="servive-block servive-block-default">
            <i class="icon-custom rounded-x icon-bg-dark fa fa-group"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Architects</h2></a>
            <p>Important and influential (but dangerous) people from Camelot</p>
        </div>
    </div>

    <div class="col-sm-4">
        <div class="servive-block servive-block-default">
            <i class="icon-custom rounded-x icon-bg-dark fa fa-file-text-o"></i>
            <a class= "" href="./hip_search_results.html"><h2 class="txt-color-blue">Information Resources</h2></a>
            <p>Are images, videos, documents or other information carriers that describe Historic Resources </p>
        </div>
    </div>
</div>