/*Center Icon*/
.center-icon {
	left: 50%;
	top: -22px;
	color: #585f69;
	min-width: 45px;
	font-size: 23px;
	background: #fff;
	padding: 10px 5px;
	text-align: center;
	position: absolute;
	margin: 0 10px 0 -22px;
	border: 1px solid #eee;
}

/*Wrapping element for colorful background Block-Description, Job_Team 
------------------------------------*/
.block-description,
.job-team {
	padding: 40px 0 30px;
	position: relative;
	background: #f9f9f9;
	border-top: 1px solid #eee;
}

/*Wrapping element for white background Block-Level-v2, Contacts
------------------------------------*/
.block-level-v2,
.contacts {
	padding: 30px 0;
	background: #fff;
	position: relative;
	border-top: 1px solid #eee;
}

/*Image Block
------------------------------------*/
.image-block {
	overflow: hidden;
	min-height: 200px;
	position: relative;
}

.image-block {
	background: url(../../img/job/slider.jpg) 70% 40% no-repeat;
}

/*Company Description*/
.image-block .company-description {
	max-width: 500px;
	margin: 40px auto;
	padding: 35px 25px;	
	position: relative;
	text-align: center;
	background: rgba(255,255,255,0.8);
}

.image-block .company-description h2 {
	margin-bottom: 20px;
	text-transform: uppercase;
}

.image-block .company-description p {
	text-align: left;
}

.image-block .benefits {
	margin-bottom: 20px;
}

.image-block .benefits li {
	margin: 0 7px 10px 0;
	font-style: italic;
}
 
.image-block .benefits li i {
	color: #555;
	min-width: 32px;
	font-size: 15px;
	padding: 7px 6px;
	margin-right: 10px;
	text-align: center;
	border: 1px solid #555;
}

/*Block Description
------------------------------------*/
.block-description {
	padding-bottom: 80px !important;
}

/*Left-Inner*/
.block-description .left-inner {
	padding: 20px;
	background: #fff;
	position: relative;
}

.block-description .left-inner .hex {
	color: #999;
	margin-bottom: 0;
}

.block-description .left-inner i.position-top {
	top: 20px;
	right: 20px;
	color: #585f69;
	font-size: 18px;
	position: absolute;
}

.block-description .left-inner img {
	float: left;
	width: 80px;
	height: auto;
	padding: 3px;
	margin: 0 10px 10px 0;
	border: 1px solid #eee;
}

.block-description .left-inner h3 {
	margin: 0 0 5px;
}

.block-description .left-inner p.hex {
	margin-bottom: 5px;
}

.block-description .star-vote {
	float: left;
	margin-right: 10px;
}

.block-description .star-vote li {
	padding: 0;
}

/*Progresses*/
.block-description .progression span {
	float: left;
	width: 150px;
	margin: -8px 15px 0 0;
}

/*Right Inner*/
.block-description .right-inner {
	padding: 20px;
	background: #fff;
}

.block-description .right-inner img {
	float: left;
	width: 90px;
	height: auto;
	margin-right: 10px;
}

.block-description .right-inner .font-s {
	font-size: 18px;
}

.block-description .right-inner hr {
	margin: 15px 0;
}

/*P chart v2*/
.block-description .p-chart {
	overflow: hidden;
}

.block-description .p-chart h3 {
	font-size: 16px;
}

.block-description .p-chart .circle {
	float: left;
	margin-right: 10px;
}

.block-description .p-chart .overflow-h li i,
.block-description .p-chart .overflow-h li a {
	color: #72c02c;
}

.block-description .p-chart .overflow-h li a {
	font-size: 11px;
}

/*Circle in Responsive*/
@media (max-width: 450px) {
	.block-description .p-chart.col-xs-6 {
		width: 100%;
	}
}

/*Save Job*/
.block-description .save-job li {
	padding: 2px 0;
}

.block-description .save-job i {
	color: #999;
	min-width: 25px;
	text-align: center;
}

.block-description .save-job a {
	color: #999;
}

.block-description .save-job a:hover {
	color: #72c02c;
}

/*Overview*/
.block-description .overview {
	margin-bottom: 10px;
}

.block-description .overview i {
	color: #fff;
	float: left;
	min-width: 38px;
	font-size: 20px;
	padding: 10px 3px;
	text-align: center;
	margin-right: 10px;
	background: #585f69;
}

/*People Say*/
.block-description .people-say img {
	float: left;
	width: 40px;
	height: auto;
	margin: 6px 10px 0 0;
}

.block-description .people-say .overflow-h span {
	font-weight: 700;
}

.block-description .people-say .overflow-h p {
	font-style: italic;
	line-height: 1.3;
}

.block-description .people-say .overflow-h small {
	text-align: right;
	font-style: italic;
}

/*Block Level
------------------------------------*/
.block-level {
	padding-bottom: 10px !important;
}

/*Block Level v2
------------------------------------*/
.block-level-v2 .responsive-video {
	margin-bottom: 15px;
}

/*Job Team
------------------------------------*/
.parallax-team {
	border-top: 1px solid #eee;
}

/*Contacts
------------------------------------*/
.contacts {
	padding-bottom: 70px;
}

.contacts h3 {
	margin-top: 0;
}

.contacts hr {
	margin: 10px 0;
}
