{% load i18n %}
<!-- Content -->              
<div style="padding-top: 0px;">
    <div class="loading-mask" style="display:none;"></div>

    <!-- Begin Search Results -->
    <div class="col-xs-12">
        
        <div id="search-results-list" data-bind="foreach: results, visible: true" style="display: none;">

            <!-- Begin Search Item  -->
            <div  class="arches-search-item" data-bind="attr: { 'data-resourceid': resourceid }">
                
                <!-- Spacer -->
                <hr class="margin-10">

                <div class="inner-results padding-left-5">

                    <!-- Item Header -->
                    <h4>
                        <a class="arches-search-title" style="" data-bind="text: primaryname, attr: { href: 'reports/' + resourceid }" target="_blank"></a> 
                        &nbsp;
                        <span class="">
                            <small class="arches-search-subtitle"><i data-bind="attr: { class: typeIcon }"></i><span data-bind="text: typeName"></span></small>
                        </span>
                    </h4>

                    <!-- Sub-header -->
                    <ul class="list-inline up-ul">
                        {% if user_can_edit == True %}
                        <li>
                            <i class="arches-search-link fa fa-pencil"></i>&nbsp;
                            <a href="./hip_resource_editor_locations.html"><span class="arches-search-link">{% trans "Edit" %}</span></a>
                        </li>
                        {% endif %}

                        <li>
                            <i class="arches-search-link fa fa-sitemap"></i>&nbsp;
                            <a href="javascript:void(0);" class="info-link related-resources-graph" id="rr-1" data-bind="attr: {'data-resourceid': resourceid, 'data-primaryname': primaryname, 'data-entitytypeid': entitytypeid}"><span class="arches-search-link" data-bind="attr: {'data-resourceid': resourceid, 'data-primaryname': primaryname, 'data-entitytypeid': entitytypeid}">{% trans "Related Resources" %}</span></a>
                        </li>

                        <li data-bind="visible: geometries().length > 0" >
                            <i class="arches-search-link fa fa-map-marker"></i>&nbsp;
                            <a href="javascript:void(0);" data-bind="attr: { 'data-resourceid': resourceid }" class="info-link navigate-map"><span class="arches-search-link">{% trans "Map" %}</span></a>
                        </li>

                    </ul>
                    <!-- End Item Sub-Header -->

                    <!-- Item Description -->
                    <p class="arches-search-item-description">
                        
                    </p>
                    <!-- End Item Description -->

                    <!-- Item Creator/Editor -->
                    <!-- This list is hidden for guests, but shown if user is logged in with editor privileges -->
                    <ul class="list-inline down-ul margin-bottom-10 {% if user_can_edit != True %}hidden{% endif %}">
                       
                        <li class="text-muted">
                            Entered April 14, 2014 by <a href="javascript:void(0);" class="text-primary">adalgity@getty.edu</a>
                        </li>

                        <li class="text-muted" style="padding-left: 0px;">
                            Last Updated: June 1, 2014 by <a href="javascript:void(0);" class="text-primary">phil.carlisle@eh.com</a>
                        </li>
                    </ul> 
                    <!-- End Item Creator/Editor -->

                    <div class="svg arches-related-resource-panel" style="display: none;">
                        {% include 'views/related-resources-graph.htm' %}
                    </div>


                    <!-- Spacer -->
                    <hr class="margin-10 margin-top-20">

                </div>
            </div>
            <!-- End Search Item -->
        </div>

        <div class="margin-bottom-30"></div>

        <!-- Pagination -->
        <div id="paginator" data-bind="html: paginator"></div>
        <!-- End Pagination -->  

    </div> 
    <!-- End Search Results -->
                               
</div>
<!-- End Content --> 