/* Tree Panel
------------------------------------*/


.concept_tree{
    padding: 13px;
}

ul.jqtree-tree div.jqtree_common { 
    display: block; 
    margin: 5px 0; 
    padding: 5px 10px;
    color: #333; 
    border: 1px solid #ccc;
    text-decoration: none; 
    font-weight: bold; 
    background: #fafafa;
    background: -webkit-linear-gradient(top, #fafafa 0%, #eee 100%);
    background:    -moz-linear-gradient(top, #fafafa 0%, #eee 100%);
    background:         linear-gradient(top, #fafafa 0%, #eee 100%);
    -webkit-border-radius: 3px !important;
            border-radius: 3px !important;
    box-sizing: border-box; 
    -moz-box-sizing: border-box;
}

ul.jqtree-tree div.jqtree_common:hover { 
    color: #2ea8e5; 
    background: #fff; 
}

ul.jqtree-tree .jqtree-toggler {
    position: absolute;
}

.jqtree-tree li.jqtree-folder {
    display: block;
    position: relative; 
    margin: 0; 
    padding: 0; 
    font-size: 13px; 
    line-height: 20px; 
}

.jqtree-tree .jqtree-title.jqtree-title-folder {
    position: relative;
    left: 1.5em;
}

.jqtree-tree .jqtree-title {
    color: #1C4257;
    vertical-align: middle;
    margin-left: 0em;
}

/*
.concept_tree.jqtree-loading:after {
    content: url(../../unify/img/select2-spinner.gif);
}
*/

.jqtree-tree .jqtree-loading > div a {
    content: url(../img/select2-spinner.gif);
}

ul.jqtree-tree li.jqtree-ghost {
    margin: 0px;
}

.jqtree-border {
    padding: 0px 5px;
    border: dashed 1px #0000ff;
    border-radius: 3px;
    -webkit-border-radius: 3px !important;
            border-radius: 3px !important;
    box-sizing: border-box; 
    -moz-box-sizing: border-box;
}

ul.jqtree-tree li.jqtree-ghost span.jqtree-line {
    background-color: #fff;
    opacity: 0.6;
    border: dashed 1px #0000ff;
    height: 35px;
    width: 100%;
    position: relative;
    left: 0px;
    top: 0px;
}

ul.jqtree-tree li.jqtree-ghost span.jqtree-circle {
    display:none;
}

/* Concept search widget
------------------------------------*/

.concept_result {
    font-weight:bold;
}

.concept_result_schemaname {
    font-size: 11px;
    padding-left: 10px;
}

/*.sticky {
    position: fixed!important;
    width: 100%;
    margin-top: -62px;
    z-index: 400;
    margin-bottom: 20px;
    overflow-x: hidden;
    overflow-y: auto;
}
*/

.sticky {
    z-index: 200;
    padding-top: 0px;
    padding-bottom: 10px; 
    padding-top: 30px;
}

.fixed {
  position: fixed;
  top: 0px;
  width: 100%;
  padding-bottom: 10px; 
}

.fixed-menu {
    margin-top: 15px;
    position: fixed;
}

.fixed-spacer {
    margin-top: 95px;
}

.menu-top {
    margin-top: 15px;
}

.menu-spacer {
    margin-top: 90px;
}

.scrolling-spacer {
    margin-top: 15px;
}



/*D3 Concept Graph Classes*/
.node {
    stroke: #b3b3b3;
    fill: #f4f4f4;
    opacity: 1.;
    stroke-width: 1.5px;
}

.node-current {
    stroke: #b3b3b3;
    stroke-width: 2px;
    fill: #dcecfa; /*#d7f2af;*/
    opacity: 1.;
    cursor: pointer;
}

.node-current-over {
    stroke: #000000;
    stroke-width: 3px;
    fill: #dcecfa; /*#7cadd8;*/
    opacity: 1.;
    cursor: pointer;
}

.node-current-neighbor {
    stroke: #115fa5;
    stroke-width: 3px;
    fill: #dcecfa; /*#7cadd8;*/
    opacity: 1.;
    cursor: pointer;
}

.node-current-label {
    stroke: #999; /*#3275b1;*/
    font-size: 21px;
    font-weight: 900;
    fill: #fcfcfc; /*#fdfdfd; */
    opacity: 1.;
    text-anchor: middle;
    pointer-events: none;
}


.node-descendent {
    stroke: #ededed; /*#7cadd8;*/
    fill: #fefefe; /*#ccedd6;*/
    opacity: 1.;
    stroke-width: 4px;
    cursor: pointer;
}

.node-descendent-over {
    stroke: #115fa5;
    stroke-width: 8px;
    fill: #dcecfa;
    opacity: 1.;
    cursor: pointer;
}

.node-descendent-neighbor {
    stroke: #115fa5;
    stroke-width: 8px;
    fill: #dcecfa;
    opacity: 1.;
    cursor: pointer;
}

.node-descendent-label {
    font-size: 12px;
    font-weight: 400;
    fill: #c2c2c2;
    opacity: 1.;
    text-anchor: middle;
    pointer-events: none;
}

.node-ancestor {
    stroke: #ededed; /*#ffa293;*/
    fill: #fefefe; /*#ebf9d6;*/
    opacity: 1.;
    stroke-width: 1px;
    cursor: pointer;
}

.node-ancestor-over {
    stroke: #000000;
    stroke-width: 3px;
    fill: #dcecfa;
    opacity: 1.;
    cursor: pointer;
}

.node-ancestor-neighbor {
    stroke: #115fa5;
    stroke-width: 3px;
    fill: #dcecfa;
    opacity: 1.;
    cursor: pointer;
}

.node-ancestor-label {
    font-size: 16px;
    font-weight: 300;
    fill: #a2a2a2;
    opacity: 1.;
    text-anchor: middle;
    pointer-events: none;
}

 
.link {
    stroke: #ededed;
    stroke-width: 5px;
}

.link-highlight {
    stroke: black;
    stroke-width: 9px;
}

.relatedlink {
    stroke: #E4E4E4;
    stroke-width: 3px;
    stroke-dasharray: 8,5;
}

.linkMouseover {
    stroke: #a1a1a1;
    stroke-opacity: .6;
    stroke-width: 5px;
}


.nodeLabels {
    font-size: 11px;
    fill: #454545;
    text-anchor: middle;
}

.node_info {
    width: 320px;
    height: auto;
    padding: 15px;
    background-color: white;
    -webkit-border-radius: 12px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-box-shadow: 1px 1px 2px rgba(0, 0, 0, 0.4);
    -moz-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.4);
    box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.4);
}

.node_info.hidden {
    display: none;
}

.node_info p {
    margin: 0;
    font-family: sans-serif;
    font-size: 16px;
    line-height: 20px;
}

.node-selected {
    fill: #aacdec;
    stroke: #115fa5;
}


/* Inventory Map Tools Buttons and panels*/
.arches-map-tools {
    width: 175px;
    height: 46px;
    background: #F5F7FB;
    color: #3A67A6;
    font-size: 15px;
    font-weight: 400;
    border: 1px solid rgba(206,217,233,.95);
}

.arches-map-tools:active {
    top: 0px;
    left: 0px;
    color: #3A67A6;
    background: #F5F7FB;
    border: 1px solid rgba(206,217,233,.95);
    z-index: 0;
    box-shadow: none;
}

.arches-map-tools:focus {
    top: 0px;
    left: 0px;
    background: #F5F7FB;
    color: #3A67A6;
    border: 1px solid rgba(206,217,233,.95);
    z-index: 0;
    box-shadow: none;
}

.arches-map-tools:hover {
    background: #fdfdfd;
    color: #645699;
    border: 1px solid rgba(206,217,233,.95);
}

.arches-map-tools-pressed {
    width: 175px;
    height: 46px;
    font-size: 15px;
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    color: #3A67A6;
    font-weight: 400;
}

.arches-map-tools-pressed:hover {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
}

.arches-map-tools-pressed:active {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
    top: 0px;
    left: 0px;
    /*box-shadow: inset 0 0px 0px rgba(0,0,0,.125);*/
    box-shadow: none;
}

.arches-map-tools-pressed:focus {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
}

.btn:active {
    top: 0px;
}

.tools-panel {
    margin-top: -518px;
    height: 400px; 
    width: 349px; 
    margin-left: -1px;
    background: #ffffff; 
    border: 1px solid rgba(0,0,0,.15); 
    opacity: 1.0; 
    border-top-left-radius: 3px; 
    border-top-right-radius: 3px;
}

.overlay-entry {
    color: #555;
    font-size: 17px;
    font-weight: 300;
    line-height: 1.15;
}

.overlay-entry-icon {
    color: #428BCA;
    font-size: 19px;
}

.font-120 {
    font-size: 120%;
}


/*Select2 overrides*/

.select2-arrow{
    display: none !important; /*removes the down arrow from dropdowns*/
}

.resource_search_widget_dropdown .select2-results li:first-child{     
    display:none;
} 

.filter-flag{
    background-color: #5CB85C !important; 
    border: 1px solid #4CAE4C !important;
}

/*
.sidebar-nav-v1 > li.active > a {
  color: #333;
}
*/

/*Scroll bar mods for Chrome/Safari
------------------------------------*/
/*
::-webkit-scrollbar {
    width: 5px;
    background: #ededed;
}

::-webkit-scrollbar-thumb 
    background: #a3a3a3;
    -webkit-border-radius: 1ex;
    -webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.5);
}

::-webkit-scrollbar-corner {
    background: #ededed;
}
*/

.branch-invalid-alert {
    margin-top: 10px !important;
}

/* Summer note */
.note-editor .note-codable {
  display: none;
  width: 100%;
  padding: 10px;
  margin-bottom: 0;
  font-family: Menlo,Monaco,monospace,sans-serif;
  font-size: 14px;
  color: #ccc;
  background-color: #222;
  border: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  box-shadow: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  resize: none;
}

.select2-hidden-accessible {
    border: 0;
    clip: rect(0 0 0 0);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute;
    width: 1px;
}


/* Timeline Overrides */

.arches-timeline {
    position:relative;
}

.arches-timeline-list {
    list-style:none;
    margin:0;
    padding:0;
}

.arches-timeline-list:after {
    content:" ";
    background-color:#eee;
    position:absolute;
    display:block;
    width:2px;
    top:0;
    left:150px;
    bottom:0;
    z-index:1;
}

.arches-timeline-list li {
    position:relative;
    margin:0;
    padding:15px 0;
}

.arches-timeline-list>li:hover {
    background-color:#f4f4f4;
}

.arches-timeline-hover li:hover {
    background-color:#f9f9f9;
}

.arches-timeline-icon {
    background:#3276b1;
    color:#fff;
    border-radius:50%;
    position:relative;
    width: 28px;
    height: 28px;
    line-height: 26px;
    font-size: 12px;
    text-align:center;
    left: -41px;
    top: 26px;
    z-index:100;
    padding: 2px;
}

.added {
    background:#c39400;
}

.edited {
    background:#ffd03a;
}

.deleted {
    background:#AE1212;
}

.arches-timeline-icon>img {
    height:32px;
    width:32px;
    border-radius:50%;
    margin-top:-2px;
    margin-left:-2px;
    border:2px solid #3276b1;
}

.arches-timeline-time {
    float:left;
    width:125px;
    font-size: 13px;
    font-weight: 300;
    color: #a0a0a0;
    font-style: italic;
} 

.arches-timeline-time>small {
    font-style:italic;
}

.arches-timeline-date {
    float:left;
    width:125px;
    font-size: 15px;
    font-weight: 400;
    text-align:right;
    color: #777;
} 

.arches-timeline-content {
    margin-left:178px;
    margin-top: -40px;
}

.arches-timeline-content-title {
    font-size: 17px;
    font-weight: 400;
    color: #666;
}

.arches-timeline-description {
    font-size: 15px;
    line-height: 1.25;
    font-weight: 300;
    color: #666;
}

.arches-timeline-editor {
    color: #666;
    position: relative;
    left: 178px;
}

.arches-layer {
    padding-bottom: 25px;
    padding-top: 15px;
    margin-right: 15px;
    margin-left: 15px;
}

.arches-layer:hover {
    background: #f7f7f7;
}

.arches-thumbnail {
    background-color: #dedede;
    border-radius: 3px 0px 0px 3px;
}

.arches-thumbnail-tc {
    background-color: #ffffff;
}

.arches-layer-divider {
    margin-left: 15px;
    margin-right: 15px;
    margin-top: 10px;
    margin-bottom: 0px;
    /*border-top: 1px solid #dedede;*/
}


/* Layer Library */
.arches-layer-library {
    padding-bottom: 0px;
    padding-top: 0px;
    margin-left: 0px;
    margin-right: 5px;
    background: #fcfcfc;
}

/*.arches-layer-library:hover {
    background: #f7f7f7;
}*/

.arches-ll-category {
    color: #777;
}

.arches-ll-title {
    font-size: 18px;
    font-weight: 400;
    padding-left: 2px;
    margin-bottom: 3px;
    color: #555;
}

.arches-ll-selected {
    background: #f9f9f9;
    border-radius: 3px;
}

.layer-selector {
    color: #bfbfbf;
}

.layer-selected-title {
    color: #285e8e;
}

.arches-subtitle {
    color: #bfbfbf;
    text-transform: lowercase;
}


.arches-related-resource {
    padding-left: 10px; 
    margin-top: -5px;
}


.arches-related-resource-title {
    color: #4765a0;
}

.arches-related-resource-button {
    margin-top: 10px; 
    margin-right: 15px;
}



/* Flippable Panel */
.panel {
    margin: 0 auto;
    /*width: 130px;
    height: 130px;  
    position: relative;
    font-size: .8em;
    -webkit-perspective: 600px;
    -moz-perspective: 600px;*/
}
/* -- make sure to declare a default for every property that you want animated -- */
/* -- general styles, including Y axis rotation -- */

.panel .front {
    /*position: absolute;
    top: 0;
    z-index: 900;
    width: inherit;
    height: inherit;
    text-align: center;*/
    -webkit-transform: rotateX(0deg) rotateY(0deg);
    -webkit-transform-style: preserve-3d;
    -webkit-backface-visibility: hidden;
    -moz-transform: rotateX(0deg) rotateY(0deg);
    -moz-transform-style: preserve-3d;
    -moz-backface-visibility: hidden;
    /* -- transition is the magic sauce for animation -- */
    -o-transition: all 1.8s ease-in-out;
    -ms-transition: all 1.8s ease-in-out;
    -moz-transition: all 1.8s ease-in-out;
    -webkit-transition: all 1.8s ease-in-out;
    transition: all 1.8s ease-in-out;
}

.panel.flip .front {
    z-index: 900;
    -webkit-transform: rotateY(180deg);
    -moz-transform: rotateY(180deg);
}

.panel .back {
    position: absolute;
    top: 0;
    z-index: 800;
    width: inherit;
    height: inherit;
    -webkit-transform: rotateY(-180deg);
    -webkit-transform-style: preserve-3d;
    -webkit-backface-visibility: hidden;
 
    -moz-transform: rotateY(-180deg);
    -moz-transform-style: preserve-3d;
    -moz-backface-visibility: hidden;
    /* -- transition is the magic sauce for animation -- */
    -o-transition: all 1.8s ease-in-out;
    -ms-transition: all 1.8s ease-in-out;
    -moz-transition: all 1.8s ease-in-out;
    -webkit-transition: all 1.8s ease-in-out;
    transition: all 1.8s ease-in-out;
}

.panel.flip .back {
    z-index: 1000;
    -webkit-transform: rotateX(0deg) rotateY(0deg);
    -moz-transform: rotateX(0deg) rotateY(0deg);
}

.map-space-panel {
    width: 100%; 
    height: 650px;
    margin-left: 0%;
}

.map-report-panel {
    width: 100%; 
    height: 500px;
    margin-left: 0%;
}


#layer-library {
    /*margin-top: -650px;
    margin-left: 100%;*/
    width: 100%;
}


/* Inventory Map Tools Buttons and panels*/
.arches-map-tools {
    width: 175px;
    height: 46px;
    background: #F5F7FB;
    color: #3A67A6;
    font-size: 15px;
    font-weight: 400;
    border: 1px solid rgba(206,217,233,.95);
}

.arches-map-tools:active {
    top: 0px;
    left: 0px;
    color: #3A67A6;
    background: #F5F7FB;
    border: 1px solid rgba(206,217,233,.95);
    z-index: 0;
    box-shadow: none;
}

.arches-map-tools:focus {
    top: 0px;
    left: 0px;
    background: #F5F7FB;
    color: #3A67A6;
    border: 1px solid rgba(206,217,233,.95);
    z-index: 0;
    box-shadow: none;
}

.arches-map-tools:hover {
    background: #fdfdfd;
    color: #645699;
    border: 1px solid rgba(206,217,233,.95);
}

.arches-map-tools-pressed {
    width: 175px;
    height: 46px;
    font-size: 15px;
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    color: #3A67A6;
    font-weight: 400;
}

.arches-map-tools-pressed:hover {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
}

.arches-map-tools-pressed:active {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
    top: 0px;
    left: 0px;
    /*box-shadow: inset 0 0px 0px rgba(0,0,0,.125);*/
    box-shadow: none;
}

.arches-map-tools-pressed:focus {
    background: #ffffff;
    border: 1px solid rgba(206,217,233,.95);
    border-top-color: #ffffff;
    cursor: pointer;
    color: #3A67A6;
}

.btn:active {
    top: 0px;
}

.tools-panel {
    margin-top: -580px;
    height: 500px; 
    width: 349px; 
    margin-left: -1px;
    background: #ffffff; 
    border: 1px solid rgba(0,0,0,.2); 
    opacity: 1.0; 
    border-top-left-radius: 3px; 
    border-top-right-radius: 3px;
    box-shadow: 0 5px 15px rgba(0,0,0,0.3);
}

.overlay-entry {
    color: #555;
    font-size: 17px;
    font-weight: 300;
    line-height: 1.15;
}

.overlay-entry-icon {
    color: #428BCA;
    font-size: 19px;
}

.arches-overlay-item {
    background: #ffffff;
}


.font-120 {
    font-size: 120%;
}

.arches-tool-item {
    font-size: 17px;
    font-weight: 200;
    color: #555;
    margin-left: 5px;
    margin-right: 5px;
    display: block;
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 4px;
    padding-bottom: 4px;
}


.arches-tool-item:hover {
    background: #f7f7f7;
}

.arches-tool-text {
    color: #555;
}



/* Search */
.search-block {
    border-bottom: 1px solid #eee;
    background: #fafafa;
    padding-bottom: 8px;
    padding-top: 24px;
}

.arches-thumbnail {
    float: left;
    width: 50%;
}

.arches-search-link {
    color: #999;
}

.arches-search-subtitle {
    color: #888;
}


.search-spinner {
    content: url(../img/spinner.gif);
}

.btn-search-filter{
    background-color: rgb(195, 195, 195);
    border-color: grey;
    color: white;
}

.btn-search-filter:hover,
.btn-search-filter:focus,
.btn-search-filter:active,
.btn-search-filter.active,
.open .dropdown-toggle.btn-search-filter{
    background-color: #5cb85c;
    border-color: #4cae4c;
    color: white;
}

.select2-search-choice.inverted {
    background-color: #B41F1F !important;
    border: 1px solid #943434 !important;
}

/* Map Filter*/

/*element.style {
    position: relative;
    overflow: hidden;
    transform: translateZ(0px);
    background-color: rgb(229, 227, 223);
}*/

.arches-search-map {
    height: 400px;
    margin-top: 0px;
    border-width: 1px 1px 1px 1px;
    border-color: #cfcfcf;
    border-style: solid;
}

.arches-map-filter {
    padding-left: 0px;
    margin-left: 20px;
    margin-top: -10px;
    margin-right: 25px;
    margin-bottom: 20px;
}

#info {
    position: absolute;
    z-index: 100;
}
.map .tooltip {
    opacity: 1;
    filter: alpha(opacity=100);  
}
.map .tooltip.in {
    opacity: 1;
    filter: alpha(opacity=100);
}
.map .tooltip.top .tooltip-arrow {
    border-top-color: rgb(134, 134, 134);
} 
.map .tooltip.bottom .tooltip-arrow {
    border-bottom-color: rgb(134, 134, 134);
} 
.map .tooltip.left .tooltip-arrow {
    border-left-color: rgb(134, 134, 134);
} 
.map .tooltip.right .tooltip-arrow {
    border-right-color: rgb(134, 134, 134);
}
.map .tooltip-inner {
    border: 1px solid rgb(197, 197, 197);
    background-color: #FFF;
    color: #416CA9;
}


/* Time Filter*/

.arches-time-filter {
    padding-left: 20px;
    margin-left: 15px;
    margin-right: 15px;
    margin-bottom: 20px;
    background: #fbfbfb;
    border: 1px solid rgba(0,0,0,.1);
}

.slider.slider-horizontal .slider-selection {
    background: #739e73;
}

.slider.slider-horizontal .slider-track {
    height: 10px;
    width: 100%;
    margin-top: -5px;
    top: 50%;
    left: 0;
}

.slider.slider-horizontal .slider-handle{
    background: #858585;
    opacity: 1;
}

.slider-track {
    position: absolute;
    cursor: pointer;
    background: #E5E5E5;
}


.ol-popup {
    display: none;
    position: absolute;
    background-color: white;
    -moz-box-shadow: 0 1px 4px rgba(0,0,0,0.2);
    -webkit-filter: drop-shadow(0 1px 4px rgba(0,0,0,0.2));
    filter: drop-shadow(0 1px 4px rgba(0,0,0,0.2));
    padding: 15px;
    border-radius: 10px;
    border: 1px solid #cccccc;
    bottom: 12px;
    left: -50px;
}
.ol-popup:after, .ol-popup:before {
    top: 100%;
    border: solid transparent;
    content: " ";
    height: 0;
    width: 0;
    position: absolute;
    pointer-events: none;
}
.ol-popup:after {
    border-top-color: white;
    border-width: 10px;
    left: 48px;
    margin-left: -10px;
}
.ol-popup:before {
    border-top-color: #cccccc;
    border-width: 11px;
    left: 48px;
    margin-left: -11px;
}
.ol-popup-closer {
    text-decoration: none;
    position: absolute;
    top: 6px;
    right: 9px;
}
.ol-popup-closer:after {
    content: "✖";
}


.arches-related-resource-panel {
    margin-right: 10px; 
    background: #fefefe; 
    border: 1px solid rgba(0,0,0,.1); 
    height: 400px; 
    padding-top: 0px; 
    padding-bottom: 0px;
}

.arches-related-resource-panel.loading {
    background-image: url("../img/spinner.gif");
    background-repeat: no-repeat;
    background-position: 50% 50%;
}

.loading-cluster-info {
    background-image: url("../img/spinner.gif");
    background-repeat: no-repeat;
    background-position: 50% 50%;
    background-size:100px;
    height: 100px;
    margin-top: 12px;
}

.select2-search-field {
    font-size: 15px;
}

.select2-search-field {
    font-weight: 200;
}

.select2-search-choice {
    margin-top: 8px;
}

.select2-container-multi .select2-choices {
    border-radius: 3px;
}

.geocodewidget {
    margin-left: 10px;
}

.map-loading {
    height: 36px;
    margin-top: 11px;
    margin-left: 22px;
    background-color: #5cb85c;
    opacity: 0.9;
    border: 1px solid #4cae4c; 
    border-radius: 2px 2px 2px 2px;
    padding-top: 1px;
}

.map-loading-text {
    font-size: 15px;
    font-weight: 300;
    color: #fdfdfd;
    margin-left: 40px;
    margin-top: -27px;
}

.d3-tip {
  line-height: 1.2;
  display: block;
  width: 200px;
  font-size:11px;
  border: solid 1px #BBBBBB;
  padding: 6px;
  background: rgba(256, 256, 256, 0.8);
  color: #808080;
  border-radius: 2px;
  pointer-events: none;
  box-shadow: 2px 2px 2px 0px rgba(0,0,0,0.25);
}

/* Creates a small triangle extender for the tooltip */
.d3-tip:after {
  box-sizing: border-box;
  display: inline;
  font-size: 10px;
  width: 100%;
  line-height: 1;
  color: rgba(180, 180, 180, 0.8);
  position: absolute;
  pointer-events: none;
}

/* Northward tooltips */
.d3-tip.n:after {
  content: "\25BC";
  margin: -1px 0 0 0;
  top: 100%;
  left: 0;
  text-align: center;
}

/* Eastward tooltips */
.d3-tip.e:after {
  content: "\25C0";
  margin: -4px 0 0 0;
  top: 50%;
  left: -8px;
}

/* Southward tooltips */
.d3-tip.s:after {
  content: "\25B2";
  margin: 0 0 1px 0;
  top: -10px;
  left: 0;
  text-align: center;
}

/* Westward tooltips */
.d3-tip.w:after {
  content: "\25B6";
  margin: -4px 0 0 -1px;
  top: 50%;
  left: 100%;
}

.graph-tooltip-name{
    font-weight: bold;
}

.loading-mask {
    position: absolute;
    z-index: 10000;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-image: url("../img/spinner.gif");
    background-size: 150px;
    background-repeat: no-repeat;
    background-position: 50% 50%;
}