.btn:hover {
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  -o-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
}

.btn-amazon {
  background-color: transparent;
  border-color: #f29e37;
  color: #f29e37; }
  .btn-amazon:hover {
    background-color: #f29e37;
    color: white; }

.btn-delicious {
  background-color: transparent;
  border-color: #3271cb;
  color: #3271cb; }
  .btn-delicious:hover {
    background-color: #3271cb;
    color: white; }

.btn-digg {
  background-color: transparent;
  border-color: #164673;
  color: #164673; }
  .btn-digg:hover {
    background-color: #164673;
    color: white; }

.btn-disqus {
  background-color: transparent;
  border-color: #2e9fff;
  color: #2e9fff; }
  .btn-disqus:hover {
    background-color: #2e9fff;
    color: white; }

.btn-eventbrite {
  background-color: transparent;
  border-color: #ff5616;
  color: #ff5616; }
  .btn-eventbrite:hover {
    background-color: #ff5616;
    color: white; }

.btn-eventful {
  background-color: transparent;
  border-color: #376095;
  color: #376095; }
  .btn-eventful:hover {
    background-color: #376095;
    color: white; }

.btn-intensedebate {
  background-color: transparent;
  border-color: #0099e1;
  color: #0099e1; }
  .btn-intensedebate:hover {
    background-color: #0099e1;
    color: white; }

.btn-lanyrd {
  background-color: transparent;
  border-color: #2e6ac2;
  color: #2e6ac2; }
  .btn-lanyrd:hover {
    background-color: #2e6ac2;
    color: white; }

.btn-pinboard {
  background-color: transparent;
  border-color: #0000ff;
  color: #0000ff; }
  .btn-pinboard:hover {
    background-color: #0000ff;
    color: white; }

.btn-songkick {
  background-color: transparent;
  border-color: #ff0050;
  color: #ff0050; }
  .btn-songkick:hover {
    background-color: #ff0050;
    color: white; }

.btn-stumbleupon {
  background-color: transparent;
  border-color: #eb4924;
  color: #eb4924; }
  .btn-stumbleupon:hover {
    background-color: #eb4924;
    color: white; }

.btn-gmail {
  background-color: transparent;
  border-color: #db4038;
  color: #db4038; }
  .btn-gmail:hover {
    background-color: #db4038;
    color: white; }

.btn-google {
  background-color: transparent;
  border-color: #4e6cf7;
  color: #4e6cf7; }
  .btn-google:hover {
    background-color: #4e6cf7;
    color: white; }

.btn-evernote {
  background-color: transparent;
  border-color: #6bb130;
  color: #6bb130; }
  .btn-evernote:hover {
    background-color: #6bb130;
    color: white; }

.btn-grooveshark {
  background-color: transparent;
  border-color: #e97a2f;
  color: #e97a2f; }
  .btn-grooveshark:hover {
    background-color: #e97a2f;
    color: white; }

.btn-instapaper {
  background-color: transparent;
  border-color: #222222;
  color: #222222; }
  .btn-instapaper:hover {
    background-color: #222222;
    color: white; }

.btn-itunes {
  background-color: transparent;
  border-color: #525152;
  color: #525152; }
  .btn-itunes:hover {
    background-color: #525152;
    color: white; }

.btn-opentable {
  background-color: transparent;
  border-color: #990000;
  color: #990000; }
  .btn-opentable:hover {
    background-color: #990000;
    color: white; }

.btn-logmein {
  background-color: transparent;
  border-color: #000000;
  color: #000000; }
  .btn-logmein:hover {
    background-color: #000000;
    color: white; }

.btn-ninetyninedesigns {
  background-color: transparent;
  border-color: #072243;
  color: #072243; }
  .btn-ninetyninedesigns:hover {
    background-color: #072243;
    color: white; }

.btn-paypal {
  background-color: transparent;
  border-color: #32689a;
  color: #32689a; }
  .btn-paypal:hover {
    background-color: #32689a;
    color: white; }

.btn-pocket {
  background-color: transparent;
  border-color: #de5a5f;
  color: #de5a5f; }
  .btn-pocket:hover {
    background-color: #de5a5f;
    color: white; }

.btn-scribd {
  background-color: transparent;
  border-color: #231c1a;
  color: #231c1a; }
  .btn-scribd:hover {
    background-color: #231c1a;
    color: white; }

.btn-spotify {
  background-color: transparent;
  border-color: #60af00;
  color: #60af00; }
  .btn-spotify:hover {
    background-color: #60af00;
    color: white; }

.btn-statusnet {
  background-color: transparent;
  border-color: #829d25;
  color: #829d25; }
  .btn-statusnet:hover {
    background-color: #829d25;
    color: white; }

.btn-stripe {
  background-color: transparent;
  border-color: #2f7ed6;
  color: #2f7ed6; }
  .btn-stripe:hover {
    background-color: #2f7ed6;
    color: white; }

.btn-yahoo {
  background-color: transparent;
  border-color: #a200c2;
  color: #a200c2; }
  .btn-yahoo:hover {
    background-color: #a200c2;
    color: white; }

.btn-yelp {
  background-color: transparent;
  border-color: #e60010;
  color: #e60010; }
  .btn-yelp:hover {
    background-color: #e60010;
    color: white; }

.btn-wikipedia {
  background-color: transparent;
  border-color: #111111;
  color: #111111; }
  .btn-wikipedia:hover {
    background-color: #111111;
    color: white; }

.btn-wordpress {
  background-color: transparent;
  border-color: #464646;
  color: #464646; }
  .btn-wordpress:hover {
    background-color: #464646;
    color: white; }

.btn-ycombinator {
  background-color: transparent;
  border-color: #ff6600;
  color: #ff6600; }
  .btn-ycombinator:hover {
    background-color: #ff6600;
    color: white; }

.btn-bitcoin {
  background-color: transparent;
  border-color: #eb9737;
  color: #eb9737; }
  .btn-bitcoin:hover {
    background-color: #eb9737;
    color: white; }

.btn-cloudapp {
  background-color: transparent;
  border-color: #312c2a;
  color: #312c2a; }
  .btn-cloudapp:hover {
    background-color: #312c2a;
    color: white; }

.btn-creativecommons {
  background-color: transparent;
  border-color: #000000;
  color: #000000; }
  .btn-creativecommons:hover {
    background-color: #000000;
    color: white; }

.btn-dropbox {
  background-color: transparent;
  border-color: #007ee5;
  color: #007ee5; }
  .btn-dropbox:hover {
    background-color: #007ee5;
    color: white; }

.btn-html5 {
  background-color: transparent;
  border-color: #ff3617;
  color: #ff3617; }
  .btn-html5:hover {
    background-color: #ff3617;
    color: white; }

.btn-ie {
  background-color: transparent;
  border-color: #00a1d9;
  color: #00a1d9; }
  .btn-ie:hover {
    background-color: #00a1d9;
    color: white; }

.btn-podcast {
  background-color: transparent;
  border-color: #9365ce;
  color: #9365ce; }
  .btn-podcast:hover {
    background-color: #9365ce;
    color: white; }

.btn-rss {
  background-color: transparent;
  border-color: #ff7f25;
  color: #ff7f25; }
  .btn-rss:hover {
    background-color: #ff7f25;
    color: white; }

.btn-skype {
  background-color: transparent;
  border-color: #00a2ed;
  color: #00a2ed; }
  .btn-skype:hover {
    background-color: #00a2ed;
    color: white; }

.btn-steam {
  background-color: transparent;
  border-color: #000000;
  color: #000000; }
  .btn-steam:hover {
    background-color: #000000;
    color: white; }

.btn-windows {
  background-color: transparent;
  border-color: #48bbef;
  color: #48bbef; }
  .btn-windows:hover {
    background-color: #48bbef;
    color: white; }

.btn-android {
  background-color: transparent;
  border-color: #a4c639;
  color: #a4c639; }
  .btn-android:hover {
    background-color: #a4c639;
    color: white; }

.btn-appstore {
  background-color: transparent;
  border-color: #000000;
  color: #000000; }
  .btn-appstore:hover {
    background-color: #000000;
    color: white; }

.btn-googleplay {
  background-color: transparent;
  border-color: #b9c13e;
  color: #b9c13e; }
  .btn-googleplay:hover {
    background-color: #b9c13e;
    color: white; }

.btn-macstore {
  background-color: transparent;
  border-color: #007dcb;
  color: #007dcb; }
  .btn-macstore:hover {
    background-color: #007dcb;
    color: white; }

.btn-appnet {
  background-color: transparent;
  border-color: #3178bd;
  color: #3178bd; }
  .btn-appnet:hover {
    background-color: #3178bd;
    color: white; }

.btn-blogger {
  background-color: transparent;
  border-color: #ee5a22;
  color: #ee5a22; }
  .btn-blogger:hover {
    background-color: #ee5a22;
    color: white; }

.btn-bitbucket {
  background-color: transparent;
  border-color: #205081;
  color: #205081; }
  .btn-bitbucket:hover {
    background-color: #205081;
    color: white; }

.btn-dribbble {
  background-color: transparent;
  border-color: #ea4c89;
  color: #ea4c89; }
  .btn-dribbble:hover {
    background-color: #ea4c89;
    color: white; }

.btn-facebook {
  background-color: transparent;
  border-color: #4863ae;
  color: #4863ae; }
  .btn-facebook:hover {
    background-color: #4863ae;
    color: white; }

.btn-flattr {
  background-color: transparent;
  border-color: #8aba42;
  color: #8aba42; }
  .btn-flattr:hover {
    background-color: #8aba42;
    color: white; }

.btn-flickr {
  background-color: transparent;
  border-color: #ff0084;
  color: #ff0084; }
  .btn-flickr:hover {
    background-color: #ff0084;
    color: white; }

.btn-foursquare {
  background-color: transparent;
  border-color: #0072b1;
  color: #0072b1; }
  .btn-foursquare:hover {
    background-color: #0072b1;
    color: white; }

.btn-github {
  background-color: transparent;
  border-color: #171515;
  color: #171515; }
  .btn-github:hover {
    background-color: #171515;
    color: white; }

.btn-googleplus {
  background-color: transparent;
  border-color: #dd4a38;
  color: #dd4a38; }
  .btn-googleplus:hover {
    background-color: #dd4a38;
    color: white; }

.btn-gowalla {
  background-color: transparent;
  border-color: #ff720a;
  color: #ff720a; }
  .btn-gowalla:hover {
    background-color: #ff720a;
    color: white; }

.btn-instagram {
  background-color: transparent;
  border-color: #3f729b;
  color: #3f729b; }
  .btn-instagram:hover {
    background-color: #3f729b;
    color: white; }

.btn-klout {
  background-color: transparent;
  border-color: #e34a25;
  color: #e34a25; }
  .btn-klout:hover {
    background-color: #e34a25;
    color: white; }

.btn-lastfm {
  background-color: transparent;
  border-color: #dc1a23;
  color: #dc1a23; }
  .btn-lastfm:hover {
    background-color: #dc1a23;
    color: white; }

.btn-linkedin {
  background-color: transparent;
  border-color: #0083a8;
  color: #0083a8; }
  .btn-linkedin:hover {
    background-color: #0083a8;
    color: white; }

.btn-meetup {
  background-color: transparent;
  border-color: #ff0026;
  color: #ff0026; }
  .btn-meetup:hover {
    background-color: #ff0026;
    color: white; }

.btn-myspace {
  background-color: transparent;
  border-color: #000000;
  color: #000000; }
  .btn-myspace:hover {
    background-color: #000000;
    color: white; }

.btn-pinterest {
  background-color: transparent;
  border-color: #c91618;
  color: #c91618; }
  .btn-pinterest:hover {
    background-color: #c91618;
    color: white; }

.btn-quora {
  background-color: transparent;
  border-color: #a82400;
  color: #a82400; }
  .btn-quora:hover {
    background-color: #a82400;
    color: white; }

.btn-reddit {
  background-color: transparent;
  border-color: #ff5700;
  color: #ff5700; }
  .btn-reddit:hover {
    background-color: #ff5700;
    color: white; }

.btn-plurk {
  background-color: transparent;
  border-color: #cf682f;
  color: #cf682f; }
  .btn-plurk:hover {
    background-color: #cf682f;
    color: white; }

.btn-smashing {
  background-color: transparent;
  border-color: #ff4f27;
  color: #ff4f27; }
  .btn-smashing:hover {
    background-color: #ff4f27;
    color: white; }

.btn-soundcloud {
  background-color: transparent;
  border-color: #ff4500;
  color: #ff4500; }
  .btn-soundcloud:hover {
    background-color: #ff4500;
    color: white; }

.btn-stackoverflow {
  background-color: transparent;
  border-color: #f18436;
  color: #f18436; }
  .btn-stackoverflow:hover {
    background-color: #f18436;
    color: white; }

.btn-tumblr {
  background-color: transparent;
  border-color: #374a61;
  color: #374a61; }
  .btn-tumblr:hover {
    background-color: #374a61;
    color: white; }

.btn-twitter {
  background-color: transparent;
  border-color: #46c0fb;
  color: #46c0fb; }
  .btn-twitter:hover {
    background-color: #46c0fb;
    color: white; }

.btn-viadeo {
  background-color: transparent;
  border-color: #e7732e;
  color: #e7732e; }
  .btn-viadeo:hover {
    background-color: #e7732e;
    color: white; }

.btn-vimeo {
  background-color: transparent;
  border-color: #00a2cd;
  color: #00a2cd; }
  .btn-vimeo:hover {
    background-color: #00a2cd;
    color: white; }

.btn-vk {
  background-color: transparent;
  border-color: #45688e;
  color: #45688e; }
  .btn-vk:hover {
    background-color: #45688e;
    color: white; }

.btn-weibo {
  background-color: transparent;
  border-color: #d7584d;
  color: #d7584d; }
  .btn-weibo:hover {
    background-color: #d7584d;
    color: white; }

.btn-xing {
  background-color: transparent;
  border-color: #0a5d5e;
  color: #0a5d5e; }
  .btn-xing:hover {
    background-color: #0a5d5e;
    color: white; }

.btn-youtube {
  background-color: transparent;
  border-color: #ff0000;
  color: #ff0000; }
  .btn-youtube:hover {
    background-color: #ff0000;
    color: white; }

.btn-csgo {
  background-color: transparent;
  border-color: #b67300;
  color: #b67300; }
  .btn-csgo:hover {
    background-color: #b67300;
    color: white; }

.btn-dota2 {
  background-color: transparent;
  border-color: #c33d2b;
  color: #c33d2b; }
  .btn-dota2:hover {
    background-color: #c33d2b;
    color: white; }

.btn-gm {
  background-color: transparent;
  border-color: #1194f0;
  color: #1194f0; }
  .btn-gm:hover {
    background-color: #1194f0;
    color: white; }

.btn-lol {
  background-color: transparent;
  border-color: #d79922;
  color: #d79922; }
  .btn-lol:hover {
    background-color: #d79922;
    color: white; }

.btn-minecraft {
  background-color: transparent;
  border-color: #94c864;
  color: #94c864; }
  .btn-minecraft:hover {
    background-color: #94c864;
    color: white; }

.btn-tf2 {
  background-color: transparent;
  border-color: #b35215;
  color: #b35215; }
  .btn-tf2:hover {
    background-color: #b35215;
    color: white; }

.btn-quake {
  background-color: transparent;
  border-color: #cd1800;
  color: #cd1800; }
  .btn-quake:hover {
    background-color: #cd1800;
    color: white; }

.btn-wot {
  background-color: transparent;
  border-color: #ff4005;
  color: #ff4005; }
  .btn-wot:hover {
    background-color: #ff4005;
    color: white; }
