{% load staticfiles %}
{% load i18n %}
<div class="footer">
    <div class="container">
        <div class="row">
            <div class="col-md-4 md-margin-bottom-40">
                <!-- About -->
                <div class="headline"><h2>About</h2></div>  
                <p class="margin-bottom-25 md-margin-bottom-40">
                    Arches is built to create and manage rich inventories of culturally signficant resources.
                </p>  

                <!-- End About -->

                <!-- Monthly Newsletter -->
                <div class="headline"><h2>Monthly Newsletter</h2></div> 
                <p>Subscribe to our newsletter and stay up to date with the latest news and deals!</p>
                <form class="footer-subsribe">
                    <div class="input-group">
                        <input type="text" class="form-control" placeholder="Email Address">                            
                        <span class="input-group-btn">
                            <button class="btn-u" type="button">Subscribe</button>
                        </span>
                    </div>                  
                </form>                         
                <!-- End Monthly Newsletter -->
            </div><!--/col-md-4-->  
            
            <div class="col-md-4 md-margin-bottom-40">
                <!-- Recent Blogs -->
                <div class="posts">
                    <div class="headline"><h2>Recent Blog Entries</h2></div>
                    <dl class="dl-horizontal">
                        <dt><a href="javascript:void(0);"><img src="{{ STATIC_URL }}img/sliders/elastislide/6.jpg" alt="" /></a></dt>
                        <dd>
                            <p><a href="javascript:void(0);">Anim moon officia Unify is an incredibly beautiful responsive Bootstrap Template</a></p> 
                        </dd>
                    </dl>
                    <dl class="dl-horizontal">
                        <dt><a href="javascript:void(0);"><img src="{{ STATIC_URL }}img/sliders/elastislide/10.jpg" alt="" /></a></dt>
                        <dd>
                            <p><a href="javascript:void(0);">Anim moon officia Unify is an incredibly beautiful responsive Bootstrap Template</a></p> 
                        </dd>
                    </dl>
                    <dl class="dl-horizontal">
                        <dt><a href="javascript:void(0);"><img src="{{ STATIC_URL }}img/sliders/elastislide/11.jpg" alt="" /></a></dt>
                        <dd>
                            <p><a href="javascript:void(0);">Anim moon officia Unify is an incredibly beautiful responsive Bootstrap Template</a></p> 
                        </dd>
                    </dl>
                </div>
                <!-- End Recent Blogs -->                    
            </div><!--/col-md-4-->

            <div class="col-md-4">
                <!-- Contact Us -->
                <div class="headline"><h2>Contact Us</h2></div> 
                <address class="md-margin-bottom-40">
                    25, Lorem Lis Street, Orange <br />
                    California, US <br />
                    Phone: 800 123 3456 <br />
                    Fax: 800 123 3456 <br />
                    Email: <a href="mailto:info@anybiz.com" class="">info@anybiz.com</a>
                </address>
                <!-- End Contact Us -->

                <!-- Social Links -->
                <div class="headline"><h2>Stay Connected</h2></div> 
                <ul class="social-icons">
                    <li><a href="javascript:void(0);" data-original-title="Feed" class="social_rss"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Facebook" class="social_facebook"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Twitter" class="social_twitter"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Goole Plus" class="social_googleplus"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Pinterest" class="social_pintrest"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Linkedin" class="social_linkedin"></a></li>
                    <li><a href="javascript:void(0);" data-original-title="Vimeo" class="social_vimeo"></a></li>
                </ul>
                <!-- End Social Links -->
            </div><!--/col-md-4-->
        </div>
    </div> 
</div> 