<form method="POST" id="resource_data_management_form" class="form-inline arches-form" role="form">
    <div class="right-inner arches-box-grey-border padding-10" id="crud" style="">
                
        <!-- Theme Title -->
        <div class="row">
            <div class="col-xs-12">
                
                <div class="headline margin-bottom-10 padding-left-10">
                    <h3 class="headline text-primary"><i class="fa fa-tag text-primary"></i>{{form.name}}</h3>

                    <!-- Save/Discard Buttons for small, medium and large screens -->
                    <span class="pull-right margin-top-minus-10">
                        
                        <button class="btn btn-primary" id="start-upload"> 
                            <i class="fa fa-plus"></i>&nbsp; Assess
                        </button>

                        <!-- Spacer (for xs screens) -->
                        <div class="hidden-sm hidden-md hidden-lg" style="margin-top: 45px;"></div>

                        <button class="btn btn-danger" id="cancel-upload" style="display: none;"> 
                            <i class="fa fa-times"></i>&nbsp; Cancel
                        </button>
                        
                        <button class="btn btn-success" id="save-upload" style="display: none;"> 
                            <i class="fa fa-check"></i>&nbsp; Save
                        </button>

                    </span>

                </div>
            </div>
        </div>
        <!-- End Theme Title -->

        {% block form_content %}
        {% endblock form_content %}

        <input id="formdata" name="formdata" type="hidden" value="{{formdata}}"/>
    </div>
</form>
