/*!
 * SmartAdmin - Responsive WebApp
 *
 * Copyright 2014 bootstraphunter.com
 * Designed and built with all the love in the world by @bootstraphunt.
 */

/*
	 * MAIN
	 */
article.sortable-grid {
  min-height: 30px;
}
.jarviswidget {
  margin: 0 0 30px 0;
  position: relative;
  -moz-border-radius: 0px;
  -khtml-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-radius: 0px;
  padding: 0;
}
.widget-content-padding {
  padding: 20px;
}
.widget-content-padding .well {
  margin-bottom: 0px;
}
/*
	 * HEADER
	 */
.jarviswidget > header {
  height: 34px;
  /* make sure ".jarviswidget-loader" is also the same height or it will flicker during collapse */
  padding: 0;
  line-height: 40px;
}
.ui-sortable .jarviswidget-sortable > header {
  cursor: move;
  -moz-border-radius: 0px;
  -khtml-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-radius: 0px;
  line-height: normal;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.jarviswidget > header > .widget-icon {
  display: block;
  width: 30px;
  height: 32px;
  position: relative;
  float: left;
  font-size: 111%;
  line-height: 32px;
  text-align: center;
  margin-right: -10px;
}
.ui-sortable .jarviswidget-sortable.jarviswidget-collapsed > header {
  -moz-border-radius: 0px;
  -khtml-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-radius: 0px;
}
.jarviswidget > header h2 {
  height: 100%;
  width: auto;
  display: inline-block;
  font-size: 14px;
  position: relative;
  margin: 0;
  line-height: 34px;
  font-weight: normal;
  letter-spacing: 0px;
}
.jarviswidget > header > h2 {
  margin-left: 10px;
  float: left;
}
.jarviswidget > header > :first-child.widget-icon {
  margin-left: 0;
}
.jarviswidget > header .jarviswidget-icon {
  width: 16px;
  height: 16px;
  float: left;
  margin: 12px 10px 0 0;
  display: block;
  zoom: 1;
  z-index: 4000;
}
.jarviswidget-ctrls {
  width: auto;
  float: right;
  padding: 0;
  margin: 0;
}
.jarviswidget-ctrls .button-icon {
  min-width: 30px;
  height: 32px;
  float: left;
  position: relative;
  font-family: Arial, Helvetica, sans-serif;
  border-left: 1px solid rgba(0, 0, 0, 0.09);
}
.jarviswidget-ctrls .button-icon:hover {
  background-color: rgba(0, 0, 0, 0.05);
}
.jarviswidget-loader {
  width: 32px;
  height: 32px;
  margin: 0;
  float: right;
  background-repeat: no-repeat;
  background-position: center center;
  display: none;
  text-align: center;
  line-height: 32px;
  font-size: 111%;
}
/*
	 * CONTENT
	 */
.jarviswidget > div {
  float: left;
  width: 100%;
  position: relative;
  font-size: 13px;
  -moz-border-radius: 0px;
  -khtml-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-radius: 0px;
  margin: 0;
  border-width: 1px 1px 2px 1px;
  border-style: solid;
  border-top: none;
  border-right-color: #CCC !important;
  border-bottom-color: #CCC !important;
  border-left-color: #CCC !important;
  padding: 13px 13px 0px;
  /* as per version 1.3 */
  overflow: visible;
}
.jarviswidget .widget-body {
  min-height: 100px;
  position: relative;
  padding-bottom: 13px;
}
.jarviswidget .widget-body.widget-hide-overflow {
  overflow: hidden;
}
.widget-toolbar.no-border {
  border-left: none;
}
.widget-body.no-padding {
  margin: -13px -13px 0px;
}
.jarviswidget.well.transparent .widget-body.no-padding {
  margin: 0px !important;
}
.widget-body > table {
  margin-bottom: 0;
}
.widget-body.no-padding .alert {
  margin: 0 0 10px;
  padding: 10px;
  box-shadow: none !important;
  -webkit-box-shadow: none !important;
  -moz-box-shadow: none !important;
  border-width: 0px 0px 1px !important;
  border-radius: 0px !important;
  -webkit-border-radius: 0px !important;
  -moz-border-radius: 0px !important;
}
.widget-body.no-padding .cke_chrome,
.no-padding .md-editor {
  border: none;
}
.widget-toolbar > .smart-form {
  margin-top: 2px;
}
.widget-toolbar > .smart-form .toggle:last-child {
  font-size: 12px;
  line-height: 29px;
}
.widget-toolbar > .smart-form .radio input + i,
.widget-toolbar > .smart-form .checkbox input + i,
.widget-toolbar > .smart-form .toggle input + i {
  border-width: 1px;
  border-color: #C7C7C7 !important;
  margin-top: 1px;
  box-shadow: 0 1px 1px #FFF,0 1px 1px #858585 inset;
  -webkit-box-shadow: 0 1px 1px #FFF,0 1px 1px #858585 inset;
  -moz-box-shadow: 0 1px 1px #FFF,0 1px 1px #858585 inset;
}
/*
	 * WELL WIDGET
	 */
.jarviswidget.well {
  margin: 0 0 30px 0;
}
.jarviswidget.well > div {
  border: none !important;
  box-shadow: none !important;
  -webkit-box-shadow: none !important;
  -moz-box-shadow: none !important;
}
.jarviswidget.well header {
  display: none;
}
/*
	 * WIDGET FOOTER
	 */
.widget-footer {
  display: block;
  min-height: 32px;
  vertical-align: middle;
  position: relative;
  background-color: #F8F7F7;
  padding: 5px;
  border-top: 1px solid #E4E4E4;
  text-align: right;
  margin: 0px -13px -13px;
}
.no-padding .widget-footer {
  margin: 0;
}
.widget-footer.smart-form > label {
  margin-top: 4px;
  display: block;
}
/*
	 * EDIT BOX
	 */
.jarviswidget-editbox {
  display: none;
  padding: 10px;
}
/*.jarviswidget-editbox div {
		width: 100%;
		float: left;
		margin-bottom: 0;
	}
	.jarviswidget-editbox label {
		width: 80px;
		height: 26px;
		float: left;
		line-height: 26px;
		font-weight: bold;
		margin-bottom:0;
	}
	.jarviswidget-editbox input {
		width: 200px;
		height: 24px;
		padding: 0 5px;
		border: 1px solid #666;
	}
	.jarviswidget-editbox span {
		height: 26px;
		width: 26px;
		float: left;
		margin: 0 5px 0 0;
		cursor: pointer;
	}*/
/*
	 * TIMESTAMP
	 */
.jarviswidget-timestamp {
  font-size: 12px;
  color: #868686;
  font-style: italic;
  margin: 10px 0 0;
}
/*
	 * HELPERS
	 */
.jarviswidget-placeholder {
  -moz-border-radius: 0px;
  -khtml-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-radius: 0px;
  margin-bottom: 28px;
  /* adjusted from 28px */
  padding: 0;
  -webkit-box-sizing: border-box;
  -khtml-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
/*
	 * FULL SCREEN
	 */
body.nooverflow {
  overflow: hidden;
  position: fixed;
  width: 100%;
}
#jarviswidget-fullscreen-mode {
  width: 100%;
  height: 100%;
  position: fixed;
  top: 0;
  left: 0;
  z-index: 99999;
}
#jarviswidget-fullscreen-mode .jarviswidget {
  margin: 0;
  -moz-border-radius: 0;
  -khtml-border-radius: 0;
  -webkit-border-radius: 0;
  border-radius: 0;
}
#jarviswidget-fullscreen-mode .jarviswidget > div {
  overflow-y: scroll;
  -moz-border-radius: 0;
  -khtml-border-radius: 0;
  -webkit-border-radius: 0;
  border-radius: 0;
}
#jarviswidget-fullscreen-mode > div > header {
  cursor: default;
}
/*
	 * WIDGET BODY TOOLBAR
	 */
.widget-body-toolbar,
.smart-form.widget-body-toolbar {
  display: block;
  padding: 8px 10px;
  margin: -13px -13px 13px;
  min-height: 42px;
  border-bottom: 1px solid #ccc;
  background: #fafafa;
}
.no-padding.widget-body-toolbar,
.no-padding .widget-body-toolbar,
.no-padding .smart-form.widget-body-toolbar {
  display: block;
  margin: 0px;
}
.widget-body-toolbar.smart-form .inline-group,
.smart-form .widget-body-toolbar .inline-group {
  float: left;
  margin-top: 4px;
}
.widget-body-toolbar .btn {
  vertical-align: middle;
}
.widget-body-toolbar .btn-xs {
  margin-top: 5px;
}
/*
	 * WIDGET BODY AJAX LOAD
	 */
.widget-body-ajax-loading::before {
  content: url('../../img/ajax-loader.gif');
  padding-top: 18%;
  text-align: center;
  font-weight: bold;
  font-size: 16px;
  color: #fff;
  display: block;
  background: rgba(255, 255, 255, 0.4);
  height: 100%;
  z-index: 1;
  width: 100%;
  position: absolute;
}
.widget-body-ajax-loading:hover {
  cursor: wait !important;
}
/*
	 * STYLING
	 */
.jarviswidget > header {
  color: #333;
  border: 1px solid #C2C2C2;
  background: #fafafa;
}
.jarviswidget > div {
  background-color: #fff !important;
}
.jarviswidget-editbox {
  border-bottom: 1px solid #B1B1B1;
  background-color: #fff;
  margin: -13px -13px 13px;
}
.no-padding .jarviswidget-editbox {
  margin: 0 0 10px;
}
.jarviswidget-placeholder {
  background-color: #FFC;
  border: 1px dashed #A7A7A7;
}
/*
	 * CUSTOM STYLES
	 */
/* remove colors */
.jarviswidget-remove-colors {
  color: #333 !important;
  padding: 0 !important;
  background: none !important;
}
/* magenta theme */
.jarviswidget-color-magenta > header {
  background: #6E3671;
  color: #FFF;
}
.jarviswidget-color-magenta > header > .jarviswidget-ctrls a,
.jarviswidget-color-magenta .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-magenta .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-magenta > header {
  border-color: #6E3671 !important;
}
/* pink theme */
.jarviswidget-color-pink > header {
  background: #AC5287;
  color: #FFF;
}
.jarviswidget-color-pink > header > .jarviswidget-ctrls a,
.jarviswidget-color-pink .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-pink .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-pink > header {
  border-color: #AC5287 !important;
}
/* pinkDark theme */
.jarviswidget-color-pinkDark > header {
  background: #A8829F;
  color: #FFF;
}
.jarviswidget-color-pinkDark > header > .jarviswidget-ctrls a,
.jarviswidget-color-pinkDark .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-pinkDark .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-pinkDark > header {
  border-color: #A8829F !important;
}
/* yellow theme */
.jarviswidget-color-yellow > header {
  background: #B09B5B;
  color: #FFF;
}
.jarviswidget-color-yellow > header > .jarviswidget-ctrls a,
.jarviswidget-color-yellow .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-yellow .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-yellow > header {
  border-color: #B09B5B !important;
}
/* orange theme */
.jarviswidget-color-orange > header {
  background: #C79121;
  color: #FFF;
}
.jarviswidget-color-orange > header > .jarviswidget-ctrls a,
.jarviswidget-color-orange .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-orange .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-orange > header {
  border-color: #C79121 !important;
}
/* orangeDark theme */
.jarviswidget-color-orangeDark > header {
  background: #A57225;
  color: #FFF;
}
.jarviswidget-color-orangeDark > header > .jarviswidget-ctrls a,
.jarviswidget-color-orangeDark .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-orangeDark .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-orangeDark > header {
  border-color: #A57225 !important;
}
/* darken theme */
.jarviswidget-color-darken > header {
  background: #404040;
  color: #FFF;
}
.jarviswidget-color-darken > header > .jarviswidget-ctrls a,
.jarviswidget-color-darken .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-darken .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-darken > header {
  border-color: #404040 !important;
}
/* purple theme */
.jarviswidget-color-purple > header {
  background: #65596B;
  color: #FFF;
}
.jarviswidget-color-purple > header > .jarviswidget-ctrls a,
.jarviswidget-color-purple .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-purple .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-purple > header {
  border-color: #65596B !important;
}
/* teal theme */
.jarviswidget-color-teal > header {
  background: #568A89;
  color: #FFF;
}
.jarviswidget-color-teal > header > .jarviswidget-ctrls a,
.jarviswidget-color-teal .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-teal .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-teal > header {
  border-color: #568A89 !important;
}
/* teal theme */
.jarviswidget-color-blueDark > header {
  background: #4C4F53;
  color: #FFF;
}
.jarviswidget-color-blueDark > header > .jarviswidget-ctrls a,
.jarviswidget-color-blueDark .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-blueDark .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-blueDark > header {
  border-color: #4C4F53 !important;
}
/* blue theme */
.jarviswidget-color-blue > header {
  background: #60747C;
  color: #FFF;
}
.jarviswidget-color-blue > header > .jarviswidget-ctrls a,
.jarviswidget-color-blue .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-blue .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-blue > header {
  border-color: #60747C !important;
}
/* blueLight theme */
.jarviswidget-color-blueLight > header {
  background: #CCDADF;
  color: #2b363c;
}
.jarviswidget-color-blueLight > header > .jarviswidget-ctrls a,
.jarviswidget-color-blueLight .nav-tabs li:not(.active) a {
  color: #2b363c !important;
}
.jarviswidget-color-blueLight .nav-tabs li a:hover {
  color: #2b363c !important;
}
.jarviswidget-color-blueLight > header {
  border-color: #92A2A8 !important;
}
/* red theme */
.jarviswidget-color-red > header {
  background: #931313;
  color: #FFF;
}
.jarviswidget-color-red > header > .jarviswidget-ctrls a,
.jarviswidget-color-red .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-red .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-red > header {
  border-color: #931313 !important;
}
/* redLight theme */
.jarviswidget-color-redLight > header {
  background: #A65858;
  color: #FFF;
}
.jarviswidget-color-redLight > header > .jarviswidget-ctrls a,
.jarviswidget-color-redLight .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-redLight .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-redLight > header {
  border-color: #A65858 !important;
}
/* white theme */
.jarviswidget-color-white > header {
  background: #fff;
  color: #838383;
}
.jarviswidget-color-white > header > .jarviswidget-ctrls a,
.jarviswidget-color-white .nav-tabs li:not(.active) a {
  color: #838383 !important;
}
.jarviswidget-color-white .nav-tabs li a:hover {
  color: #838383 !important;
}
.jarviswidget-color-white > header {
  border-color: #C8C8C8 !important;
}
/* greenDark theme */
.jarviswidget-color-greenDark > header {
  background: #496949;
  color: #FFF;
}
.jarviswidget-color-greenDark > header > .jarviswidget-ctrls a,
.jarviswidget-color-greenDark .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-greenDark .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-greenDark > header {
  border-color: #638167 !important;
}
/* green theme */
.jarviswidget-color-green > header {
  background: #356E35;
  color: #FFF;
}
.jarviswidget-color-green > header > .jarviswidget-ctrls a,
.jarviswidget-color-green .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-green .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-green > header {
  border-color: #638167 !important;
}
/* greenLight theme */
.jarviswidget-color-greenLight > header {
  background: #71843F;
  color: #FFF;
}
.jarviswidget-color-greenLight > header > .jarviswidget-ctrls a,
.jarviswidget-color-greenLight .nav-tabs li:not(.active) a {
  color: #fff !important;
}
.jarviswidget-color-greenLight .nav-tabs li a:hover {
  color: #333 !important;
}
.jarviswidget-color-greenLight > header {
  border-color: #638167 !important;
}
/* 
	 * WIDGET COLOR DROPDOWN
	 * 
	 */
.color-select {
  list-style: none;
  margin: 0;
  padding: 4px;
  min-width: 166px;
  max-width: 156px;
  right: -3px;
}
.color-select li {
  display: block;
  margin: 2px;
  float: left;
}
.color-select li span,
.color-box {
  display: block;
  width: 22px;
  height: 22px;
  padding: 0;
  background: #333;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  border: 1px solid rgba(0, 0, 0, 0.1);
  cursor: pointer;
}
.color-select li span:hover {
  border: 3px solid rgba(0, 0, 0, 0.2);
}
.color-box {
  position: relative;
  vertical-align: middle;
  border: 1px solid rgba(255, 255, 255, 0.3) !important;
  outline: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(255, 255, 255, 0.3) !important;
}
.color-box:hover,
.open .color-box {
  outline: 1px solid rgba(0, 0, 0, 0.1) !important;
}
.color-box:hover {
  -webkit-transform: scale(1.07);
  -moz-transform: scale(1.07);
}
.color-box:active {
  top: 1px;
  left: 1px;
}
.widget-toolbar > .color-box {
  margin-top: 7px;
  width: 18px;
  height: 18px;
  outline: 1px solid rgba(0, 0, 0, 0.2);
}
.widget-toolbar > .color-box:hover,
.widget-toolbar > .color-box:active,
.widget-toolbar > .color-box:focus {
  outline: 1px solid rgba(0, 0, 0, 0.25) !important;
}
.widget-toolbar .dropdown-menu.color-select {
  right: -1px;
}
/*
	 * ICONS
	 */
.jarviswidget-ctrls a {
  text-decoration: none;
  font-size: 14px;
  text-align: center;
  display: inline-block;
  line-height: 32px;
  padding: 0;
  margin: 0;
  color: #333;
}
/*
	 * RTL - SUPPORT
	 */
.rtl .jarviswidget > header {
  padding: 0 7px 0 0;
}
.rtl .jarviswidget > header h2 {
  float: right;
  text-align: right;
}
.rtl .jarviswidget > header .jarviswidget-icon {
  float: right;
  margin: 12px 0 0 7px;
}
.rtl .jarviswidget-ctrls {
  float: left;
  padding: 10px 0 0 3px;
  margin: 0;
}
.rtl .jarviswidget-ctrls .button-icon {
  margin: 0 0 5px 5px;
}
.rtl .jarviswidget-loader {
  float: left;
}
/*
	 * CLEARFIX
	 */
.jarviswidget:before,
.jarviswidget:after,
.jarviswidget > div:before,
.jarviswidget > div:after,
.inner-spacer:before,
.inner-spacer:after,
.jarviswidget-editbox:before,
.jarviswidget-editbox:after,
.clearfix:before,
.clearfix:after {
  content: "\0020";
  display: block;
  height: 0;
  overflow: hidden;
  font-size: 0;
  line-height: 0;
  visibility: hidden;
}
.jarviswidget:after,
.jarviswidget > div:after,
.inner-spacer:after,
.jarviswidget-editbox:after,
.clearfix:after {
  clear: both;
}
.jarviswidget,
.jarviswidget > div,
.inner-spacer:after,
.jarviswidget-editbox,
.clearfix {
  zoom: 1;
  /*IE*/
}
/*
	 * WIDGET TOOLBARS
	 */
.widget-toolbar {
  display: inline-block;
  float: right;
  width: auto;
  height: 32px;
  line-height: 32px;
  position: relative;
  border-left: 1px solid rgba(0, 0, 0, 0.09);
  cursor: pointer;
  padding: 0 8px;
  text-align: center;
}
.widget-toolbar > :first-child {
  text-align: left;
}
/*
	 * WIDGET TOOLBAR COMPONENTS
	 */
/*
		 * TABS
		 */
.jarviswidget header .nav-tabs {
  border-bottom-color: transparent;
}
.jarviswidget header .nav-tabs > li > a {
  border-radius: 0px;
  border: none;
  padding: 7px 15px 6px;
}
.jarviswidget header .nav-tabs > li.active > a,
.jarviswidget header .nav-tabs > li.active > a:hover,
.jarviswidget header .nav-tabs > li.active > a:focus {
  color: #555;
  background-color: #FFF ;
  border: 1px solid #C2C2C2;
  border-bottom-color: transparent;
  border-top: none;
  cursor: default;
}
.jarviswidget header:first-child .nav-tabs {
  float: left;
}
.jarviswidget header:first-child .nav-tabs li {
  padding-left: 0;
}
.jarviswidget header:first-child .nav-tabs li a {
  color: #333;
}
.jarviswidget header:first-child .nav-tabs.pull-right li:last-child a {
  margin-right: 0px !important;
  border-right: none !important;
}
/*
		 * PILLS
		 */
.jarviswidget header .nav-pills {
  margin: 3px;
}
.jarviswidget header .nav-pills > li > a {
  padding: 3px 5px 4px;
}
/*
		 * BTN GROUPS
		 */
.widget-toolbar .btn-group {
  margin-top: -3px;
}
/*
		 * BTNs
		 */
.widget-toolbar > .btn {
  margin-top: -3px;
  font-size: 12px !important;
  padding: 1px 8px !important;
}
/*
		 * INPUT
		 */
.widget-toolbar .smart-form label.checkbox,
.widget-toolbar .smart-form label.radio {
  line-height: 29px;
}
/*
		 * LABELS
		 */
.widget-toolbar > .label {
  vertical-align: middle;
  margin-top: -3px;
  display: inline-block;
  text-align: center;
  font-size: 12px;
  padding: 4px 7px;
}
/*
		 * BADGE
		 */
.widget-toolbar > .badge {
  padding: 5px 5px;
  font-size: 14px;
  border-radius: 50%;
  font-weight: normal;
  min-width: 24px;
  text-align: center !important;
}
/*
		 * PROGRESS BARS
		 */
.widget-toolbar .progress {
  width: 130px;
  margin: 7px 0 0 0;
  height: 18px !important;
  font-size: 12px;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #d1d1d1 inset;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #d1d1d1 inset;
  -moz-box-shadow: 0 1px 0 transparent, 0 0 0 1px #d1d1d1 inset;
}
.widget-toolbar .progress-bar {
  font-size: 12px;
}
/*
		 * PAGINATION
		 */
.widget-toolbar .pagination {
  margin: 4px 0;
}
.widget-toolbar .pagination > li > a {
  padding: 2px 7px;
}
/*
		 * TEXT INPUT
		 */
.widget-toolbar .widget-text-input {
  max-width: 220px;
}
.widget-toolbar input[type='text'] {
  height: 28px !important;
  margin-top: 2px;
}
.widget-toolbar.smart-form .icon-append,
.widget-toolbar.smart-form .icon-prepend,
.widget-toolbar .smart-form .icon-append,
.widget-toolbar .smart-form .icon-prepend {
  top: 3px !important;
}
/*
	 * SMART FORMS
	 */
.smart-form *,
.smart-form *:after,
.smart-form *:before {
  margin: 0;
  padding: 0;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
}
.smart-form .btn {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.smart-form .radio + .radio,
.smart-form .checkbox + .checkbox {
  margin-top: 0;
}
.smart-form footer .btn {
  float: right;
  height: 31px;
  margin: 10px 0 0 5px;
  padding: 0 22px;
  font: 300 15px/29px 'Open Sans', Helvetica, Arial, sans-serif;
  cursor: pointer;
}
.smart-form legend {
  padding-top: 15px;
}
.smart-form {
  margin: 0;
  outline: none;
  color: #666;
  position: relative;
}
.smart-form header {
  display: block;
  padding: 8px 0;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.2);
  background: white;
  font-size: 16px;
  font-weight: 300;
  color: #232323;
  margin: 10px 14px 0;
}
.smart-form fieldset {
  display: block;
  padding: 25px 14px 5px;
  border: none;
  background: rgba(255, 255, 255, 0.9);
  position: relative;
}
.smart-form fieldset + fieldset {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
}
.smart-form section {
  margin-bottom: 15px;
  position: relative;
}
.smart-form footer {
  display: block;
  padding: 7px 14px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
}
.smart-form footer:after {
  content: '';
  display: table;
  clear: both;
}
.smart-form .label {
  display: block;
  margin-bottom: 6px;
  line-height: 19px;
  font-weight: 400;
  font-size: 13px;
  color: #333;
  text-align: left;
}
.smart-form .label.col {
  margin: 0;
  padding-top: 7px;
}
.smart-form .note,
.note {
  margin-top: 6px;
  padding: 0 1px;
  font-size: 11px;
  line-height: 15px;
  color: #999;
}
.note {
  margin-top: 2px;
  font-size: 10px;
}
.smart-form .note a {
  font-size: 13px;
}
.smart-form .input,
.smart-form .select,
.smart-form .textarea,
.smart-form .radio,
.smart-form .checkbox,
.smart-form .toggle,
.smart-form .button {
  position: relative;
  display: block;
  font-weight: 400;
}
.smart-form .input input,
.smart-form .select select,
.smart-form .textarea textarea {
  display: block;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  width: 100%;
  height: 32px;
  padding: 8px 10px;
  outline: none;
  border-width: 1px;
  border-style: solid;
  border-radius: 0;
  background: #fff;
  font: 13px/16px 'Open Sans', Helvetica, Arial, sans-serif;
  color: #404040;
  appearance: normal;
  -moz-appearance: none;
  -webkit-appearance: none;
}
/*
		 * File inputs
		 */
.smart-form .input-file .button {
  position: absolute;
  top: 4px;
  right: 4px;
  float: none;
  height: 22px;
  margin: 0;
  padding: 0 14px;
  font-size: 13px;
  line-height: 22px;
}
.smart-form .input-file .button:hover {
  box-shadow: none;
}
.smart-form .input-file .button input {
  position: absolute;
  top: 0;
  right: 0;
  padding: 0;
  font-size: 30px;
  cursor: pointer;
  opacity: 0;
}
/*
		 * Selects
		 */
.smart-form .select i {
  position: absolute;
  top: 10px;
  right: 11px;
  width: 5px;
  height: 11px;
  background: white;
  box-shadow: 0 0 0 9px white;
}
.smart-form .select i:after,
.smart-form .select i:before {
  content: '';
  position: absolute;
  right: 0;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.smart-form .select i:after {
  bottom: 0;
  border-top: 4px solid #404040;
}
.smart-form .select i:before {
  top: 0;
  border-bottom: 4px solid #404040;
}
.smart-form .select-multiple select {
  height: auto;
}
/*
		 * Text areas
		 */
.smart-form .textarea textarea {
  height: auto;
  resize: none;
}
.smart-form .textarea-resizable textarea {
  resize: vertical;
}
.smart-form .textarea-expandable textarea {
  height: 31px;
}
.smart-form .textarea-expandable textarea:focus {
  height: auto;
}
/*
		 * Radio and checkboxes
		 */
.smart-form .radio,
.smart-form .checkbox {
  margin-bottom: 4px;
  padding-left: 25px;
  font-size: 15px;
  line-height: 25px;
  color: #404040;
  cursor: pointer;
  font-size: 13px;
}
.smart-form .radio:last-child,
.smart-form .checkbox:last-child {
  margin-bottom: 0;
}
.smart-form .radio input,
.smart-form .checkbox input {
  position: absolute;
  left: -9999px;
}
.smart-form .radio i,
.smart-form .checkbox i {
  position: absolute;
  top: 3px;
  left: 0;
  display: block;
  width: 17px;
  height: 17px;
  outline: none;
  border-width: 1px;
  border-style: solid;
  background: #FFF;
}
.smart-form .radio i {
  border-radius: 50%;
}
.smart-form .radio input + i:after,
.smart-form .checkbox input + i:after {
  position: absolute;
  opacity: 0;
  transition: opacity 0.1s;
  -o-transition: opacity 0.1s;
  -ms-transition: opacity 0.1s;
  -moz-transition: opacity 0.1s;
  -webkit-transition: opacity 0.1s;
}
.smart-form .radio input + i:after {
  content: '';
  top: 4px;
  left: 4px;
  width: 9px;
  height: 9px;
  border-radius: 50%;
}
.smart-form .checkbox input + i:after {
  content: '\f00c';
  top: -1px;
  left: 1px;
  width: 15px;
  height: 15px;
  font: normal 16px/19px FontAwesome;
  text-align: center;
}
.smart-form .checkbox input:checked:hover + i:after {
  content: '\f00d';
}
.smart-form .checkbox input:checked:disabled:hover + i:after {
  content: '\f00c';
}
.smart-form .radio input:checked + i:after,
.smart-form .checkbox input:checked + i:after {
  opacity: 1;
}
.smart-form .inline-group {
  margin: 0 -30px -4px 0;
}
.smart-form .inline-group:after {
  content: '';
  display: table;
  clear: both;
}
.smart-form .inline-group .radio,
.smart-form .inline-group .checkbox {
  float: left;
  margin-right: 30px;
}
.smart-form .inline-group .radio:last-child,
.smart-form .inline-group .checkbox:last-child {
  margin-bottom: 4px;
}
/*
		 * toggles
		 */
.smart-form .toggle {
  margin-bottom: 4px;
  padding-right: 61px;
  font-size: 15px;
  line-height: 25px;
  color: #404040;
  cursor: pointer;
}
.smart-form .toggle:last-child {
  margin-bottom: 0;
}
.smart-form .toggle input {
  position: absolute;
  left: -9999px;
}
.smart-form .toggle i {
  content: '';
  position: absolute;
  top: 4px;
  right: 0;
  display: block;
  width: 49px;
  height: 17px;
  border-width: 1px;
  border-style: solid;
  border-radius: 12px;
  background: #fff;
}
.smart-form .toggle i:after {
  content: attr(data-swchoff-text);
  position: absolute;
  top: 2px;
  right: 8px;
  left: 8px;
  font-style: normal;
  font-size: 9px;
  line-height: 13px;
  font-weight: 700;
  text-align: left;
  color: #5f5f5f;
}
.smart-form .toggle i:before {
  content: '';
  position: absolute;
  z-index: 1;
  top: 4px;
  right: 4px;
  display: block;
  width: 9px;
  height: 9px;
  border-radius: 50%;
  opacity: 1;
  transition: right 0.2s;
  -o-transition: right 0.2s;
  -ms-transition: right 0.2s;
  -moz-transition: right 0.2s;
  -webkit-transition: right 0.2s;
}
.smart-form .toggle input:checked + i:after {
  content: attr(data-swchon-text);
  text-align: right;
}
.smart-form .toggle input:checked + i:before {
  right: 36px;
}
/*
		 * ratings
		 */
.smart-form .rating {
  margin-bottom: 4px;
  font-size: 13px;
  line-height: 25px;
  color: #404040;
}
.smart-form .rating:last-child {
  margin-bottom: 0;
}
.smart-form .rating input {
  position: absolute;
  left: -9999px;
}
.smart-form .rating label {
  display: block;
  float: right;
  height: 17px;
  margin-top: 5px;
  padding: 0 2px;
  font-size: 17px;
  line-height: 17px;
  cursor: pointer;
}
/*
		 * buttons
		 */
.smart-form .button {
  float: right;
  height: 31px;
  overflow: hidden;
  margin: 10px 0 0 5px;
  padding: 0 25px;
  outline: none;
  border: 0;
  font: 300 15px/31px 'Open Sans', Helvetica, Arial, sans-serif;
  text-decoration: none;
  color: #fff;
  cursor: pointer;
}
.smart-form .icon-append,
.smart-form .icon-prepend {
  position: absolute;
  top: 5px;
  width: 22px;
  height: 22px;
  font-size: 14px;
  line-height: 22px;
  text-align: center;
}
.smart-form .icon-append {
  right: 5px;
  padding-left: 3px;
  border-left-width: 1px;
  border-left-style: solid;
}
.smart-form .icon-prepend {
  left: 5px;
  padding-right: 3px;
  border-right-width: 1px;
  border-right-style: solid;
}
.smart-form .input .icon-prepend + input,
.smart-form .textarea .icon-prepend + textarea {
  padding-left: 37px;
}
.smart-form .input .icon-append + input,
.smart-form .textarea .icon-append + textarea {
  padding-right: 37px;
}
.smart-form .input .icon-prepend + .icon-append + input,
.smart-form .textarea .icon-prepend + .icon-append + textarea {
  padding-left: 37px;
}
/*
		 * grid
		 */
.smart-form .row {
  margin: 0 -15px;
}
.smart-form .row:after {
  content: '';
  display: table;
  clear: both;
}
.smart-form .col {
  float: left;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.smart-form .col-1 {
  width: 8.33%;
}
.smart-form .col-2 {
  width: 16.66%;
}
.smart-form .col-3 {
  width: 25%;
}
.smart-form .col-4 {
  width: 33.33%;
}
.smart-form .col-5 {
  width: 41.66%;
}
.smart-form .col-6 {
  width: 50%;
}
.smart-form .col-8 {
  width: 66.67%;
}
.smart-form .col-9 {
  width: 75%;
}
.smart-form .col-10 {
  width: 83.33%;
}
@media screen and (max-width: 600px) {
  .smart-form .col {
    float: none;
    width: 100%;
  }
}
/*
		 * tooltips
		 */
.smart-form .select select {
  padding: 5px;
}
.smart-form .tooltip {
  position: absolute;
  z-index: 99999;
  left: -9999px;
  padding: 2px 8px 3px;
  font-size: 11px;
  line-height: 16px;
  font-weight: 400;
  background: rgba(0, 0, 0, 0.9);
  color: #fff;
  opacity: 0;
  transition: margin 0.3s, opacity 0.3s;
  -o-transition: margin 0.3s, opacity 0.3s;
  -ms-transition: margin 0.3s, opacity 0.3s;
  -moz-transition: margin 0.3s, opacity 0.3s;
  -webkit-transition: margin 0.3s, opacity 0.3s;
}
.smart-form .tooltip:after {
  content: '';
  position: absolute;
}
.smart-form .input input:focus + .tooltip,
.smart-form .textarea textarea:focus + .tooltip {
  opacity: 1;
}
.smart-form .tooltip-top-right {
  bottom: 100%;
  margin-bottom: 15px;
}
.smart-form .tooltip-top-right:after {
  top: 100%;
  right: 11px;
  border-top: 4px solid rgba(0, 0, 0, 0.9);
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.smart-form .input input:focus + .tooltip-top-right,
.smart-form .textarea textarea:focus + .tooltip-top-right {
  right: 0;
  left: auto;
  margin-bottom: 5px;
}
.smart-form .tooltip-top-left {
  bottom: 100%;
  margin-bottom: 15px;
}
.smart-form .tooltip-top-left:after {
  top: 100%;
  left: 11px;
  border-top: 4px solid rgba(0, 0, 0, 0.9);
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.smart-form .input input:focus + .tooltip-top-left,
.smart-form .textarea textarea:focus + .tooltip-top-left {
  right: auto;
  left: 0;
  margin-bottom: 5px;
}
.smart-form .tooltip-right {
  top: 4px;
  white-space: nowrap;
  margin-left: 15px;
}
.smart-form .tooltip-right:after {
  top: 6px;
  right: 100%;
  border-top: 4px solid transparent;
  border-right: 4px solid rgba(0, 0, 0, 0.9);
  border-bottom: 4px solid transparent;
}
.smart-form .input input:focus + .tooltip-right,
.smart-form .textarea textarea:focus + .tooltip-right {
  left: 100%;
  margin-left: 5px;
}
.smart-form .tooltip-left {
  top: 4px;
  white-space: nowrap;
  margin-right: 15px;
}
.smart-form .tooltip-left:after {
  top: 6px;
  left: 100%;
  border-top: 4px solid transparent;
  border-bottom: 4px solid transparent;
  border-left: 4px solid rgba(0, 0, 0, 0.9);
}
.smart-form .input input:focus + .tooltip-left,
.smart-form .textarea textarea:focus + .tooltip-left {
  right: 100%;
  left: auto;
  margin-right: 5px;
}
.smart-form .tooltip-bottom-right {
  top: 100%;
  margin-top: 15px;
}
.smart-form .tooltip-bottom-right:after {
  bottom: 100%;
  right: 11px;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(0, 0, 0, 0.9);
  border-left: 4px solid transparent;
}
.smart-form .input input:focus + .tooltip-bottom-right,
.smart-form .textarea textarea:focus + .tooltip-bottom-right {
  right: 0;
  left: auto;
  margin-top: 5px;
}
.smart-form .tooltip-bottom-left {
  top: 100%;
  margin-top: 15px;
}
.smart-form .tooltip-bottom-left:after {
  bottom: 100%;
  left: 11px;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(0, 0, 0, 0.9);
  border-left: 4px solid transparent;
}
.smart-form .input input:focus + .tooltip-bottom-left,
.smart-form .textarea textarea:focus + .tooltip-bottom-left {
  right: auto;
  left: 0;
  margin-top: 5px;
}
/*
		 * normal state
		 */
.smart-form .input input,
.smart-form .select select,
.smart-form .textarea textarea,
.smart-form .radio i,
.smart-form .checkbox i,
.smart-form .toggle i,
.smart-form .icon-append,
.smart-form .icon-prepend {
  border-color: #BDBDBD;
  transition: border-color 0.3s;
  -o-transition: border-color 0.3s;
  -ms-transition: border-color 0.3s;
  -moz-transition: border-color 0.3s;
  -webkit-transition: border-color 0.3s;
}
.smart-form .toggle i:before {
  background-color: #3276B1;
}
.smart-form .rating label {
  color: #ccc;
  transition: color 0.3s;
  -o-transition: color 0.3s;
  -ms-transition: color 0.3s;
  -moz-transition: color 0.3s;
  -webkit-transition: color 0.3s;
}
.smart-form .button {
  background-color: #3276B1;
  opacity: 0.8;
  transition: opacity 0.2s;
  -o-transition: opacity 0.2s;
  -ms-transition: opacity 0.2s;
  -moz-transition: opacity 0.2s;
  -webkit-transition: opacity 0.2s;
}
.smart-form .button.button-secondary {
  background-color: #b3b3b3;
}
.smart-form .icon-append,
.smart-form .icon-prepend {
  color: #A2A2A2;
}
/*
		 * hover state
		 */
.smart-form .input:hover input,
.smart-form .select:hover select,
.smart-form .textarea:hover textarea,
.smart-form .radio:hover i,
.smart-form .checkbox:hover i,
.smart-form .toggle:hover i {
  border-color: #5D98CC;
}
.smart-form .rating input + label:hover,
.smart-form .rating input + label:hover ~ label {
  color: #3276B1;
}
.smart-form .button:hover {
  opacity: 1;
}
.smart-form .radio:hover i,
.smart-form .checkbox:hover i,
.smart-form .toggle:hover i {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
}
/*
		 * radio/toggle/checkbox active state
		 */
.smart-form .radio:active i,
.smart-form .checkbox:active i,
.smart-form .toggle:active i {
  background: #F0F0F0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
}
/*
		 * focus state
		 */
.smart-form .input input:focus,
.smart-form .select select:focus,
.smart-form .textarea textarea:focus,
.smart-form .radio input:focus + i,
.smart-form .checkbox input:focus + i,
.smart-form .toggle input:focus + i {
  border-color: #3276B1;
}
/*
		 * checked state
		 */
.smart-form .radio input + i:after {
  background-color: #3276B1;
}
.smart-form .checkbox input + i:after {
  color: #3276B1;
}
.smart-form .radio input:checked + i,
.smart-form .checkbox input:checked + i,
.smart-form .toggle input:checked + i {
  border-color: #3276B1;
}
.smart-form .rating input:checked ~ label {
  color: #3276B1;
}
/*
		 * error state
		 */
.smart-form .state-error input,
.smart-form .state-error select,
.smart-form .state-error textarea,
.smart-form .radio.state-error i,
.smart-form .checkbox.state-error i,
.smart-form .toggle.state-error i {
  background: #fff0f0;
  border-color: #A90329;
}
.smart-form .toggle.state-error input:checked + i {
  background: #fff0f0;
}
.smart-form .state-error + em {
  display: block;
  margin-top: 6px;
  padding: 0 1px;
  font-style: normal;
  font-size: 11px;
  line-height: 15px;
  color: #D56161;
}
.smart-form .rating.state-error + em {
  margin-top: -4px;
  margin-bottom: 4px;
}
.smart-form .state-error select + i {
  background: #FFF0F0;
  box-shadow: 0 0 0 9px #FFF0F0;
}
.state-error .icon-append,
.state-error .icon-prepend {
  color: #ed1c24;
}
/*
		 * success state
		 */
.smart-form .state-success input,
.smart-form .state-success select,
.smart-form .state-success textarea,
.smart-form .radio.state-success i,
.smart-form .checkbox.state-success i,
.smart-form .toggle.state-success i {
  background: #f0fff0;
  border-color: #7DC27D;
}
.smart-form .toggle.state-success input:checked + i {
  background: #f0fff0;
}
.smart-form .note-success {
  color: #6fb679;
}
.smart-form .state-success select + i {
  background: honeyDew;
  box-shadow: 0 0 0 9px honeyDew;
}
/*
		 * disable state
		 */
.smart-form .input.state-disabled input,
.smart-form .select.state-disabled,
.smart-form .textarea.state-disabled,
.smart-form .radio.state-disabled,
.smart-form .checkbox.state-disabled,
.smart-form .toggle.state-disabled,
.smart-form .button.state-disabled {
  cursor: default !important;
  opacity: 0.6 !important;
}
.smart-form .input.state-disabled:hover input,
.smart-form .select.state-disabled:hover select,
.smart-form .textarea.state-disabled:hover textarea,
.smart-form .radio.state-disabled:hover i,
.smart-form .checkbox.state-disabled:hover i,
.smart-form .toggle.state-disabled:hover i {
  border-color: #e5e5e5 !important;
}
.smart-form .state-disabled.radio input:checked + i,
.smart-form .state-disabled.checkbox input:checked + i,
.smart-form .state-disabled.toggle input:checked + i,
.smart-form .state-disabled.checkbox input + i:after,
.smart-form .state-disabled.radio input + i:after {
  border-color: #e5e5e5 !important;
  color: #333 !important;
}
.smart-form .state-disabled.radio input + i:after {
  background-color: #333;
}
/*
		 * submit state
		 */
.smart-form .message {
  display: none;
  color: #6fb679;
}
.smart-form .message i {
  display: block;
  margin: 0 auto 20px;
  width: 81px;
  height: 81px;
  border: 1px solid #6fb679;
  border-radius: 50%;
  font-size: 30px;
  line-height: 81px;
}
.smart-form.submited fieldset,
.smart-form.submited footer {
  display: none;
}
.smart-form.submited .message {
  display: block;
  padding: 25px 30px;
  background: rgba(255, 255, 255, 0.9);
  font: 300 18px/27px 'Open Sans', Helvetica, Arial, sans-serif;
  text-align: center;
}
/*
		 * JQUERY UI UPDATE
		 */
.smart-form .ui-widget-content .ui-spinner-input {
  margin: 0px;
  border: 0px;
  box-shadow: none !important;
  height: 29px;
}
/*
		 * date picker
		
		.ui-datepicker {
			display: none;
			padding: 10px 12px;
			background: #fff;
			box-shadow: 0 0 10px rgba(0,0,0,.3);
			font: 13px/1.55 'Open Sans', Helvetica, Arial, sans-serif;
			text-align: center;
			color: #666;
		}
		.ui-datepicker a {
			color: #404040;
		}
		.ui-datepicker-header {
			position: relative;
			margin: -10px -12px 10px;
			padding: 10px;
			border-bottom: 1px solid rgba(0,0,0,.1);
			font-size: 15px;
			line-height: 27px;
		}
		.ui-datepicker-prev, .ui-datepicker-next {
			position: absolute;
			top: 0;
			display: block;
			width: 47px;
			height: 47px;
			font-size: 15px;
			line-height: 47px;
			text-decoration: none;
			cursor: pointer;
		}
		.ui-datepicker-prev {
			left: 0;
		}
		.ui-datepicker-next {
			right: 0;
		}
		.ui-datepicker-calendar {
			border-collapse: collapse;
			font-size: 13px;
			line-height: 27px;
		}
		.ui-datepicker-calendar th {
			color: #999;
		}
		.ui-datepicker-calendar a, .ui-datepicker-calendar span {
			display: block;
			width: 31px;
			margin: auto;
			text-decoration: none;
			color: #404040;
			text-align:center;
		}
		.ui-datepicker-unselectable.ui-state-disabled {
			
		}
		.ui-datepicker-unselectable.ui-state-disabled > span {
			color:#bfbfbf;
			background-color: #FAFCFD;
		}
		
		.ui-datepicker-calendar a:hover {
			background: #3276B1;
			color:#fff;
		}
		.ui-datepicker-calendar span {
			
		}
		.ui-datepicker-today a {
			font-weight: 700;
		}
		.ui-datepicker-calendar .ui-state-active {
			background: rgba(0,0,0,.05);
			cursor: default;
		}
		.ui-datepicker-inline {
			border: 2px solid #e5e5e5;
			background: #fff;
			box-shadow: none;
		}
		.ui-datepicker-inline .ui-datepicker-calendar {
			width: 100%;
		} */
/*
		 * model
		 */
.smart-form-modal {
  position: fixed;
  z-index: 1;
  display: none;
  width: 400px;
}
.smart-form-modal-overlay {
  position: fixed;
  top: 0;
  left: 0;
  display: none;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.7);
}
/*
		 * Time picker
		 */
.ui-timepicker-div .ui-widget-header {
  margin-bottom: 8px;
}
.ui-timepicker-div dl {
  text-align: left;
}
.ui-timepicker-div dl dt {
  float: left;
  clear: left;
  padding: 0 0 0 5px;
}
.ui-timepicker-div dl dd {
  margin: 17px 10px 12px 40%;
}
.ui-timepicker-div td {
  font-size: 90%;
}
.ui-tpicker-grid-label {
  background: none;
  border: none;
  margin: 0;
  padding: 0;
}
.ui-timepicker-rtl {
  direction: rtl;
}
.ui-timepicker-rtl dl {
  text-align: right;
  padding: 0 5px 0 0;
}
.ui-timepicker-rtl dl dt {
  float: right;
  clear: right;
}
.ui-timepicker-rtl dl dd {
  margin: 0 40% 10px 10px;
}
/*
		 * Large, small and extra small fields
		 */
.smart-form input.input-lg {
  height: 44px;
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.33;
}
.smart-form input.input-sm {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
}
.smart-form input.input-xs {
  height: 24px;
  padding: 2px 10px;
  font-size: 11px;
  line-height: 1.5;
}
/* SELECT */
.smart-form select.input-sm {
  height: 30px;
  line-height: 15px;
  font-size: 12px;
}
.smart-form select.input-sm + i {
  height: 10px;
}
.smart-form select.input-lg {
  height: 44px;
  line-height: 22px;
  font-size: 17px;
}
.smart-form select.input-lg + i {
  height: 11px;
  top: 17px;
}
/*! X-editable - v1.5.0 
* In-place editing with Twitter Bootstrap, jQuery UI or pure jQuery
* http://github.com/vitalets/x-editable
* Copyright (c) 2013 Vitaliy Potapov; Licensed MIT */
.editableform {
  margin-bottom: 0;
  /* overwrites bootstrap margin */
}
.editableform .control-group {
  margin-bottom: 0;
  /* overwrites bootstrap margin */
  white-space: nowrap;
  /* prevent wrapping buttons on new line */
}
.editable-buttons {
  display: inline-block;
  /* should be inline to take effect of parent's white-space: nowrap */
  vertical-align: top;
  margin-left: 7px;
  /* inline-block emulation for IE7*/
  zoom: 1;
  *display: inline;
}
.editable-buttons.editable-buttons-bottom {
  display: block;
  margin-top: 7px;
  margin-left: 0;
}
.editable-input {
  vertical-align: top;
  display: inline-block;
  /* should be inline to take effect of parent's white-space: nowrap */
  width: auto;
  /* bootstrap-responsive has width: 100% that breakes layout */
  white-space: normal;
  /* reset white-space decalred in parent*/
  /* display-inline emulation for IE7*/
  zoom: 1;
  *display: inline;
}
.editable-buttons .editable-cancel {
  margin-left: 7px;
}
/*for jquery-ui buttons need set height to look more pretty*/
.editable-buttons button.ui-button-icon-only {
  height: 24px;
  width: 30px;
}
.editableform-loading {
  background: url('../../img/loading.gif') center center no-repeat;
  height: 25px;
  width: auto;
  min-width: 25px;
}
.editable-inline .editableform-loading {
  background-position: left 5px;
}
.editable-error-block {
  max-width: 300px;
  margin: 5px 0 0 0;
  width: auto;
  white-space: normal;
}
/*add padding for jquery ui*/
.editable-error-block.ui-state-error {
  padding: 3px;
}
.editable-error {
  color: red;
}
/* ---- For specific types ---- */
.editableform .editable-date {
  padding: 0;
  margin: 0;
  float: left;
}
/* move datepicker icon to center of add-on button. See https://github.com/vitalets/x-editable/issues/183 */
.editable-inline .add-on .icon-th {
  margin-top: 3px;
  margin-left: 1px;
}
/* checklist vertical alignment */
.editable-checklist label input[type="checkbox"],
.editable-checklist label span {
  vertical-align: middle;
  margin: 0;
}
.editable-checklist label {
  white-space: nowrap;
}
/* set exact width of textarea to fit buttons toolbar */
.editable-wysihtml5 {
  width: 566px;
  height: 250px;
}
/* clear button shown as link in date inputs */
.editable-clear {
  clear: both;
  font-size: 0.9em;
  text-decoration: none;
  text-align: right;
}
/* IOS-style clear button for text inputs */
.editable-clear-x {
  background: url('../../img/clear.png') center center no-repeat;
  display: block;
  width: 13px;
  height: 13px;
  position: absolute;
  opacity: 0.6;
  z-index: 100;
  top: 50%;
  right: 6px;
  margin-top: -6px;
}
.editable-clear-x:hover {
  opacity: 1;
}
.editable-pre-wrapped {
  white-space: pre-wrap;
}
.editable-container.editable-popup {
  max-width: none !important;
  /* without this rule poshytip/tooltip does not stretch */
}
.editable-container.popover {
  width: auto;
  /* without this rule popover does not stretch */
}
.editable-container.editable-inline {
  display: inline-block;
  vertical-align: middle;
  width: auto;
  /* inline-block emulation for IE7*/
  zoom: 1;
  *display: inline;
}
.editable-container.ui-widget {
  font-size: inherit;
  /* jqueryui widget font 1.1em too big, overwrite it */
  z-index: 9990;
  /* should be less than select2 dropdown z-index to close dropdown first when click */
}
.editable-click,
a.editable-click,
a.editable-click:hover {
  text-decoration: none;
  border-bottom: dashed 1px #0088cc;
}
.editable-click.editable-disabled,
a.editable-click.editable-disabled,
a.editable-click.editable-disabled:hover {
  color: #585858;
  cursor: default;
  border-bottom: none;
}
.editable-empty,
.editable-empty:hover,
.editable-empty:focus {
  font-style: italic;
  color: #DD1144;
  /* border-bottom: none; */
  text-decoration: none;
}
.editable-unsaved {
  font-weight: bold;
}
.editable-unsaved:after {
  /*    content: '*'*/
}
.editable-bg-transition {
  -webkit-transition: background-color 1400ms ease-out;
  -moz-transition: background-color 1400ms ease-out;
  -o-transition: background-color 1400ms ease-out;
  -ms-transition: background-color 1400ms ease-out;
  transition: background-color 1400ms ease-out;
}
/*see https://github.com/vitalets/x-editable/issues/139 */
.form-horizontal .editable {
  padding-top: 5px;
  display: inline-block;
}
/*
 * x-editable CSS
 */
.editable-address {
  display: block;
  margin-bottom: 5px;
}
.editable-address span {
  width: 70px;
  display: inline-block;
}
/*!
 * Datepicker for Bootstrap
 *
 * Copyright 2012 Stefan Petre
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 */
.editable-input .datepicker {
  top: 0;
  left: 0;
  padding: 4px;
  /*.dow {
		border-top: 1px solid #ddd !important;
	}*/
}
.editable-input .datepicker:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 6px;
}
.editable-input .datepicker:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #ffffff;
  position: absolute;
  top: -6px;
  left: 7px;
}
.editable-input .datepicker > div {
  display: none;
}
.editable-input .datepicker table {
  width: 100%;
  min-width: 214px;
  margin: 0;
}
.editable-input .datepicker td,
.editable-input .datepicker th {
  text-align: center;
  width: 24px;
  height: 20px;
}
.editable-input .datepicker td.day:hover {
  background: #eeeeee;
  cursor: pointer;
}
.editable-input .datepicker td.day.disabled {
  color: #555555;
}
.editable-input .datepicker td.old,
.editable-input .datepicker td.new {
  color: #555555;
}
.editable-input .datepicker td.active,
.editable-input .datepicker td.active:hover {
  background: #3276b1;
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-radius: 3px;
}
.editable-input .datepicker td span {
  display: block;
  width: 47px;
  height: 54px;
  line-height: 54px;
  float: left;
  margin: 2px;
  cursor: pointer;
}
.editable-input .datepicker td span:hover {
  background: #eeeeee;
}
.editable-input .datepicker td span.active {
  background: #3276b1;
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-radius: 3px;
}
.editable-input .datepicker td span.old {
  color: #555555;
}
.editable-input .datepicker th.switch {
  width: 145px;
}
.editable-input .datepicker th.next,
.editable-input .datepicker th.prev {
  font-size: 19.5px;
}
.editable-input .datepicker thead tr:first-child th {
  cursor: pointer;
}
.editable-input .datepicker thead tr:first-child th:hover {
  background: #eeeeee;
}
.input-append.date .add-on i,
.input-prepend.date .add-on i {
  display: block;
  cursor: pointer;
  width: 16px;
  height: 16px;
}
.editable-input .datepicker .next i,
.datepicker .prev i {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 14px;
}
.editable-input .datepicker .prev i:before {
  content: "\f060";
}
.editable-input .datepicker .next i:before {
  content: "\f061";
}
/*
 * FullCalendar v1.5.4 Stylesheet
 *
 * Copyright (c) 2011 Adam Shaw
 * Dual licensed under the MIT and GPL licenses, located in
 * MIT-LICENSE.txt and GPL-LICENSE.txt respectively.
 *
 * Date: Tue Sep 4 23:38:33 2012 -0700
 *
 */
.fc {
  direction: ltr;
  text-align: left;
}
.fc table {
  border-collapse: collapse;
  border-spacing: 0;
}
html .fc,
.fc table {
  font-size: 1em;
}
.fc td,
.fc th {
  padding: 0;
  vertical-align: top;
}
/* Header
------------------------------------------------------------------------*/
.fc-header td {
  white-space: nowrap;
}
.fc-header-left {
  width: 25%;
  text-align: left;
}
.fc-header-center {
  text-align: center;
}
.fc-header-right {
  width: 25%;
  text-align: right;
}
.fc-header-title {
  display: inline-block;
  vertical-align: top;
}
.fc-header-title h2 {
  margin-top: 0;
  white-space: nowrap;
}
.fc .fc-header-space {
  padding-left: 10px;
}
.fc-header .fc-button {
  margin-bottom: 1em;
  vertical-align: top;
}
/* buttons edges butting together */
.fc-header .fc-button {
  margin-right: -1px;
}
.fc-header .fc-corner-right {
  margin-right: 1px;
  /* back to normal */
}
.fc-header .ui-corner-right {
  margin-right: 0;
  /* back to normal */
}
/* button layering (for border precedence) */
.fc-header .fc-state-hover,
.fc-header .ui-state-hover {
  z-index: 2;
}
.fc-header .fc-state-down {
  z-index: 3;
}
.fc-header .fc-state-active,
.fc-header .ui-state-active {
  z-index: 4;
}
/* Content
------------------------------------------------------------------------*/
.fc-content {
  clear: both;
}
.fc-view {
  width: 100%;
  /* needed for view switching (when view is absolute) */
  overflow: hidden;
}
/* Cell Styles
------------------------------------------------------------------------*/
.fc-widget-header,
.fc-widget-content {
  /* <td>, usually */
  border: 1px solid #ccc;
}
.fc-state-highlight {
  /* <td> today cell */
  /* TODO: add .fc-today to <th> */
  background: #ffc;
}
.fc-cell-overlay {
  /* semi-transparent rectangle while dragging */
  background: #9cf;
  opacity: .2;
  filter: alpha(opacity=20);
  /* for IE */
}
/* Buttons
------------------------------------------------------------------------*/
.fc-button {
  position: relative;
  display: inline-block;
  cursor: pointer;
}
.fc-state-default {
  /* non-theme */
  border-style: solid;
  border-width: 1px 0;
}
.fc-button-inner {
  position: relative;
  float: left;
  overflow: hidden;
}
.fc-state-default .fc-button-inner {
  /* non-theme */
  border-style: solid;
  border-width: 0 1px;
}
.fc-button-content {
  position: relative;
  float: left;
  height: 1.9em;
  line-height: 1.9em;
  padding: 0 .6em;
  white-space: nowrap;
}
/* icon (for jquery ui) */
.fc-button-content .fc-icon-wrap {
  position: relative;
  float: left;
  top: 50%;
}
.fc-button-content .ui-icon {
  position: relative;
  float: left;
  margin-top: -50%;
  *margin-top: 0;
  *top: -50%;
}
/* gloss effect */
.fc-state-default .fc-button-effect {
  position: absolute;
  top: 50%;
  left: 0;
}
.fc-state-default .fc-button-effect span {
  position: absolute;
  top: -100px;
  left: 0;
  width: 500px;
  height: 100px;
  border-width: 100px 0 0 1px;
  border-style: solid;
  border-color: #fff;
  background: #444;
  opacity: .09;
  filter: alpha(opacity=9);
}
/* button states (determines colors)  */
.fc-state-default,
.fc-state-default .fc-button-inner {
  border-style: solid;
  border-color: #ccc #bbb #aaa;
  background: #F3F3F3;
  color: #000;
}
.fc-state-hover,
.fc-state-hover .fc-button-inner {
  border-color: #999;
}
.fc-state-down,
.fc-state-down .fc-button-inner {
  border-color: #555;
  background: #777;
}
.fc-state-active,
.fc-state-active .fc-button-inner {
  border-color: #555;
  background: #777;
  color: #fff;
}
.fc-state-disabled,
.fc-state-disabled .fc-button-inner {
  color: #999;
  border-color: #ddd;
}
.fc-state-disabled {
  cursor: default;
}
.fc-state-disabled .fc-button-effect {
  display: none;
}
/* Global Event Styles
------------------------------------------------------------------------*/
.fc-event {
  border-style: solid;
  border-width: 0;
  font-size: .85em;
  cursor: default;
}
a.fc-event,
.fc-event-draggable {
  cursor: pointer;
}
a.fc-event {
  text-decoration: none;
}
.fc-rtl .fc-event {
  text-align: right;
}
.fc-event-skin {
  color: #FFF;
  border-right: none !important;
  cursor: move;
}
.fc-event-inner {
  position: relative;
  width: 100%;
  height: 100%;
  border-style: solid;
  border-width: 0;
  overflow: hidden;
}
.fc-event-time,
.fc-event-title {
  padding: 0 1px;
}
.fc .ui-resizable-handle {
  /*** TODO: don't use ui-resizable anymore, change class ***/
  display: block;
  position: absolute;
  z-index: 99999;
  overflow: hidden;
  /* hacky spaces (IE6/7) */
  font-size: 300%;
  /* */
  line-height: 50%;
  /* */
}
/* Horizontal Events
------------------------------------------------------------------------*/
.fc-event-hori {
  border-width: 1px 0;
  margin-bottom: 1px;
}
/* resizable */
.fc-event-hori .ui-resizable-e {
  top: 0           !important;
  /* importants override pre jquery ui 1.7 styles */
  right: -3px !important;
  width: 7px       !important;
  height: 100%     !important;
  cursor: e-resize;
}
.fc-event-hori .ui-resizable-w {
  top: 0           !important;
  left: -3px !important;
  width: 7px       !important;
  height: 100%     !important;
  cursor: w-resize;
}
.fc-event-hori .ui-resizable-handle {
  _padding-bottom: 14px;
  /* IE6 had 0 height */
}
/* Fake Rounded Corners (for buttons and events)
------------------------------------------------------------*/
.fc-corner-left {
  margin-left: 1px;
}
.fc-corner-left .fc-button-inner,
.fc-corner-left .fc-event-inner {
  margin-left: -1px;
}
.fc-corner-right {
  margin-right: 1px;
}
.fc-corner-right .fc-button-inner,
.fc-corner-right .fc-event-inner {
  margin-right: -1px;
}
.fc-corner-top {
  margin-top: 1px;
}
.fc-corner-top .fc-event-inner {
  margin-top: -1px;
}
.fc-corner-bottom {
  margin-bottom: 1px;
}
.fc-corner-bottom .fc-event-inner {
  margin-bottom: -1px;
}
/* Fake Rounded Corners SPECIFICALLY FOR EVENTS
-----------------------------------------------------------------*/
.fc-corner-left .fc-event-inner {
  border-left: 6px solid rgba(0, 0, 0, 0.15);
  padding-left: 2px;
}
.fc-corner-right .fc-event-inner {
  padding-left: 2px;
}
.fc-corner-top .fc-event-inner {
  border-top-width: 1px;
}
.fc-corner-bottom .fc-event-inner {
  border-bottom-width: 1px;
}
/* ICONS
-----------------------------------------------------------------*/
.fc-event-skin .fa:before {
  display: block;
  font-size: 14px;
  position: absolute;
  right: 4px;
  top: 3px;
}
/* Reusable Separate-border Table
------------------------------------------------------------*/
table.fc-border-separate {
  border-collapse: separate;
}
.fc-border-separate th,
.fc-border-separate td {
  border-width: 1px 0 0 1px;
}
.fc-border-separate th.fc-last,
.fc-border-separate td.fc-last {
  border-right-width: 1px;
}
.fc-border-separate tr.fc-last th,
.fc-border-separate tr.fc-last td {
  border-bottom-width: 1px;
}
.fc-border-separate tbody tr.fc-first td,
.fc-border-separate tbody tr.fc-first th {
  border-top-width: 0;
}
/* Month View, Basic Week View, Basic Day View
------------------------------------------------------------------------*/
.fc-grid th {
  text-align: center;
}
.fc-grid .fc-day-number {
  float: right;
  padding: 0 2px;
}
.fc-grid .fc-other-month .fc-day-number {
  opacity: 0.3;
  filter: alpha(opacity=30);
  /* for IE */
  /* opacity with small font can sometimes look too faded
	   might want to set the 'color' property instead
	   making day-numbers bold also fixes the problem */
}
.fc-grid .fc-day-content {
  clear: both;
  padding: 2px 2px 1px;
  /* distance between events and day edges */
}
/* event styles */
.fc-grid .fc-event-time {
  font-weight: bold;
}
/* right-to-left */
.fc-rtl .fc-grid .fc-day-number {
  float: left;
}
.fc-rtl .fc-grid .fc-event-time {
  float: right;
}
/* Agenda Week View, Agenda Day View
------------------------------------------------------------------------*/
.fc-agenda table {
  border-collapse: separate;
}
.fc-agenda-days th {
  text-align: center;
}
.fc-agenda .fc-agenda-axis {
  width: 50px;
  padding: 0 4px;
  vertical-align: middle;
  text-align: right;
  white-space: nowrap;
  font-weight: normal;
}
.fc-agenda .fc-day-content {
  padding: 2px 2px 1px;
}
/* make axis border take precedence */
.fc-agenda-days .fc-agenda-axis {
  border-right-width: 1px;
}
.fc-agenda-days .fc-col0 {
  border-left-width: 0;
}
/* all-day area */
.fc-agenda-allday th {
  border-width: 0 1px;
}
.fc-agenda-allday .fc-day-content {
  min-height: 34px;
  /* TODO: doesnt work well in quirksmode */
  _height: 34px;
}
/* divider (between all-day and slots) */
.fc-agenda-divider-inner {
  height: 2px;
  overflow: hidden;
}
.fc-widget-header .fc-agenda-divider-inner {
  background: #eee;
}
/* slot rows */
.fc-agenda-slots th {
  border-width: 1px 1px 0;
}
.fc-agenda-slots td {
  border-width: 1px 0 0;
  background: none;
}
.fc-agenda-slots td div {
  height: 20px;
}
.fc-agenda-slots tr.fc-slot0 th,
.fc-agenda-slots tr.fc-slot0 td {
  border-top-width: 0;
}
.fc-agenda-slots tr.fc-minor th,
.fc-agenda-slots tr.fc-minor td {
  border-top-style: dotted;
}
.fc-agenda-slots tr.fc-minor th.ui-widget-header {
  *border-top-style: solid;
  /* doesn't work with background in IE6/7 */
}
/* Vertical Events
------------------------------------------------------------------------*/
.fc-event-vert {
  border-width: 0 1px;
}
.fc-event-vert .fc-event-head,
.fc-event-vert .fc-event-content {
  position: relative;
  z-index: 2;
  width: 100%;
  overflow: hidden;
}
.fc-event-vert .fc-event-time {
  white-space: nowrap;
  font-size: 10px;
}
.fc-event-vert .fc-event-bg {
  /* makes the event lighter w/ a semi-transparent overlay  */
  position: absolute;
  z-index: 1;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: #fff;
  opacity: .3;
  filter: alpha(opacity=30);
}
.fc .ui-draggable-dragging .fc-event-bg,
.fc-select-helper .fc-event-bg {
  display: none\9;
  /* for IE6/7/8. nested opacity filters while dragging don't work */
}
/* resizable */
.fc-event-vert .ui-resizable-s {
  bottom: 0        !important;
  /* importants override pre jquery ui 1.7 styles */
  width: 100%      !important;
  height: 8px      !important;
  overflow: hidden !important;
  line-height: 8px !important;
  font-size: 11px  !important;
  font-family: monospace;
  text-align: center;
  cursor: s-resize;
}
.fc-agenda .ui-resizable-resizing {
  /* TODO: better selector */
  _overflow: hidden;
}
/*!
 * Colorpicker for Bootstrap
 *
 * Copyright 2012 Stefan Petre
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 */
.colorpicker-saturation {
  width: 100px;
  height: 100px;
  background-image: url("../../img/saturation.png");
  cursor: crosshair;
  float: left;
}
.colorpicker-saturation i {
  display: block;
  height: 5px;
  width: 5px;
  border: 1px solid #000;
  position: absolute;
  top: 0;
  left: 0;
  margin: -4px 0 0 -4px;
}
.colorpicker-saturation i b {
  display: block;
  height: 5px;
  width: 5px;
  border: 1px solid #fff;
}
.colorpicker-hue,
.colorpicker-alpha {
  width: 15px;
  height: 100px;
  float: left;
  cursor: row-resize;
  margin-left: 4px;
  margin-bottom: 4px;
}
.colorpicker-hue i,
.colorpicker-alpha i {
  display: block;
  height: 1px;
  background: #000;
  border-top: 1px solid #fff;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  margin-top: -1px;
}
.colorpicker-hue {
  background-image: url("../../img/hue.png");
}
.colorpicker-alpha {
  background-image: url("../../img/alpha.png");
  display: none;
}
.colorpicker {
  zoom: 1;
  /*IE*/
  top: 0;
  left: 0;
  padding: 4px;
  min-width: 120px;
  margin-top: 1px;
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
.colorpicker:before,
.colorpicker:after {
  content: " ";
  display: table;
}
.colorpicker:after {
  clear: both;
}
.colorpicker:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 6px;
}
.colorpicker:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #fff;
  position: absolute;
  top: -6px;
  left: 7px;
}
.colorpicker div {
  position: relative;
}
.colorpicker.alpha {
  min-width: 140px;
}
.colorpicker.alpha .colorpicker-alpha {
  display: block;
}
.colorpicker-color {
  height: 10px;
  margin-top: 5px;
  clear: both;
  background-image: url("../../img/alpha.png");
  background-position: 0 100%;
}
.colorpicker-color div {
  height: 10px;
}
.input-append.color .add-on i,
.input-prepend.color .add-on i {
  display: block;
  cursor: pointer;
  width: 16px;
  height: 16px;
}
/*!
 * Timepicker Component for Twitter Bootstrap
 *
 * Copyright 2013 Joris de Wit
 *
 * Contributors https://github.com/jdewit/bootstrap-timepicker/graphs/contributors
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
.bootstrap-timepicker {
  position: relative;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu {
  left: auto;
  right: 0;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu:before {
  left: auto;
  right: 12px;
}
.bootstrap-timepicker.pull-right .bootstrap-timepicker-widget.dropdown-menu:after {
  left: auto;
  right: 13px;
}
.bootstrap-timepicker .add-on {
  cursor: pointer;
}
.bootstrap-timepicker .add-on i {
  display: inline-block;
  width: 16px;
  height: 16px;
}
.bootstrap-timepicker-widget.dropdown-menu {
  padding: 4px;
}
.bootstrap-timepicker-widget.dropdown-menu.open {
  display: inline-block;
}
.bootstrap-timepicker-widget.dropdown-menu:before {
  border-bottom: 7px solid rgba(0, 0, 0, 0.2);
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
}
.bootstrap-timepicker-widget.dropdown-menu:after {
  border-bottom: 6px solid #FFFFFF;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
}
.bootstrap-timepicker-widget.timepicker-orient-left:before {
  left: 6px;
}
.bootstrap-timepicker-widget.timepicker-orient-left:after {
  left: 7px;
}
.bootstrap-timepicker-widget.timepicker-orient-right:before {
  right: 6px;
}
.bootstrap-timepicker-widget.timepicker-orient-right:after {
  right: 7px;
}
.bootstrap-timepicker-widget.timepicker-orient-top:before {
  top: -7px;
}
.bootstrap-timepicker-widget.timepicker-orient-top:after {
  top: -6px;
}
.bootstrap-timepicker-widget.timepicker-orient-bottom:before {
  bottom: -7px;
  border-bottom: 0;
  border-top: 7px solid #999;
}
.bootstrap-timepicker-widget.timepicker-orient-bottom:after {
  bottom: -6px;
  border-bottom: 0;
  border-top: 6px solid #ffffff;
}
.bootstrap-timepicker-widget a.btn,
.bootstrap-timepicker-widget input {
  border-radius: 4px;
}
.bootstrap-timepicker-widget table {
  width: 100%;
  margin: 0;
}
.bootstrap-timepicker-widget table td {
  text-align: center;
  height: 30px;
  margin: 0;
  padding: 2px;
}
.bootstrap-timepicker-widget table td:not(.separator) {
  min-width: 30px;
}
.bootstrap-timepicker-widget table td span {
  width: 100%;
}
.bootstrap-timepicker-widget table td a {
  border: 1px transparent solid;
  width: 100%;
  display: inline-block;
  margin: 0;
  padding: 8px 0;
  outline: 0;
  color: #333;
}
.bootstrap-timepicker-widget table td a:hover {
  text-decoration: none;
  background-color: #eee;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  border-color: #ddd;
}
.bootstrap-timepicker-widget table td a i {
  margin-top: 2px;
  font-size: 18px;
}
.bootstrap-timepicker-widget table td input {
  width: 25px;
  margin: 0;
  text-align: center;
}
.bootstrap-timepicker-widget .modal-content {
  padding: 4px;
}
@media (min-width: 767px) {
  .bootstrap-timepicker-widget.modal {
    width: 200px;
    margin-left: -100px;
  }
}
@media (max-width: 767px) {
  .bootstrap-timepicker {
    width: 100%;
  }
  .bootstrap-timepicker .dropdown-menu {
    width: 100%;
  }
}
.animated {
  -webkit-animation-duration: 1s;
  -moz-animation-duration: 1s;
  -o-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  -moz-animation-fill-mode: both;
  -o-animation-fill-mode: both;
  animation-fill-mode: both;
}
.animated.fast {
  -webkit-animation-duration: .5s;
  -moz-animation-duration: .5s;
  -o-animation-duration: .5s;
  animation-duration: .5s;
}
.animated.hinge {
  -webkit-animation-duration: 2s;
  -moz-animation-duration: 2s;
  -o-animation-duration: 2s;
  animation-duration: 2s;
}
@-webkit-keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@-moz-keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@-o-keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
.animated.flash {
  -webkit-animation-name: flash;
  -moz-animation-name: flash;
  -o-animation-name: flash;
  animation-name: flash;
}
@-webkit-keyframes shake {
  0%,
  100% {
    -webkit-transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translateX(10px);
  }
}
@-moz-keyframes shake {
  0%,
  100% {
    -moz-transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -moz-transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    -moz-transform: translateX(10px);
  }
}
@-o-keyframes shake {
  0%,
  100% {
    -o-transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -o-transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    -o-transform: translateX(10px);
  }
}
@keyframes shake {
  0%,
  100% {
    transform: translateX(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    transform: translateX(-10px);
  }
  20%,
  40%,
  60%,
  80% {
    transform: translateX(10px);
  }
}
.animated.shake {
  -webkit-animation-name: shake;
  -moz-animation-name: shake;
  -o-animation-name: shake;
  animation-name: shake;
}
@-webkit-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -webkit-transform: translateY(0);
  }
  40% {
    -webkit-transform: translateY(-30px);
  }
  60% {
    -webkit-transform: translateY(-15px);
  }
}
@-moz-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -moz-transform: translateY(0);
  }
  40% {
    -moz-transform: translateY(-30px);
  }
  60% {
    -moz-transform: translateY(-15px);
  }
}
@-o-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -o-transform: translateY(0);
  }
  40% {
    -o-transform: translateY(-30px);
  }
  60% {
    -o-transform: translateY(-15px);
  }
}
@keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    transform: translateY(0);
  }
  40% {
    transform: translateY(-30px);
  }
  60% {
    transform: translateY(-15px);
  }
}
.animated.bounce {
  -webkit-animation-name: bounce;
  -moz-animation-name: bounce;
  -o-animation-name: bounce;
  animation-name: bounce;
}
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scale(1);
  }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -webkit-transform: scale(1) rotate(0);
  }
}
@-moz-keyframes tada {
  0% {
    -moz-transform: scale(1);
  }
  10%,
  20% {
    -moz-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -moz-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -moz-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -moz-transform: scale(1) rotate(0);
  }
}
@-o-keyframes tada {
  0% {
    -o-transform: scale(1);
  }
  10%,
  20% {
    -o-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -o-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -o-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -o-transform: scale(1) rotate(0);
  }
}
@keyframes tada {
  0% {
    transform: scale(1);
  }
  10%,
  20% {
    transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    transform: scale(1.1) rotate(-3deg);
  }
  100% {
    transform: scale(1) rotate(0);
  }
}
.animated.tada {
  -webkit-animation-name: tada;
  -moz-animation-name: tada;
  -o-animation-name: tada;
  animation-name: tada;
}
@-webkit-keyframes swing {
  20%,
  40%,
  60%,
  80%,
  100% {
    -webkit-transform-origin: top center;
  }
  20% {
    -webkit-transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
  }
  100% {
    -webkit-transform: rotate(0deg);
  }
}
@-moz-keyframes swing {
  20% {
    -moz-transform: rotate(15deg);
  }
  40% {
    -moz-transform: rotate(-10deg);
  }
  60% {
    -moz-transform: rotate(5deg);
  }
  80% {
    -moz-transform: rotate(-5deg);
  }
  100% {
    -moz-transform: rotate(0deg);
  }
}
@-o-keyframes swing {
  20% {
    -o-transform: rotate(15deg);
  }
  40% {
    -o-transform: rotate(-10deg);
  }
  60% {
    -o-transform: rotate(5deg);
  }
  80% {
    -o-transform: rotate(-5deg);
  }
  100% {
    -o-transform: rotate(0deg);
  }
}
@keyframes swing {
  20% {
    transform: rotate(15deg);
  }
  40% {
    transform: rotate(-10deg);
  }
  60% {
    transform: rotate(5deg);
  }
  80% {
    transform: rotate(-5deg);
  }
  100% {
    transform: rotate(0deg);
  }
}
.animated.swing {
  -webkit-transform-origin: top center;
  -moz-transform-origin: top center;
  -o-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  -moz-animation-name: swing;
  -o-animation-name: swing;
  animation-name: swing;
}
@-webkit-keyframes wobble {
  0% {
    -webkit-transform: translateX(0%);
  }
  15% {
    -webkit-transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    -webkit-transform: translateX(20%) rotate(3deg);
  }
  45% {
    -webkit-transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    -webkit-transform: translateX(10%) rotate(2deg);
  }
  75% {
    -webkit-transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    -webkit-transform: translateX(0%);
  }
}
@-moz-keyframes wobble {
  0% {
    -moz-transform: translateX(0%);
  }
  15% {
    -moz-transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    -moz-transform: translateX(20%) rotate(3deg);
  }
  45% {
    -moz-transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    -moz-transform: translateX(10%) rotate(2deg);
  }
  75% {
    -moz-transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    -moz-transform: translateX(0%);
  }
}
@-o-keyframes wobble {
  0% {
    -o-transform: translateX(0%);
  }
  15% {
    -o-transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    -o-transform: translateX(20%) rotate(3deg);
  }
  45% {
    -o-transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    -o-transform: translateX(10%) rotate(2deg);
  }
  75% {
    -o-transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    -o-transform: translateX(0%);
  }
}
@keyframes wobble {
  0% {
    transform: translateX(0%);
  }
  15% {
    transform: translateX(-25%) rotate(-5deg);
  }
  30% {
    transform: translateX(20%) rotate(3deg);
  }
  45% {
    transform: translateX(-15%) rotate(-3deg);
  }
  60% {
    transform: translateX(10%) rotate(2deg);
  }
  75% {
    transform: translateX(-5%) rotate(-1deg);
  }
  100% {
    transform: translateX(0%);
  }
}
.animated.wobble {
  -webkit-animation-name: wobble;
  -moz-animation-name: wobble;
  -o-animation-name: wobble;
  animation-name: wobble;
}
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.1);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@-moz-keyframes pulse {
  0% {
    -moz-transform: scale(1);
  }
  50% {
    -moz-transform: scale(1.1);
  }
  100% {
    -moz-transform: scale(1);
  }
}
@-o-keyframes pulse {
  0% {
    -o-transform: scale(1);
  }
  50% {
    -o-transform: scale(1.1);
  }
  100% {
    -o-transform: scale(1);
  }
}
@keyframes pulse {
  0% {
    transform: scale(1);
  }
  50% {
    transform: scale(1.1);
  }
  100% {
    transform: scale(1);
  }
}
.animated.pulse {
  -webkit-animation-name: pulse;
  -moz-animation-name: pulse;
  -o-animation-name: pulse;
  animation-name: pulse;
}
@-webkit-keyframes flip {
  0% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -webkit-animation-timing-function: ease-out;
  }
  40% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -webkit-animation-timing-function: ease-out;
  }
  50% {
    -webkit-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -webkit-animation-timing-function: ease-in;
  }
  80% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -webkit-animation-timing-function: ease-in;
  }
  100% {
    -webkit-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -webkit-animation-timing-function: ease-in;
  }
}
@-moz-keyframes flip {
  0% {
    -moz-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -moz-animation-timing-function: ease-out;
  }
  40% {
    -moz-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -moz-animation-timing-function: ease-out;
  }
  50% {
    -moz-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -moz-animation-timing-function: ease-in;
  }
  80% {
    -moz-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -moz-animation-timing-function: ease-in;
  }
  100% {
    -moz-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -moz-animation-timing-function: ease-in;
  }
}
@-o-keyframes flip {
  0% {
    -o-transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    -o-animation-timing-function: ease-out;
  }
  40% {
    -o-transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    -o-animation-timing-function: ease-out;
  }
  50% {
    -o-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    -o-animation-timing-function: ease-in;
  }
  80% {
    -o-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    -o-animation-timing-function: ease-in;
  }
  100% {
    -o-transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    -o-animation-timing-function: ease-in;
  }
}
@keyframes flip {
  0% {
    transform: perspective(400px) translateZ(0) rotateY(0) scale(1);
    animation-timing-function: ease-out;
  }
  40% {
    transform: perspective(400px) translateZ(150px) rotateY(170deg) scale(1);
    animation-timing-function: ease-out;
  }
  50% {
    transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
    animation-timing-function: ease-in;
  }
  80% {
    transform: perspective(400px) translateZ(0) rotateY(360deg) scale(0.95);
    animation-timing-function: ease-in;
  }
  100% {
    transform: perspective(400px) translateZ(0) rotateY(360deg) scale(1);
    animation-timing-function: ease-in;
  }
}
.animated.flip {
  -webkit-backface-visibility: visible !important;
  -webkit-animation-name: flip;
  -moz-backface-visibility: visible !important;
  -moz-animation-name: flip;
  -o-backface-visibility: visible !important;
  -o-animation-name: flip;
  backface-visibility: visible !important;
  animation-name: flip;
}
@-webkit-keyframes flipInX {
  0% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateX(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
@-moz-keyframes flipInX {
  0% {
    -moz-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    -moz-transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    -moz-transform: perspective(400px) rotateX(10deg);
  }
  100% {
    -moz-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
@-o-keyframes flipInX {
  0% {
    -o-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    -o-transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    -o-transform: perspective(400px) rotateX(10deg);
  }
  100% {
    -o-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
@keyframes flipInX {
  0% {
    transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
  40% {
    transform: perspective(400px) rotateX(-10deg);
  }
  70% {
    transform: perspective(400px) rotateX(10deg);
  }
  100% {
    transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
}
.animated.flipInX {
  -webkit-backface-visibility: visible !important;
  -webkit-animation-name: flipInX;
  -moz-backface-visibility: visible !important;
  -moz-animation-name: flipInX;
  -o-backface-visibility: visible !important;
  -o-animation-name: flipInX;
  backface-visibility: visible !important;
  animation-name: flipInX;
}
@-webkit-keyframes flipOutX {
  0% {
    -webkit-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
@-moz-keyframes flipOutX {
  0% {
    -moz-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    -moz-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
@-o-keyframes flipOutX {
  0% {
    -o-transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    -o-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
@keyframes flipOutX {
  0% {
    transform: perspective(400px) rotateX(0deg);
    opacity: 1;
  }
  100% {
    transform: perspective(400px) rotateX(90deg);
    opacity: 0;
  }
}
.animated.flipOutX {
  -webkit-animation-name: flipOutX;
  -webkit-backface-visibility: visible !important;
  -moz-animation-name: flipOutX;
  -moz-backface-visibility: visible !important;
  -o-animation-name: flipOutX;
  -o-backface-visibility: visible !important;
  animation-name: flipOutX;
  backface-visibility: visible !important;
}
@-webkit-keyframes flipInY {
  0% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    -webkit-transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    -webkit-transform: perspective(400px) rotateY(10deg);
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
@-moz-keyframes flipInY {
  0% {
    -moz-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    -moz-transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    -moz-transform: perspective(400px) rotateY(10deg);
  }
  100% {
    -moz-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
@-o-keyframes flipInY {
  0% {
    -o-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    -o-transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    -o-transform: perspective(400px) rotateY(10deg);
  }
  100% {
    -o-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
@keyframes flipInY {
  0% {
    transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
  40% {
    transform: perspective(400px) rotateY(-10deg);
  }
  70% {
    transform: perspective(400px) rotateY(10deg);
  }
  100% {
    transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
}
.animated.flipInY {
  -webkit-backface-visibility: visible !important;
  -webkit-animation-name: flipInY;
  -moz-backface-visibility: visible !important;
  -moz-animation-name: flipInY;
  -o-backface-visibility: visible !important;
  -o-animation-name: flipInY;
  backface-visibility: visible !important;
  animation-name: flipInY;
}
@-webkit-keyframes flipOutY {
  0% {
    -webkit-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
@-moz-keyframes flipOutY {
  0% {
    -moz-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    -moz-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
@-o-keyframes flipOutY {
  0% {
    -o-transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    -o-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
@keyframes flipOutY {
  0% {
    transform: perspective(400px) rotateY(0deg);
    opacity: 1;
  }
  100% {
    transform: perspective(400px) rotateY(90deg);
    opacity: 0;
  }
}
.animated.flipOutY {
  -webkit-backface-visibility: visible !important;
  -webkit-animation-name: flipOutY;
  -moz-backface-visibility: visible !important;
  -moz-animation-name: flipOutY;
  -o-backface-visibility: visible !important;
  -o-animation-name: flipOutY;
  backface-visibility: visible !important;
  animation-name: flipOutY;
}
@-webkit-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-moz-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-o-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
.animated.fadeIn {
  -webkit-animation-name: fadeIn;
  -moz-animation-name: fadeIn;
  -o-animation-name: fadeIn;
  animation-name: fadeIn;
}
@-webkit-keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes fadeInUp {
  0% {
    opacity: 0;
    -moz-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
}
@-o-keyframes fadeInUp {
  0% {
    opacity: 0;
    -o-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateY(0);
  }
}
@keyframes fadeInUp {
  0% {
    opacity: 0;
    transform: translateY(20px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.animated.fadeInUp {
  -webkit-animation-name: fadeInUp;
  -moz-animation-name: fadeInUp;
  -o-animation-name: fadeInUp;
  animation-name: fadeInUp;
}
@-webkit-keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes fadeInDown {
  0% {
    opacity: 0;
    -moz-transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
}
@-o-keyframes fadeInDown {
  0% {
    opacity: 0;
    -o-transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateY(0);
  }
}
@keyframes fadeInDown {
  0% {
    opacity: 0;
    transform: translateY(-20px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.animated.fadeInDown {
  -webkit-animation-name: fadeInDown;
  -moz-animation-name: fadeInDown;
  -o-animation-name: fadeInDown;
  animation-name: fadeInDown;
}
@-webkit-keyframes fadeInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes fadeInLeft {
  0% {
    opacity: 0;
    -moz-transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
}
@-o-keyframes fadeInLeft {
  0% {
    opacity: 0;
    -o-transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0);
  }
}
@keyframes fadeInLeft {
  0% {
    opacity: 0;
    transform: translateX(-20px);
  }
  100% {
    opacity: 1;
    transform: translateX(0);
  }
}
.animated.fadeInLeft {
  -webkit-animation-name: fadeInLeft;
  -moz-animation-name: fadeInLeft;
  -o-animation-name: fadeInLeft;
  animation-name: fadeInLeft;
}
@-webkit-keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes fadeInRight {
  0% {
    opacity: 0;
    -moz-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
}
@-o-keyframes fadeInRight {
  0% {
    opacity: 0;
    -o-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0);
  }
}
@keyframes fadeInRight {
  0% {
    opacity: 0;
    transform: translateX(20px);
  }
  100% {
    opacity: 1;
    transform: translateX(0);
  }
}
.animated.fadeInRight {
  -webkit-animation-name: fadeInRight;
  -moz-animation-name: fadeInRight;
  -o-animation-name: fadeInRight;
  animation-name: fadeInRight;
}
@-webkit-keyframes fadeInUpBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes fadeInUpBig {
  0% {
    opacity: 0;
    -moz-transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
}
@-o-keyframes fadeInUpBig {
  0% {
    opacity: 0;
    -o-transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    -o-transform: translateY(0);
  }
}
@keyframes fadeInUpBig {
  0% {
    opacity: 0;
    transform: translateY(2000px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.animated.fadeInUpBig {
  -webkit-animation-name: fadeInUpBig;
  -moz-animation-name: fadeInUpBig;
  -o-animation-name: fadeInUpBig;
  animation-name: fadeInUpBig;
}
@-webkit-keyframes fadeInDownBig {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes fadeInDownBig {
  0% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
}
@-o-keyframes fadeInDownBig {
  0% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    -o-transform: translateY(0);
  }
}
@keyframes fadeInDownBig {
  0% {
    opacity: 0;
    transform: translateY(-2000px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.animated.fadeInDownBig {
  -webkit-animation-name: fadeInDownBig;
  -moz-animation-name: fadeInDownBig;
  -o-animation-name: fadeInDownBig;
  animation-name: fadeInDownBig;
}
@-webkit-keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
}
@-o-keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0);
  }
}
@keyframes fadeInLeftBig {
  0% {
    opacity: 0;
    transform: translateX(-2000px);
  }
  100% {
    opacity: 1;
    transform: translateX(0);
  }
}
.animated.fadeInLeftBig {
  -webkit-animation-name: fadeInLeftBig;
  -moz-animation-name: fadeInLeftBig;
  -o-animation-name: fadeInLeftBig;
  animation-name: fadeInLeftBig;
}
@-webkit-keyframes fadeInRightBig {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes fadeInRightBig {
  0% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
}
@-o-keyframes fadeInRightBig {
  0% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0);
  }
}
@keyframes fadeInRightBig {
  0% {
    opacity: 0;
    transform: translateX(2000px);
  }
  100% {
    opacity: 1;
    transform: translateX(0);
  }
}
.animated.fadeInRightBig {
  -webkit-animation-name: fadeInRightBig;
  -moz-animation-name: fadeInRightBig;
  -o-animation-name: fadeInRightBig;
  animation-name: fadeInRightBig;
}
@-webkit-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@-moz-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@-o-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
.animated.fadeOut {
  -webkit-animation-name: fadeOut;
  -moz-animation-name: fadeOut;
  -o-animation-name: fadeOut;
  animation-name: fadeOut;
}
@-webkit-keyframes fadeOutUp {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-20px);
  }
}
@-moz-keyframes fadeOutUp {
  0% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(-20px);
  }
}
@-o-keyframes fadeOutUp {
  0% {
    opacity: 1;
    -o-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(-20px);
  }
}
@keyframes fadeOutUp {
  0% {
    opacity: 1;
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    transform: translateY(-20px);
  }
}
.animated.fadeOutUp {
  -webkit-animation-name: fadeOutUp;
  -moz-animation-name: fadeOutUp;
  -o-animation-name: fadeOutUp;
  animation-name: fadeOutUp;
}
@-webkit-keyframes fadeOutDown {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
}
@-moz-keyframes fadeOutDown {
  0% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(20px);
  }
}
@-o-keyframes fadeOutDown {
  0% {
    opacity: 1;
    -o-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(20px);
  }
}
@keyframes fadeOutDown {
  0% {
    opacity: 1;
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    transform: translateY(20px);
  }
}
.animated.fadeOutDown {
  -webkit-animation-name: fadeOutDown;
  -moz-animation-name: fadeOutDown;
  -o-animation-name: fadeOutDown;
  animation-name: fadeOutDown;
}
@-webkit-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
  }
}
@-moz-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(-20px);
  }
}
@-o-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(-20px);
  }
}
@keyframes fadeOutLeft {
  0% {
    opacity: 1;
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(-20px);
  }
}
.animated.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  -moz-animation-name: fadeOutLeft;
  -o-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft;
}
@-webkit-keyframes fadeOutRight {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(20px);
  }
}
@-moz-keyframes fadeOutRight {
  0% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(20px);
  }
}
@-o-keyframes fadeOutRight {
  0% {
    opacity: 1;
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(20px);
  }
}
@keyframes fadeOutRight {
  0% {
    opacity: 1;
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(20px);
  }
}
.animated.fadeOutRight {
  -webkit-animation-name: fadeOutRight;
  -moz-animation-name: fadeOutRight;
  -o-animation-name: fadeOutRight;
  animation-name: fadeOutRight;
}
@-webkit-keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@-moz-keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
}
@-o-keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    -o-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
}
@keyframes fadeOutUpBig {
  0% {
    opacity: 1;
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    transform: translateY(-2000px);
  }
}
.animated.fadeOutUpBig {
  -webkit-animation-name: fadeOutUpBig;
  -moz-animation-name: fadeOutUpBig;
  -o-animation-name: fadeOutUpBig;
  animation-name: fadeOutUpBig;
}
@-webkit-keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
}
@-moz-keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(2000px);
  }
}
@-o-keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    -o-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(2000px);
  }
}
@keyframes fadeOutDownBig {
  0% {
    opacity: 1;
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    transform: translateY(2000px);
  }
}
.animated.fadeOutDownBig {
  -webkit-animation-name: fadeOutDownBig;
  -moz-animation-name: fadeOutDownBig;
  -o-animation-name: fadeOutDownBig;
  animation-name: fadeOutDownBig;
}
@-webkit-keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@-moz-keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
}
@-o-keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
}
@keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(-2000px);
  }
}
.animated.fadeOutLeftBig {
  -webkit-animation-name: fadeOutLeftBig;
  -moz-animation-name: fadeOutLeftBig;
  -o-animation-name: fadeOutLeftBig;
  animation-name: fadeOutLeftBig;
}
@-webkit-keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@-moz-keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
}
@-o-keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
}
@keyframes fadeOutRightBig {
  0% {
    opacity: 1;
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(2000px);
  }
}
.animated.fadeOutRightBig {
  -webkit-animation-name: fadeOutRightBig;
  -moz-animation-name: fadeOutRightBig;
  -o-animation-name: fadeOutRightBig;
  animation-name: fadeOutRightBig;
}
@-webkit-keyframes bounceIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0.3);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.05);
  }
  70% {
    -webkit-transform: scale(0.9);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@-moz-keyframes bounceIn {
  0% {
    opacity: 0;
    -moz-transform: scale(0.3);
  }
  50% {
    opacity: 1;
    -moz-transform: scale(1.05);
  }
  70% {
    -moz-transform: scale(0.9);
  }
  100% {
    -moz-transform: scale(1);
  }
}
@-o-keyframes bounceIn {
  0% {
    opacity: 0;
    -o-transform: scale(0.3);
  }
  50% {
    opacity: 1;
    -o-transform: scale(1.05);
  }
  70% {
    -o-transform: scale(0.9);
  }
  100% {
    -o-transform: scale(1);
  }
}
@keyframes bounceIn {
  0% {
    opacity: 0;
    transform: scale(0.3);
  }
  50% {
    opacity: 1;
    transform: scale(1.05);
  }
  70% {
    transform: scale(0.9);
  }
  100% {
    transform: scale(1);
  }
}
@-webkit-keyframes slideInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes slideInDown {
  0% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
  100% {
    -moz-transform: translateY(0);
  }
}
@-o-keyframes slideInDown {
  0% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
  100% {
    -o-transform: translateY(0);
  }
}
@keyframes slideInDown {
  0% {
    opacity: 0;
    transform: translateY(-2000px);
  }
  100% {
    transform: translateY(0);
  }
}
.slideInDown {
  -webkit-animation-name: slideInDown;
  -moz-animation-name: slideInDown;
  -o-animation-name: slideInDown;
  animation-name: slideInDown;
}
@-webkit-keyframes slideInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes slideInLeft {
  0% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
  100% {
    -moz-transform: translateX(0);
  }
}
@-o-keyframes slideInLeft {
  0% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
  100% {
    -o-transform: translateX(0);
  }
}
@keyframes slideInLeft {
  0% {
    opacity: 0;
    transform: translateX(-2000px);
  }
  100% {
    transform: translateX(0);
  }
}
.slideInLeft {
  -webkit-animation-name: slideInLeft;
  -moz-animation-name: slideInLeft;
  -o-animation-name: slideInLeft;
  animation-name: slideInLeft;
}
@-webkit-keyframes slideInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes slideInRight {
  0% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
  100% {
    -moz-transform: translateX(0);
  }
}
@-o-keyframes slideInRight {
  0% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
  100% {
    -o-transform: translateX(0);
  }
}
@keyframes slideInRight {
  0% {
    opacity: 0;
    transform: translateX(2000px);
  }
  100% {
    transform: translateX(0);
  }
}
.slideInRight {
  -webkit-animation-name: slideInRight;
  -moz-animation-name: slideInRight;
  -o-animation-name: slideInRight;
  animation-name: slideInRight;
}
@-webkit-keyframes slideOutLeft {
  0% {
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@-moz-keyframes slideOutLeft {
  0% {
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
}
@-o-keyframes slideOutLeft {
  0% {
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
}
@keyframes slideOutLeft {
  0% {
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(-2000px);
  }
}
.slideOutLeft {
  -webkit-animation-name: slideOutLeft;
  -moz-animation-name: slideOutLeft;
  -o-animation-name: slideOutLeft;
  animation-name: slideOutLeft;
}
@-webkit-keyframes slideOutRight {
  0% {
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@-moz-keyframes slideOutRight {
  0% {
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
}
@-o-keyframes slideOutRight {
  0% {
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
}
@keyframes slideOutRight {
  0% {
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(2000px);
  }
}
.slideOutRight {
  -webkit-animation-name: slideOutRight;
  -moz-animation-name: slideOutRight;
  -o-animation-name: slideOutRight;
  animation-name: slideOutRight;
}
@-webkit-keyframes slideOutUp {
  0% {
    -webkit-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@-moz-keyframes slideOutUp {
  0% {
    -moz-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
}
@-o-keyframes slideOutUp {
  0% {
    -o-transform: translateY(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
}
@keyframes slideOutUp {
  0% {
    transform: translateY(0);
  }
  100% {
    opacity: 0;
    transform: translateY(-2000px);
  }
}
.slideOutUp {
  -webkit-animation-name: slideOutUp;
  -moz-animation-name: slideOutUp;
  -o-animation-name: slideOutUp;
  animation-name: slideOutUp;
}
.animated.bounceIn {
  -webkit-animation-name: bounceIn;
  -moz-animation-name: bounceIn;
  -o-animation-name: bounceIn;
  animation-name: bounceIn;
}
@-webkit-keyframes bounceInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(-30px);
  }
  80% {
    -webkit-transform: translateY(10px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes bounceInUp {
  0% {
    opacity: 0;
    -moz-transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    -moz-transform: translateY(-30px);
  }
  80% {
    -moz-transform: translateY(10px);
  }
  100% {
    -moz-transform: translateY(0);
  }
}
@-o-keyframes bounceInUp {
  0% {
    opacity: 0;
    -o-transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    -o-transform: translateY(-30px);
  }
  80% {
    -o-transform: translateY(10px);
  }
  100% {
    -o-transform: translateY(0);
  }
}
@keyframes bounceInUp {
  0% {
    opacity: 0;
    transform: translateY(2000px);
  }
  60% {
    opacity: 1;
    transform: translateY(-30px);
  }
  80% {
    transform: translateY(10px);
  }
  100% {
    transform: translateY(0);
  }
}
.animated.bounceInUp {
  -webkit-animation-name: bounceInUp;
  -moz-animation-name: bounceInUp;
  -o-animation-name: bounceInUp;
  animation-name: bounceInUp;
}
@-webkit-keyframes bounceInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateY(30px);
  }
  80% {
    -webkit-transform: translateY(-10px);
  }
  100% {
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes bounceInDown {
  0% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    -moz-transform: translateY(30px);
  }
  80% {
    -moz-transform: translateY(-10px);
  }
  100% {
    -moz-transform: translateY(0);
  }
}
@-o-keyframes bounceInDown {
  0% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    -o-transform: translateY(30px);
  }
  80% {
    -o-transform: translateY(-10px);
  }
  100% {
    -o-transform: translateY(0);
  }
}
@keyframes bounceInDown {
  0% {
    opacity: 0;
    transform: translateY(-2000px);
  }
  60% {
    opacity: 1;
    transform: translateY(30px);
  }
  80% {
    transform: translateY(-10px);
  }
  100% {
    transform: translateY(0);
  }
}
.animated.bounceInDown {
  -webkit-animation-name: bounceInDown;
  -moz-animation-name: bounceInDown;
  -o-animation-name: bounceInDown;
  animation-name: bounceInDown;
}
@-webkit-keyframes bounceInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(30px);
  }
  80% {
    -webkit-transform: translateX(-10px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes bounceInLeft {
  0% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    -moz-transform: translateX(30px);
  }
  80% {
    -moz-transform: translateX(-10px);
  }
  100% {
    -moz-transform: translateX(0);
  }
}
@-o-keyframes bounceInLeft {
  0% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    -o-transform: translateX(30px);
  }
  80% {
    -o-transform: translateX(-10px);
  }
  100% {
    -o-transform: translateX(0);
  }
}
@keyframes bounceInLeft {
  0% {
    opacity: 0;
    transform: translateX(-2000px);
  }
  60% {
    opacity: 1;
    transform: translateX(30px);
  }
  80% {
    transform: translateX(-10px);
  }
  100% {
    transform: translateX(0);
  }
}
.animated.bounceInLeft {
  -webkit-animation-name: bounceInLeft;
  -moz-animation-name: bounceInLeft;
  -o-animation-name: bounceInLeft;
  animation-name: bounceInLeft;
}
@-webkit-keyframes bounceInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    -webkit-transform: translateX(-30px);
  }
  80% {
    -webkit-transform: translateX(10px);
  }
  100% {
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes bounceInRight {
  0% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    -moz-transform: translateX(-30px);
  }
  80% {
    -moz-transform: translateX(10px);
  }
  100% {
    -moz-transform: translateX(0);
  }
}
@-o-keyframes bounceInRight {
  0% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    -o-transform: translateX(-30px);
  }
  80% {
    -o-transform: translateX(10px);
  }
  100% {
    -o-transform: translateX(0);
  }
}
@keyframes bounceInRight {
  0% {
    opacity: 0;
    transform: translateX(2000px);
  }
  60% {
    opacity: 1;
    transform: translateX(-30px);
  }
  80% {
    transform: translateX(10px);
  }
  100% {
    transform: translateX(0);
  }
}
.animated.bounceInRight {
  -webkit-animation-name: bounceInRight;
  -moz-animation-name: bounceInRight;
  -o-animation-name: bounceInRight;
  animation-name: bounceInRight;
}
@-webkit-keyframes bounceOut {
  0% {
    -webkit-transform: scale(1);
  }
  25% {
    -webkit-transform: scale(0.95);
  }
  50% {
    opacity: 1;
    -webkit-transform: scale(1.1);
  }
  100% {
    opacity: 0;
    -webkit-transform: scale(0.3);
  }
}
@-moz-keyframes bounceOut {
  0% {
    -moz-transform: scale(1);
  }
  25% {
    -moz-transform: scale(0.95);
  }
  50% {
    opacity: 1;
    -moz-transform: scale(1.1);
  }
  100% {
    opacity: 0;
    -moz-transform: scale(0.3);
  }
}
@-o-keyframes bounceOut {
  0% {
    -o-transform: scale(1);
  }
  25% {
    -o-transform: scale(0.95);
  }
  50% {
    opacity: 1;
    -o-transform: scale(1.1);
  }
  100% {
    opacity: 0;
    -o-transform: scale(0.3);
  }
}
@keyframes bounceOut {
  0% {
    transform: scale(1);
  }
  25% {
    transform: scale(0.95);
  }
  50% {
    opacity: 1;
    transform: scale(1.1);
  }
  100% {
    opacity: 0;
    transform: scale(0.3);
  }
}
.animated.bounceOut {
  -webkit-animation-name: bounceOut;
  -moz-animation-name: bounceOut;
  -o-animation-name: bounceOut;
  animation-name: bounceOut;
}
@-webkit-keyframes bounceOutUp {
  0% {
    -webkit-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-2000px);
  }
}
@-moz-keyframes bounceOutUp {
  0% {
    -moz-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -moz-transform: translateY(20px);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(-2000px);
  }
}
@-o-keyframes bounceOutUp {
  0% {
    -o-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -o-transform: translateY(20px);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(-2000px);
  }
}
@keyframes bounceOutUp {
  0% {
    transform: translateY(0);
  }
  20% {
    opacity: 1;
    transform: translateY(20px);
  }
  100% {
    opacity: 0;
    transform: translateY(-2000px);
  }
}
.animated.bounceOutUp {
  -webkit-animation-name: bounceOutUp;
  -moz-animation-name: bounceOutUp;
  -o-animation-name: bounceOutUp;
  animation-name: bounceOutUp;
}
@-webkit-keyframes bounceOutDown {
  0% {
    -webkit-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(2000px);
  }
}
@-moz-keyframes bounceOutDown {
  0% {
    -moz-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -moz-transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    -moz-transform: translateY(2000px);
  }
}
@-o-keyframes bounceOutDown {
  0% {
    -o-transform: translateY(0);
  }
  20% {
    opacity: 1;
    -o-transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    -o-transform: translateY(2000px);
  }
}
@keyframes bounceOutDown {
  0% {
    transform: translateY(0);
  }
  20% {
    opacity: 1;
    transform: translateY(-20px);
  }
  100% {
    opacity: 0;
    transform: translateY(2000px);
  }
}
.animated.bounceOutDown {
  -webkit-animation-name: bounceOutDown;
  -moz-animation-name: bounceOutDown;
  -o-animation-name: bounceOutDown;
  animation-name: bounceOutDown;
}
@-webkit-keyframes bounceOutLeft {
  0% {
    -webkit-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-2000px);
  }
}
@-moz-keyframes bounceOutLeft {
  0% {
    -moz-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -moz-transform: translateX(20px);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(-2000px);
  }
}
@-o-keyframes bounceOutLeft {
  0% {
    -o-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -o-transform: translateX(20px);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(-2000px);
  }
}
@keyframes bounceOutLeft {
  0% {
    transform: translateX(0);
  }
  20% {
    opacity: 1;
    transform: translateX(20px);
  }
  100% {
    opacity: 0;
    transform: translateX(-2000px);
  }
}
.animated.bounceOutLeft {
  -webkit-animation-name: bounceOutLeft;
  -moz-animation-name: bounceOutLeft;
  -o-animation-name: bounceOutLeft;
  animation-name: bounceOutLeft;
}
@-webkit-keyframes bounceOutRight {
  0% {
    -webkit-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -webkit-transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(2000px);
  }
}
@-moz-keyframes bounceOutRight {
  0% {
    -moz-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -moz-transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(2000px);
  }
}
@-o-keyframes bounceOutRight {
  0% {
    -o-transform: translateX(0);
  }
  20% {
    opacity: 1;
    -o-transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(2000px);
  }
}
@keyframes bounceOutRight {
  0% {
    transform: translateX(0);
  }
  20% {
    opacity: 1;
    transform: translateX(-20px);
  }
  100% {
    opacity: 0;
    transform: translateX(2000px);
  }
}
.animated.bounceOutRight {
  -webkit-animation-name: bounceOutRight;
  -moz-animation-name: bounceOutRight;
  -o-animation-name: bounceOutRight;
  animation-name: bounceOutRight;
}
@-webkit-keyframes rotateIn {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@-moz-keyframes rotateIn {
  0% {
    -moz-transform-origin: center center;
    -moz-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -moz-transform-origin: center center;
    -moz-transform: rotate(0);
    opacity: 1;
  }
}
@-o-keyframes rotateIn {
  0% {
    -o-transform-origin: center center;
    -o-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -o-transform-origin: center center;
    -o-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateIn {
  0% {
    transform-origin: center center;
    transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    transform-origin: center center;
    transform: rotate(0);
    opacity: 1;
  }
}
.animated.rotateIn {
  -webkit-animation-name: rotateIn;
  -moz-animation-name: rotateIn;
  -o-animation-name: rotateIn;
  animation-name: rotateIn;
}
@-webkit-keyframes rotateInUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@-moz-keyframes rotateInUpLeft {
  0% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
}
@-o-keyframes rotateInUpLeft {
  0% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInUpLeft {
  0% {
    transform-origin: left bottom;
    transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    transform-origin: left bottom;
    transform: rotate(0);
    opacity: 1;
  }
}
.animated.rotateInUpLeft {
  -webkit-animation-name: rotateInUpLeft;
  -moz-animation-name: rotateInUpLeft;
  -o-animation-name: rotateInUpLeft;
  animation-name: rotateInUpLeft;
}
@-webkit-keyframes rotateInDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@-moz-keyframes rotateInDownLeft {
  0% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
}
@-o-keyframes rotateInDownLeft {
  0% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInDownLeft {
  0% {
    transform-origin: left bottom;
    transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    transform-origin: left bottom;
    transform: rotate(0);
    opacity: 1;
  }
}
.animated.rotateInDownLeft {
  -webkit-animation-name: rotateInDownLeft;
  -moz-animation-name: rotateInDownLeft;
  -o-animation-name: rotateInDownLeft;
  animation-name: rotateInDownLeft;
}
@-webkit-keyframes rotateInUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@-moz-keyframes rotateInUpRight {
  0% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
}
@-o-keyframes rotateInUpRight {
  0% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInUpRight {
  0% {
    transform-origin: right bottom;
    transform: rotate(-90deg);
    opacity: 0;
  }
  100% {
    transform-origin: right bottom;
    transform: rotate(0);
    opacity: 1;
  }
}
.animated.rotateInUpRight {
  -webkit-animation-name: rotateInUpRight;
  -moz-animation-name: rotateInUpRight;
  -o-animation-name: rotateInUpRight;
  animation-name: rotateInUpRight;
}
@-webkit-keyframes rotateInDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@-moz-keyframes rotateInDownRight {
  0% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
}
@-o-keyframes rotateInDownRight {
  0% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateInDownRight {
  0% {
    transform-origin: right bottom;
    transform: rotate(90deg);
    opacity: 0;
  }
  100% {
    transform-origin: right bottom;
    transform: rotate(0);
    opacity: 1;
  }
}
.animated.rotateInDownRight {
  -webkit-animation-name: rotateInDownRight;
  -moz-animation-name: rotateInDownRight;
  -o-animation-name: rotateInDownRight;
  animation-name: rotateInDownRight;
}
@-webkit-keyframes rotateOut {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(200deg);
    opacity: 0;
  }
}
@-moz-keyframes rotateOut {
  0% {
    -moz-transform-origin: center center;
    -moz-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -moz-transform-origin: center center;
    -moz-transform: rotate(200deg);
    opacity: 0;
  }
}
@-o-keyframes rotateOut {
  0% {
    -o-transform-origin: center center;
    -o-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -o-transform-origin: center center;
    -o-transform: rotate(200deg);
    opacity: 0;
  }
}
@keyframes rotateOut {
  0% {
    transform-origin: center center;
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    transform-origin: center center;
    transform: rotate(200deg);
    opacity: 0;
  }
}
.animated.rotateOut {
  -webkit-animation-name: rotateOut;
  -moz-animation-name: rotateOut;
  -o-animation-name: rotateOut;
  animation-name: rotateOut;
}
@-webkit-keyframes rotateOutUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
}
@-moz-keyframes rotateOutUpLeft {
  0% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(-90deg);
    opacity: 0;
  }
}
@-o-keyframes rotateOutUpLeft {
  0% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(-90deg);
    opacity: 0;
  }
}
@keyframes rotateOutUpLeft {
  0% {
    transform-origin: left bottom;
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    transform-origin: left bottom;
    transform: rotate(-90deg);
    opacity: 0;
  }
}
.animated.rotateOutUpLeft {
  -webkit-animation-name: rotateOutUpLeft;
  -moz-animation-name: rotateOutUpLeft;
  -o-animation-name: rotateOutUpLeft;
  animation-name: rotateOutUpLeft;
}
@-webkit-keyframes rotateOutDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: left bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
}
@-moz-keyframes rotateOutDownLeft {
  0% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -moz-transform-origin: left bottom;
    -moz-transform: rotate(90deg);
    opacity: 0;
  }
}
@-o-keyframes rotateOutDownLeft {
  0% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -o-transform-origin: left bottom;
    -o-transform: rotate(90deg);
    opacity: 0;
  }
}
@keyframes rotateOutDownLeft {
  0% {
    transform-origin: left bottom;
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    transform-origin: left bottom;
    transform: rotate(90deg);
    opacity: 0;
  }
}
.animated.rotateOutDownLeft {
  -webkit-animation-name: rotateOutDownLeft;
  -moz-animation-name: rotateOutDownLeft;
  -o-animation-name: rotateOutDownLeft;
  animation-name: rotateOutDownLeft;
}
@-webkit-keyframes rotateOutUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(90deg);
    opacity: 0;
  }
}
@-moz-keyframes rotateOutUpRight {
  0% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(90deg);
    opacity: 0;
  }
}
@-o-keyframes rotateOutUpRight {
  0% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(90deg);
    opacity: 0;
  }
}
@keyframes rotateOutUpRight {
  0% {
    transform-origin: right bottom;
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    transform-origin: right bottom;
    transform: rotate(90deg);
    opacity: 0;
  }
}
.animated.rotateOutUpRight {
  -webkit-animation-name: rotateOutUpRight;
  -moz-animation-name: rotateOutUpRight;
  -o-animation-name: rotateOutUpRight;
  animation-name: rotateOutUpRight;
}
@-webkit-keyframes rotateOutDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -webkit-transform-origin: right bottom;
    -webkit-transform: rotate(-90deg);
    opacity: 0;
  }
}
@-moz-keyframes rotateOutDownRight {
  0% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -moz-transform-origin: right bottom;
    -moz-transform: rotate(-90deg);
    opacity: 0;
  }
}
@-o-keyframes rotateOutDownRight {
  0% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(0);
    opacity: 1;
  }
  100% {
    -o-transform-origin: right bottom;
    -o-transform: rotate(-90deg);
    opacity: 0;
  }
}
@keyframes rotateOutDownRight {
  0% {
    transform-origin: right bottom;
    transform: rotate(0);
    opacity: 1;
  }
  100% {
    transform-origin: right bottom;
    transform: rotate(-90deg);
    opacity: 0;
  }
}
.animated.rotateOutDownRight {
  -webkit-animation-name: rotateOutDownRight;
  -moz-animation-name: rotateOutDownRight;
  -o-animation-name: rotateOutDownRight;
  animation-name: rotateOutDownRight;
}
@-webkit-keyframes hinge {
  0% {
    -webkit-transform: rotate(0);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    -webkit-transform: rotate(80deg);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  40% {
    -webkit-transform: rotate(60deg);
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  80% {
    -webkit-transform: rotate(60deg) translateY(0);
    opacity: 1;
    -webkit-transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
  }
  100% {
    -webkit-transform: translateY(700px);
    opacity: 0;
  }
}
@-moz-keyframes hinge {
  0% {
    -moz-transform: rotate(0);
    -moz-transform-origin: top left;
    -moz-animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    -moz-transform: rotate(80deg);
    -moz-transform-origin: top left;
    -moz-animation-timing-function: ease-in-out;
  }
  40% {
    -moz-transform: rotate(60deg);
    -moz-transform-origin: top left;
    -moz-animation-timing-function: ease-in-out;
  }
  80% {
    -moz-transform: rotate(60deg) translateY(0);
    opacity: 1;
    -moz-transform-origin: top left;
    -moz-animation-timing-function: ease-in-out;
  }
  100% {
    -moz-transform: translateY(700px);
    opacity: 0;
  }
}
@-o-keyframes hinge {
  0% {
    -o-transform: rotate(0);
    -o-transform-origin: top left;
    -o-animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    -o-transform: rotate(80deg);
    -o-transform-origin: top left;
    -o-animation-timing-function: ease-in-out;
  }
  40% {
    -o-transform: rotate(60deg);
    -o-transform-origin: top left;
    -o-animation-timing-function: ease-in-out;
  }
  80% {
    -o-transform: rotate(60deg) translateY(0);
    opacity: 1;
    -o-transform-origin: top left;
    -o-animation-timing-function: ease-in-out;
  }
  100% {
    -o-transform: translateY(700px);
    opacity: 0;
  }
}
@keyframes hinge {
  0% {
    transform: rotate(0);
    transform-origin: top left;
    animation-timing-function: ease-in-out;
  }
  20%,
  60% {
    transform: rotate(80deg);
    transform-origin: top left;
    animation-timing-function: ease-in-out;
  }
  40% {
    transform: rotate(60deg);
    transform-origin: top left;
    animation-timing-function: ease-in-out;
  }
  80% {
    transform: rotate(60deg) translateY(0);
    opacity: 1;
    transform-origin: top left;
    animation-timing-function: ease-in-out;
  }
  100% {
    transform: translateY(700px);
    opacity: 0;
  }
}
.animated.hinge {
  -webkit-animation-name: hinge;
  -moz-animation-name: hinge;
  -o-animation-name: hinge;
  animation-name: hinge;
}
@-webkit-keyframes rollIn {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0px) rotate(0deg);
  }
}
@-moz-keyframes rollIn {
  0% {
    opacity: 0;
    -moz-transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0px) rotate(0deg);
  }
}
@-o-keyframes rollIn {
  0% {
    opacity: 0;
    -o-transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0px) rotate(0deg);
  }
}
@keyframes rollIn {
  0% {
    opacity: 0;
    transform: translateX(-100%) rotate(-120deg);
  }
  100% {
    opacity: 1;
    transform: translateX(0px) rotate(0deg);
  }
}
.animated.rollIn {
  -webkit-animation-name: rollIn;
  -moz-animation-name: rollIn;
  -o-animation-name: rollIn;
  animation-name: rollIn;
}
@-webkit-keyframes rollOut {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0px) rotate(0deg);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(100%) rotate(120deg);
  }
}
@-moz-keyframes rollOut {
  0% {
    opacity: 1;
    -moz-transform: translateX(0px) rotate(0deg);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(100%) rotate(120deg);
  }
}
@-o-keyframes rollOut {
  0% {
    opacity: 1;
    -o-transform: translateX(0px) rotate(0deg);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(100%) rotate(120deg);
  }
}
@keyframes rollOut {
  0% {
    opacity: 1;
    transform: translateX(0px) rotate(0deg);
  }
  100% {
    opacity: 0;
    transform: translateX(100%) rotate(120deg);
  }
}
.animated.rollOut {
  -webkit-animation-name: rollOut;
  -moz-animation-name: rollOut;
  -o-animation-name: rollOut;
  animation-name: rollOut;
}
@-webkit-keyframes lightSpeedIn {
  0% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    -webkit-transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    -webkit-transform: translateX(0%) skewX(-15deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
}
@-moz-keyframes lightSpeedIn {
  0% {
    -moz-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    -moz-transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    -moz-transform: translateX(0%) skewX(-15deg);
    opacity: 1;
  }
  100% {
    -moz-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
}
@-o-keyframes lightSpeedIn {
  0% {
    -o-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    -o-transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    -o-transform: translateX(0%) skewX(-15deg);
    opacity: 1;
  }
  100% {
    -o-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
}
@keyframes lightSpeedIn {
  0% {
    transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
  60% {
    transform: translateX(-20%) skewX(30deg);
    opacity: 1;
  }
  80% {
    transform: translateX(0%) skewX(-15deg);
    opacity: 1;
  }
  100% {
    transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
}
.animated.lightSpeedIn {
  -webkit-animation-name: lightSpeedIn;
  -moz-animation-name: lightSpeedIn;
  -o-animation-name: lightSpeedIn;
  animation-name: lightSpeedIn;
  -webkit-animation-timing-function: ease-out;
  -moz-animation-timing-function: ease-out;
  -o-animation-timing-function: ease-out;
  animation-timing-function: ease-out;
}
.animated.lightSpeedIn {
  -webkit-animation-duration: .5s;
  -moz-animation-duration: .5s;
  -o-animation-duration: .5s;
  animation-duration: 0.5s;
}
@-webkit-keyframes lightSpeedOut {
  0% {
    -webkit-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
  100% {
    -webkit-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
@-moz-keyframes lightSpeedOut {
  0% {
    -moz-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
  100% {
    -moz-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
@-o-keyframes lightSpeedOut {
  0% {
    -o-transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
  100% {
    -o-transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
@keyframes lightSpeedOut {
  0% {
    transform: translateX(0%) skewX(0deg);
    opacity: 1;
  }
  100% {
    transform: translateX(100%) skewX(-30deg);
    opacity: 0;
  }
}
.animated.lightSpeedOut {
  -webkit-animation-name: lightSpeedOut;
  -moz-animation-name: lightSpeedOut;
  -o-animation-name: lightSpeedOut;
  animation-name: lightSpeedOut;
  -webkit-animation-timing-function: ease-in;
  -moz-animation-timing-function: ease-in;
  -o-animation-timing-function: ease-in;
  animation-timing-function: ease-in;
}
.animated.lightSpeedOut {
  -webkit-animation-duration: .25s;
  -moz-animation-duration: .25s;
  -o-animation-duration: .25s;
  animation-duration: 0.25s;
}
.fade {
  opacity: 0;
  -webkit-transition: opacity .15s linear;
  -moz-transition: opacity .15s linear;
  -o-transition: opacity .15s linear;
  transition: opacity 0.15s linear;
}
@-moz-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
  }
  100% {
    -moz-transform: rotate(359deg);
  }
}
@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
  }
}
@-o-keyframes spin {
  0% {
    -o-transform: rotate(0deg);
  }
  100% {
    -o-transform: rotate(359deg);
  }
}
@-ms-keyframes spin {
  0% {
    -ms-transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(359deg);
  }
}
@keyframes spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.note-editor {
  border: 1px solid #a9a9a9;
}
.note-editor.fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1050;
  width: 100%;
}
.note-editor.fullscreen .note-editable {
  background-color: #ffffff;
}
.note-editor.fullscreen .note-resizebar {
  display: none;
}
.note-editor.codeview .note-editable {
  display: none;
}
.note-editor.codeview .note-codeable {
  display: block;
}
.note-editor .note-toolbar {
  padding-bottom: 5px;
  padding-left: 5px;
  margin: 0;
  background-color: #f5f5f5;
  border-bottom: 1px solid #a9a9a9;
}
.note-editor .note-toolbar > .btn-group {
  margin-top: 5px;
  margin-right: 5px;
  margin-left: 0;
}
.note-editor .note-toolbar .note-table .dropdown-menu {
  min-width: 0;
  padding: 5px;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker {
  font-size: 18px;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-mousecatcher {
  position: absolute!important;
  z-index: 3;
  width: 10em;
  height: 10em;
  cursor: pointer;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-unhighlighted {
  position: relative!important;
  z-index: 1;
  width: 5em;
  height: 5em;
  background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIj4+Pjp6ekKlAqjAAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKhmnaJzPAAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC') repeat;
}
.note-editor .note-toolbar .note-table .dropdown-menu .note-dimension-picker .note-dimension-picker-highlighted {
  position: absolute!important;
  z-index: 2;
  width: 1em;
  height: 1em;
  background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIjd6vvD2f9LKLW+AAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKwNDEVT0AAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC') repeat;
}
.note-editor .note-toolbar .note-style h1,
.note-editor .note-toolbar .note-style h2,
.note-editor .note-toolbar .note-style h3,
.note-editor .note-toolbar .note-style h4,
.note-editor .note-toolbar .note-style h5,
.note-editor .note-toolbar .note-style h6,
.note-editor .note-toolbar .note-style blockquote {
  margin: 0;
}
.note-editor .note-toolbar .note-color .dropdown-toggle {
  width: 20px;
  padding-left: 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu {
  min-width: 290px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group {
  margin: 0;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group:first-child {
  margin: 0 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-palette-title {
  margin: 2px 7px;
  font-size: 12px;
  text-align: center;
  border-bottom: 1px solid #eeeeee;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset {
  padding: 0 3px;
  margin: 5px;
  font-size: 12px;
  cursor: pointer;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.note-editor .note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset:hover {
  background: #eeeeee;
}
.note-editor .note-toolbar .note-para .dropdown-menu {
  min-width: 153px;
  padding: 5px;
}
.note-editor .note-toolbar .note-para li:first-child {
  margin-bottom: 5px;
}
.note-editor .note-statusbar {
  background-color: #f5f5f5;
}
.note-editor .note-statusbar .note-resizebar {
  width: 100%;
  height: 8px;
  cursor: s-resize;
  border-top: 1px solid #a9a9a9;
}
.note-editor .note-statusbar .note-resizebar .note-icon-bar {
  width: 20px;
  margin: 1px auto;
  border-top: 1px solid #a9a9a9;
}
.note-editor .note-popover .popover {
  max-width: none;
}
.note-editor .note-popover .popover .popover-content {
  padding: 5px;
}
.note-editor .note-popover .popover .popover-content a {
  display: inline-block;
  max-width: 200px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  vertical-align: middle;
}
.note-editor .note-popover .popover .popover-content .btn-group + .btn-group {
  margin-left: 5px;
}
.note-editor .note-popover .popover .arrow {
  left: 20px;
}
.note-editor .note-handle .note-control-selection {
  position: absolute;
  display: none;
  border: 1px solid #000000;
}
.note-editor .note-handle .note-control-selection > div {
  position: absolute;
}
.note-editor .note-handle .note-control-selection .note-control-selection-bg {
  width: 100%;
  height: 100%;
  background-color: black;
  -webkit-opacity: .3;
  -khtml-opacity: .3;
  -moz-opacity: .3;
  opacity: .3;
  -ms-filter: alpha(opacity=30);
  filter: alpha(opacity=30);
}
.note-editor .note-handle .note-control-selection .note-control-handle {
  width: 7px;
  height: 7px;
  border: 1px solid #000000;
}
.note-editor .note-handle .note-control-selection .note-control-holder {
  width: 7px;
  height: 7px;
  border: 1px solid #000000;
}
.note-editor .note-handle .note-control-selection .note-control-sizing {
  width: 7px;
  height: 7px;
  background-color: white;
  border: 1px solid #000000;
}
.note-editor .note-handle .note-control-selection .note-control-nw {
  top: -5px;
  left: -5px;
  border-right: 0;
  border-bottom: 0;
}
.note-editor .note-handle .note-control-selection .note-control-ne {
  top: -5px;
  right: -5px;
  border-bottom: 0;
  border-left: none;
}
.note-editor .note-handle .note-control-selection .note-control-sw {
  bottom: -5px;
  left: -5px;
  border-top: 0;
  border-right: 0;
}
.note-editor .note-handle .note-control-selection .note-control-se {
  right: -5px;
  bottom: -5px;
  cursor: se-resize;
}
.note-editor .note-handle .note-control-selection .note-control-selection-info {
  right: 0;
  bottom: 0;
  padding: 5px;
  margin: 5px;
  font-size: 12px;
  color: white;
  background-color: black;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  -webkit-opacity: .7;
  -khtml-opacity: .7;
  -moz-opacity: .7;
  opacity: .7;
  -ms-filter: alpha(opacity=70);
  filter: alpha(opacity=70);
}
.note-editor .note-dialog > div {
  display: none;
}
.note-editor .note-dialog .note-image-dialog .note-dropzone {
  min-height: 200px;
  font-size: 30px;
  line-height: 6;
  color: lightgray;
  text-align: center;
  border: 4px dashed #d3d3d3;
}
.note-editor .note-dialog .note-help-dialog {
  font-size: 12px;
  color: #ccc;
  background: transparent;
  background-color: #222!important;
  border: 0;
  -webkit-opacity: .9;
  -khtml-opacity: .9;
  -moz-opacity: .9;
  opacity: .9;
  -ms-filter: alpha(opacity=90);
  filter: alpha(opacity=90);
}
.note-editor .note-dialog .note-help-dialog .modal-content {
  background: transparent;
  border: 1px solid white;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.note-editor .note-dialog .note-help-dialog a {
  font-size: 12px;
  color: #ffffff;
}
.note-editor .note-dialog .note-help-dialog .title {
  padding-bottom: 5px;
  font-size: 14px;
  font-weight: bold;
  color: white;
  border-bottom: #ffffff 1px solid;
}
.note-editor .note-dialog .note-help-dialog .modal-close {
  font-size: 14px;
  color: #dd0;
  cursor: pointer;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut-layout {
  width: 100%;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut-layout td {
  vertical-align: top;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut {
  margin-top: 8px;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut th {
  font-size: 13px;
  color: #dd0;
  text-align: left;
}
.note-editor .note-dialog .note-help-dialog .note-shortcut td:first-child {
  min-width: 110px;
  padding-right: 10px;
  font-family: "Courier New";
  color: #dd0;
  text-align: right;
}
.note-editor .note-editable {
  padding: 10px;
  overflow: scroll;
  outline: 0;
}
.note-editor .note-codeable {
  display: none;
  width: 100%;
  padding: 10px;
  margin-bottom: 0;
  font-family: Menlo, Monaco, monospace, sans-serif;
  font-size: 14px;
  color: #ccc;
  background-color: #222;
  border: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  box-shadow: none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  resize: none;
}
.note-editor .dropdown-menu {
  min-width: 90px;
}
.note-editor .dropdown-menu.right {
  right: 0;
  left: auto;
}
.note-editor .dropdown-menu.right::before {
  right: 9px;
  left: auto !important;
}
.note-editor .dropdown-menu.right::after {
  right: 10px;
  left: auto !important;
}
.note-editor .dropdown-menu li a i {
  color: deepskyblue;
  visibility: hidden;
}
.note-editor .dropdown-menu li a.checked i {
  visibility: visible;
}
.note-editor .note-color-palette {
  line-height: 1;
}
.note-editor .note-color-palette div .note-color-btn {
  width: 17px;
  height: 17px;
  padding: 0;
  margin: 0;
  border: 1px solid #ffffff;
}
.note-editor .note-color-palette div .note-color-btn:hover {
  border: 1px solid #000000;
}
/* adjustment */
.no-padding .note-editor {
  border: none;
}
.note-editor .note-editable {
  background-color: rgba(48, 126, 204, 0.05);
}
.note-editor .note-editable:focus {
  background-color: #fff;
}
.note-editor .note-statusbar .note-resizebar {
  border-top: 1px solid #DBDBDB;
}
.note-editor .note-statusbar:hover {
  background: #EEE;
}
.note-editor .note-statusbar:active {
  background: #eaeaea;
}
/**
 * Bootstrap-Markdown.less
 *
 * @author Taufan Aditya @taufanaditya
 * @copyright 2013 Taufan Aditya
 */
.md-editor {
  display: block;
  border: 1px solid #dddddd;
}
.md-editor > .md-header,
.md-editor .md-footer {
  display: block;
  padding: 6px 4px;
  background: #f5f5f5;
}
.md-editor > .md-preview {
  background: #ffffff;
  border-top: 1px dashed #dddddd;
  border-bottom: 1px dashed #dddddd;
  min-height: 10px;
  padding: 10px;
}
.md-editor > textarea {
  font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
  font-size: 13px;
  outline: 0;
  outline: thin dotted  \9;
  /* IE6-9 */
  margin: 0;
  display: block;
  padding: 0;
  width: 100%;
  border: 0;
  padding: 10px;
  border-top: 1px dashed #dddddd;
  border-bottom: 1px dashed #dddddd;
  border-radius: 0;
  box-shadow: none;
  background: #eeeeee;
}
.md-editor > textarea:focus {
  box-shadow: none;
  background: #ffffff;
}
.md-editor.active {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
/* The MIT License */
.dropzone,
.dropzone *,
.dropzone-previews,
.dropzone-previews * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.dropzone {
  position: relative;
  border: 1px solid rgba(0, 0, 0, 0.08);
  background: rgba(0, 0, 0, 0.02);
  padding: 1em;
}
.dropzone.dz-clickable {
  cursor: pointer;
}
.dropzone.dz-clickable .dz-message,
.dropzone.dz-clickable .dz-message span {
  cursor: pointer;
}
.dropzone.dz-clickable * {
  cursor: default;
}
.dropzone .dz-message {
  opacity: 1;
  -ms-filter: none;
  filter: none;
}
.dropzone.dz-drag-hover {
  border-color: rgba(0, 0, 0, 0.15);
  background: rgba(0, 0, 0, 0.04);
}
.dropzone.dz-started .dz-message {
  display: none;
}
.dropzone .dz-preview,
.dropzone-previews .dz-preview {
  background: rgba(255, 255, 255, 0.8);
  position: relative;
  display: inline-block;
  margin: 17px;
  vertical-align: top;
  border: 1px solid #acacac;
  padding: 6px 6px 6px 6px;
}
.dropzone .dz-preview.dz-file-preview [data-dz-thumbnail],
.dropzone-previews .dz-preview.dz-file-preview [data-dz-thumbnail] {
  display: none;
}
.dropzone .dz-preview .dz-details,
.dropzone-previews .dz-preview .dz-details {
  width: 100px;
  height: 100px;
  position: relative;
  background: #ebebeb;
  padding: 5px;
  margin-bottom: 22px;
}
.dropzone .dz-preview .dz-details .dz-filename,
.dropzone-previews .dz-preview .dz-details .dz-filename {
  overflow: hidden;
  height: 100%;
}
.dropzone .dz-preview .dz-details img,
.dropzone-previews .dz-preview .dz-details img {
  position: absolute;
  top: 0;
  left: 0;
  width: 100px;
  height: 100px;
}
.dropzone .dz-preview .dz-details .dz-size,
.dropzone-previews .dz-preview .dz-details .dz-size {
  position: absolute;
  bottom: -28px;
  left: 3px;
  height: 28px;
  line-height: 28px;
}
.dropzone .dz-preview.dz-error .dz-error-mark,
.dropzone-previews .dz-preview.dz-error .dz-error-mark {
  display: block;
}
.dropzone .dz-preview.dz-success .dz-success-mark,
.dropzone-previews .dz-preview.dz-success .dz-success-mark {
  display: block;
}
.dropzone .dz-preview:hover .dz-details img,
.dropzone-previews .dz-preview:hover .dz-details img {
  display: none;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark,
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  display: none;
  position: absolute;
  width: 40px;
  height: 40px;
  font-size: 30px;
  text-align: center;
  right: -10px;
  top: -10px;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  color: #8cc657;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  color: #ee162d;
}
.dropzone .dz-preview .dz-progress,
.dropzone-previews .dz-preview .dz-progress {
  position: absolute;
  top: 100px;
  left: 6px;
  right: 6px;
  height: 6px;
  background: #d7d7d7;
  display: none;
}
.dropzone .dz-preview .dz-progress .dz-upload,
.dropzone-previews .dz-preview .dz-progress .dz-upload {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 0%;
  background-color: #8cc657;
}
.dropzone .dz-preview.dz-processing .dz-progress,
.dropzone-previews .dz-preview.dz-processing .dz-progress {
  display: block;
}
.dropzone .dz-preview .dz-error-message,
.dropzone-previews .dz-preview .dz-error-message {
  display: none;
  position: absolute;
  top: -5px;
  left: -20px;
  background: rgba(245, 245, 245, 0.8);
  padding: 8px 10px;
  color: #800;
  min-width: 140px;
  max-width: 500px;
  z-index: 500;
}
.dropzone .dz-preview:hover.dz-error .dz-error-message,
.dropzone-previews .dz-preview:hover.dz-error .dz-error-message {
  display: block;
}
/* The MIT License */
.dropzone,
.dropzone *,
.dropzone-previews,
.dropzone-previews * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.dropzone {
  position: relative;
  border: 1px solid rgba(0, 0, 0, 0.08);
  background: rgba(0, 0, 0, 0.02);
  padding: 1em;
}
.dropzone.dz-clickable {
  cursor: pointer;
}
.dropzone.dz-clickable .dz-message,
.dropzone.dz-clickable .dz-message span {
  cursor: pointer;
}
.dropzone.dz-clickable * {
  cursor: default;
}
.dropzone .dz-message {
  opacity: 1;
  -ms-filter: none;
  filter: none;
}
.dropzone.dz-drag-hover {
  background-image: -webkit-gradient(linear, left top, right bottom, color-stop(0.25, rgba(0, 0, 0, 0.03)), color-stop(0.25, rgba(0, 0, 0, 0)), color-stop(0.5, rgba(0, 0, 0, 0)), color-stop(0.5, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0)), to(rgba(0, 0, 0, 0)));
  background-image: -webkit-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, rgba(0, 0, 0, 0) 25%, rgba(0, 0, 0, 0) 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, rgba(0, 0, 0, 0) 75%, rgba(0, 0, 0, 0));
  background-image: -moz-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -ms-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, rgba(0, 0, 0, 0) 25%, rgba(0, 0, 0, 0) 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, rgba(0, 0, 0, 0) 75%, rgba(0, 0, 0, 0));
  background-color: #fafafa;
  background-size: 22px 22px;
  border: 5px dashed #ccc;
}
.dropzone.dz-started .dz-message {
  display: none;
}
.dropzone .dz-preview,
.dropzone-previews .dz-preview {
  background: rgba(255, 255, 255, 0.8);
  position: relative;
  display: inline-block;
  margin: 10px;
  vertical-align: top;
  border: 1px solid #acacac;
  padding: 6px 6px 6px 6px;
}
.dropzone .dz-preview.dz-file-preview [data-dz-thumbnail],
.dropzone-previews .dz-preview.dz-file-preview [data-dz-thumbnail] {
  display: none;
}
.dropzone .dz-preview .dz-details,
.dropzone-previews .dz-preview .dz-details {
  width: 100px;
  height: 100px;
  position: relative;
  background: #ebebeb;
  padding: 5px;
  margin-bottom: 22px;
}
.dropzone .dz-preview .dz-details .dz-filename,
.dropzone-previews .dz-preview .dz-details .dz-filename {
  overflow: hidden;
  height: 100%;
}
.dropzone .dz-preview .dz-details img,
.dropzone-previews .dz-preview .dz-details img {
  position: absolute;
  top: 0;
  left: 0;
  width: 100px;
  height: 100px;
}
.dropzone .dz-preview .dz-details .dz-size,
.dropzone-previews .dz-preview .dz-details .dz-size {
  position: absolute;
  bottom: -28px;
  left: 3px;
  height: 28px;
  line-height: 28px;
}
.dropzone .dz-preview.dz-error .dz-error-mark,
.dropzone-previews .dz-preview.dz-error .dz-error-mark {
  display: block;
}
.dropzone .dz-preview.dz-success .dz-success-mark,
.dropzone-previews .dz-preview.dz-success .dz-success-mark {
  display: block;
}
.dropzone .dz-preview:hover .dz-details img,
.dropzone-previews .dz-preview:hover .dz-details img {
  display: none;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark,
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  display: none;
  position: absolute;
  width: 40px;
  height: 40px;
  font-size: 30px;
  text-align: center;
  right: -10px;
  top: -10px;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  color: #8cc657;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  color: #ee162d;
}
.dropzone .dz-preview .dz-progress,
.dropzone-previews .dz-preview .dz-progress {
  position: absolute;
  top: 100px;
  left: 6px;
  right: 6px;
  height: 6px;
  background: #d7d7d7;
  display: none;
}
.dropzone .dz-preview .dz-progress .dz-upload,
.dropzone-previews .dz-preview .dz-progress .dz-upload {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 0%;
  background-color: #8cc657;
}
.dropzone .dz-preview.dz-processing .dz-progress,
.dropzone-previews .dz-preview.dz-processing .dz-progress {
  display: block;
}
.dropzone .dz-preview .dz-error-message,
.dropzone-previews .dz-preview .dz-error-message {
  display: none;
  position: absolute;
  top: -5px;
  left: -20px;
  background: rgba(245, 245, 245, 0.8);
  padding: 8px 10px;
  color: #800;
  min-width: 140px;
  max-width: 500px;
  z-index: 500;
}
.dropzone .dz-preview:hover.dz-error .dz-error-message,
.dropzone-previews .dz-preview:hover.dz-error .dz-error-message {
  display: block;
}
.dropzone {
  border: 1px solid rgba(0, 0, 0, 0.03);
  min-height: 360px;
  -webkit-border-radius: 3px;
  border-radius: 3px;
  background: rgba(0, 0, 0, 0.03);
}
.dropzone .dz-default.dz-message {
  opacity: 1;
  -ms-filter: none;
  filter: none;
  -webkit-transition: opacity 0.3s ease-in-out;
  -moz-transition: opacity 0.3s ease-in-out;
  -o-transition: opacity 0.3s ease-in-out;
  -ms-transition: opacity 0.3s ease-in-out;
  transition: opacity 0.3s ease-in-out;
  background-image: url("../../img/dropzone/spritemap.png");
  background-repeat: no-repeat;
  background-position: 0 0;
  position: absolute;
  width: 428px;
  height: 123px;
  margin-left: -214px;
  margin-top: -61.5px;
  top: 50%;
  left: 50%;
}
.dropzone .dz-default.dz-message span {
  display: none;
}
.dropzone.dz-square .dz-default.dz-message {
  background-position: 0 -123px;
  width: 268px;
  margin-left: -134px;
  height: 174px;
  margin-top: -87px;
}
.dropzone.dz-drag-hover .dz-message {
  opacity: 0.15;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=15)";
  filter: alpha(opacity=15);
}
.dropzone.dz-started .dz-message {
  display: block;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
}
.dropzone .dz-preview,
.dropzone-previews .dz-preview {
  -webkit-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.16);
  box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.16);
  font-size: 14px;
}
.dropzone .dz-preview.dz-image-preview:hover .dz-details img,
.dropzone-previews .dz-preview.dz-image-preview:hover .dz-details img {
  display: block;
  opacity: 0.1;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=10)";
  filter: alpha(opacity=10);
}
.dropzone .dz-preview.dz-success .dz-success-mark,
.dropzone-previews .dz-preview.dz-success .dz-success-mark {
  opacity: 1;
  -ms-filter: none;
  filter: none;
}
.dropzone .dz-preview.dz-error .dz-error-mark,
.dropzone-previews .dz-preview.dz-error .dz-error-mark {
  opacity: 1;
  -ms-filter: none;
  filter: none;
}
.dropzone .dz-preview.dz-error .dz-progress .dz-upload,
.dropzone-previews .dz-preview.dz-error .dz-progress .dz-upload {
  background: #ee1e2d;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark,
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  display: block;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.4s ease-in-out;
  -moz-transition: opacity 0.4s ease-in-out;
  -o-transition: opacity 0.4s ease-in-out;
  -ms-transition: opacity 0.4s ease-in-out;
  transition: opacity 0.4s ease-in-out;
  background-image: url("../../img/dropzone/spritemap.png");
  background-repeat: no-repeat;
}
.dropzone .dz-preview .dz-error-mark span,
.dropzone-previews .dz-preview .dz-error-mark span,
.dropzone .dz-preview .dz-success-mark span,
.dropzone-previews .dz-preview .dz-success-mark span {
  display: none;
}
.dropzone .dz-preview .dz-error-mark,
.dropzone-previews .dz-preview .dz-error-mark {
  background-position: -268px -123px;
}
.dropzone .dz-preview .dz-success-mark,
.dropzone-previews .dz-preview .dz-success-mark {
  background-position: -268px -163px;
}
.dropzone .dz-preview .dz-progress .dz-upload,
.dropzone-previews .dz-preview .dz-progress .dz-upload {
  -webkit-animation: loading 0.4s linear infinite;
  -moz-animation: loading 0.4s linear infinite;
  -o-animation: loading 0.4s linear infinite;
  -ms-animation: loading 0.4s linear infinite;
  animation: loading 0.4s linear infinite;
  -webkit-transition: width 0.3s ease-in-out;
  -moz-transition: width 0.3s ease-in-out;
  -o-transition: width 0.3s ease-in-out;
  -ms-transition: width 0.3s ease-in-out;
  transition: width 0.3s ease-in-out;
  -webkit-border-radius: 2px;
  border-radius: 2px;
  position: absolute;
  top: 0;
  left: 0;
  width: 0%;
  height: 100%;
  background-image: url("../../img/dropzone/spritemap.png");
  background-repeat: repeat-x;
  background-position: 0px -400px;
}
.dropzone .dz-preview.dz-success .dz-progress,
.dropzone-previews .dz-preview.dz-success .dz-progress {
  display: block;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.4s ease-in-out;
  -moz-transition: opacity 0.4s ease-in-out;
  -o-transition: opacity 0.4s ease-in-out;
  -ms-transition: opacity 0.4s ease-in-out;
  transition: opacity 0.4s ease-in-out;
}
.dropzone .dz-preview .dz-error-message,
.dropzone-previews .dz-preview .dz-error-message {
  display: block;
  opacity: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.3s ease-in-out;
  -moz-transition: opacity 0.3s ease-in-out;
  -o-transition: opacity 0.3s ease-in-out;
  -ms-transition: opacity 0.3s ease-in-out;
  transition: opacity 0.3s ease-in-out;
}
.dropzone .dz-preview:hover.dz-error .dz-error-message,
.dropzone-previews .dz-preview:hover.dz-error .dz-error-message {
  opacity: 1;
  -ms-filter: none;
  filter: none;
}
.dropzone a.dz-remove,
.dropzone-previews a.dz-remove {
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #fafafa), color-stop(1, #eeeeee));
  background-image: -webkit-linear-gradient(top, #fafafa 0, #eeeeee 100%);
  background-image: -moz-linear-gradient(top, #fafafa 0, #eeeeee 100%);
  background-image: -o-linear-gradient(top, #fafafa 0, #eeeeee 100%);
  background-image: -ms-linear-gradient(top, #fafafa 0, #eeeeee 100%);
  background-image: linear-gradient(top, #fafafa 0, #eeeeee 100%);
  -webkit-border-radius: 2px;
  border-radius: 2px;
  border: 1px solid #eee;
  text-decoration: none;
  display: block;
  padding: 4px 5px;
  text-align: center;
  color: #aaa;
  margin-top: 26px;
}
.dropzone a.dz-remove:hover,
.dropzone-previews a.dz-remove:hover {
  color: #666;
}
@-moz-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@-webkit-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@-o-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@-ms-keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
@keyframes loading {
  0% {
    background-position: 0 -400px;
  }
  100% {
    background-position: -7px -400px;
  }
}
/*
 * CSS TABLES
 */
.the-price {
  background-color: rgba(220, 220, 220, 0.17);
  box-shadow: 0 1px 0 #dcdcdc, inset 0 1px 0 #fff;
  padding: 20px;
  margin: 0;
}
.the-price h1 {
  line-height: 1em;
  padding: 0;
  margin: 0;
}
.subscript {
  font-size: 21px;
  color: #999;
}
/* 
 * RIBBON
 */
.ribbon {
  position: absolute;
  right: 9px;
  top: -4px;
}
/*
 * Price BIG
 */
.pricing-big {
  border: none !important;
}
.pricing-big .panel-heading {
  border-radius: 5px 5px 0 0;
}
.pricing-big .panel-title {
  text-transform: capitalize;
  font-size: 18px;
  padding: 20px 0;
  text-align: center;
  border-radius: 5px 5px 0 0;
  margin: 0;
  font-weight: bold;
}
.pricing-big .the-price {
  padding: 20px 0;
  background: #333;
  text-align: center;
  font-size: 24px;
  font-weight: bold;
  color: #FFF;
  box-shadow: none !important;
  -moz-box-shadow: none !important;
}
.pricing-big .subscript {
  font-size: 18px;
  color: #999;
  margin-left: 5px;
}
.price-features {
  background: #FAFAFA;
  padding: 20px 15px;
  min-height: 230px;
  font-size: 13.5px;
}
.price-features li + li {
  margin-top: 10px;
}
.pricing-big .panel-footer {
  border-radius: 0 0 5px 5px;
}
.pricing-big .panel-footer .btn {
  padding: 15px 0;
  border-radius: 3px;
  font-weight: bold;
  font-size: 14px;
}
.pricing-big .panel-footer .btn span {
  font-weight: normal;
  font-style: italic;
}
.pricing-big .panel-footer {
  background-color: #F2F2F2 !important;
}
.pricing-big .panel-footer > div {
  padding: 15px 0 10px;
  display: block;
  font-size: 13px;
}
.pricing-big table {
  background: #FAFAFA;
  padding: 20px 15px;
  height: 230px;
  text-align: left;
}
/*
	Important this file is beeen modified by Webarch
*/
/*------------------------------------*\
    SuperBox
\*------------------------------------*/
.superbox *,
.superbox *:after,
.superbox *:before {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-font-smoothing: antialiased;
  -moz-font-smoothing: antialiased;
  -o-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
}
/* SuperBox */
.superbox-list {
  display: inline-block;
  *display: inline;
  zoom: 1;
  width:  16.666667%;
  padding: 5px;
  position: relative;
}
.superbox-list.active:before {
  content: "\f0d8";
  font-family: FontAwesome;
  display: block;
  position: absolute;
  left: 43%;
  bottom: -34px;
  z-index: 2;
  text-align: center;
  font-size: 45px;
  color: #222222;
}
.superbox-img {
  max-width: 100%;
  width: 100%;
  cursor: pointer;
}
.superbox-show {
  text-align: left;
  position: relative;
  background-color: #222222;
  width: 100%;
  float: left;
  padding: 25px 0 12px 25px;
  display: none;
  margin: 5px 0;
}
.superbox-current-img {
  max-width: 100%;
  float: left;
  padding-right: 25px;
  padding-bottom: 13px;
}
.superbox-img:hover {
  opacity: 0.8;
}
.superbox-float {
  float: left;
}
.superbox-close {
  opacity: 0.7;
  cursor: pointer;
  position: absolute;
  top: 15px;
  right: 15px;
  transition: all 0.1s linear 0s;
}
.superbox-close:hover {
  opacity: 1;
}
.superbox-imageinfo {
  display: inline-block;
  max-width: 500px;
  color: #fff;
  padding: 0 25px 0 0;
}
.superbox-imageinfo span {
  font-size: 13px;
  color: #a19994;
  margin-right: -2px;
  padding-top: 10px;
  display: inline-block;
  padding-bottom: 13px;
}
.superbox-imageinfo > :first-child {
  margin-bottom: 10px;
  font-weight: bold;
}
.superbox-imageinfo span p:last-child {
  margin-top: 30px;
}
@media only screen and (min-width: 320px) {
  .superbox-list {
    width: 50%;
  }
}
@media only screen and (min-width: 486px) {
  .superbox-list {
    width: 25%;
  }
}


@media only screen and (min-width: 768px) {
  .superbox-list {
    width: 25%;
  }
}
@media only screen and (min-width: 1025px) {
  .superbox-list {
    width: 25%;
  }
}
@media only screen and (min-width: 1824px) {
  .superbox-list {
    width: 16.66666667%;
  }
}

.bootstrap-tagsinput {
  display: block;
  width: 100%;
  min-height: 32px;
  padding: 1px 3px;
  font-size: 13px;
  line-height: 1.428571429;
  color: #555;
  vertical-align: middle;
  background-color: #FFF;
  border: 1px solid #CCC;
  border-radius: 0;
}
.bootstrap-tagsinput > span {
  border-radius: 0px !important;
  font-weight: normal;
  padding: 3px 28px 4px 8px;
  font-size: 13px;
  border: 1px solid #285E8E;
  background: #3276B1;
}
.bootstrap-tagsinput input {
  border: none;
  box-shadow: none;
  outline: none;
  background-color: transparent;
  padding: 0;
  margin: 0;
  width: auto !important;
  max-width: inherit;
}
.bootstrap-tagsinput input:focus {
  border: none;
  box-shadow: none;
}
.bootstrap-tagsinput .tag {
  color: #FFF;
  position: relative;
  margin: 3px 0 3px 2px;
  display: inline-block;
}
.bootstrap-tagsinput .tag [data-role="remove"] {
  display: block;
  top: -1px;
  right: 0px;
  padding: 3px 4px 3px 5px;
  width: 23px;
  height: 22px;
  position: absolute;
  cursor: pointer;
}
.bootstrap-tagsinput .tag [data-role="remove"]:hover {
  background: rgba(0, 0, 0, 0.3);
}
.bootstrap-tagsinput .tag [data-role="remove"]:after {
  content: "\f057";
  font-family: fontAwesome;
  padding: 2px 1px;
  line-height: 17px;
  font-size: 15px;
  text-align: center;
}
.bootstrap-tagsinput .tag [data-role="remove"]:hover {
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.bootstrap-tagsinput .tag [data-role="remove"]:hover:active {
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
div.dt-top-row {
  height: 0;
  line-height: 0;
  position: relative;
}
div.dt-bottom-row {
  background: #fafafa;
  font-size: 11px;
  overflow: hidden;
  padding: 5px 10px;
  border-top: 1px solid #ccc;
  -webkit-box-shadow: inset 0 1px #fff;
  -moz-box-shadow: inset 0 1px #fff;
  -ms-box-shadow: inset 0 1px #fff;
  box-shadow: inset 0 1px #ffffff;
}
div.dataTables_length {
  position: absolute;
  right: 13px;
  top: -38px;
}
div.dataTables_length select {
  width: 60px;
  padding: 3px;
  border: none;
  font-size: 13px;
}
div.dataTables_filter {
  position: absolute;
  left: 10px;
  top: -38px;
}
div.dataTables_filter input {
  /*height: 26px;*/
  padding: 2px 8px;
  font-size: 13px;
  border: none;
}
.dataTables_filter .input-group {
  width: 180px !important;
}
div.dataTables_length select,
div.dataTables_filter input {
  border: 1px solid #bbbbbb;
}
div.dataTables_paginate {
  margin: 4px 0 0;
}
div.dataTables_paginate .pagination {
  margin: 0;
}
.dataTables_wrapper {
  position: relative;
}
.dt-wrapper {
  overflow: hidden;
}
.dataTables_wrapper table.table {
  clear: both;
  max-width: inherit;
  margin-bottom: 0;
}
.dataTables_wrapper table.table thead th {
  white-space: nowrap;
  text-overflow: ellipsis;
  -ms-text-overflow: ellipsis;
}
.dataTables_wrapper table.table thead .sorting,
.dataTables_wrapper table.table thead .sorting_asc,
.dataTables_wrapper table.table thead .sorting_desc,
.dataTables_wrapper table.table thead .sorting_asc_disabled,
.dataTables_wrapper table.table thead .sorting_desc_disabled {
  cursor: hand;
  cursor: pointer;
  padding-right: 20px;
}
.dataTables_wrapper table.table thead .sorting {
  background: url('../../img/sort_both.png') no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_asc {
  background: url('../../img/sort_asc.png') no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_desc {
  background: url('../../img/sort_desc.png') no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_asc_disabled {
  background: url('../../img/sort_asc_disabled.png') no-repeat center right;
}
.dataTables_wrapper table.table thead .sorting_desc_disabled {
  background: url('../../img/sort_desc_disabled.png') no-repeat center right;
}
.dataTables_wrapper table.dataTable th:active {
  outline: none;
}
.dataTables_wrapper table.table tbody tr.active td,
.dataTables_wrapper table.table tbody tr.active th {
  background-color: #08C;
  color: #ffffff;
}
.dataTables_wrapper table.table tbody tr.active:hover td,
.dataTables_wrapper table.table tbody tr.active:hover th {
  background-color: #0075b0 !important;
}
.dataTables_wrapper .table-striped tbody tr.active:nth-child(odd) td,
.dataTables_wrapper .table-striped tbody tr.active:nth-child(odd) th {
  background-color: #017ebc;
}
.dataTables_wrapper select {
  min-height: inherit;
}
.dataTables_wrapper table + .row {
  margin-bottom: 0;
  margin-top: 10px;
}
.dataTables_scrollBody {
  -webkit-overflow-scrolling: touch;
}
.dataTables_wrapper .top,
.dataTables_wrapper .bottom {
  background-color: #f5f5f5;
  border: 1px solid #CCC;
  padding: 15px;
}
.top .dataTables_info {
  float: none;
}
div.dt-bottom-row .dataTables_info {
  float: left;
  line-height: 32px;
  font-size: 12px;
}
.dataTables_empty {
  text-align: center !important;
  font-size: 15px;
  background: #fff !important;
  padding: 20px 0 !important;
}
.dataTables_scroll {
  clear: both;
}
.dataTables_scrollHeadInner table.table-bordered {
  -webkit-border-radius: 4px 4px 0 0;
  border-radius: 4px 4px 0 0;
  border-bottom: none;
}
.dataTables_scrollHeadInner table.table-bordered,
.dataTables_scrollHeadInner table.table-bordered thead {
  border-bottom: none;
}
.dataTables_scrollBody table {
  border-top: none;
}
.dataTables_processing {
  position: absolute;
  top: 50%;
  margin-top: -24px;
  z-index: 100;
  left: 50%;
  width: 250px;
  margin-left: -125px;
  border: 1px solid #ddd;
  text-align: center;
  color: #000;
  background: #fff;
  font-size: 15px !important;
  -webkit-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  -ms-box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.2);
  padding: 10px 0;
}
.dataTables_wrapper .center {
  text-align: center;
}
.dataTables_wrapper .details,
.dataTables_wrapper .details:hover {
  background: #dddddd !important;
}
.dataTables_wrapper .details table td {
  background: #ffffff !important;
}
.dataTables_scrollHeadInner table.table,
.dataTables_wrapper .details table.table {
  margin: 0 !important;
}
.dataTables_wrapper .dt_actions {
  float: left;
  margin-right: 20px;
}
.dataTables_empty {
  cursor: default;
}
.dataTables_full {
  width: 100% !important;
}
.dataTables_wrapper div.DTTT .btn:hover {
  text-decoration: none !important;
}
.dataTables_wrapper ul.DTTT_dropdown.dropdown-menu a {
  color: #333333 !important;
}
.dataTables_wrapper ul.DTTT_dropdown.dropdown-menu li:hover a {
  background-color: #08c;
  color: #ffffff !important;
}
.dataTables_wrapper div.DTTT_print_info.modal {
  height: 150px;
  margin-top: -75px;
  text-align: center;
}
.dataTables_wrapper div.DTTT_print_info h6 {
  font-weight: 400;
  font-size: 28px;
  line-height: 28px;
  margin: 1em;
}
.dataTables_wrapper div.DTTT_print_info p {
  font-size: 14px;
  line-height: 20px;
}
.dataTables_wrapper div.DTFC_LeftHeadWrapper table,
.dataTables_wrapper div.DTFC_LeftFootWrapper table,
.dataTables_wrapper table.DTFC_Cloned tr.even {
  background-color: #ffffff;
}
.dataTables_wrapper div.DTFC_LeftHeadWrapper table {
  margin-bottom: 0 !important;
  border-top-right-radius: 0 !important;
  border-bottom-left-radius: 0 !important;
  border-bottom-right-radius: 0 !important;
}
div.dataTables_scrollHead table {
  margin-bottom: 0 !important;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
div.dataTables_scrollHead table thead tr:last-child th:first-child,
div.dataTables_scrollHead table thead tr:last-child td:first-child,
div.DTFC_LeftHeadWrapper table thead tr:last-child th:first-child,
div.DTFC_LeftHeadWrapper table thead tr:last-child td:first-child {
  border-bottom-left-radius: 0 !important;
  border-bottom-right-radius: 0 !important;
}
div.dataTables_scrollBody table,
div.DTFC_LeftBodyWrapper table {
  border-top: none;
  margin-bottom: 0 !important;
}
div.dataTables_scrollBody tbody tr:first-child th,
div.dataTables_scrollFoot table,
div.DTFC_LeftBodyWrapper tbody tr:first-child th,
div.DTFC_LeftBodyWrapper tbody tr:first-child td,
div.DTFC_LeftFootWrapper table {
  border-top: none;
}
.dt-row {
  padding: 4px 10px;
}
.ColVis {
  position: absolute;
  right: 83px;
  top: -38px;
}
.ColVis_collection .ColVis_Button {
  position: relative;
  margin-right: 3px;
  height: 30px;
  background-color: #fff;
  border: 1px solid #d0d0d0;
  cursor: hand;
  padding: 3px 5px;
}
button.ColVis_Button::-moz-focus-inner {
  border: none !important;
  padding: 0;
}
div.ColVis_collectionBackground {
  background-color: #000;
  z-index: 1100;
}
div.ColVis_collection {
  position: relative;
  width: 180px;
  background-color: #fff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  z-index: 1102;
}
div.ColVis_collection button.ColVis_Button {
  padding: 4px 12px;
  height: 26px;
  background-color: #fff;
  border: none;
  width: 100%;
  float: none;
  font-size: 12px;
}
div.ColVis_collection button.ColVis_Button + button.ColVis_Button {
  border-top: 1px solid #e1e1e1;
}
div.ColVis_collection button.ColVis_Button input {
  margin: 0;
}
div.ColVis_catcher {
  position: absolute;
  z-index: 1101;
}
.disabled {
  color: #999999;
}
button.ColVis_Button {
  text-align: left;
}
span.ColVis_radio {
  display: inline-block;
  width: 20px;
  vertical-align: -2px;
}
.ColVis_text_hover,
div.ColVis_collection button.ColVis_Button:hover {
  background: #F2F2F2;
  color: #222222;
}
table.DTCR_clonedTable {
  background-color: #fff;
  z-index: 202;
}
div.DTCR_pointer {
  width: 1px;
  background-color: #0259C4;
  z-index: 201;
}
ul.DTTT_dropdown.dropdown-menu li {
  position: relative;
}
ul.DTTT_dropdown.dropdown-menu li:hover a {
  background-color: #f2f2f2;
  color: #333 !important;
}
.table_tools_group {
  position: absolute;
  right: 83px;
  top: -37px;
}
.DTTT.btn-group {
  position: absolute;
  top: -38px;
  right: 83px;
}
.DTTT_dropdown {
  z-index: 2002;
}
.DTFC_LeftHeadWrapper {
  border-bottom: 1px solid #dddddd;
}
/*
 * File:        TableTools.css
 * Description: Styles for TableTools 2
 * Author:      Allan Jardine (www.sprymedia.co.uk)
 * Language:    Javascript
 * License:     GPL v2 / 3 point BSD
 * Project:     DataTables
 * 
 * Copyright 2009-2012 Allan Jardine, all rights reserved.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *
 * CSS name space:
 *   DTTT                  DataTables TableTools
 *
 * Style sheet provides:
 *   CONTAINER             TableTools container element and styles applying to all components
 *   BUTTON_STYLES         Action specific button styles
 *   SELECTING             Row selection styles
 *   COLLECTIONS           Drop down list (collection) styles
 *   PRINTING              Print display styles
 */
/*
 * CONTAINER
 * TableTools container element and styles applying to all components
 */
div.DTTT_container {
  position: relative;
  float: right;
  margin-bottom: 1em;
}
button.DTTT_button,
div.DTTT_button,
a.DTTT_button {
  position: relative;
  float: left;
  margin-right: 3px;
  padding: 5px 8px;
  border: 1px solid #999;
  cursor: pointer;
  *cursor: hand;
  font-size: 0.88em;
  color: black !important;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  -o-border-radius: 2px;
  border-radius: 2px;
  -webkit-box-shadow: 1px 1px 3px #ccc;
  -moz-box-shadow: 1px 1px 3px #ccc;
  -ms-box-shadow: 1px 1px 3px #ccc;
  -o-box-shadow: 1px 1px 3px #ccc;
  box-shadow: 1px 1px 3px #ccc;
  /* Generated by http://www.colorzilla.com/gradient-editor/ */
  background: #ffffff;
  /* Old browsers */
  background: -webkit-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* Chrome10+,Safari5.1+ */
  background: -moz-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* FF3.6+ */
  background: -ms-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* IE10+ */
  background: -o-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* Opera 11.10+ */
  background: linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f9f9f9', GradientType=0);
  /* IE6-9 */
}
/* Buttons are cunning border-box sizing - we can't just use that for A and DIV due to IE6/7 */
button.DTTT_button {
  height: 30px;
  padding: 3px 8px;
}
.DTTT_button embed {
  outline: none;
}
button.DTTT_button:hover,
div.DTTT_button:hover,
a.DTTT_button:hover {
  border: 1px solid #666;
  text-decoration: none !important;
  -webkit-box-shadow: 1px 1px 3px #999;
  -moz-box-shadow: 1px 1px 3px #999;
  -ms-box-shadow: 1px 1px 3px #999;
  -o-box-shadow: 1px 1px 3px #999;
  box-shadow: 1px 1px 3px #999;
  background: #f3f3f3;
  /* Old browsers */
  background: -webkit-linear-gradient(top, #f3f3f3 0%, #e2e2e2 89%, #f4f4f4 100%);
  /* Chrome10+,Safari5.1+ */
  background: -moz-linear-gradient(top, #f3f3f3 0%, #e2e2e2 89%, #f4f4f4 100%);
  /* FF3.6+ */
  background: -ms-linear-gradient(top, #f3f3f3 0%, #e2e2e2 89%, #f4f4f4 100%);
  /* IE10+ */
  background: -o-linear-gradient(top, #f3f3f3 0%, #e2e2e2 89%, #f4f4f4 100%);
  /* Opera 11.10+ */
  background: linear-gradient(top, #f3f3f3 0%, #e2e2e2 89%, #f4f4f4 100%);
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f3f3f3', endColorstr='#f4f4f4', GradientType=0);
  /* IE6-9 */
}
button.DTTT_disabled,
div.DTTT_disabled,
a.DTTT_disabled {
  color: #999;
  border: 1px solid #d0d0d0;
  background: #ffffff;
  /* Old browsers */
  background: -webkit-linear-gradient(top, #ffffff 0%, #f9f9f9 89%, #fafafa 100%);
  /* Chrome10+,Safari5.1+ */
  background: -moz-linear-gradient(top, #ffffff 0%, #f9f9f9 89%, #fafafa 100%);
  /* FF3.6+ */
  background: -ms-linear-gradient(top, #ffffff 0%, #f9f9f9 89%, #fafafa 100%);
  /* IE10+ */
  background: -o-linear-gradient(top, #ffffff 0%, #f9f9f9 89%, #fafafa 100%);
  /* Opera 11.10+ */
  background: linear-gradient(top, #ffffff 0%, #f9f9f9 89%, #fafafa 100%);
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#fafafa', GradientType=0);
  /* IE6-9 */
}
/*
 * BUTTON_STYLES
 * Action specific button styles
 * If you want images - comment this back in

button.DTTT_button_csv,
button.DTTT_button_xls,
button.DTTT_button_copy,
button.DTTT_button_pdf,
button.DTTT_button_print {
	padding-right: 0px;
}

button.DTTT_button_csv span,
button.DTTT_button_xls span,
button.DTTT_button_copy span,
button.DTTT_button_pdf span,
button.DTTT_button_print span {
	display: inline-block;
	height: 24px;
	line-height: 24px;
	padding-right: 30px;
}


button.DTTT_button_csv span { background: url(../../img/csv.png) no-repeat bottom right; }
button.DTTT_button_csv:hover span { background: url(../../img/csv_hover.png) no-repeat center right; }

button.DTTT_button_xls span { background: url(../../img/xls.png) no-repeat center right; }
button.DTTT_button_xls:hover span { background: #f0f0f0 url(../../img/xls_hover.png) no-repeat center right; }

button.DTTT_button_copy span { background: url(../../img/copy.png) no-repeat center right; }
button.DTTT_button_copy:hover span { background: #f0f0f0 url(../../img/copy_hover.png) no-repeat center right; }

button.DTTT_button_pdf span { background: url(../../img/pdf.png) no-repeat center right; }
button.DTTT_button_pdf:hover span { background: #f0f0f0 url(../../img/pdf_hover.png) no-repeat center right; }

button.DTTT_button_print span { background: url(../../img/print.png) no-repeat center right; }
button.DTTT_button_print:hover span { background: #f0f0f0 url(../../img/print_hover.png) no-repeat center right; }



button.DTTT_button_collection span {
	padding-right: 17px;
	background: url(../../img/collection.png) no-repeat center right;
}

button.DTTT_button_collection:hover span {
	padding-right: 17px;
	background: #f0f0f0 url(../../img/collection_hover.png) no-repeat center right;
} */
/*
 * SELECTING
 * Row selection styles
 */
table.DTTT_selectable tbody tr {
  cursor: pointer;
  *cursor: hand;
}
table.dataTable tr.DTTT_selected.odd {
  background-color: #9FAFD1;
}
table.dataTable tr.DTTT_selected.odd td.sorting_1 {
  background-color: #9FAFD1;
}
table.dataTable tr.DTTT_selected.odd td.sorting_2 {
  background-color: #9FAFD1;
}
table.dataTable tr.DTTT_selected.odd td.sorting_3 {
  background-color: #9FAFD1;
}
table.dataTable tr.DTTT_selected.even {
  background-color: #B0BED9;
}
table.dataTable tr.DTTT_selected.even td.sorting_1 {
  background-color: #B0BED9;
}
table.dataTable tr.DTTT_selected.even td.sorting_2 {
  background-color: #B0BED9;
}
table.dataTable tr.DTTT_selected.even td.sorting_3 {
  background-color: #B0BED9;
}
/*
 * COLLECTIONS
 * Drop down list (collection) styles
 */
div.DTTT_collection {
  width: 150px;
  padding: 8px 8px 4px 8px;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.4);
  background-color: #f3f3f3;
  background-color: rgba(255, 255, 255, 0.3);
  overflow: hidden;
  z-index: 2002;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  -ms-border-radius: 5px;
  -o-border-radius: 5px;
  border-radius: 5px;
  -webkit-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  -ms-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  -o-box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
  box-shadow: 3px 3px 5px rgba(0, 0, 0, 0.3);
}
div.DTTT_collection_background {
  /*background: transparent url(../../img/background.png) repeat top left;*/
  z-index: 2001;
}
div.DTTT_collection button.DTTT_button,
div.DTTT_collection div.DTTT_button,
div.DTTT_collection a.DTTT_button {
  position: relative;
  left: 0;
  right: 0;
  display: block;
  float: none;
  margin-bottom: 4px;
  -webkit-box-shadow: 1px 1px 3px #999;
  -moz-box-shadow: 1px 1px 3px #999;
  -ms-box-shadow: 1px 1px 3px #999;
  -o-box-shadow: 1px 1px 3px #999;
  box-shadow: 1px 1px 3px #999;
}
/*
 * PRINTING
 * Print display styles
 */
.DTTT_print_info {
  position: fixed;
  top: 50%;
  left: 50%;
  width: 400px;
  height: 150px;
  margin-left: -200px;
  margin-top: -75px;
  text-align: center;
  color: #333;
  padding: 10px 30px;
  background: #ffffff;
  /* Old browsers */
  background: -webkit-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* Chrome10+,Safari5.1+ */
  background: -moz-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* FF3.6+ */
  background: -ms-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* IE10+ */
  background: -o-linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* Opera 11.10+ */
  background: linear-gradient(top, #ffffff 0%, #f3f3f3 89%, #f9f9f9 100%);
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f9f9f9', GradientType=0);
  /* IE6-9 */
  opacity: 0.95;
  border: 1px solid black;
  border: 1px solid rgba(0, 0, 0, 0.5);
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  -ms-border-radius: 6px;
  -o-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  -ms-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  -o-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.5);
}
.DTTT_print_info h6 {
  font-weight: normal;
  font-size: 28px;
  line-height: 28px;
  margin: 1em;
}
.DTTT_print_info p {
  font-size: 14px;
  line-height: 20px;
}
/* The styles given to the associated form element in order to hide it */
.fd-form-element-hidden {
  display: none;
}
/* Horizontal Outer wrapper - all other DOM elements added as children to this top level wrapper */
.fd-slider {
  width: 100%;
  /* The height of the slider handle */
  height: 20px;
  margin: 0;
}
/* Vertical Outer wrapper - all other DOM elements added as children to this top level wrapper */
.fd-slider-vertical {
  /* The width of the slider handle */
  width: 20px;
  /* Fill the available space */
  height: 100%;
  /* Set a 10 pixel right and bottom margin */
  margin: 0 10px 10px 0;
  /* You may wish to float the vertical sliders left or display:inline-block */
  /* float:left; */
}
/* Shared rules - both horizontal & vertical sliders */
.fd-slider,
.fd-slider-vertical {
  /* display:block required as the wrapper element is a span */
  display: block;
  /* This lets us absolutely position the drag handle */
  position: relative;
  text-decoration: none;
  border: 0 none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-touch-callout: none;
  user-select: none;
}
.fd-slider-inner {
  /* Used by IE for the onfocus blur effect */
  display: none;
}
/* The inner track bar */
.fd-slider-bar {
  position: absolute;
  display: block;
  z-index: 2;
  height: 6px;
  width: 100%;
  border: 1px solid #bbb;
  border-bottom: 1px solid #fff;
  border-right: 1px solid #fff;
  margin: 0;
  padding: 0;
  overflow: hidden;
  line-height: 4px;
  top: 8px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  border-radius: 4px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #333;
}
/* The animated range bar */
.fd-slider-range {
  position: absolute;
  display: block;
  z-index: 3;
  height: 6px;
  margin: 0;
  padding: 0 2px 0 0;
  overflow: hidden;
  top: 9px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background-color: #eee;
}
/* The drag handle */
.fd-slider-handle {
  position: absolute;
  display: block;
  padding: 0;
  border: 0 none;
  margin: 0 0 0 1px;
  z-index: 3;
  top: 5px;
  left: 0;
  width: 12px;
  height: 12px;
  line-height: 1px !important;
  outline: 0 none;
  background: #eee;
  border: 1px solid #aaa;
  border-radius: 12px;
  -webkit-user-select: none;
  -webkit-touch-callout: none;
  -moz-user-select: none;
  -moz-user-focus: none;
  -moz-outline: 0 none;
  user-select: none;
}
/* Focus styles */
.fd-slider-handle:focus {
  outline: 0 none;
  border: 0 none;
  -moz-user-focus: normal;
}
button.fd-slider-handle:focus::-moz-focus-inner {
  border-color: transparent;
}
body.fd-slider-drag-vertical,
body.fd-slider-drag-vertical * {
  /* Stop text selection */
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
}
body.fd-slider-drag-horizontal,
body.fd-slider-drag-horizontal * {
  /* Stop text selection */
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
}
/*
	 Sample tooltip code. Only works on grade A browsers (so no IE6,7 or 8).
	
	 See: http://nicolasgallagher.com/multiple-backgrounds-and-borders-with-css2/ for full info on
	 how to style generated content & the associated pitfalls
	
	 This code to be taken as experimental & untested - use at your discretion
	
	 If showing the tooltip above the sider handle you are relegated to showing
	 single line tooltips due to styling constraints!
	 */
.fd-slider-handle:before,
.fd-slider-handle:after {
  /* Remove from screen */
  opacity: 0;
  /* The following rules are not really needed as no browser yet supports CSS transitions
		 on generated content but I'll leave it in for the day when they do! */
  /* Firefox */
  -moz-transition-property: opacity;
  -moz-transition-duration: 1s;
  -moz-transition-delay: 1s;
  /* WebKit */
  -webkit-transition-property: opacity;
  -webkit-transition-duration: 1s;
  -webkit-transition-delay: 1s;
  /* Opera */
  -o-transition-property: opacity;
  -o-transition-duration: 1s;
  -o-transition-delay: 1s;
  /* Standard */
  transition-property: opacity;
  transition-duration: 1s;
  transition-delay: 1s;
}
/*
	 The tooltip body - as we position it above the slider and position the tooltip arrow
	 below it, we need to know the height of the body. This means that multi-line tooltips
	 are not supported.
	
	 To support multi-line tooltips, you will need to position the tooltip below the slider
	 and the tooltip pointer above the tooltip body. Additionally, you will have to set the
	 tooltip bodies "height" to auto
	 */
.fd-slider-focused .fd-slider-handle:before,
.fd-slider-hover .fd-slider-handle:before,
.fd-slider-active .fd-slider-handle:before {
  display: block;
  position: absolute;
  top: -21px;
  left: -8px;
  margin: 0;
  width: 20px;
  padding: 3px;
  height: 14px;
  line-height: 12px;
  text-align: center;
  font-size: 10px;
  font-weight: bold;
  color: #fff;
  text-shadow: 1px 1px 1px #1a3a95;
  background: #2f6ee0;
  z-index: 1;
  /* Use the ARIA valuetext property, set by the script, to generate the tooltip content */
  content: attr(aria-valuetext);
  /* Border radius and box shadow */
  -moz-border-radius: 3px;
  -webkit-border-radius: 3px;
  border-radius: 3px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -moz-box-shadow: 0 0 4px #aaa;
  -webkit-box-shadow: 0 0 4px #aaa;
  box-shadow: 0px 0px 4px #999;
  /* Change opacity for transition */
  opacity: 1;
}
/* The tooltip pointer */
.fd-slider-focused .fd-slider-handle:after,
.fd-slider-hover .fd-slider-handle:after,
.fd-slider-active .fd-slider-handle:after {
  outline: none;
  content: "";
  display: block;
  position: absolute;
  top: -9px;
  left: 50%;
  margin: 0 0 0 -5px;
  background: #2f6ee0;
  z-index: 2;
  width: 10px;
  height: 10px;
  overflow: hidden;
  /* Rotate element by 45 degress to get the "\/" pointer effect */
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  /* Add a box shadow */
  -moz-box-shadow: 0 0 4px #aaa;
  -webkit-box-shadow: 0 0 4px #aaa;
  box-shadow: 0 0 4px #aaa;
  /* Clip */
  clip: rect(4px, 14px, 14px, 4px);
  /* Change opacity for transition */
  opacity: 1;
}
/* Remove completely for IE */
.oldie .fd-slider-handle:before,
.oldie .fd-slider-handle:after {
  display: none;
}
/*!
 * Slider for Bootstrap
 *
 * Copyright 2012 Stefan Petre
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 */
.slider {
  display: inline-block;
  vertical-align: middle;
  position: relative;
}
.slider.slider-horizontal {
  width: 100% !important;
  height: 20px;
}
.slider.slider-horizontal .slider-track {
  height: 10px;
  width: 100%;
  margin-top: -5px;
  top: 50%;
  left: 0;
}
.slider.slider-horizontal .slider-selection {
  height: 100%;
  top: 0;
  bottom: 0;
}
.slider.slider-horizontal .slider-handle {
  margin-left: -10px;
  margin-top: -5px;
}
.slider.slider-horizontal .slider-handle.triangle {
  width: 20px;
  height: 20px;
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(0deg);
  -moz-transform: rotate(0deg);
  -ms-transform: rotate(0deg);
  -o-transform: rotate(0deg);
  transform: rotate(0deg);
  border: none;
  line-height: 21px;
  color: #797777;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-horizontal .slider-handle.triangle:before {
  content: "\f0da";
  font-size: 34px;
}
.slider-horizontal .slider-selection + .slider-handle.triangle + .slider-handle.triangle:before {
  content: "\f0d9";
}
.slider.slider-vertical {
  height: 210px;
  width: 20px;
}
.slider.slider-vertical .slider-track {
  width: 10px;
  height: 100%;
  margin-left: -5px;
  left: 50%;
  top: 0;
}
.slider.slider-vertical .slider-selection {
  width: 100%;
  left: 0;
  top: 0;
  bottom: 0;
}
.slider.slider-vertical .slider-handle {
  margin-left: -5px;
  margin-top: -10px;
}
.slider.slider-vertical .slider-handle.triangle {
  width: 20px;
  height: 20px;
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(0deg);
  -moz-transform: rotate(0deg);
  -ms-transform: rotate(0deg);
  -o-transform: rotate(0deg);
  transform: rotate(0deg);
  border: none;
  line-height: 21px;
  color: #797777;
  text-shadow: 0 -1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-vertical .slider-handle.triangle:before {
  content: "\f0d7";
  font-size: 32px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.8);
}
.slider.slider-vertical .slider-selection + .slider-handle.triangle + .slider-handle.triangle:before {
  content: "\f0d8";
  text-shadow: 0 -1px 0 rgba(255, 255, 255, 0.8);
}
.slider input {
  display: none;
}
.slider .tooltip-inner {
  white-space: nowrap;
}
.slider-track {
  position: absolute;
  cursor: pointer;
  background: #E5E5E5;
}
.slider-selection {
  position: absolute;
  background: #3276b1;
}
.slider-handle {
  position: absolute;
  width: 20px;
  height: 20px;
  border: 1px solid #FFF;
  background: #858585;
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-align: center;
  line-height: 18px;
  font-size: 10px;
  color: #BDBDBD;
  text-shadow: 0 1px 0 rgba(77, 77, 77, 0.5);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(90deg);
  -moz-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  -o-transform: rotate(90deg);
  transform: rotate(90deg);
}
.slider-handle:before {
  content: "\f0c9";
}
.slider-handle.round {
  -webkit-border-radius: 20px;
  -moz-border-radius: 20px;
  border-radius: 20px;
  width: 20px;
  height: 20px;
}
.slider-handle.triangle {
  background: transparent none;
}
/*
 * Slider colors
 */
.slider-danger + .slider-track > .slider-selection {
  background: #a90329;
}
.slider-warning + .slider-track > .slider-selection {
  background: #c79121;
}
.slider-info + .slider-track > .slider-selection {
  background: #57889c;
}
.slider-success + .slider-track > .slider-selection {
  background: #739e73;
}
/*!
 * jQuery UI Bootstrap (1.0 alpha)
 * http://addyosmani.github.io/jquery-ui-bootstrap/
 *
 * Copyright 2012 - 2013, Addy Osmani
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 * Portions copyright jQuery UI & Twitter Bootstrap
 */
/********** VJ - Move to Less - Start *************/
/* Layout helpers
 ----------------------------------*/
.ui-helper-hidden {
  display: none;
}
.ui-helper-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
.ui-helper-reset {
  margin: 0;
  padding: 0;
  border: 0;
  outline: 0;
  line-height: 1.3;
  text-decoration: none;
  font-size: 100%;
  list-style: none;
}
.ui-helper-clearfix:before,
.ui-helper-clearfix:after {
  content: "";
  display: table;
  border-collapse: collapse;
}
.ui-helper-clearfix:after {
  content: ".";
  display: block;
  height: 0;
  clear: both;
  visibility: hidden;
}
.ui-helper-clearfix {
  /*display: inline-block; */
  display: block;
  min-height: 0;
  /* support: IE7 */
}
/* required comment for clearfix to work in Opera \*/
* html .ui-helper-clearfix {
  height: 1%;
}
/* end clearfix */
.ui-helper-zfix {
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  position: absolute;
  opacity: 0;
  filter: alpha(opacity=0);
}
.ui-front {
  z-index: 100;
}
/* Interaction Cues
 ----------------------------------*/
.ui-state-disabled {
  cursor: default !important;
}
/* Icons
 ----------------------------------*/
/* states and images */
.ui-icon {
  display: block;
  text-indent: -99999px;
  overflow: hidden;
  background-repeat: no-repeat;
}
/* Misc visuals
 ----------------------------------*/
/* Overlays */
.ui-widget-overlay {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
/*
 * jQuery UI Resizable 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/resizable/
 */
.ui-resizable {
  position: relative;
}
.ui-resizable-handle {
  position: absolute;
  font-size: 0.1px;
  z-index: 99999;
  display: block;
}
.ui-resizable-disabled .ui-resizable-handle,
.ui-resizable-autohide .ui-resizable-handle {
  display: none;
}
.ui-resizable-n {
  cursor: n-resize;
  height: 7px;
  width: 100%;
  top: -5px;
  left: 0;
}
.ui-resizable-s {
  cursor: s-resize;
  height: 7px;
  width: 100%;
  bottom: -5px;
  left: 0;
}
.ui-resizable-e {
  cursor: e-resize;
  width: 7px;
  right: -5px;
  top: 0;
  height: 100%;
}
.ui-resizable-w {
  cursor: w-resize;
  width: 7px;
  left: -5px;
  top: 0;
  height: 100%;
}
.ui-resizable-se {
  cursor: se-resize;
  width: 12px;
  height: 12px;
  right: 1px;
  bottom: 1px;
}
.ui-resizable-sw {
  cursor: sw-resize;
  width: 9px;
  height: 9px;
  left: -5px;
  bottom: -5px;
}
.ui-resizable-nw {
  cursor: nw-resize;
  width: 9px;
  height: 9px;
  left: -5px;
  top: -5px;
}
.ui-resizable-ne {
  cursor: ne-resize;
  width: 9px;
  height: 9px;
  right: -5px;
  top: -5px;
}
/*
 * jQuery UI Selectable 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/selectable/
 */
.ui-selectable-helper {
  position: absolute;
  z-index: 100;
  border: 1px dotted black;
}
/*
 * jQuery UI CSS Framework 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 *
 *
 * To view and modify this theme, visit http://jqueryui.com/themeroller/
 */
/* Component containers
 ----------------------------------*/
.ui-widget {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
}
.ui-widget .ui-widget {
  font-size: 13px;
}
.ui-widget input,
.ui-widget select,
.ui-widget textarea,
.ui-widget button {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: inherit;
}
.ui-widget-content {
  border: 1px solid #aaaaaa;
  background: #ffffff;
  color: #404040;
}
.ui-widget-header {
  font-weight: bold;
  background-color: #F5F5F5;
  border-color: #DDDDDD;
  color: #333333;
}
.ui-widget-header a {
  color: #222222;
}
/* Interaction states
 ----------------------------------*/
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  color: #333333;
  background-color: #ffffff;
  font-weight: normal;
  border: 1px solid #cccccc;
}
.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited {
  color: #555555;
  text-decoration: none;
}
.ui-state-hover,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-hover,
.ui-state-focus,
.ui-widget-content .ui-state-focus,
.ui-widget-header .ui-state-focus {
  color: #333333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
.ui-state-hover a,
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited {
  color: #333333;
  text-decoration: none;
}
.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active {
  border: 1px solid #adadad;
  font-weight: normal;
  color: #333333;
}
.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
  color: #333333;
  text-decoration: none;
}
.ui-widget :active {
  outline: none;
}
/* Interaction Cues
 ----------------------------------*/
.ui-state-highlight,
.ui-state-error,
.ui-state-default {
  position: relative;
  border-width: 1px;
  border-style: solid;
}
.ui-state-highlight p,
.ui-state-error p,
.ui-state-default p {
  font-size: 13px;
  font-weight: normal;
  line-height: 18px;
  margin: 7px 15px;
}
.ui-state-highlight,
.ui-widget-content .ui-state-highlight,
.ui-widget-header .ui-state-highlight {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.ui-state-highlight a,
.ui-widget-content .ui-state-highlight a,
.ui-widget-header .ui-state-highlight a {
  color: #2d6987;
}
.ui-state-error,
.ui-widget-content .ui-state-error,
.ui-widget-header .ui-state-error {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #eed3d7;
}
.ui-state-error a,
.ui-widget-content .ui-state-error a,
.ui-widget-header .ui-state-error a {
  color: #953b39;
}
.ui-state-error-text,
.ui-widget-content .ui-state-error-text,
.ui-widget-header .ui-state-error-text {
  color: #953b39;
}
.ui-priority-primary,
.ui-widget-content .ui-priority-primary,
.ui-widget-header .ui-priority-primary {
  font-weight: bold;
}
.ui-priority-secondary,
.ui-widget-content .ui-priority-secondary,
.ui-widget-header .ui-priority-secondary {
  opacity: .7;
  filter: alpha(opacity=70);
  font-weight: normal;
}
.ui-state-disabled,
.ui-widget-content .ui-state-disabled,
.ui-widget-header .ui-state-disabled {
  opacity: .35;
  filter: alpha(opacity=35);
  background-image: none;
}
.ui-state-disabled .ui-icon {
  filter: alpha(opacity=35);
  /* For IE8 - See #6059 */
}
/* Icons
 ----------------------------------*/
/* states and images

.ui-icon {
	width: 16px;
	height: 16px;
	background-image: url("@{base-url}/jqueryui/ui-icons_222222_256x240.png");
}

.ui-widget-content .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_222222_256x240.png");
}

.ui-widget-header .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_222222_256x240.png");
}

.ui-state-default .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_888888_256x240.png");
}

.ui-state-hover .ui-icon, .ui-state-focus .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_454545_256x240.png");
}

.ui-state-active .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_454545_256x240.png");
}

.ui-state-highlight .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_2e83ff_256x240.png");
}

.ui-state-error .ui-icon, .ui-state-error-text .ui-icon {
	background-image: url("@{base-url}/jqueryui/ui-icons_f6cf3b_256x240.png");
} */
/* positioning */
.ui-icon-carat-1-n {
  background-position: 0 0;
}
.ui-icon-carat-1-ne {
  background-position: -16px 0;
}
.ui-icon-carat-1-e {
  background-position: -32px 0;
}
.ui-icon-carat-1-se {
  background-position: -48px 0;
}
.ui-icon-carat-1-s {
  background-position: -64px 0;
}
.ui-icon-carat-1-sw {
  background-position: -80px 0;
}
.ui-icon-carat-1-w {
  background-position: -96px 0;
}
.ui-icon-carat-1-nw {
  background-position: -112px 0;
}
.ui-icon-carat-2-n-s {
  background-position: -128px 0;
}
.ui-icon-carat-2-e-w {
  background-position: -144px 0;
}
.ui-icon-triangle-1-n {
  background-position: 0 -16px;
}
.ui-icon-triangle-1-ne {
  background-position: -16px -16px;
}
.ui-icon-triangle-1-e {
  background-position: -32px -16px;
}
.ui-icon-triangle-1-se {
  background-position: -48px -16px;
}
.ui-icon-triangle-1-s {
  background-position: -64px -16px;
}
.ui-icon-triangle-1-sw {
  background-position: -80px -16px;
}
.ui-icon-triangle-1-w {
  background-position: -96px -16px;
}
.ui-icon-triangle-1-nw {
  background-position: -112px -16px;
}
.ui-icon-triangle-2-n-s {
  background-position: -128px -16px;
}
.ui-icon-triangle-2-e-w {
  background-position: -144px -16px;
}
.ui-icon-arrow-1-n {
  background-position: 0 -32px;
}
.ui-icon-arrow-1-ne {
  background-position: -16px -32px;
}
.ui-icon-arrow-1-e {
  background-position: -32px -32px;
}
.ui-icon-arrow-1-se {
  background-position: -48px -32px;
}
.ui-icon-arrow-1-s {
  background-position: -64px -32px;
}
.ui-icon-arrow-1-sw {
  background-position: -80px -32px;
}
.ui-icon-arrow-1-w {
  background-position: -96px -32px;
}
.ui-icon-arrow-1-nw {
  background-position: -112px -32px;
}
.ui-icon-arrow-2-n-s {
  background-position: -128px -32px;
}
.ui-icon-arrow-2-ne-sw {
  background-position: -144px -32px;
}
.ui-icon-arrow-2-e-w {
  background-position: -160px -32px;
}
.ui-icon-arrow-2-se-nw {
  background-position: -176px -32px;
}
.ui-icon-arrowstop-1-n {
  background-position: -192px -32px;
}
.ui-icon-arrowstop-1-e {
  background-position: -208px -32px;
}
.ui-icon-arrowstop-1-s {
  background-position: -224px -32px;
}
.ui-icon-arrowstop-1-w {
  background-position: -240px -32px;
}
.ui-icon-arrowthick-1-n {
  background-position: 0 -48px;
}
.ui-icon-arrowthick-1-ne {
  background-position: -16px -48px;
}
.ui-icon-arrowthick-1-e {
  background-position: -32px -48px;
}
.ui-icon-arrowthick-1-se {
  background-position: -48px -48px;
}
.ui-icon-arrowthick-1-s {
  background-position: -64px -48px;
}
.ui-icon-arrowthick-1-sw {
  background-position: -80px -48px;
}
.ui-icon-arrowthick-1-w {
  background-position: -96px -48px;
}
.ui-icon-arrowthick-1-nw {
  background-position: -112px -48px;
}
.ui-icon-arrowthick-2-n-s {
  background-position: -128px -48px;
}
.ui-icon-arrowthick-2-ne-sw {
  background-position: -144px -48px;
}
.ui-icon-arrowthick-2-e-w {
  background-position: -160px -48px;
}
.ui-icon-arrowthick-2-se-nw {
  background-position: -176px -48px;
}
.ui-icon-arrowthickstop-1-n {
  background-position: -192px -48px;
}
.ui-icon-arrowthickstop-1-e {
  background-position: -208px -48px;
}
.ui-icon-arrowthickstop-1-s {
  background-position: -224px -48px;
}
.ui-icon-arrowthickstop-1-w {
  background-position: -240px -48px;
}
.ui-icon-arrowreturnthick-1-w {
  background-position: 0 -64px;
}
.ui-icon-arrowreturnthick-1-n {
  background-position: -16px -64px;
}
.ui-icon-arrowreturnthick-1-e {
  background-position: -32px -64px;
}
.ui-icon-arrowreturnthick-1-s {
  background-position: -48px -64px;
}
.ui-icon-arrowreturn-1-w {
  background-position: -64px -64px;
}
.ui-icon-arrowreturn-1-n {
  background-position: -80px -64px;
}
.ui-icon-arrowreturn-1-e {
  background-position: -96px -64px;
}
.ui-icon-arrowreturn-1-s {
  background-position: -112px -64px;
}
.ui-icon-arrowrefresh-1-w {
  background-position: -128px -64px;
}
.ui-icon-arrowrefresh-1-n {
  background-position: -144px -64px;
}
.ui-icon-arrowrefresh-1-e {
  background-position: -160px -64px;
}
.ui-icon-arrowrefresh-1-s {
  background-position: -176px -64px;
}
.ui-icon-arrow-4 {
  background-position: 0 -80px;
}
.ui-icon-arrow-4-diag {
  background-position: -16px -80px;
}
.ui-icon-extlink {
  background-position: -32px -80px;
}
.ui-icon-newwin {
  background-position: -48px -80px;
}
.ui-icon-refresh {
  background-position: -64px -80px;
}
.ui-icon-shuffle {
  background-position: -80px -80px;
}
.ui-icon-transfer-e-w {
  background-position: -96px -80px;
}
.ui-icon-transferthick-e-w {
  background-position: -112px -80px;
}
.ui-icon-folder-collapsed {
  background-position: 0 -96px;
}
.ui-icon-folder-open {
  background-position: -16px -96px;
}
.ui-icon-document {
  background-position: -32px -96px;
}
.ui-icon-document-b {
  background-position: -48px -96px;
}
.ui-icon-note {
  background-position: -64px -96px;
}
.ui-icon-mail-closed {
  background-position: -80px -96px;
}
.ui-icon-mail-open {
  background-position: -96px -96px;
}
.ui-icon-suitcase {
  background-position: -112px -96px;
}
.ui-icon-comment {
  background-position: -128px -96px;
}
.ui-icon-person {
  background-position: -144px -96px;
}
.ui-icon-print {
  background-position: -160px -96px;
}
.ui-icon-trash {
  background-position: -176px -96px;
}
.ui-icon-locked {
  background-position: -192px -96px;
}
.ui-icon-unlocked {
  background-position: -208px -96px;
}
.ui-icon-bookmark {
  background-position: -224px -96px;
}
.ui-icon-tag {
  background-position: -240px -96px;
}
.ui-icon-home {
  background-position: 0 -112px;
}
.ui-icon-flag {
  background-position: -16px -112px;
}
.ui-icon-calendar {
  background-position: -32px -112px;
}
.ui-icon-cart {
  background-position: -48px -112px;
}
.ui-icon-pencil {
  background-position: -64px -112px;
}
.ui-icon-clock {
  background-position: -80px -112px;
}
.ui-icon-disk {
  background-position: -96px -112px;
}
.ui-icon-calculator {
  background-position: -112px -112px;
}
.ui-icon-zoomin {
  background-position: -128px -112px;
}
.ui-icon-zoomout {
  background-position: -144px -112px;
}
.ui-icon-search {
  background-position: -160px -112px;
}
.ui-icon-wrench {
  background-position: -176px -112px;
}
.ui-icon-gear {
  background-position: -192px -112px;
}
.ui-icon-heart {
  background-position: -208px -112px;
}
.ui-icon-star {
  background-position: -224px -112px;
}
.ui-icon-link {
  background-position: -240px -112px;
}
.ui-icon-cancel {
  background-position: 0 -128px;
}
.ui-icon-plus {
  background-position: -16px -128px;
}
.ui-icon-plusthick {
  background-position: -32px -128px;
}
.ui-icon-minus {
  background-position: -48px -128px;
}
.ui-icon-minusthick {
  background-position: -64px -128px;
}
.ui-icon-close {
  background-position: -80px -128px;
}
.ui-icon-closethick {
  background-position: -96px -128px;
}
.ui-icon-key {
  background-position: -112px -128px;
}
.ui-icon-lightbulb {
  background-position: -128px -128px;
}
.ui-icon-scissors {
  background-position: -144px -128px;
}
.ui-icon-clipboard {
  background-position: -160px -128px;
}
.ui-icon-copy {
  background-position: -176px -128px;
}
.ui-icon-contact {
  background-position: -192px -128px;
}
.ui-icon-image {
  background-position: -208px -128px;
}
.ui-icon-video {
  background-position: -224px -128px;
}
.ui-icon-script {
  background-position: -240px -128px;
}
.ui-icon-alert {
  background-position: 0 -144px;
}
.ui-icon-info {
  background-position: -16px -144px;
}
.ui-icon-notice {
  background-position: -32px -144px;
}
.ui-icon-help {
  background-position: -48px -144px;
}
.ui-icon-check {
  background-position: -64px -144px;
}
.ui-icon-bullet {
  background-position: -80px -144px;
}
.ui-icon-radio-on {
  background-position: -96px -144px;
}
.ui-icon-radio-off {
  background-position: -112px -144px;
}
.ui-icon-pin-w {
  background-position: -128px -144px;
}
.ui-icon-pin-s {
  background-position: -144px -144px;
}
.ui-icon-play {
  background-position: 0 -160px;
}
.ui-icon-pause {
  background-position: -16px -160px;
}
.ui-icon-seek-next {
  background-position: -32px -160px;
}
.ui-icon-seek-prev {
  background-position: -48px -160px;
}
.ui-icon-seek-end {
  background-position: -64px -160px;
}
.ui-icon-seek-first {
  background-position: -80px -160px;
}
.ui-icon-seek-start {
  background-position: -80px -160px;
}
.ui-icon-stop {
  background-position: -96px -160px;
}
.ui-icon-eject {
  background-position: -112px -160px;
}
.ui-icon-volume-off {
  background-position: -128px -160px;
}
.ui-icon-volume-on {
  background-position: -144px -160px;
}
.ui-icon-power {
  background-position: 0 -176px;
}
.ui-icon-signal-diag {
  background-position: -16px -176px;
}
.ui-icon-signal {
  background-position: -32px -176px;
}
.ui-icon-battery-0 {
  background-position: -48px -176px;
}
.ui-icon-battery-1 {
  background-position: -64px -176px;
}
.ui-icon-battery-2 {
  background-position: -80px -176px;
}
.ui-icon-battery-3 {
  background-position: -96px -176px;
}
.ui-icon-circle-plus {
  background-position: 0 -192px;
}
.ui-icon-circle-minus {
  background-position: -16px -192px;
}
.ui-icon-circle-close {
  background-position: -32px -192px;
}
.ui-icon-circle-triangle-e {
  background-position: -48px -192px;
}
.ui-icon-circle-triangle-s {
  background-position: -64px -192px;
}
.ui-icon-circle-triangle-w {
  background-position: -80px -192px;
}
.ui-icon-circle-triangle-n {
  background-position: -96px -192px;
}
.ui-icon-circle-arrow-e {
  background-position: -112px -192px;
}
.ui-icon-circle-arrow-s {
  background-position: -128px -192px;
}
.ui-icon-circle-arrow-w {
  background-position: -144px -192px;
}
.ui-icon-circle-arrow-n {
  background-position: -160px -192px;
}
.ui-icon-circle-zoomin {
  background-position: -176px -192px;
}
.ui-icon-circle-zoomout {
  background-position: -192px -192px;
}
.ui-icon-circle-check {
  background-position: -208px -192px;
}
.ui-icon-circlesmall-plus {
  background-position: 0 -208px;
}
.ui-icon-circlesmall-minus {
  background-position: -16px -208px;
}
.ui-icon-circlesmall-close {
  background-position: -32px -208px;
}
.ui-icon-squaresmall-plus {
  background-position: -48px -208px;
}
.ui-icon-squaresmall-minus {
  background-position: -64px -208px;
}
.ui-icon-squaresmall-close {
  background-position: -80px -208px;
}
.ui-icon-grip-dotted-vertical {
  background-position: 0 -224px;
}
.ui-icon-grip-dotted-horizontal {
  background-position: -16px -224px;
}
.ui-icon-grip-solid-vertical {
  background-position: -32px -224px;
}
.ui-icon-grip-solid-horizontal {
  background-position: -48px -224px;
}
.ui-icon-gripsmall-diagonal-se {
  background-position: -64px -224px;
}
.ui-icon-grip-diagonal-se {
  background-position: -80px -224px;
}
/* Misc visuals
 ----------------------------------*/
/* Corner radius */
.ui-corner-all {
  -webkit-border-radius: 0px;
  /* Safari 4 */
  -moz-border-radius: 0px;
  /* Firefox 3.6 */
  border-radius: 0px;
}
.ui-corner-top,
.ui-corner-left,
.ui-corner-tl {
  -webkit-border-top-left-radius: 4px;
  /* Safari 4 */
  -moz-border-radius-topleft: 4px;
  /* Firefox 3.6 */
  border-top-left-radius: 4px;
}
.ui-corner-top,
.ui-corner-right,
.ui-corner-tr {
  -webkit-border-top-right-radius: 4px;
  /* Safari 4 */
  -moz-border-radius-topright: 4px;
  /* Firefox 3.6 */
  border-top-right-radius: 4px;
}
.ui-corner-bottom,
.ui-corner-left,
.ui-corner-bl {
  -webkit-border-bottom-left-radius: 4px;
  /* Safari 4 */
  -moz-border-radius-bottomleft: 4px;
  /* Firefox 3.6 */
  border-bottom-left-radius: 4px;
}
.ui-corner-bottom,
.ui-corner-right,
.ui-corner-br {
  -webkit-border-bottom-right-radius: 4px;
  /* Safari 4 */
  -moz-border-radius-bottomright: 4px;
  /* Firefox 3.6 */
  border-bottom-right-radius: 4px;
}
/* Overlays */
.ui-widget-overlay {
  background: #aaaaaa;
  opacity: .30;
  filter: alpha(opacity=30);
}
.ui-widget-shadow {
  margin: -8px 0 0 -8px;
  padding: 8px;
  background: #aaaaaa;
  opacity: .30;
  filter: alpha(opacity=30);
  -webkit-border-radius: 8px;
  /* Safari 4 */
  -moz-border-radius: 8px;
  /* Firefox 3.6 */
  border-radius: 8px;
}
/*
 * jQuery UI Accordion 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/accordion/
 */
/* IE/Win - Fix animation bug - #4615 */
.ui-accordion {
  width: 100%;
}
.ui-accordion .ui-accordion-li-fix {
  display: inline;
}
.ui-accordion .ui-accordion-header-active {
  border-bottom: 0 !important;
}
.ui-accordion .ui-accordion-header {
  display: block;
  cursor: pointer;
  position: relative;
  margin-top: 2px;
  padding: .5em .5em .5em .7em;
  min-height: 0;
  /* support: IE7 */
}
.ui-accordion .ui-accordion-icons {
  padding-left: 2.2em;
}
.ui-accordion .ui-accordion-noicons {
  padding-left: .7em;
}
.ui-accordion .ui-accordion-icons .ui-accordion-icons {
  padding-left: 2.2em;
}
.ui-accordion .ui-accordion-header .ui-accordion-header-icon {
  position: absolute;
  left: .5em;
  top: 50%;
  margin-top: -8px;
}
.ui-accordion .ui-accordion-content {
  padding: 1em 2.2em;
  border-top: 0 none;
  margin-top: -3px;
  position: relative;
  top: 1px;
  margin-bottom: 2px;
  overflow: auto;
  display: none;
}
.ui-accordion .ui-accordion-content-active {
  display: block;
}
/*
 * jQuery UI Autocomplete 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/autocomplete/
 */
.ui-autocomplete {
  position: absolute;
  top: 0;
  left: 0;
  cursor: default;
}
/*
 * jQuery UI Button 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Button#theming
 */
.ui-button {
  display: inline-block;
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid #ccc;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none;
}
.ui-button:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.ui-button:focus,
.ui-button:hover {
  color: #333333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
ui-button.disabled,
ui-button[disabled],
fieldset[disabled] ui-button,
ui-button.disabled:hover,
ui-button[disabled]:hover,
fieldset[disabled] ui-button:hover,
ui-button.disabled:focus,
ui-button[disabled]:focus,
fieldset[disabled] ui-button:focus,
ui-button.disabled:active,
ui-button[disabled]:active,
fieldset[disabled] ui-button:active,
ui-button.disabled.active,
ui-button[disabled].active,
fieldset[disabled] ui-button.ui-state-active {
  background-color: #ffffff;
  border-color: #cccccc;
}
.ui-btn-lg {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px;
}
.ui-btn-sm,
.ui-btn-xs {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
.ui-btn-xs {
  padding: 1px 5px;
}
.ui-btn-block {
  display: block;
  width: 100%;
  padding-right: 0;
  padding-left: 0;
}
.ui-btn-block + .ui-btn-block {
  margin-top: 5px;
}
input[type="submit"].ui-btn-block,
input[type="reset"].ui-btn-block,
input[type="button"].ui-btn-block {
  width: 100%;
}
.ui-button-text-icon-primary .ui-button-icon-primary {
  float: left;
}
.ui-button-text-icon-primary {
  padding: 2px 7px 3px;
}
.ui-button-primary {
  color: #ffffff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-button-warning {
  color: #ffffff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.ui-button-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.ui-button-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.ui-button-inverse {
  color: #ffffff;
  background-color: #222222;
  border-color: #080808;
}
.ui-button-success {
  color: #ffffff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.ui-button-error {
  color: #ffffff;
  background-color: #c43c35;
  border-color: #882a25;
}
.ui-button-primary:hover,
.ui-button-success:hover,
.ui-button-info:hover,
.ui-button-danger:hover,
.ui-button-warning:hover,
.ui-button-inverse:hover {
  color: #ffffff;
  text-decoration: none;
}
.ui-button-primary:hover,
.ui-button-primary:focus {
  color: #ffffff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.ui-button-success:hover {
  color: #ffffff;
  background-color: #47a447;
  border-color: #398439;
}
.ui-button-info:hover {
  color: #ffffff;
  background-color: #39b3d7;
  border-color: #269abc;
}
.ui-button-danger:hover {
  color: #ffffff;
  background-color: #d2322d;
  border-color: #ac2925;
}
.ui-button-warning:hover {
  color: #ffffff;
  background-color: #ed9c28;
  border-color: #d58512;
}
.ui-button-inverse:hover {
  color: #ffffff;
  background-color: #363636;
  border-color: #000000;
}
/* to make room for the icon, a width needs to be set here */
.ui-button-icon-only {
  width: 2.2em;
}
/* button elements seem to need a little more width */
.ui-button-icons-only {
  width: 3.4em;
}
button.ui-button-icons-only {
  width: 3.7em;
}
.ui-button-text-icon-primary .ui-button-icon-primary.ui-icon {
  margin-top: 5px;
}
/*button text element */
.ui-button .ui-button-text {
  display: block;
  line-height: normal;
}
.ui-button-icon-only .ui-button-text,
.ui-button-icons-only .ui-button-text {
  padding: .4em;
  text-indent: -9999px;
  display: none;
  /*tempfix*/
}
.ui-button-text-icon-primary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: .4em 1em .4em 2.1em;
}
.ui-button-text-icon-secondary .ui-button-text,
.ui-button-text-icons .ui-button-text {
  padding: .4em 2.1em .4em 1em;
}
.ui-button-text-icons .ui-button-text {
  padding-left: 2.1em;
  padding-right: 2.1em;
}
/* no icon support for input elements, provide padding by default */
input.ui-button {
  padding: .4em 1em;
}
/*button icon element(s) */
.ui-button-icon-only .ui-icon,
.ui-button-text-icon-primary .ui-icon,
.ui-button-text-icon-secondary .ui-icon,
.ui-button-text-icons .ui-icon,
.ui-button-icons-only .ui-icon {
  margin-bottom: 0;
  margin-top: 0;
  top: 50%;
}
.ui-button-icon-only .ui-icon {
  left: 50%;
  /* chrome margin*/
  margin-left: -8px;
  /* firefox margin*/
  margin-right: -6px;
}
.ui-button-text-icon-primary .ui-button-icon-primary,
.ui-button-text-icons .ui-button-icon-primary,
.ui-button-icons-only .ui-button-icon-primary {
  left: .5em;
}
.ui-button-text-icon-secondary .ui-button-icon-secondary,
.ui-button-text-icons .ui-button-icon-secondary,
.ui-button-icons-only .ui-button-icon-secondary {
  right: .5em;
}
.ui-button-text-icons .ui-button-icon-secondary,
.ui-button-icons-only .ui-button-icon-secondary {
  right: .5em;
}
/*button sets*/
.ui-buttonset {
  margin-right: 7px;
}
.ui-buttonset .ui-state-active {
  color: #ffffff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-buttonset .ui-state-active.ui-state-hover {
  color: #ffffff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.ui-buttonset .ui-button {
  margin-left: 0;
  margin-right: -0.4em;
}
/* reset extra padding in Firefox */
button.ui-button::-moz-focus-inner {
  border: 0;
  padding: 0;
}
/*
 * jQuery UI Menu 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Menu#theming
 */
.ui-menu {
  list-style: none;
  padding: 2px;
  margin: 0;
  display: block;
  outline: none;
}
.ui-menu .ui-menu {
  margin-top: -3px;
  position: absolute;
  list-style: none;
}
.ui-menu .ui-menu-item {
  margin: 0;
  padding: 0;
  width: 100%;
  list-style: none;
  /* support: IE10, see #8844 */
  list-style-image: url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);
}
.ui-menu .ui-menu-divider {
  margin: 5px -2px 5px -2px;
  height: 0;
  font-size: 0;
  line-height: 0;
  border-width: 1px 0 0 0;
}
.ui-menu .ui-menu-item a {
  text-decoration: none;
  display: block;
  padding: 2px .4em;
  line-height: 1.5;
  min-height: 0;
  /* support: IE7 */
  font-weight: normal;
}
.ui-menu .ui-menu-item a.ui-corner-all {
  -webkit-border-radius: 0px;
  /* Safari 4 */
  -moz-border-radius: 0px;
  /* Firefox 3.6 */
  border-radius: 0px;
}
.ui-menu .ui-menu-item a.ui-state-focus,
.ui-menu .ui-menu-item a.ui-state-active,
.ui-menu .ui-menu-item a.ui-widget-content {
  font-weight: bold;
  margin: 0;
  background-color: #428BCA;
  border-color: #357EBD;
  color: #FFFFFF;
  display: block;
  white-space: nowrap;
}
/* Fix problem with border in ui-state-active */
.ui-menu .ui-menu-item a.ui-state-active {
  padding: 1px .4em;
}
.ui-menu .ui-state-disabled {
  font-weight: normal;
  margin: .4em 0 .2em;
  line-height: 1.5;
}
.ui-menu .ui-state-disabled a {
  cursor: default;
}
/* icon support */
.ui-menu-icons {
  position: relative;
}
.ui-menu-icons .ui-menu-item a {
  position: relative;
  padding-left: 2em;
}
/* left-aligned */
.ui-menu .ui-icon {
  position: absolute;
  top: .2em;
  left: .2em;
}
/* right-aligned */
.ui-menu .ui-menu-icon {
  position: static;
  float: right;
}
.ui-menu {
  width: 200px;
  margin-bottom: 2em;
}
/*
 * jQuery UI spinner 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Menu#theming
 */
.ui-spinner {
  position: relative;
  display: inline-block;
  overflow: hidden;
  padding: 0;
  vertical-align: middle;
}
.ui-spinner-input {
  border: none;
  background: none;
  padding: 0;
  margin: .2em 0;
  vertical-align: middle;
  margin-left: .4em;
  margin-right: 22px;
}
.ui-spinner-button {
  width: 16px;
  height: 50%;
  font-size: .5em;
  padding: 0;
  margin: 0;
  text-align: center;
  position: absolute;
  cursor: default;
  display: block;
  overflow: hidden;
  right: 0;
}
/* more specificity required here to overide default borders */
.ui-spinner a.ui-spinner-button {
  border-top: none;
  border-bottom: none;
  border-right: none;
}
/* vertical centre icon */
.ui-spinner .ui-icon {
  position: absolute;
  margin-top: -8px;
  top: 50%;
  left: 0;
}
.ui-spinner-up {
  top: 0;
}
.ui-spinner-down {
  bottom: 0;
}
/* need to fix icons sprite */
.ui-spinner .ui-icon-triangle-1-s {
  background-position: -65px -16px;
}
/********** VJ - Move to Less - End *************/
/*
 * jQuery UI Dialog 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Dialog#theming
 */
.ui-dialog {
  position: absolute;
  top: 0;
  left: 0;
  padding: 0;
  width: 300px;
  overflow: hidden;
  outline: 0;
  background-clip: padding-box;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.3);
  border-radius: 6px 6px 6px 6px;
  -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  /* Safari 4 */
  -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  /* Firefox 3.6 */
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  /*left: 50%;
	 margin-left: -280px;*/
  outline: medium none;
  /*top: 10%;
	 width: 560px;*/
  z-index: 1050;
}
.ui-dialog .ui-dialog-titlebar {
  /*padding: .4em 1em;*/
  position: relative;
  border: 0 0 0 1px solid;
  border-color: white;
  padding: 5px 15px;
  font-size: 18px;
  text-decoration: none;
  -webkit-border-bottom-right-radius: 0;
  /* Safari 4 */
  -moz-border-radius-bottomright: 0;
  /* Firefox 3.6 */
  border-bottom-right-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  /* Safari 4 */
  -moz-border-radius-bottomleft: 0;
  /* Firefox 3.6 */
  border-bottom-left-radius: 0;
  border-bottom: 1px solid #ccc;
}
.ui-dialog .ui-dialog-title {
  float: left;
  color: #404040;
  font-weight: bold;
  margin-top: 5px;
  margin-bottom: 5px;
  padding: 5px;
  text-overflow: ellipsis;
  overflow: hidden;
}
.ui-dialog .ui-dialog-titlebar-close {
  position: absolute;
  right: .3em;
  top: 50%;
  width: 19px;
  margin: -20px 0 0 0;
  padding: 1px;
  height: 18px;
  font-size: 20px;
  font-weight: bold;
  line-height: 13.5px;
  text-shadow: 0 1px 0 #ffffff;
  filter: alpha(opacity=25);
  -khtml-opacity: 0.25;
  -moz-opacity: 0.25;
  opacity: 0.25;
  background: none;
  border-width: 0;
  border: none;
  -webkit-box-shadow: none;
  /* Safari 4 */
  -moz-box-shadow: none;
  /* Firefox 3.6 */
  box-shadow: none;
}
.ui-dialog .ui-dialog-titlebar-close span {
  display: block;
  margin: 1px;
  text-indent: 9999px;
}
.ui-dialog .ui-dialog-titlebar-close:hover,
.ui-dialog .ui-dialog-titlebar-close:focus {
  padding: 1px;
  filter: alpha(opacity=90);
  -moz-opacity: 0.90;
  opacity: 0.90;
}
.ui-dialog .ui-dialog-content {
  position: relative;
  border: 0;
  padding: .5em 1em;
  background: none;
  overflow: auto;
}
.ui-dialog .ui-dialog-buttonpane {
  text-align: left;
  border-width: 1px 0 0 0;
  background-image: none;
  margin: .5em 0 0 0;
  background-color: #ffffff;
  padding: 5px 15px 5px;
  border-top: 1px solid #ddd;
  -webkit-border-radius: 0 0 6px 6px;
  /* Safari 4 */
  -moz-border-radius: 0 0 6px 6px;
  /* Firefox 3.6 */
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  /* Safari 4 */
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  /* Firefox 3.6 */
  box-shadow: inset 0 1px 0 #ffffff;
  margin-bottom: 0;
}
.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
  float: right;
}
.ui-dialog .ui-dialog-buttonpane button {
  margin: .5em .4em .5em 0;
  cursor: pointer;
}
.ui-dialog .ui-resizable-se {
  width: 14px;
  height: 14px;
  right: 3px;
  bottom: 3px;
}
.ui-draggable .ui-dialog-titlebar {
  cursor: move;
}
.ui-dialog-buttonpane .ui-dialog-buttonset .ui-button {
  color: #ffffff;
  background-color: #428bca;
  border-color: #357ebd;
}
.ui-dialog-buttonpane .ui-dialog-buttonset .ui-button.ui-state-hover {
  color: #ffffff;
  background-color: #3276b1;
  border-color: #285e8e;
}
/***Dialog fixes**/
.ui-dialog-buttonset .ui-button:not(:first-child) {
  cursor: pointer;
  display: inline-block;
  color: #333333;
  background-color: #ffffff;
  border: 1px solid #cccccc;
  -webkit-transition: 0.1s linear all;
  -moz-transition: 0.1s linear all;
  -o-transition: 0.1s linear all;
  transition: 0.1s linear all;
  overflow: visible;
}
.ui-dialog-buttonset .ui-button:not(:first-child) .ui-state-hover {
  color: #333333;
  background-color: #ebebeb;
  border-color: #adadad;
  text-decoration: none;
}
/* ui-dialog-buttonset UI info */
.ui-dialog-buttonset .ui-button.ui-button-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.ui-dialog-buttonset .ui-button.ui-button-info.ui-state-hover {
  color: #ffffff;
  background-color: #39b3d7;
  border-color: #269abc;
}
/* ui-dialog-buttonset UI success */
.ui-dialog-buttonset .ui-button.ui-button-success {
  color: #ffffff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.ui-dialog-buttonset .ui-button.ui-button-success.ui-state-hover {
  color: #ffffff;
  background-color: #47a447;
  border-color: #398439;
}
/* ui-dialog-buttonset UI warning */
.ui-dialog-buttonset .ui-button.ui-button-warning {
  color: #ffffff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.ui-dialog-buttonset .ui-button.ui-button-warning.ui-state-hover {
  color: #ffffff;
  background-color: #ed9c28;
  border-color: #d58512;
}
/* ui-dialog-buttonset UI Danger */
.ui-dialog-buttonset .ui-button.ui-button-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.ui-dialog-buttonset .ui-button.ui-button-danger.ui-state-hover {
  color: #ffffff;
  background-color: #d2322d;
  border-color: #ac2925;
}
/* ui-dialog-buttonset UI Inverse */
.ui-dialog-buttonset .ui-button.ui-button-inverse {
  color: #ffffff;
  background-color: #222222;
  border-color: #080808;
}
.ui-dialog-buttonset .ui-button.ui-button-inverse.ui-state-hover {
  color: #ffffff;
  background-color: #363636;
  border-color: #000000;
}
/*
 * jQuery UI Slider 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Slider#theming
 */
.ui-slider {
  position: relative;
  text-align: left;
}
/* For IE8 - See #6727 */
.ui-slider.ui-state-disabled .ui-slider-handle,
.ui-slider.ui-state-disabled .ui-slider-range {
  filter: inherit;
}
.ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  width: 16px;
  height: 18px;
  cursor: default;
}
.ui-slider .ui-slider-range {
  position: absolute;
  z-index: 1;
  font-size: .7em;
  display: block;
  border: 0;
  background-position: 0 0;
  color: #ffffff;
  background-color: #0e90d2;
  background-image: -moz-linear-gradient(top, #149bdf, #0480be);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#149bdf), to(#0480be));
  background-image: -webkit-linear-gradient(top, #149bdf, #0480be);
  background-image: -o-linear-gradient(top, #149bdf, #0480be);
  background-image: linear-gradient(to bottom, #149bdf, #0480be);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff149bdf', endColorstr='#ff0480be', GradientType=0);
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -moz-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width 0.6s ease;
  -moz-transition: width 0.6s ease;
  -o-transition: width 0.6s ease;
  transition: width 0.6s ease;
}
.ui-slider-horizontal {
  height: 10px;
  background: #D5D5D5;
  border: none;
}
.ui-slider-horizontal .ui-slider-handle {
  top: -0.3em;
  margin-left: -0.6em;
  background-color: #fff;
  border-color: #CCC;
}
.ui-slider-horizontal .ui-slider-handle:focus {
  background-color: #fff;
  border-color: #357EBD;
}
.ui-slider-horizontal .ui-slider-handle:hover {
  background-color: #fff;
  border-color: #285E8E;
  outline: 0;
}
.ui-slider-horizontal .ui-slider-handle:active {
  background-color: #428BCA;
  border-color: #3276B1;
}
.ui-slider-horizontal .ui-slider-range {
  top: 0;
  height: 100%;
}
.ui-slider-horizontal .ui-slider-range-min {
  left: 0;
}
.ui-slider-horizontal .ui-slider-range-max {
  right: 0;
}
.ui-slider-vertical {
  width: .8em;
  height: 100px;
}
.ui-slider-vertical .ui-slider-handle {
  left: -0.3em;
  margin-left: 0;
  margin-bottom: -0.6em;
}
.ui-slider-vertical .ui-slider-range {
  left: 0;
  width: 100%;
}
.ui-slider-vertical .ui-slider-range-min {
  bottom: 0;
}
.ui-slider-vertical .ui-slider-range-max {
  top: 0;
}
/*
 * jQuery UI Tabs 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/tabs/
 */
.ui-tabs {
  position: relative;
  /* position: relative prevents IE scroll bug (element with position: relative inside container with overflow: auto appear as "fixed") */
  border: 0;
  -webkit-border-radius: 0;
  /* Safari 4 */
  -moz-border-radius: 0;
  /* Firefox 3.6 */
  border-radius: 0;
}
.ui-tabs .ui-tabs-nav {
  margin-bottom: 5px;
  border: solid #ddd;
  border-width: 0 0 1px 0;
  -webkit-border-radius: 0;
  /* Safari 4 */
  -moz-border-radius: 0;
  /* Firefox 3.6 */
  border-radius: 0;
  background: none;
}
.ui-tabs .ui-tabs-nav li {
  position: relative;
  top: 0;
  float: left;
  margin-right: 2px;
  margin-bottom: -1px;
  border: 0;
  list-style: none;
  white-space: nowrap;
  background: none;
}
.ui-tabs-nav .ui-state-default {
  border: 0;
  -webkit-box-shadow: none;
  /* Safari 4 */
  -moz-box-shadow: none;
  /* Firefox 3.6 */
  box-shadow: none;
}
.ui-tabs .ui-tabs-nav li a {
  float: left;
  border: 1px solid #fff;
  border-bottom: 1px solid #ddd;
  -webkit-border-radius: 4px 4px 0 0;
  /* Safari 4 */
  -moz-border-radius: 4px 4px 0 0;
  /* Firefox 3.6 */
  border-radius: 4px 4px 0 0;
  padding: 8px 12px;
  font-weight: normal;
  text-decoration: none;
  outline: none;
  color: #0069D6;
  background: none;
}
.ui-tabs .ui-tabs-nav li a:hover {
  border: 1px solid whiteSmoke;
  border-bottom: 1px solid #ddd;
  background-color: whiteSmoke;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active a {
  border: 1px solid #ddd;
  border-bottom: 1px solid #fff;
  background-color: #fff;
  color: #555;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active:hover {
  background: #fff;
  cursor: text;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active a,
.ui-tabs .ui-tabs-nav li.ui-state-disabled a,
.ui-tabs .ui-tabs-nav li.ui-tabs-loading a {
  cursor: text;
}
/* first selector in group seems obsolete, but required to overcome bug in Opera applying cursor: text overall if defined elsewhere... */
.ui-tabs .ui-tabs-panel {
  display: block;
  margin: 1em 0;
  border: 0;
  -webkit-border-radius: 0;
  /* Safari 4 */
  -moz-border-radius: 0;
  /* Firefox 3.6 */
  border-radius: 0;
  padding: 1px 0;
  background: none;
}
.ui-tabs .ui-tabs-hide {
  display: none !important;
}
/* IE fix for background inheritance from ui-widget */
.ui-tabs .ui-tabs-nav li {
  filter: none;
}
/*
 * jQuery UI Tooltip 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/tooltip/
 */
.ui-tooltip {
  display: block;
  font-size: 11px;
  opacity: 0.8;
  position: absolute;
  visibility: visible;
  z-index: 1024;
  max-width: 200px;
}
.ui-tooltip {
  background: #000000;
  border: 1px solid #000000;
}
.ui-tooltip {
  color: #FFFFFF;
  padding: 3px 8px;
  text-align: center;
  text-decoration: none;
  -webkit-box-shadow: inset 0 1px 0 #000000;
  /* Safari 4 */
  -moz-box-shadow: inset 0 1px 0 #000000;
  /* Firefox 3.6 */
  box-shadow: inset 0 1px 0 #000000;
  border-radius: 4px 4px 4px 4px;
}
body .ui-tooltip {
  border-width: 1px;
}
/*
 .arrow {
 overflow: hidden;
 position: absolute;
 margin-left: 0;
 height: 20px;
 width: 20px;
 }

 .arrow.bottom {
 top: 100%;
 left: 38%;
 }

 .arrow.top {
 top: -50%;
 bottom: 22px;
 left: 42%;
 }

 .arrow.left {
 top : 25%;
 left: -15%;
 right: 0;
 bottom:-16px;
 }

 .arrow.right {
 top: 26%;
 left: 100%;
 right: 0;
 bottom:-16px;
 margin-left: 1px;
 }

 .arrow:after {
 content : " " ;
 position : absolute ;
 height : 0 ;
 left:0;
 top: 0;
 width: 0;
 margin-left : 0 ;
 bottom : 12px ;
 box-shadow: 6px 5px 9px -9px black;
 }

 .arrow.bottom:after {
 border-top:8px solid #000000;
 border-right:8px solid transparent;
 border-bottom:8px solid transparent;
 border-left:8px solid transparent;
 }

 .arrow.top:after {
 border-top:6px solid transparent;
 border-right:6px solid transparent;
 border-bottom:6px solid #000000;
 border-left:6px solid transparent;
 }

 .arrow.left:after{
 width:0;
 border-top: 6px solid transparent;
 border-right: 6px solid #000000;
 border-bottom: 6px solid transparent;
 border-left: 6px solid transparent;
 }

 .arrow.right:after{
 width:0;
 border-top: 6px solid transparent;
 border-right: 6px solid transparent;
 border-bottom: 6px solid transparent;
 border-left: 6px solid #000000;
 }*/
/*
 * jQuery UI Datepicker 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://jqueryui.com/datepicker/
 */
.ui-datepicker {
  width: 17em;
  padding: .2em .2em 0;
  display: none;
}
.ui-datepicker .ui-datepicker-header {
  position: relative;
  padding: .2em 0;
  border: 0;
  font-weight: bold;
  width: 100%;
  padding: 4px 0;
  background-color: #f5f5f5;
  color: #808080;
}
.ui-datepicker .ui-datepicker-prev,
.ui-datepicker .ui-datepicker-next {
  position: absolute;
  top: 2px;
  width: 1.8em;
  height: 1.8em;
}
.ui-datepicker .ui-datepicker-prev-hover,
.ui-datepicker .ui-datepicker-next-hover {
  /*top: 1px;*/
}
.ui-datepicker .ui-datepicker-prev {
  left: 2px;
}
.ui-datepicker .ui-datepicker-next {
  right: 2px;
}
.ui-datepicker .ui-datepicker-prev-hover {
  /*left:1px;*/
}
.ui-datepicker .ui-datepicker-next-hover {
  /*right:1px;*/
}
.ui-datepicker .ui-datepicker-prev span,
.ui-datepicker .ui-datepicker-next span {
  display: block;
  position: absolute;
  left: 50%;
  margin-left: -8px;
  top: 50%;
  margin-top: -8px;
}
.ui-datepicker .ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  text-align: center;
}
.ui-datepicker .ui-datepicker-title select {
  font-size: 1em;
  margin: 1px 0;
}
.ui-datepicker select.ui-datepicker-month-year {
  width: 100%;
}
.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
  width: 49%;
}
.ui-datepicker table {
  width: 100%;
  font-size: .9em;
  border-collapse: collapse;
  margin: 0 0 .4em;
}
.ui-datepicker th {
  padding: .7em .3em;
  text-align: center;
  font-weight: bold;
  border: 0;
}
.ui-datepicker td {
  border: 0;
  padding: 1px;
}
.ui-datepicker td span,
.ui-datepicker td a {
  display: block;
  padding: .2em;
  text-align: right;
  text-decoration: none;
}
.ui-datepicker .ui-datepicker-buttonpane {
  background-image: none;
  margin: .7em 0 0 0;
  padding: 0 .2em;
  border-left: 0;
  border-right: 0;
  border-bottom: 0;
}
.ui-datepicker .ui-datepicker-buttonpane button {
  float: right;
  margin: .5em .2em .4em;
  cursor: pointer;
  padding: .2em .6em .3em .6em;
  width: auto;
  overflow: visible;
}
.ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current {
  float: left;
}
/* with multiple calendars */
.ui-datepicker.ui-datepicker-multi {
  width: auto;
}
.ui-datepicker-multi .ui-datepicker-group {
  float: left;
}
.ui-datepicker-multi .ui-datepicker-group table {
  width: 95%;
  margin: 0 auto .4em;
}
.ui-datepicker-multi-2 .ui-datepicker-group {
  width: 50%;
}
.ui-datepicker-multi-3 .ui-datepicker-group {
  width: 33.3%;
}
.ui-datepicker-multi-4 .ui-datepicker-group {
  width: 25%;
}
.ui-datepicker-multi .ui-datepicker-group-last .ui-datepicker-header {
  border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-group-middle .ui-datepicker-header {
  border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-buttonpane {
  clear: left;
}
.ui-datepicker-row-break {
  clear: both;
  width: 100%;
  font-size: 0em;
}
/* RTL support */
.ui-datepicker-rtl {
  direction: rtl;
}
.ui-datepicker-rtl .ui-datepicker-prev {
  right: 2px;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next {
  left: 2px;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-prev:hover {
  right: 1px;
  left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next:hover {
  left: 1px;
  right: auto;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane {
  clear: right;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button {
  float: left;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current {
  float: right;
}
.ui-datepicker-rtl .ui-datepicker-group {
  float: right;
}
.ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header {
  border-right-width: 0;
  border-left-width: 1px;
}
.ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header {
  border-right-width: 0;
  border-left-width: 1px;
}
/* IE6 IFRAME FIX (taken from datepicker 1.5.3 */
.ui-datepicker-cover {
  display: none;
  display: block;
  position: absolute;
  z-index: -1;
  filter: mask();
  top: -4px;
  left: -4px;
  width: 200px;
  height: 200px;
}
.ui-datepicker th {
  font-weight: bold;
  color: gray;
}
.ui-datepicker-today a:hover {
  background-color: #808080;
  color: #ffffff;
}
.ui-datepicker-today a {
  background-color: #BFBFBF;
  cursor: pointer;
  padding: 0 4px;
  margin-bottom: 0;
}
.ui-datepicker td a {
  margin-bottom: 0;
  border: 0;
}
.ui-datepicker td:hover {
  color: #ffffff;
}
.ui-datepicker td .ui-state-default {
  border: 0;
  background: none;
  margin-bottom: 0;
  padding: 5px;
  color: gray;
  text-align: center;
  filter: none;
}
.ui-datepicker td .ui-state-highlight {
  color: #ffffff;
  background-color: #A90329;
  border-color: #46b8da;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  -webkit-border-radius: 0px;
  /* Safari 4 */
  -moz-border-radius: 0px;
  /* Firefox 3.6 */
  border-radius: 0px;
}
.ui-datepicker td .ui-state-active {
  color: #333333;
  background-color: #ebebeb;
  border-color: #adadad;
  margin-bottom: 0;
  font-size: normal;
  text-shadow: 0;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  -webkit-border-radius: 0px;
  /* Safari 4 */
  -moz-border-radius: 0px;
  /* Firefox 3.6 */
  border-radius: 0px;
}
.ui-datepicker td .ui-state-hover {
  color: #ffffff;
  background: #428bca;
  background-color: #428bca;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  border-color: #357ebd;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  -webkit-border-radius: 0px;
  /* Safari 4 */
  -moz-border-radius: 0px;
  /* Firefox 3.6 */
  border-radius: 0px;
}
/*
 * jQuery UI Progressbar 1.10.3
 *
 * Copyright 2013, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Progressbar#theming
 */
.ui-progressbar {
  height: 2em;
  margin-bottom: 20px;
  border: 0px;
  overflow: hidden;
  background-color: #f7f7f7;
  background-image: -moz-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f5f5f5), to(#f9f9f9));
  background-image: -webkit-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: -o-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: linear-gradient(to bottom, #f5f5f5, #f9f9f9);
  background-repeat: repeat-x;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  border-radius: 0px;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff5f5f5', endColorstr='#fff9f9f9', GradientType=0);
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}
.ui-progressbar .ui-progressbar-value {
  margin: 0px;
  height: 100%;
  color: #ffffff;
  /*this can be removed if ui-widget-header is blue*/
  background-color: #428BCA;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width 0.6s ease;
  transition: width 0.6s ease;
}
.ui-progressbar .ui-progressbar-overlay {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px;
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -moz-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.ui-progressbar-indeterminate .ui-progressbar-value {
  background-image: none;
}
/**Toolbar**/
.ui-toolbar {
  padding: 7px 14px;
  margin: 0 0 18px;
  background-color: #f5f5f5;
  background-repeat: repeat-x;
  background-image: -webkit-linear-gradient(top, #ffffff, #f5f5f5);
  /* Safari 5.1+, Chrome 10+ */
  background-image: -moz-linear-gradient(top, #ffffff, #f5f5f5);
  /* Firefox 3.6 */
  background-image: -o-linear-gradient(top, #ffffff, #f5f5f5);
  /* Opera 11.10+ */
  background-image: linear-gradient(top, #ffffff, #f5f5f5);
  /* CSS3 Compliant */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f5f5f5', GradientType=0);
  /* IE8 */
  border: 1px solid #ddd;
  -webkit-border-radius: 3px;
  /* Safari 4 */
  -moz-border-radius: 3px;
  /* Firefox 3.6 */
  border-radius: 3px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  /* Safari 4 */
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  /* Firefox 3.6 */
  box-shadow: inset 0 1px 0 #ffffff;
}
/** File Input **/
.customfile-button {
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid #ccc;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none;
}
/***Wijmo Theming**/
div.wijmo-wijmenu {
  padding: 0 20px;
  background-color: #222222;
  background-repeat: repeat-x;
  background-image: -webkit-linear-gradient(top, #333333, #222222);
  /* Safari 5.1+, Chrome 10+ */
  background-image: -moz-linear-gradient(top, #333333, #222222);
  /* Firefox 3.6 */
  background-image: -o-linear-gradient(top, #333333, #222222);
  /* Opera 11.10+ */
  background-image: linear-gradient(top, #333333, #222222);
  /* CSS3 Compliant */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#333333', endColorstr='#222222', GradientType=0);
  /* IE8 */
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
  /* Safari 4 */
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
  /* Firefox 3.6 */
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}
.wijmo-wijmenu .ui-state-default {
  -webkit-box-shadow: none;
  /* Safari 4 */
  -moz-box-shadow: none;
  /* Firefox 3.6 */
  box-shadow: none;
  color: #bfbfbf;
}
.wijmo-wijmenu .ui-state-default .wijmo-wijmenu-text {
  color: #bfbfbf;
}
.wijmo-wijmenu .ui-state-hover {
  background: #444;
  background: rgba(255, 255, 255, 0.05);
}
.wijmo-wijmenu .ui-state-hover .wijmo-wijmenu-text {
  color: #ffffff;
}
div.wijmo-wijmenu .ui-widget-header h3 {
  position: relative;
  margin-top: 1px;
  padding: 0;
}
.wijmo-wijmenu h3 a {
  color: #ffffff;
  display: block;
  float: left;
  font-size: 20px;
  font-weight: 200;
  line-height: 1;
  margin-left: -20px;
  margin-top: 1px;
  padding: 8px 20px 12px;
}
.wijmo-wijmenu h3 a:hover {
  background-color: rgba(255, 255, 255, 0.05);
  color: #ffffff;
  text-decoration: none;
}
.wijmo-wijmenu .ui-widget-header {
  border: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-parent .wijmo-wijmenu-child {
  padding: 0.3em 0;
}
div.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-child {
  background: #333;
  border: 0;
  margin: 0;
  padding: 6px 0;
  width: 160px;
  -webkit-border-radius: 0 0 6px 6px;
  /* Safari 4 */
  -moz-border-radius: 0 0 6px 6px;
  /* Firefox 3.6 */
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  /* Safari 4 */
  -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  /* Firefox 3.6 */
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
}
div.wijmo-wijmenu .wijmo-wijmenu-item {
  margin: 0;
  border: 0;
}
.wijmo-wijmenu a.wijmo-wijmenu-link {
  margin: 0;
  line-height: 19px;
  padding: 10px 10px 11px;
  border: 0;
  -webkit-border-radius: 0;
  /* Safari 4 */
  -moz-border-radius: 0;
  /* Firefox 3.6 */
  border-radius: 0;
}
div.wijmo-wijmenu .wijmo-wijmenu-child .wijmo-wijmenu-link {
  display: block;
  float: none;
  padding: 4px 15px;
  width: auto;
}
div.wijmo-wijmenu .wijmo-wijmenu-child .wijmo-wijmenu-text {
  float: none;
}
.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-child .ui-state-hover {
  background: #191919;
}
.wijmo-wijmenu .wijmo-wijmenu-item .wijmo-wijmenu-separator {
  padding: 5px 0;
  background-image: none;
  background-color: #222;
  border-top: 1px solid #444;
  border-bottom: 0;
  border-left: 0;
  border-right: 0;
}
.wijmo-wijmenu .wijmo-wijmenu-item input {
  -moz-transition: none 0s ease 0s;
  background-color: rgba(255, 255, 255, 0.3);
  border: 1px solid #111111;
  border-radius: 4px 4px 4px 4px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px 0 rgba(255, 255, 255, 0.25);
  /* Safari 4 */
  -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px 0 rgba(255, 255, 255, 0.25);
  /* Firefox 3.6 */
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px 0 rgba(255, 255, 255, 0.25);
  color: rgba(255, 255, 255, 0.75);
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  line-height: 1;
  margin: 5px 10px 0 10px;
  padding: 4px 9px;
  width: 100px;
}
.wijmo-wijmenu .wijmo-wijmenu-item input:hover {
  background-color: rgba(255, 255, 255, 0.5);
  color: #ffffff;
}
.wijmo-wijmenu .wijmo-wijmenu-item input:focus {
  background-color: #ffffff;
  border: 0 none;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  /* Safari 4 */
  -moz-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  /* Firefox 3.6 */
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  color: #404040;
  outline: 0 none;
  padding: 5px 10px;
  text-shadow: 0 1px 0 #ffffff;
}
.wijmo-wijmenu .ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  text-shadow: none;
}
.wijmo-wijmenu .ui-state-default {
  -webkit-box-shadow: none;
  /* Safari 4 */
  -moz-box-shadow: none;
  /* Firefox 3.6 */
  box-shadow: none;
  color: #bfbfbf;
  filter: none;
}
/**
 * Font Awesome in jQuery UI
 * @author Gerits Aurelien
 *
 **/
.ui-button-icon-primary.ui-icon[class^="icon-"]:before,
.ui-button-icon-primary.ui-icon[class*=" icon-"]:before,
.ui-button-icon-secondary.ui-icon[class^="icon-"]:before,
.ui-button-icon-secondary.ui-icon[class*=" icon-"]:before {
  font-size: inherit;
  margin-left: 7px !important;
  margin-left: 5px;
  display: inline;
  text-decoration: inherit;
  color: inherit;
}
/* **
 * If you use "Font awesome" is disable UI icons in element
 ** */
.ui-state-default .ui-icon[class*=" icon-"] {
  /* Reset background with font Awesome */
  background: none;
  margin-left: -12px;
  /*fix for margin issue with font awesome buttons*/
}
/* If you do not use ui-icon uncomment the lines */
/*
 .ui-button .ui-button-text{
 display: inline-block;
 padding: 0px;
 }

 .ui-button-text-icon-primary .ui-button-icon-primary{
 float:none;
 }*/
#chat-container *,
#chat-container *:after,
#chat-container *:before {
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
#chat-container input[type='text'] {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
}
#chat-container {
  position: absolute;
  width: 250px;
  height: 270px;
  z-index: 2;
  border-left: 1px solid #CDCECF;
  right: -251px;
  top: 0px;
  background: #fff;
  transition-duration: .25s;
  -webkit-transition-duration: .25s;
  -moz-transition-duration: .25s;
  -o-transition-duration: .25s;
  -ms-transition-duration: .25s;
}
#chat-container:hover,
#chat-container:hover .chat-list-open-close {
  border-color: #A7A7A7;
}
#chat-container.open {
  right: 0px;
  top: 0px;
}
#chat-container .chat-list-open-close {
  display: block;
  width: 25px;
  height: 25px;
  border: 1px solid #CDCECF;
  border-right: 1px solid #f2f4f8 !important;
  position: absolute;
  left: -32px;
  top: 7%;
  border-radius: 50% 0 0 50%;
  background: #FFF;
  padding: 3px 1px 3px 5px;
  font-size: 21px;
  line-height: 22px;
  cursor: pointer;
  color: #868686;
  box-shadow: inset 0 0.2em 0 rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 0.2em 0 rgba(0, 0, 0, 0.05);
  background: #f2f4f8;
  text-align: center;
}
#chat-container .chat-list-open-close b {
  position: absolute;
  right: 0px;
  background: #ed1c24;
  line-height: 9px;
  height: 10px;
  width: 10px;
  font-size: 0;
  top: 3px;
  border: 1px solid #FFF;
  border-radius: 3px;
  font-size: 9px;
  text-align: center;
  vertical-align: middle;
  color: #fff;
  font-weight: normal;
}
#chat-container.open .chat-list-open-close i:before {
  content: "\f00d" !important;
}
#chat-container.open .chat-list-open-close b {
  display: none;
}
#chat-container .chat-list-body {
  height: 217px;
  overflow-y: scroll;
  overflow-x: hidden;
  display: block;
  padding: 0;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  background: #f2f4f8;
}
#chat-container #chat-users {
  list-style: none;
  margin: 10px 0;
  padding: 0;
}
#chat-container #chat-users li {
  margin-bottom: 3px;
  margin-left: 5px;
}
#chat-container #chat-users li a {
  display: block;
  font-size: 13px;
  color: #3d3d3d;
  text-decoration: none !important;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  padding: 3px 8px 3px 3px;
  line-height: 33px;
  vertical-align: middle;
}
#chat-container #chat-users li a:hover {
  background: #e0e4ee;
}
#chat-container #chat-users li a img {
  width: 33px;
  height: auto;
  margin-right: 10px;
}
#chat-container #chat-users li a i {
  color: #ACACAC;
  font-size: 8px;
  line-height: 34px;
  font-style: normal;
}
#chat-container #chat-users li a i.last-online {
  font-size: 12px;
  letter-spacing: -1px;
}
#chat-container .chat-list-footer {
  overflow: hidden;
  border-top: 1px solid #CCC;
  padding: 10px;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
#chat-container .chat-list-footer input[type="text"] {
  border: 1px solid #bababa !important;
}
#chat-container .control-group {
  padding: 0px;
}
.chat-body {
  background: #FAFAFA;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJod…EiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);
  background: -moz-linear-gradient(top, #fafafa 0%, #ffffff 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #fafafa), color-stop(100%, #ffffff));
  background: -webkit-linear-gradient(top, #fafafa 0%, #ffffff 100%);
  background: -o-linear-gradient(top, #fafafa 0%, #ffffff 100%);
  background: -ms-linear-gradient(top, #fafafa 0%, #ffffff 100%);
  background: linear-gradient(to bottom, #f5fcff 0%, #ffffff 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fafafa', endColorstr='#ffffff', GradientType=0);
  box-shadow: inset 2px 2px 5px rgba(0, 0, 0, 0.04);
  -moz-box-shadow: inset -2px -2px 5px rgba(0, 0, 0, 0.04);
  display: block;
  height: 270px;
  overflow-y: scroll;
  overflow-x: hidden;
  padding: 10px;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  border: 1px solid #fff;
  border-top: none;
}
.chat-body ul {
  margin: 0;
  padding: 0;
}
.chat-body li.message {
  display: block;
  position: relative;
  margin: 20px 20px 0;
}
.chat-body li:first-child {
  margin-top: 10px;
}
.chat-body li.message img {
  display: inline-block;
  border-left: 4px solid #fff;
  position: absolute;
}
.chat-body li.message img.online {
  border-left-color: #00a300;
}
.chat-body li.message img.offline {
  border-left-color: #ddd;
}
.chat-body li.message img.busy {
  border-left-color: #A90329;
}
.chat-body li.message img.away {
  border-left-color: #ffc40d;
}
.chat-body li.message .message-text {
  display: inline-block;
  vertical-align: top;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  padding: 0;
  margin-left: 65px;
  line-height: normal;
}
.chat-body li.message .message-text time {
  position: absolute;
  top: 1px;
  right: 0px;
  font-size: 10px;
  line-height: 10px;
  color: #AFAFAF;
}
.chat-body li.message .message-text .chat-file:nth-child(3) {
  margin-top: 15px;
}
.chat-body li.message .message-text .chat-file {
  display: block;
  margin: 3px 0;
  padding: 4px;
  border: 1px dotted #ddd;
  background: rgba(0, 0, 0, 0.05);
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  text-align: right;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.chat-body li.message .message-text .chat-file.row-fluid [class*="span"] {
  min-height: 10px !important;
}
.chat-body li.message .message-text .chat-file b {
  font-style: italic;
  white-space: nowrap;
  width: 250px;
  overflow: hidden;
  text-overflow: ellipsis;
  text-align: left;
}
.chat-body li.message .message-text a.username {
  display: block;
  font-weight: bold;
  margin-bottom: 4px;
  vertical-align: top;
  line-height: 14px;
  font-size: 14px;
  letter-spacing: -1px;
  text-decoration: none !important;
}
/* message reply */
.profile-message {
  background: none !important;
  height: auto !important;
  box-shadow: none !important;
  -moz-box-shadow: none !important;
  -webkit-box-shadow: none !important;
  overflow: hidden;
}
.profile-message li.message.message-reply {
  margin-left: 85px !important;
  background: #F7F7F7;
  padding: 10px;
  margin: 3px 0 0 20px;
}
.profile-message li.message.message-reply img {
  width: 35px !important;
}
.profile-message li.message.message-reply .message-text {
  margin-left: 45px !important;
}
.profile-message .wall-comment-reply {
  margin-left: 85px;
  margin-bottom: 20px;
}
.chat-footer {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
  padding: 0 10px 15px;
  position: relative;
  box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.textarea-div {
  background-color: #FFF;
  border: 1px solid #CCC;
  border-bottom: none;
  margin: 10px 0 0;
}
.typearea {
  cursor: text;
  overflow-x: hidden;
  overflow-y: auto;
  max-height: 90px;
  padding: 5px 25px 5px 5px;
  position: relative;
  border-bottom: 1px solid #EEE;
}
.typearea textarea {
  width: 100%;
  border-color: transparent !important;
  box-sizing: border-box;
  box-shadow: none;
  -moz-box-shadow: none ;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -webkit-box-shadow: none;
  overflow: hidden;
  padding: 0;
  margin: 0;
  -webkit-transition: height 0.2s;
  -moz-transition: height 0.2s;
  transition: height 0.2s;
  outline: none;
  resize: none;
  min-height: 61px;
}
textarea.clone {
  position: absolute;
  visibility: hidden;
}
.textarea-controls {
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  padding: 5px;
  display: block;
  background-color: #FFF;
  border: 1px solid #CCC;
  border-top: none;
  height: 43px;
  line-height: 33px;
  overflow: hidden;
}
.textarea-controls > label {
  margin: 3px 10px 0 10px;
}
.textarea-controls .smart-form .checkbox {
  padding-left: 22px !important;
}
@media (min-width: 768px) and (max-width: 880px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
@media (max-width: 480px) {
  .chat-body li.message .message-text .chat-file b {
    width: 150px;
  }
}
/*Messagebox */
.divMessageBox {
  width: 100%;
  height: 100%;
  position: fixed;
  top: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.6);
  z-index: 100000;
}
/*
.MessageIE{
    background-image: url("@{base-url}/bg.png");
    
}*/
.MessageBoxContainer {
  top: 35%;
  color: white;
  position: relative;
  width: 100%;
  background-color: #232323;
  background-color: rgba(0, 0, 0, 0.8);
  padding: 20px;
}
.MessageBoxMiddle {
  position: relative;
  left: 20%;
  width: 60%;
}
.MessageBoxMiddle .MsgTitle {
  letter-spacing: -1px;
  font-size: 24px;
  font-weight: 300;
}
.MessageBoxMiddle .pText {
  font-style: 30px;
}
.MessageBoxContainer input {
  width: 50%;
  padding: 5px;
}
.MessageBoxContainer select {
  width: 50%;
  padding: 5px;
}
.MessageBoxButtonSection {
  width: 100%;
  height: 30px;
}
.MessageBoxButtonSection button {
  float: right;
  margin-right: 7px;
  padding-left: 15px;
  padding-right: 15px;
  font-size: 14px;
  font-weight: bold;
}
/* End of MessageBox */
.LoadingBoxContainer {
  top: 20%;
  color: white;
  position: relative;
  width: 100%;
  background-color: #232323;
}
.LoadingBoxMiddle {
  position: relative;
  left: 20%;
  width: 50%;
  padding: 10px;
}
.LoadingBoxContainer .MsgTitle {
  font-size: 26px;
}
.LoadingBoxContainer .pText {
  font-style: 30px;
}
#LoadingPoints {
  position: absolute;
}
/* bigBoxes */
.bigBox {
  position: fixed;
  right: 10px;
  bottom: 10px;
  background-color: #004d60;
  padding-left: 10px;
  padding-top: 10px;
  padding-right: 10px;
  padding-bottom: 5px;
  width: 390px;
  height: 150px;
  color: white;
  z-index: 99999;
  box-sizing: content-box;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  border-left: 5px solid rgba(0, 0, 0, 0.15);
  overflow: hidden;
}
.bigBox span {
  font-size: 17px;
  font-weight: 300;
  letter-spacing: -1px;
  padding: 5px 0 !important;
  display: block;
}
.bigBox p {
  font-size: 13px;
  margin-top: 10px;
}
#divMiniIcons {
  position: fixed;
  width: 415px;
  right: 10px;
  bottom: 180px;
  z-index: 9999;
  float: right;
}
.botClose {
  position: absolute;
  right: 10px;
  height: 16px;
  width: 15px;
  cursor: pointer;
  font-size: 18px;
  opacity: .5;
  display: block;
  top: 15px;
}
.botClose:hover {
  opacity: 1;
}
#divMiniIcons .cajita {
  text-align: center;
  vertical-align: middle;
  padding: 4px 6px;
  color: #FFF;
  float: right;
  cursor: pointer;
  display: block;
  background-color: #F00;
  font-size: 17px;
  margin-left: 4px;
  margin-top: 5px;
}
#divMiniIcons .cajita:active {
  top: 1px;
  left: 1px;
  position: relative;
}
.cajita img {
  width: 23px;
  height: 23px;
  padding-left: 3px;
  padding-top: 3px;
}
.bigBox .bigboxicon {
  font-size: 30px;
  text-align: left;
  position: absolute;
  top: 120px;
  left: 6px;
  z-index: 0;
}
.bigBox .bigboxnumber {
  width: 100%;
  text-align: right;
  font-size: 25px;
}
/* End of  bigBoxes */
/* SmallBox */
#divSmallBoxes {
  position: fixed;
  right: 0;
  top: 0;
  z-index: 9999;
}
.SmallBox {
  position: absolute;
  right: 5px;
  top: 20px;
  width: 420px;
  color: white;
  z-index: 9999;
  overflow: hidden;
  border: 1px solid transparent;
}
.SmallBox:hover {
  border: 1px solid #fff;
  cursor: pointer;
}
.SmallBox .foto {
  font-size: 50px;
  position: absolute;
  left: 17px;
}
.SmallBox .textoFull {
  width: 93%;
  float: left;
  padding-left: 20px;
}
.SmallBox .textoFoto {
  width: 78%;
  margin: 3px 20px 3px 80px;
  float: left;
}
.miniPic {
  position: absolute;
  bottom: 8px;
  right: 9px;
}
.miniIcono {
  height: 100%;
  font-size: 20px;
}
.SmallBox span {
  font-size: 17px;
  font-weight: 300;
  letter-spacing: -1px;
  display: block;
  margin: 4px 0;
}
.SmallBox p {
  font-size: 13px;
  margin-top: 2px;
}
/* End of SmallBox */
#pageslide {
  /* These styles MUST be included. Do not change. */
  display: none;
  position: absolute;
  position: fixed;
  top: 0;
  height: 100%;
  z-index: 999999;
  /* Specify the width of your pageslide here */
  width: 305px;
  padding: 20px;
  /* These styles are optional, and describe how the pageslide will look */
  background-color: #004d60;
  color: #FFF;
  -webkit-box-shadow: inset 0 0 5px 5px #222;
  -moz-shadow: inset 0 0 0px 0px #222;
  box-shadow: inset 0 0 0px 0px #222;
}
.purehtml {
  color: white;
  font-size: 16px;
}
/* Mobile Phones */
@media screen and (max-width: 450px) and (max-width: 767px) {
  /* SmallBox Responsive */
  #divSmallBoxes {
    position: fixed;
    width: 90%;
    right: 0;
    top: 0;
  }
  .SmallBox {
    width: 95%;
  }
  .SmallBox:hover {
    box-shadow: 0px 0px 10px #888888;
    cursor: pointer;
  }
  .SmallBox span {
    font-size: 16px;
    /*font-weight:bold;*/
  }
  .SmallBox p {
    font-size: 12px;
    margin-top: 2px;
  }
  .SmallBox .textoFull {
    width: 93%;
    float: left;
    padding-left: 20px;
  }
  .SmallBox .textoFoto {
    width: 55%;
    margin: 3px 20px 3px 80px;
    float: left;
  }
  /* End of SmallBox Responsive*/
  /* bigBoxes Responsive */
  .bigBox {
    position: fixed;
    right: 10px;
    bottom: 10px;
    background-color: #004d60;
    padding-left: 10px;
    padding-top: 10px;
    padding-right: 10px;
    padding-bottom: 5px;
    width: 88%;
    height: 150px;
    color: white;
    z-index: 99999;
  }
  /* End of  bigBoxes  Responsive */
  /*Messagebox Responsive */
  .divMessageBox {
    width: 100%;
    height: 100%;
    position: fixed;
    top: 0;
    left: 0;
    background: rgba(0, 0, 0, 0.6);
    z-index: 100000;
  }
  .MessageBoxContainer {
    top: 25%;
    color: white;
    position: relative;
    width: 100%;
    background-color: #232323;
  }
  .MessageBoxMiddle {
    position: relative;
    left: 0;
    width: 100%;
    padding: 3px;
  }
  .MessageBoxMiddle .MsgTitle {
    font-size: 22px;
  }
  .MessageBoxMiddle .pText {
    font-style: 10px;
  }
  .MessageBoxContainer input {
    width: 50%;
    padding: 5px;
  }
  .MessageBoxContainer select {
    width: 50%;
    padding: 5px;
  }
  .MessageBoxButtonSection {
    width: 100%;
    height: 30px;
  }
  .MessageBoxButtonSection button {
    float: right;
    margin-right: 5px;
    padding-left: 15px;
    padding-right: 15px;
  }
  /* End of MessageBox Responsive */
}
/* Animations */
.animated {
  -webkit-animation-duration: 1s;
  -moz-animation-duration: 1s;
  -o-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  -moz-animation-fill-mode: both;
  -o-animation-fill-mode: both;
  animation-fill-mode: both;
}
.animated.fast {
  -webkit-animation-duration: 0.4s;
  -moz-animation-duration: 0.4s;
  -ms-animation-duration: 0.4s;
  -o-animation-duration: 0.4s;
  animation-duration: 0.4s;
}
@-webkit-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-moz-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-o-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
.fadeIn {
  -webkit-animation-name: fadeIn;
  -moz-animation-name: fadeIn;
  -o-animation-name: fadeIn;
  animation-name: fadeIn;
}
@-webkit-keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
}
@-moz-keyframes fadeInRight {
  0% {
    opacity: 0;
    -moz-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
}
@-o-keyframes fadeInRight {
  0% {
    opacity: 0;
    -o-transform: translateX(20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateX(0);
  }
}
@keyframes fadeInRight {
  0% {
    opacity: 0;
    transform: translateX(20px);
  }
  100% {
    opacity: 1;
    transform: translateX(0);
  }
}
.fadeInRight {
  -webkit-animation-name: fadeInRight;
  -moz-animation-name: fadeInRight;
  -o-animation-name: fadeInRight;
  animation-name: fadeInRight;
}
@-webkit-keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
  }
}
@-moz-keyframes fadeInUp {
  0% {
    opacity: 0;
    -moz-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -moz-transform: translateY(0);
  }
}
@-o-keyframes fadeInUp {
  0% {
    opacity: 0;
    -o-transform: translateY(20px);
  }
  100% {
    opacity: 1;
    -o-transform: translateY(0);
  }
}
@keyframes fadeInUp {
  0% {
    opacity: 0;
    transform: translateY(20px);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.fadeInUp {
  -webkit-animation-name: fadeInUp;
  -moz-animation-name: fadeInUp;
  -o-animation-name: fadeInUp;
  animation-name: fadeInUp;
}
@-webkit-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@-moz-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@-o-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
@keyframes fadeOut {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
.fadeOut {
  -webkit-animation-name: fadeOut;
  -moz-animation-name: fadeOut;
  -o-animation-name: fadeOut;
  animation-name: fadeOut;
}
@-webkit-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-20px);
  }
}
@-moz-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -moz-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -moz-transform: translateX(-20px);
  }
}
@-o-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -o-transform: translateX(0);
  }
  100% {
    opacity: 0;
    -o-transform: translateX(-20px);
  }
}
@keyframes fadeOutLeft {
  0% {
    opacity: 1;
    transform: translateX(0);
  }
  100% {
    opacity: 0;
    transform: translateX(-20px);
  }
}
.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  -moz-animation-name: fadeOutLeft;
  -o-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft;
}
/*
	 * USED WITH DEMO
	 */
.square {
  display: block;
  float: left;
  margin-right: 10px;
  height: 20px;
  width: 20px;
}
/*
	 * RESET BOOTSTRAP DEFAULT IE FILTER
	 */
[class^="bg-"],
[class*=" bg-"] {
  filter: none !important;
}
/*
	 * TEXT COLOR
	 */
.txt-color-blue {
  color: #57889c !important;
}
.txt-color-blueLight {
  color: #92a2a8 !important;
}
.txt-color-blueDark {
  color: #4c4f53 !important;
}
.txt-color-green {
  color: #356e35 !important;
}
.txt-color-greenLight {
  color: #71843f !important;
}
.txt-color-greenDark {
  color: #496949 !important;
}
.txt-color-red {
  color: #a90329 !important;
}
.txt-color-yellow {
  color: #b09b5b !important;
}
.txt-color-orange {
  color: #b19a6b !important;
}
.txt-color-orangeDark {
  color: #a57225 !important;
}
.txt-color-pink {
  color: #ac5287 !important;
}
.txt-color-pinkDark {
  color: #a8829f !important;
}
.txt-color-purple {
  color: #6e587a !important;
}
.txt-color-darken {
  color: #404040 !important;
}
.txt-color-lighten {
  color: #d5e7ec !important;
}
.txt-color-white {
  color: #ffffff !important;
}
.txt-color-grayDark {
  color: #525252 !important;
}
.txt-color-magenta {
  color: #6e3671 !important;
}
.txt-color-teal {
  color: #568a89 !important;
}
.txt-color-redLight {
  color: #a65858 !important;
}
/*
	 * BACKGROUNDS
	 */
.bg-color-blue {
  background-color: #57889c !important;
}
.bg-color-blueLight {
  background-color: #92a2a8 !important;
}
.bg-color-blueDark {
  background-color: #4c4f53 !important;
}
.bg-color-green {
  background-color: #356e35 !important;
}
.bg-color-greenLight {
  background-color: #71843f !important;
}
.bg-color-greenDark {
  background-color: #496949 !important;
}
.bg-color-red {
  background-color: #a90329 !important;
}
.bg-color-yellow {
  background-color: #b09b5b !important;
}
.bg-color-orange {
  background-color: #c79121 !important;
}
.bg-color-orangeDark {
  background-color: #a57225 !important;
}
.bg-color-pink {
  background-color: #ac5287 !important;
}
.bg-color-pinkDark {
  background-color: #a8829f !important;
}
.bg-color-purple {
  background-color: #6e587a !important;
}
.bg-color-darken {
  background-color: #404040 !important;
}
.bg-color-lighten {
  background-color: #d5e7ec !important;
}
.bg-color-white {
  background-color: #ffffff !important;
}
.bg-color-grayDark {
  background-color: #525252 !important;
}
.bg-color-magenta {
  background-color: #6e3671 !important;
}
.bg-color-teal {
  background-color: #568a89 !important;
}
.bg-color-redLight {
  background-color: #a65858 !important;
}
/*
 * Ion Slider
 */
/* =====================================================================================================================
 // RangeSlider */
.irs {
  position: relative;
  display: block;
}
.irs-line {
  position: relative;
  display: block;
  overflow: hidden;
}
.irs-line-left,
.irs-line-mid,
.irs-line-right {
  position: absolute;
  display: block;
  top: 0;
}
.irs-line-left {
  left: 0;
  width: 10%;
}
.irs-line-mid {
  left: 10%;
  width: 80%;
}
.irs-line-right {
  right: 0;
  width: 10%;
}
.irs-diapason {
  position: absolute;
  display: block;
  left: 0;
  width: 100%;
}
.irs-slider {
  position: absolute;
  display: block;
  cursor: default;
  z-index: 1;
}
.irs-slider.single {
  left: 10px;
}
.irs-slider.single:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: -150%;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.from {
  left: 100px;
}
.irs-slider.from:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: -300%;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.to {
  left: 300px;
}
.irs-slider.to:before {
  position: absolute;
  display: block;
  content: "";
  top: -50%;
  left: 0;
  width: 400%;
  height: 200%;
  background: rgba(0, 0, 0, 0);
}
.irs-slider.last {
  z-index: 2;
}
.irs-min {
  position: absolute;
  display: block;
  left: 0;
  cursor: default;
}
.irs-max {
  position: absolute;
  display: block;
  right: 0;
  cursor: default;
}
.irs-from,
.irs-to,
.irs-single {
  position: absolute;
  display: block;
  top: 0;
  left: 0;
  cursor: default;
  white-space: nowrap;
}
.irs-grid {
  position: absolute;
  display: none;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 20px;
}
.irs-with-grid .irs-grid {
  display: block;
}
.irs-grid-pol {
  position: absolute;
  top: 0;
  left: 0;
  width: 1px;
  height: 8px;
  background: #000;
}
.irs-grid-pol.small {
  height: 4px;
}
.irs-grid-text {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100px;
  white-space: nowrap;
  text-align: center;
  font-size: 9px;
  line-height: 9px;
  color: #000;
}
/*
 * CUST
 *
 */
.irs {
  height: 40px;
}
.irs-with-grid {
  height: 60px;
}
.irs-line {
  height: 8px;
  top: 25px;
  background: #eeeeee;
}
.irs-line-left {
  height: 8px;
}
.irs-line-mid {
  height: 8px;
}
.irs-line-right {
  height: 8px;
}
.irs-diapason {
  height: 8px;
  top: 25px;
}
.irs-slider {
  width: 10px;
  height: 22px;
  top: 17px;
  border: 1px solid #ffffff;
  background: #858585;
}
.irs-slider:hover {
  background: #6c6c6c;
}
#irs-active-slider {
  background: #686868;
  box-shadow: rgba(0, 0, 0, 0.3) 1px 1px 1px 0px;
  width: 12px;
  height: 24px;
  top: 16px;
}
.irs-min,
.irs-max {
  color: #999999;
  font-size: 12px;
  line-height: 1.333;
  text-shadow: none;
  top: 0;
  padding: 1px 3px;
  background: rgba(0, 0, 0, 0.1);
  border-radius: 0;
}
.lt-ie9 .irs-min,
.lt-ie9 .irs-max {
  background: #bfbfbf;
}
.irs-from,
.irs-to,
.irs-single {
  color: #ffffff;
  font-size: 10px;
  line-height: 1.333;
  text-shadow: none;
  padding: 1px 5px;
  background: rgba(0, 0, 0, 0.4);
  border-radius: 0;
}
.lt-ie9 .irs-from,
.lt-ie9 .irs-to,
.lt-ie9 .irs-single {
  background: #999999;
}
.irs-grid-pol {
  background: #99a4ac;
}
.irs-grid-text {
  color: #99a4ac;
}
.irs-diapason {
  background: #3276b1;
}
/*
 * JQUI STUFF
 */
/*	Overlay	 */
.ui-widget-overlay {
  background-image: none;
  background: #AAA;
  height: 200%;
  z-index: 9999;
  position: fixed;
  top: 0px;
  left: 0px;
}
/* Slider */
.slider {
  margin-top: 0px;
  margin-bottom: 30px;
}
.slider.slider-vertical {
  margin-bottom: 0px;
  margin-right: 5px;
}
/* menu */
.ui-menu {
  width: 155px;
  padding: 2px;
  -webkit-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  -moz-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  background: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  z-index: 1;
}
.ui-menu .ui-state-disabled {
  margin: .4em 0 .2em !important;
  background: none !important;
  color: #999 !important;
  font-weight: normal !important;
  cursor: default;
}
.ui-icon-carat-1-e:before {
  content: "\f105";
  font-family: FontAwesome;
  font-size: 14px;
  display: inline;
}
.ui-menu .ui-menu-item a .ui-menu-icon {
  width: auto;
  height: auto;
  top: 0px;
  left: auto;
  right: auto;
  bottom: auto;
  text-indent: 0px;
}
/* tabs */
.ui-tabs .ui-tabs-nav li a {
  border-radius: 0px;
  -moz-border-radius: 0px;
  background-color: #F5F5F5;
  border: 1px solid #F5F5F5;
  border-bottom: 1px solid #dddddd;
  color: #838383;
}
.ui-tabs .ui-tabs-nav li {
  margin-right: 3px;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active a {
  font-weight: bold;
  border-top-width: 0px !important;
  margin-top: 1px !important;
  -webkit-box-shadow: 0 -2px 0 #57889c;
  -moz-box-shadow: 0 -2px 0 #57889c;
  box-shadow: 0 -2px 0 #57889c;
}
.ui-tabs .ui-tabs-panel {
  border: 1px solid #dddddd;
  margin: 0;
  padding: 10px 13px;
  border-top: none;
}
.ui-tabs .ui-tabs-nav {
  margin-bottom: 0;
}
/* accordions */
.ui-accordion .ui-accordion-content {
  padding: 0;
}
.ui-accordion .ui-accordion-header {
  background-color: #fbfbfb;
  font-size: 15px;
  padding: 10px 15px 10px 36px !important;
}
.ui-accordion .ui-accordion-header,
.ui-accordion .ui-accordion-content {
  border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-border-radius: 0px;
}
.ui-accordion .ui-accordion-content {
  padding: 15px;
}
.ui-accordion-header-active + .ui-accordion-content {
  border-top: 1px solid #dddddd;
}
.ui-accordion .ui-accordion-header {
  margin-top: -2px;
}
.ui-accordion .ui-accordion-header,
.ui-accordion-content {
  border-color: #dddddd !important;
}
.ui-accordion-header-icon {
  text-indent: 0px !important;
  background-image: none !important;
  text-align: center;
  line-height: normal;
  left: 12px !important;
  margin-top: -6px !important;
  font-size: 14px !important;
}
/*
	 * Calendar
	 */
.ui-datepicker .ui-datepicker-next,
.ui-datepicker .ui-datepicker-prev {
  text-align: center;
  margin-top: 2px;
}
.ui-datepicker-next > :first-child,
.ui-datepicker-prev > :first-child {
  text-indent: 0px !important;
}
/*
 * JS SLIDER
 * Copied from: js/plugin/noUiSlider/jquery.nouislider.css 
 */
/*	General CSS resets;
 *		The target itself is not affected, allowing
 *		the remainder of the document to use an
 *		alternate box-sizing model;
 *		Support for box-sizing is wide spread:
 *		http://caniuse.com/#search=box-sizing
 */
.noUi-target * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-touch-callout: none;
  -ms-touch-action: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  cursor: default;
}
/*	Main slider bar;
 *		Standard styles no longer incorrectly force a
 *		width or height on the slider.
 */
.noUi-base {
  width: 100%;
  height: 14px;
  position: relative;
  max-width: 100%;
  max-height: 100%;
  border: 1px solid #bfbfbf;
  z-index: 1;
}
.noUi-origin-lower {
  background: #72a8d7;
}
/*	Handles + active state;
 *		The :after pseudo-element wont inherit
 *		box-sizing, so it needs to applied manually.
 */
.noUi-handle {
  background: #858585;
  height: 30px;
  width: 16px;
  border: 1px solid #ffffff;
  margin: -8px 0 0 -8px;
  cursor: default;
}
.noUi-handle:hover {
  background: #6c6c6c;
}
.noUi-active {
  cursor: default;
  box-shadow: rgba(0, 0, 0, 0.1) 1px 1px 1px 0px;
  background: #686868;
  height: 32px;
  width: 18px;
  margin: -9px 0 0 -8px;
  border: none;
}
.noUi-active:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  content: "";
  display: block;
  height: 100%;
  border: 1px solid #dddddd;
}
/*	Styling-only classes;
 *		Structured to prevent double declarations
 *		for various states of the slider.
 */
.noUi-connect {
  background: #3276b1;
}
.noUi-background {
  background: #eeeeee;
  border: none;
}
/*	Functional styles for handle positioning;
 *		Note that the origins have z-index 0, the base has
 *		z-index 1; This fixes a bug where borders become invisible.
 */
.noUi-origin {
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  z-index: 0;
}
.noUi-origin-upper {
  background: inherit !important;
}
.noUi-z-index {
  z-index: 10;
}
/*	Adaptations for the vertical slider;
 *		Some standard styles have been extended to keep
 *		exceptions for the vertical slider as minimal as possible.
 */
.noUi-vertical {
  width: 10px;
  height: 100%;
}
.noUi-vertical .noUi-origin {
  bottom: 0;
  left: 0;
}
.noUi-vertical .noUi-handle {
  margin: -8px 0 0 -3px;
}
/*	Various alternate slider states;
 *		Support for transition is widely available,
 *		Only IE7, IE8 and IE9 will ignore these rules.
 *		Since this is merely a progressive enhancement,
 *		this is no problem at all.
 *		http://caniuse.com/#search=transition
 */
.noUi-target[disabled] .noUi-base {
  background: #999999;
}
.noUi-target[disabled] .noUi-connect {
  background: #BBB;
}
.noUi-state-tap .noUi-origin {
  -webkit-transition: left 0.3s, top 0.3s;
  transition: left 0.3s, top 0.3s;
}
/*
 * JQUI SPINNERS
 */
.ui-spinner-input {
  margin: 0 !important;
  height: 30px;
  padding: 6px 24px 6px 12px;
}
.ui-spinner-input.spinner-left {
  padding: 6px 12px 6px 24px;
}
.ui-spinner {
  width: 100%;
}
.ui-spinner-input.spinner-left + .ui-spinner-button,
.ui-spinner-input.spinner-left + .ui-spinner-button + .ui-spinner-button {
  right: auto;
  left: 0px;
}
.ui-spinner-up,
.ui-spinner-down {
  background: #739e73;
  border-radius: 0px;
}
.ui-spinner-up:hover,
.ui-spinner-up:active,
.ui-spinner-up:focus {
  background: #5b835b;
}
.ui-spinner-down:hover,
.ui-spinner-down:active,
.ui-spinner-down:focus {
  background: #77021d;
}
.ui-spinner-down {
  background: #c2032f;
}
.ui-spinner-up:before,
.ui-spinner-down:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f067";
  color: #ffffff;
  font-size: 14px;
  margin-top: 1px;
}
.ui-spinner-down:before {
  content: "\f068";
}
.ui-spinner-up > :first-child,
.ui-spinner-down > :first-child {
  display: none;
}
.ui-spinner-button {
  width: 19px;
}
.ui-widget-content .ui-icon {
  background: none !important;
}
/* spinner both */
.ui-spinner-input.spinner-both {
  padding: 6px 30px;
}
.ui-spinner-input.spinner-both + .ui-spinner-button + .ui-spinner-button {
  left: 0px;
  right: auto;
}
.ui-spinner-input.spinner-both + .ui-spinner-button,
.ui-spinner-input.spinner-both + .ui-spinner-button + .ui-spinner-button {
  height: 30px;
  width: 25px;
}
.ui-spinner-input.spinner-both + .ui-spinner-up:before,
.ui-spinner-input.spinner-both + .ui-spinner-up + .ui-spinner-down:before {
  margin-top: 8px;
}
/*
 * JQUI ADJUSTMENT
 */
.ui-dialog {
  -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  border: 1px solid #999999;
  border: 1px solid rgba(0, 0, 0, 0.2);
}
.widget-header > :first-child {
  margin: 13px 0;
}
.ui-widget-overlay {
  z-index: 999;
}
.ui-dialog .ui-dialog-titlebar {
  padding: 0 10px;
  background: #ffffff;
  border-bottom-color: #eeeeee;
}
.ui-dialog .ui-dialog-title {
  margin: 0;
}
.ui-dialog .ui-dialog-titlebar-close {
  margin-top: -16px;
  margin-right: 4px;
}
.ui-dialog-titlebar-close:before {
  content: "\f00d";
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 13px;
}
.ui-dialog .ui-dialog-buttonpane button {
  margin: 0 .4em 0 0;
}
.ui-dialog .ui-dialog-buttonpane {
  margin-top: 13px;
  padding: 19px 15px 20px;
  text-align: right;
  border-top: 1px solid #eeeeee;
}
/*
 * Custom Radio and Input
 * SETUP
 */
.checkbox input[type="checkbox"].checkbox + span,
.checkbox-inline input[type="checkbox"].checkbox + span,
.radiobox-inline input[type="radio"].radiobox + span,
.radio input[type="radio"].radiobox + span {
  margin-left: -20px;
}
.form-inline .checkbox input[type="checkbox"].checkbox + span,
.form-inline .radiobox input[type="radio"].radiobox + span {
  margin-left: 0px;
}
.form-inline .checkbox,
.form-inline .radiobox {
  padding-left: 0px;
}
label input[type="radio"].radiobox + span,
input[type="checkbox"].checkbox + span {
  vertical-align: middle;
  line-height: 20px;
}
input[type="checkbox"].checkbox + span,
input[type="checkbox"].checkbox + span:after,
input[type="checkbox"].checkbox + span:before,
input[type="radio"].radiobox + span,
input[type="radio"].radiobox + span:after,
input[type="radio"].radiobox + span:before {
  box-sizing: content-box !important;
  -webkit-box-sizing: content-box !important;
  -moz-box-sizing: content-box !important;
}
input[type="checkbox"].checkbox,
input[type="radio"].radiobox {
  visibility: hidden;
  position: absolute;
  z-index: 20;
  width: 18px;
  height: 18px;
}
label input[type="checkbox"].checkbox + span,
label input[type="radio"].radiobox + span {
  position: relative;
  z-index: 19;
  display: inline-block;
  margin: 0;
  line-height: 17px;
  min-height: 14px;
  min-width: 14px;
  margin-right: 5px;
}
label input[type="checkbox"].checkbox + span:hover,
label input[type="radio"].radiobox + span:hover {
  cursor: pointer;
}
label input[type="radio"].radiobox + span:before,
label input[type="checkbox"].checkbox + span:before {
  font-family: 'FontAwesome';
  font-size: 12px;
  border-radius: 0;
  content: "\a0";
  /* we use '\a0'; to simulate a non-breaking-space (http://milov.nl/7029) */
  display: inline-block;
  text-align: center;
  vertical-align: middle;
  padding: 1px;
  height: 12px;
  line-height: 12px;
  min-width: 12px;
  margin-right: 5px;
  border: 1px solid #bfbfbf;
  background-color: #f4f4f4;
  font-weight: normal;
  margin-top: -1px;
}
/*
 * RADIO
 */
label input[type="radio"].radiobox + span:before {
  content: "\a0";
  /* we use '\a0'; to simulate a non-breaking-space (http://milov.nl/7029) */
  border-radius: 50%;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.1), 0px 1px 0px 0px rgba(255, 255, 255, 0.2);
}
label input[type="radio"].radiobox:checked + span {
  font-weight: bold;
}
/* DEFAULT COLOR */
label input[type="radio"].radiobox:checked + span:before {
  content: "\f111";
  /* circle */
  color: #2E7BCC;
}
/* ORANGE COLOR */
label input[type="radio"].radiobox.style-3:checked + span:before {
  color: #a90329;
  border-color: #a90329;
}
/* CHROME COLOR */
label input[type="radio"].radiobox.style-2:checked + span:before {
  color: #66665e;
  border-color: #4d90fe;
  font-size: 9px;
}
label input[type="radio"].radiobox.style-2:checked + span {
  font-weight: normal;
}
/* Style 1 Radio */
label input[type="radio"].radiobox.style-1 + span:before {
  font-size: 9px;
  background: #ffffff;
  text-shadow: none;
  box-shadow: none !important;
  border-width: 1px;
  height: 13px;
  line-height: 13px;
  min-width: 13px;
}
label input[type="radio"].radiobox.style-1:checked + span:before {
  font-size: 10px;
  color: #333333;
  border-color: #333333;
  background: #ffffff;
}
label input[type="radio"].radiobox.style-1:checked + span {
  font-weight: normal;
}
/*
 * RADIO:HOVER & ACTIVE STATES
 */
/* DEFAULT:HOVER radio content --> 2022 */
label:hover input[type="radio"].radiobox + span:before,
label:hover input[type="radio"].radiobox:checked + span:before {
  color: #2E7BCC;
  border-color: #2E7BCC;
}
/* ORANGE:HOVER */
label:hover input[type="radio"].radiobox.style-3 + span:before,
label:hover input[type="radio"].radiobox.style-3:checked + span:before {
  color: #a90329;
  border-color: #a90329;
}
/* CHROME:HOVER */
label:hover input[type="radio"].radiobox.style-2:checked + span:before {
  color: #66665e;
  border-color: #4d90fe;
}
/* METRO:HOVER */
label:hover input[type="radio"].radiobox.style-1:checked + span:before {
  color: #333333;
  border-color: #333333;
  background: #ffffff;
}
label:hover input[type="radio"].radiobox.style-1 + span:before {
  color: #333333;
  border-color: #333333;
  background: #ffffff;
}
/* DEFAULT:ACTIVE */
label:active input[type="radio"].radiobox + span:before {
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.3), 0px 1px 0px 0px rgba(255, 255, 255, 0.4);
}
/*
 * RADIO:DISABLE STATES
 */
/* GLOBAL */
label input[type="radio"][disabled].radiobox + span,
label input[type="radio"][disabled].radiobox:checked + span,
label:hover input[type="radio"][disabled].radiobox:checked + span:before {
  color: #A7A7A7;
  cursor: not-allowed;
}
label input[type="radio"][disabled].radiobox:checked + span:before {
  content: "\f111";
}
label input[type="radio"][disabled].radiobox:checked + span:before,
label input[type="radio"][disabled].radiobox + span:before,
label:active input[type="radio"][disabled].radiobox:checked + span:before,
label:hover input[type="radio"][disabled].radiobox:checked + span:before {
  background: #eee !important;
  border-color: #CCC !important;
  box-shadow: none;
  color: #A7A7A7;
}
/*
 * CHECKBOX
 */
label input[type="checkbox"].checkbox + span:before {
  content: "\a0";
  /* we use '\a0'; to simulate a non-breaking-space (http://milov.nl/7029) */
}
label input[type="checkbox"].checkbox:checked + span:before {
  content: "\f00c";
}
label input[type="checkbox"].checkbox:checked + span {
  font-weight: bold;
}
/* DEFAULT COLOR */
label input[type="checkbox"].checkbox:checked + span:before {
  color: #2E7BCC;
}
/* RED COLOR */
label input[type="checkbox"].checkbox.style-3:checked + span:before {
  color: #ffffff;
  border-color: #a90329;
  background: #a90329;
}
/* CHROME */
label input[type="checkbox"].checkbox.style-2 + span:before {
  background: transparent;
  border-color: #c1c1c1;
  box-shadow: none;
}
label input[type="checkbox"].checkbox.style-2:checked + span:before {
  content: "\f00c";
  color: #66665e;
  border-color: #4d90fe;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6MUQ0MEM4RUFEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6MUQ0MEM4RUJEQUE4MTFFMkEwMjM5NzlCRjAxM0UwRjciPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDoxRDQwQzhFOERBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDoxRDQwQzhFOURBQTgxMUUyQTAyMzk3OUJGMDEzRTBGNyIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/PsD/PVAAAAAQSURBVHjaYv7//78vQIABAAlYA05NMPppAAAAAElFTkSuQmCC) #ffffff;
  /*#fefeec*/
}
label input[type="checkbox"].checkbox.style-2:checked + span {
  font-weight: normal;
}
/* METRO COLOR */
label input[type="checkbox"].checkbox.style-1 + span:before {
  color: #333333;
  background: #ffffff;
  text-shadow: none;
  box-shadow: none !important;
  border-width: 1px;
  height: 12px;
  line-height: 13px;
  min-width: 12px;
}
label input[type="checkbox"].checkbox.style-1:checked + span:before {
  color: #333333;
  border-color: #333333;
}
label input[type="checkbox"].checkbox.style-1:checked + span {
  font-weight: normal;
}
/*
 * CHECKBOX:HOVER & ACTIVE STATES
 */
label:active input[type="checkbox"].checkbox + span:before {
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.3), 0px 1px 0px 0px rgba(255, 255, 255, 0.4);
}
/* DEFAULT:HOVER */
label:hover input[type="checkbox"].checkbox + span:before {
  color: #2E7BCC;
  border-color: #2E7BCC;
}
/* RED:HOVER*/
label:hover input[type="checkbox"].checkbox.style-3 + span:before {
  color: #ffffff;
  border-color: #A90327;
}
/* CHROME:HOVER*/
label:hover input[type="checkbox"].checkbox.style-2 + span:before {
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.1), 0px 1px 0px 0px rgba(255, 255, 255, 0.2);
}
label:hover input[type="checkbox"].checkbox.style-2:checked + span:before {
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.3), 0px 1px 0px 0px rgba(255, 255, 255, 0.4);
}
/* METRO:HOVER*/
label:hover input[type="checkbox"].checkbox.style-1 + span:before {
  border-color: #333333;
}
/* DEFAULT:ACTIVE */
label:active input[type="checkbox"].checkbox:checked + span:before {
  color: #ffffff;
  background: #2E7BCC;
  border-color: #2E7BCC;
}
/* RED:ACTIVE */
label:active input[type="checkbox"].checkbox.style-3:checked + span:before {
  color: #a90329;
  background: #ffffff;
  border-color: #a90329;
}
/* CHROME:ACTIVE */
label:active input[type="checkbox"].checkbox.style-2:checked + span:before {
  color: #66665e;
  background: transparent;
  border-color: #c1c1c1;
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.3), 0px 1px 0px 0px rgba(255, 255, 255, 0.4);
}
label:active input[type="checkbox"].checkbox.style-2 + span:before {
  color: #66665e;
  background: transparent;
  border-color: #c1c1c1;
  box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.3), 0px 1px 0px 0px rgba(255, 255, 255, 0.4);
}
/* METRO:ACTIVE */
label:active input[type="checkbox"].checkbox.style-1:checked + span:before {
  color: #ffffff;
  background: #333333;
  border-color: #333333;
}
/*
 * CHECKBOX:DISABLE STATES
 */
/* GLOBAL */
label input[type="checkbox"][disabled].checkbox + span,
label input[type="checkbox"][disabled].checkbox:checked + span,
label:hover input[type="checkbox"][disabled].checkbox:checked + span:before {
  color: #A7A7A7;
  cursor: not-allowed;
}
label input[type="checkbox"][disabled].checkbox:checked + span:before {
  content: "\f00c";
  color: #A7A7A7;
}
label input[type="checkbox"][disabled].checkbox.style-2:checked + span:before {
  content: "\f00c";
}
label input[type="checkbox"][disabled].checkbox:checked + span:before,
label input[type="checkbox"][disabled].checkbox + span:before,
label:active input[type="checkbox"][disabled].checkbox:checked + span:before,
label:hover input[type="checkbox"][disabled].checkbox:checked + span:before {
  background: #eee !important;
  border-color: #CCC !important;
  box-shadow: none;
  color: #A7A7A7;
  box-shadow: none !important;
}
:-webkit-full-screen {
  /* properties */
}
:-webkit-full-screen #fullscreen > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
:-moz-full-screen {
  /* properties */
}
:-moz-full-screen #fullscreen > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
:-ms-fullscreen {
  /* properties */
}
:-ms-fullscreen #fullscreen > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
:full-screen {
  /*pre-spec */
  /* properties */
}
:full-screen #fullscreen > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
:fullscreen {
  /* spec */
  /* properties */
}
:fullscreen #fullscreen > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
/* deeper elements */
:-webkit-full-screen video {
  width: 100%;
  height: 100%;
}
/* styling the backdrop*/
::backdrop {
  /* properties */
}
::-ms-backdrop {
  /* properties */
}
/*
 * Error Page
 */
.error-box {
  max-width: 900px;
  margin: 0 auto;
}
.error-text {
  font-weight: 400;
  color: #ffffff;
  letter-spacing: -4px;
  font-size: 700%;
  margin-bottom: 30px;
  text-shadow: 0 1px 0 #cccccc, 0 2px 0 #bfbfbf, 0 3px 0 #bbbbbb, 0 4px 0 #b9b9b9, 0 5px 0 #aaaaaa, 0 6px 1px rgba(0, 0, 0, 0.1), 0 0 5px rgba(0, 0, 0, 0.1), 0 1px 3px rgba(0, 0, 0, 0.3), 0 3px 5px rgba(0, 0, 0, 0.2), 0 5px 10px rgba(0, 0, 0, 0.25), 0 10px 10px rgba(0, 0, 0, 0.2), 0 20px 20px rgba(0, 0, 0, 0.15);
}
.error-search {
  width: 300px;
  margin: 0 auto 20px;
}
.error-icon-shadow {
  text-shadow: 0 1px 0 #803838, 0 2px 0 #a85d5d, 0 3px 0 #b86565, 0 4px 0 #d86f6f, 0 5px 0 #b3a5a5, 0 6px 1px rgba(131, 51, 51, 0.1), 0 0 5px rgba(102, 30, 30, 0.1), 0 1px 3px rgba(95, 15, 15, 0.3), 0 3px 5px rgba(100, 23, 23, 0.2), 0 5px 10px rgba(114, 30, 30, 0.25), 0 10px 10px rgba(94, 15, 15, 0.2), 0 20px 20px rgba(121, 38, 38, 0.15);
}
/*
 * LOGIN/REGISTER PAGE
 */
.display-image {
  margin-top: -60px;
  margin-right: 20px;
}
.terms-body {
  max-height: 400px;
  overflow: auto;
}
#login {
  background: #ffffff;
  overflow: visible;
}
#login .container {
  border: none;
}
#login #header {
  margin: 0;
  height: 71px;
  border-bottom: 1px solid #eeeeee !important;
  overflow: hidden;
  padding: 0 30px;
  background-clip: padding-box;
  border-width: 0;
  min-height: 28px;
  background: #f4f4f4 !important;
  margin-bottom: 20px;
}
#login #header #logo {
  margin-top: 22px;
  margin-left: 0px;
}
#login #header #logo img {
  width: 137px;
}
#login-header-space {
  float: right;
  text-align: right;
  display: block;
  vertical-align: middle;
  line-height: 71px;
}
#login-header-space > :first-child {
  font-size: 13px;
  margin-right: 14px;
  vertical-align: -3px;
  font-weight: 400;
}
#login-header-space .btn {
  font-weight: bold;
  text-transform: uppercase;
}
#login-header-space > * {
  display: inline-block;
}
#login #main {
  background: #ffffff;
  margin: 0;
}
#login .hero {
  background-image: url("../../img/gradient/login.png");
  background-repeat: no-repeat;
  background-position: 0 137px;
  height: 360px;
  width: 100%;
  float: left;
}
#login h4.paragraph-header {
  color: #565656;
  font-size: 15px;
  font-weight: normal;
  line-height: 22px;
  margin-top: 15px;
  width: 270px;
}
#login h5.about-heading {
  color: #565656;
  font-size: 15px;
  font-weight: bold;
  line-height: 24px;
  margin: 0 0 5px;
}
#login .login-header-big {
  font-weight: 400;
}
#login .login-desc-box-l {
  min-height: 350px;
  width: 50%;
}
#login .login-app-icons {
  vertical-align: top;
  margin-top: 90px;
  width: 300px;
}
@media (min-width: 768px) and (max-width: 880px) {
  #login #header {
    padding: 0 5px !important;
  }
}
@media only screen and (min-width: 0px) and (max-width: 679px) {
  #login #header {
    padding: 0 5px !important;
  }
  #login #header #logo img {
    width: 135px;
  }
  #login #header #logo {
    margin-top: 22px;
  }
}
/*
 * NESTABLES
 */
.dd {
  position: relative;
  display: block;
  margin: 0;
  padding: 0;
  max-width: 600px;
  list-style: none;
  font-size: 13px;
  line-height: 20px;
}
.dd-list {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  list-style: none;
}
.dd-list .dd-list {
  padding-left: 30px;
}
.dd-collapsed .dd-list {
  display: none;
}
.dd-item,
.dd-empty,
.dd-placeholder {
  display: block;
  position: relative;
  margin: 0;
  padding: 0;
  min-height: 20px;
  font-size: 13px;
  line-height: 20px;
}
.dd-handle {
  display: block;
  font-size: 15px;
  margin: 5px 0;
  padding: 7px 15px;
  color: #333333;
  text-decoration: none;
  border: 1px solid #cfcfcf;
  background: #fbfbfb;
}
.dd-handle:hover {
  color: #2ea8e5;
  background: #ffffff;
}
.dd-item > button {
  position: relative;
  cursor: pointer;
  float: left;
  width: 25px;
  height: 20px;
  margin: 7px 10px;
  line-height: 22px !important;
  padding: 0;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden;
  border: 0;
  background: rgba(0, 0, 0, 0);
  text-align: center;
}
.dd-item > button {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 18px;
}
.dd-item > button:before {
  content: '\f055';
  display: block;
  position: absolute;
  width: 100%;
  text-align: center;
  text-indent: 0;
  color: #0091d9;
}
.dd-item > button[data-action="collapse"]:before {
  content: '\f056';
  color: #a90329;
}
.dd-placeholder,
.dd-empty {
  margin: 5px 0;
  padding: 0;
  min-height: 30px;
  background: #f2fbff;
  border: 1px dashed #b6bcbf;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}
.dd-empty {
  border: 1px dashed #bbb;
  min-height: 100px;
  background-color: #eeeeee;
  background-image: -webkit-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff), -webkit-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff);
  background-image: -moz-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff), -moz-linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff);
  background-image: linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff), linear-gradient(45deg, #ffffff 25%, transparent 25%, transparent 75%, #ffffff 75%, #ffffff);
  background-size: 60px 60px;
  background-position: 0 0, 30px 30px;
}
.dd-dragel {
  position: absolute;
  pointer-events: none;
  z-index: 9999;
}
.dd-dragel > .dd-item .dd-handle {
  margin-top: 0;
}
.dd-dragel .dd-handle {
  -webkit-box-shadow: 2px 4px 6px 0 rgba(0, 0, 0, 0.1);
  box-shadow: 2px 4px 6px 0 rgba(0, 0, 0, 0.1);
}
/**
 * Nestable Extras
 */
.nestable-lists {
  display: block;
  clear: both;
  padding: 30px 0;
  width: 100%;
  border: 0;
  border-top: 2px solid #bfbfbf;
  border-bottom: 2px solid #bfbfbf;
}
#nestable-menu {
  padding: 0;
  margin: 10px 0 20px;
}
#nestable-output,
#nestable2-output {
  width: 100%;
  padding: 5px;
}
@media only screen and (min-width: 700px) {
  .dd {
    float: left;
    width: 100%;
  }
  .dd + .dd {
    margin-left: 2%;
  }
}
.dd-hover > .dd-handle {
  background: #2ea8e5 !important;
}
/**
 * Nestable Draggable Handles
 */
.dd3-content {
  display: block;
  margin: 5px 0;
  padding: 6px 10px 8px 40px;
  font-size: 15px;
  color: #333333;
  text-decoration: none;
  border: 1px solid #cfcfcf;
  background: #fbfbfb;
}
.dd3-content:hover {
  color: #2ea8e5;
  background: #ffffff;
}
.dd-dragel > .dd3-item > .dd3-content {
  margin: 0;
}
.dd3-item > button {
  margin-left: 38px;
}
.dd3-handle {
  position: absolute;
  margin: 0;
  left: 0;
  top: 0;
  cursor: move;
  width: 30px;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden;
  border: 1px solid #aaa;
  background: #bfbfbf;
  background: -webkit-linear-gradient(top, #dddddd 0%, #bbbbbb 100%);
  background: -moz-linear-gradient(top, #dddddd 0%, #bbbbbb 100%);
  background: linear-gradient(top, #dddddd 0%, #bbbbbb 100%);
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-size: 18px;
  padding: 8px 15px;
}
.dd3-handle:before {
  content: '\f0c9';
  display: block;
  position: absolute;
  left: 0;
  top: 3px;
  width: 100%;
  text-align: center;
  text-indent: 0;
  color: #818181;
  font-weight: normal;
  line-height: 28px;
}
.dd3-handle:hover:before {
  color: #C27616;
}
.dd-handle:hover + .dd-list .dd-handle,
.dd-handle:hover {
  background: #FDDFB3 !important;
  border: 1px solid #FAA937;
  color: #333 !important;
}
.dd-handle > span {
  font-size: 13px;
  color: #777;
}
.dd-dragel > .dd-item > .dd-handle {
  border-left-width: 4px;
}
.dd-dragel > li.dd-item.dd3-item {
  position: relative;
  top: 10px;
  left: 10px;
  z-index: 999;
}
/*
 * FULL CALENDAR
 */
#calendar-container {
  position: relative;
}
html .fc,
.fc table {
  font-size: 12px;
}
.dt-header.calender-spacer {
  height: 46px;
  display: block;
}
.jarviswidget #calendar {
  margin-top: -18px;
}
.fc-widget-header,
.fc-widget-content {
  border-right: none;
}
tr.fc-first th.fc-first,
tr td.fc-first {
  border-left: none;
}
tr.fc-last td {
  border-bottom: none;
}
.jarviswidget .fc-header-title h2 {
  text-shadow: 0 1px 0 #ffffff;
  margin-top: -12px;
  margin-left: 10px;
  font-size: 14px;
  font-weight: bold;
  margin-bottom: 0px;
}
.fc-event-time,
.fc-event-title {
  padding: 3px 0px 2px 3px;
  display: inline-block;
  line-height: 16px;
  font-weight: bold;
  font-size: 11px;
  box-sizing: border-box;
}
/* calendar button */
#calendar-buttons {
  position: absolute;
  right: 14px;
  top: 5px;
}
/* other month */
td.fc-other-month,
.dropzone {
  background-image: -webkit-gradient(linear, left top, right bottom, color-stop(0.25, rgba(0, 0, 0, 0.03)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(0, 0, 0, 0.03)), color-stop(0.75, rgba(0, 0, 0, 0.03)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -ms-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-image: linear-gradient(135deg, rgba(0, 0, 0, 0.03) 25%, transparent 25%, transparent 50%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.03) 75%, transparent 75%, transparent);
  background-color: #FAFCFD;
  background-size: 16px 16px;
}
.fc-corner-right .fc-event-inner {
  padding-right: 15px;
}
/*
	* Select color
	*/
.btn-select-tick i {
  display: none;
}
.btn-select-tick .btn:hover i {
  opacity: .3;
  display: block;
}
.btn-select-tick .active i {
  display: block;
  opacity: 1 !important;
}
/* 
	* Drag and drop events
	*/
#external-events > li {
  margin: 6px 4px 6px 0;
  display: inline-block;
}
#external-events > li > :first-child {
  padding: 5px 10px 10px;
  cursor: move;
  display: block;
}
#external-events > li > :first-child:after {
  color: #ffffff;
  color: rgba(255, 255, 255, 0.7);
  content: attr(data-description);
  font-size: 11px;
  font-weight: 400;
  display: block;
  line-height: 0;
  margin: 7px 0;
  text-transform: lowercase;
}
/*
 * INBOX
 */
.table-wrap {
  overflow: auto;
}
.inbox-body {
  position: relative;
}
.inbox-body .table-wrap {
  background: #ffffff;
  padding: 10px 14px 7px;
  position: relative;
  margin-left: 200px;
}
.inbox-body.no-content-padding {
  margin-top: 0;
  background: #ffffff;
}
.inbox-nav-bar {
  height: 70px;
  margin-bottom: 0;
  /*border-bottom: 1px solid #CECECE;*/
  padding: 20px 14px;
  background: #ffffff;
}
.inbox-nav-bar .page-title {
  display: inline-block;
  margin: 0;
  width: 196px;
  line-height: 33px;
  vertical-align: middle;
}
.inbox-footer {
  height: 52px;
  padding: 15px 14px 0;
  border-top: 1px solid #CECECE;
  background: #2a2725;
  position: absolute;
  bottom: -53px;
  width: 100%;
}
.inbox-paging {
  margin-left: 10px;
}
.inbox-footer .btn-group {
  margin-left: 10px;
}
#inbox-table {
  font-size: 13px;
  border-top: none;
  border-left-color: transparent !important;
  border-right-color: transparent !important;
}
#inbox-table tbody tr:hover {
  cursor: pointer;
  background: #E4E4E4;
}
#inbox-table tr td {
  border-right: none;
  border-left: none;
  line-height: 26px;
  padding: 6px 4px 7px !important;
}
#inbox-table .inbox-table-icon {
  padding-left: 15px !important;
}
#inbox-table tbody tr th {
  overflow: hidden;
}
#inbox-table.table tbody > tr > td {
  border-color: #fff !important;
}
#inbox-table .radio,
#inbox-table .checkbox {
  margin-top: -1px;
  margin-bottom: 0px;
}
.inbox-table-icon,
.inbox-data-attachment {
  width: 28px;
  text-align: left;
  padding-left: 12px !important;
  padding-right: 0px !important;
}
.inbox-data-from {
  width: 200px;
}
.inbox-data-from > :first-child {
  width: 200px;
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.inbox-data-date {
  width: 80px;
  padding-left: 7px !important;
  padding-right: 0px !important;
}
.inbox-data-message > :first-child {
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 27px;
  color: #8A8A8A;
}
.inbox-data-message > :first-child span {
  color: #111;
}
.inbox-data-message > :first-child span.label {
  color: #ffffff;
}
.inbox-data-message > :first-child > :first-child:after {
  content: " - ";
}
.unread td {
  background: #ffffff;
}
.unread .inbox-data-message > :first-child > :first-child,
.unread .inbox-data-from > :first-child,
.unread .inbox-data-date > :first-child {
  font-weight: bold;
}
tr.highlight td,
tr.unread.highlight td {
  background: #ffffcc !important;
  /*#ffffcc;*/
  color: #333333;
}
.inbox-checkbox-triggered {
  display: inline-block;
}
.inbox-checkbox-triggered > .btn-group {
  margin-right: 10px;
}
.inbox-checkbox-triggered > .btn-group .btn {
  padding-left: 14px;
  padding-right: 14px;
}
.inbox-side-bar {
  height: 100%;
  position: absolute;
  background: #ffffff;
  display: block;
  width: 200px;
  padding: 10px 0 10px 14px;
}
.inbox-side-bar h6 {
  font-weight: normal;
  font-size: 11px;
  display: block;
  padding: 0px 15px;
  text-transform: uppercase;
  color: #838383;
}
.inbox-side-bar h6 a {
  font-size: 14px;
  margin-top: -2px;
}
.inbox-side-bar h6 .tooltip {
  text-transform: none !important;
}
.inbox-side-bar > .btn {
  margin-bottom: 35px;
}
.inbox-side-bar .input-group {
  margin-bottom: 25px;
}
#compose-mail-mini {
  margin-left: 4px;
}
.inbox-space {
  display: block;
  width: 185px;
}
.inbox-space > .progress {
  margin-top: 5px;
}
.inbox-menu-lg {
  list-style: none;
  padding: 0;
  margin: 0 0 20px 0;
}
.inbox-menu-lg li a {
  display: block;
  padding: 6px 15px 7px;
  font-size: 13px;
  color: #333333;
}
.inbox-menu-lg li {
  display: block;
  width: 100%;
}
.inbox-menu-lg li a:hover {
  text-decoration: none;
  background: #f4f4f4;
}
.inbox-menu-lg li.active a {
  font-weight: bold;
  background: #F0F0F0;
  border-bottom: 1px solid #E7E7E7;
  color: #3276b1;
}
.inbox-menu-sm {
  list-style: none;
  padding: 0;
  margin: 0 0 20px 0;
}
.inbox-menu-sm li a {
  display: block;
  padding: 8px 15px 10px;
  font-size: 13px;
  color: #333333;
}
.inbox-menu-sm li {
  display: block;
  width: 100%;
}
.inbox-menu-sm li a:hover {
  text-decoration: none;
  background: #f4f4f4;
}
.inbox-menu-sm li.active a {
  font-weight: bold;
  background: #F0F0F0;
  border-bottom: 1px solid #E7E7E7;
  color: #3276b1;
}
/*
	* Email opened
	*/
.email-open-header {
  margin: -10px 0 0 0;
  font-size: 20px;
  border-bottom: 1px solid #bfbfbf;
  border-top: 1px solid #eeeeee;
  padding: 15px 3px;
}
.email-open-header > span {
  font-size: 10px;
  font-weight: normal;
  padding: 3px 5px;
  letter-spacing: normal;
  text-transform: uppercase;
  vertical-align: middle;
  line-height: 33px;
  background: #ACACAC;
}
.inbox-info-bar {
  padding: 10px 0px;
  border-bottom: 1px solid #bfbfbf;
}
.inbox-info-bar img {
  width: 35px;
  height: auto;
  display: inline-block;
  vertical-align: middle;
  margin-right: 7px;
  margin-left: 2px;
  border-left: 3px solid #ffffff;
}
.inbox-message,
.inbox-download {
  padding: 15px 4px;
  border-bottom: 1px solid #bfbfbf;
}
.inbox-download-list {
  list-style: none;
  margin: 5px 0 0;
  padding: 0;
}
.inbox-download-list li {
  display: inline-block;
  margin: 0 5px 0 0;
  vertical-align: top;
}
.inbox-download-list li > :first-child {
  margin-bottom: 0;
  width: 150px;
  overflow: hidden;
}
.inbox-download-list li > :first-child:hover {
  background: #ffffff;
  border-color: #C0C0C0;
}
.inbox-download-list li > :first-child > :first-child {
  text-align: center;
  display: block;
  color: #D6D6D6;
}
.inbox-download-list li > :first-child > :first-child > .fa {
  font-size: 150px;
}
.inbox-download-list li > :first-child > :first-child > img {
  max-width: 120px;
}
.inbox-compose-footer {
  padding: 10px;
  background: #F5F5F5;
  border-bottom: 1px solid #A9A9A9;
}
/* added space for large width devices */
.inbox-info-bar,
.inbox-message,
.inbox-download,
.inbox-compose-footer {
  margin-right: 240px;
  position: relative;
}
.email-infobox {
  display: block;
  width: 180px;
  border-bottom: 1px solid #bfbfbf;
  padding-bottom: 0px;
  padding-top: 15px;
  position: absolute;
  top: 65px;
  right: 15px;
}
/* compose email */
.inbox-info-bar .form-group {
  margin: 0;
}
.inbox-info-bar .form-group input,
.inbox-info-bar .select2-container-multi .select2-choices {
  border-color: #ffffff !important;
}
.inbox-info-bar .select2-choices > div {
  display: none;
}
.inbox-info-bar .col-md-1,
.inbox-info-bar .col-md-11 {
  padding-left: 0px;
  padding-right: 0px;
}
.fileinput {
  padding-top: 3px;
}
.hidden {
  display: none;
}
.inbox-info-bar em {
  position: absolute;
  top: 6px;
  right: 20px;
  text-align: right;
  font-style: normal;
}
/* email reply text */
.email-reply-text > div {
  border-left: 1px solid #D6D6D6;
  padding-left: 10px;
  margin-left: 50px;
  color: #A9A9A9;
}
.email-reply-text > :first-child {
  padding-left: 45px;
}
@media (max-width: 1280px) {
  .inbox-info-bar,
  .inbox-message,
  .inbox-compose-footer {
    margin-right: 0px;
  }
  .email-infobox {
    display: none;
  }
}
@media (max-width: 1024px) {
  .inbox-side-bar {
    display: none !important;
  }
  .inbox-body .table-wrap {
    margin-left: 0px !important;
  }
  .inbox-info-bar .col-md-1,
  .inbox-info-bar .col-md-11 {
    padding-left: 26px;
    padding-right: 26px;
  }
}
/*
 * PROFILE PAGE
 */
.profile-pic {
  text-align: right;
}
.profile-pic > img {
  border-radius: 0%;
  position: relative;
  border: 5px solid #ffffff;
  top: -30px;
  left: 10px;
  display: inline-block;
  text-align: right;
  z-index: 4;
  max-width: 100px;
  margin-bottom: -30px;
}
.profile-carousel .carousel-inner {
  max-height: 150px;
}
.friends-list li {
  margin-bottom: 10px;
  margin-right: 3px;
  padding: 0;
}
.friends-list img {
  width: 35px;
  border: 1px solid #ffffff;
  outline: 1px solid #bfbfbf;
}
.profile-link-btn {
  color: #999999;
  font-size: 14px;
}
/*
 * Calendar Icon
 */
time.icon {
  font-size: 14px;
  /* change icon size */
  display: block;
  position: relative;
  width: 35px;
  height: 43px;
  background-color: #fff;
  margin: 3px auto;
  border-radius: 7px;
  box-shadow: 0 1px 0 #bdbdbd,0 2px 0 #fff,0 3px 0 #EEE9E9,0 4px 0 #fff,0 5px 0 #FFFFFF,0 0 0 1px #D3D3D3;
  overflow: hidden;
}
time.icon * {
  display: block;
  width: 100%;
  font-size: 10px;
  font-weight: bold;
  font-style: normal;
  text-align: center;
}
time.icon strong {
  position: absolute;
  top: 0;
  padding: 2px 0;
  color: #fff;
  background-color: #3a3633;
  -webkit-box-shadow: 0 2px 0 #3a3633;
  box-shadow: 0 2px 0 #3a3633;
  border-radius: 6px 6px 0 0;
}
time.icon em {
  position: absolute;
  bottom: 3px;
  color: #3276b1;
}
time.icon span {
  width: 100%;
  font-size: 15px;
  letter-spacing: -0.05em;
  padding-top: 21px;
  color: #2f2f2f;
}
/*
 * New users
 */
.user {
  display: block;
  float: left;
  width: 170px;
  margin: 0 15px 15px 0;
  overflow: hidden;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.user img {
  float: left;
  width: 35px;
  margin-right: 5px;
}
.user .email {
  color: #999;
  overflow: hidden;
  -o-text-overflow: ellipsis;
  text-overflow: ellipsis;
  white-space: nowrap;
}
/*
 * SEARCH RESULTS
 */
.search-results {
  padding: 18px 5px;
}
.search-results + .search-results {
  border-top: 1px dashed #E3E3E3;
}
.search-results > :first-child {
  margin-bottom: 4px;
  font-weight: 400;
}
.search-results > :first-child a {
  text-decoration: underline;
}
.search-results .url {
  font-style: normal;
  font-size: 14px;
}
.search-results img {
  display: inline-block;
  margin-top: 4px;
  margin-right: 4px;
  width: 80px;
}
.search-results > div {
  display: inline-block;
  vertical-align: top;
}
.search-results .note {
  margin: 0;
  line-height: normal;
}
.search-results .note a {
  text-decoration: none !important;
  color: #333333;
}
.search-results .note a:hover {
  color: #ed1c24;
}
/*
Version: 3.4.5 Timestamp: Mon Nov  4 08:22:42 PST 2013
*/
.select2-container {
  margin: 0;
  position: relative;
  display: inline-block;
  /* inline-block for ie7 */
  zoom: 1;
  *display: inline;
  vertical-align: middle;
}
.select2-container,
.select2-drop,
.select2-search,
.select2-search input {
  /*
    Force border-box so that % widths fit the parent
    container without overlap because of margin/padding.

    More Info : http://www.quirksmode.org/css/box.html
  */
  -webkit-box-sizing: border-box;
  /* webkit */
  -moz-box-sizing: border-box;
  /* firefox */
  box-sizing: border-box;
  /* css3 */
}
.select2-container .select2-choice {
  display: block;
  height: 32px;
  padding: 0 0 0 8px;
  overflow: hidden;
  position: relative;
  border: 1px solid #ccc;
  white-space: nowrap;
  line-height: 32px;
  color: #444;
  text-decoration: none;
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #fff;
}
.select2-container.select2-drop-above .select2-choice {
  border-bottom-color: #ccc;
}
.select2-container.select2-allowclear .select2-choice .select2-chosen {
  margin-right: 42px;
}
.select2-container .select2-choice > .select2-chosen {
  margin-right: 26px;
  display: block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.select2-container .select2-choice abbr {
  display: none;
  width: 12px;
  height: 12px;
  position: absolute;
  right: 24px;
  top: 8px;
  font-size: 1px;
  text-decoration: none;
  border: 0;
  /*background: url('@{base-url}/select2.png') right top no-repeat;*/
  cursor: pointer;
  outline: 0;
}
.select2-container.select2-allowclear .select2-choice abbr {
  display: inline-block;
}
.select2-container .select2-choice abbr:hover {
  /*background-position: right -11px;*/
  cursor: pointer;
}
.select2-drop-mask {
  border: 0;
  margin: 0;
  padding: 0;
  position: fixed;
  left: 0;
  top: 0;
  min-height: 100%;
  min-width: 100%;
  height: auto;
  width: auto;
  opacity: 0;
  z-index: 9998;
  /* styles required for IE to work */
  background: #fff;
  filter: alpha(opacity=0);
}
.select2-drop {
  margin-top: -1px;
  width: 100%;
  position: absolute;
  z-index: 9999;
  top: 100%;
  background: #fff;
  color: #000;
  border: 1px solid #ccc;
  border-top: 0;
  -webkit-box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
}
.select2-drop-auto-width {
  border-top: 1px solid #ccc;
  width: auto;
}
.select2-drop-auto-width .select2-search {
  padding-top: 4px;
}
.select2-drop.select2-drop-above {
  margin-bottom: 0px;
  border-top: 1px solid #5D98CC;
  border-top-width: 3px;
  border-bottom: 0;
  -webkit-box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
}
.select2-drop-active {
  border: 1px solid #5D98CC;
  border-top: none;
  border-bottom-width: 3px;
}
.select2-drop.select2-drop-above.select2-drop-active {
  border-top-width: 3px;
}
.select2-container .select2-choice .select2-arrow {
  display: inline-block;
  width: 34px;
  height: 100%;
  position: absolute;
  right: 0;
  top: 0;
  border-left: 1px solid #ccc;
  background-clip: padding-box;
  background: #eee;
}
.select2-container .select2-choice .select2-arrow b {
  display: block;
  width: 100%;
  height: 100%;
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  position: relative;
  font-size: 14px;
}
.select2-container .select2-choice .select2-arrow b:before {
  content: "\f107";
  width: 100%;
  height: 100%;
  text-align: center;
  display: block;
}
.select2-search {
  display: inline-block;
  width: 100%;
  min-height: 26px;
  margin: 0;
  padding-left: 4px;
  padding-right: 4px;
  position: relative;
  z-index: 10000;
  white-space: nowrap;
}
.select2-search input {
  width: 100%;
  height: auto !important;
  min-height: 29px;
  padding: 6px 20px 5px 10px;
  margin: 0;
  outline: 0;
  font-family: sans-serif;
  font-size: 1em;
  border: 1px solid #aaa;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: #fff;
  background: -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: -moz-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: linear-gradient(top, #ffffff 85%, #eeeeee 99%);
}
.select2-search:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  position: absolute;
  content: "\f002";
  top: 25%;
  right: 10px;
  color: #686868 !important;
}
.select2-drop.select2-drop-above .select2-search input {
  margin-top: 4px;
}
.select2-drop.select2-drop-above .select2-search:before {
  top: 34%;
}
.select2-search input.select2-active {
  background: #ffffff url('../../img/select2-spinner.gif') no-repeat 100%;
  background: url('../../img/select2-spinner.gif') no-repeat 100%, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: url('../../img/select2-spinner.gif') no-repeat 100%, -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('../../img/select2-spinner.gif') no-repeat 100%, -moz-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('../../img/select2-spinner.gif') no-repeat 100%, linear-gradient(top, #ffffff 85%, #eeeeee 99%);
}
.select2-container-active .select2-choice,
.select2-container-active .select2-choices {
  border: 1px solid #5D98CC;
  outline: none;
}
.select2-dropdown-open .select2-choice {
  border-bottom-color: transparent;
  -webkit-box-shadow: 0 1px 0 #fff inset;
  box-shadow: 0 1px 0 #fff inset;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  background-color: #fff;
}
.select2-dropdown-open.select2-drop-above .select2-choice,
.select2-dropdown-open.select2-drop-above .select2-choices {
  border: 1px solid #5D98CC;
  border-top-color: transparent;
}
.select2-dropdown-open .select2-choice .select2-arrow {
  background: transparent;
  border-left: none;
  filter: none;
}
.select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -18px 1px;
}
/* results */
.select2-results {
  max-height: 200px;
  padding: 0 0 0 4px;
  margin: 4px 4px 4px 0;
  position: relative;
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}
.select2-results ul.select2-result-sub {
  margin: 0;
  padding-left: 0;
}
.select2-results ul.select2-result-sub > li .select2-result-label {
  padding-left: 20px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 40px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 60px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 80px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 100px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 110px;
}
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label {
  padding-left: 120px;
}
.select2-results li {
  list-style: none;
  display: list-item;
  background-image: none;
}
.select2-results li.select2-result-with-children > .select2-result-label {
  font-weight: bold;
}
.select2-results .select2-result-label {
  padding: 3px 7px 4px;
  margin: 0;
  cursor: pointer;
  min-height: 1em;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.select2-results .select2-highlighted {
  background: #3276b1;
  color: #fff;
}
.select2-results li em {
  background: #feffde;
  font-style: normal;
}
.select2-results .select2-highlighted em {
  background: transparent;
}
.select2-results .select2-highlighted ul {
  background: #fff;
  color: #000;
}
.select2-results .select2-no-results,
.select2-results .select2-searching,
.select2-results .select2-selection-limit {
  background: #f4f4f4;
  display: list-item;
  padding: 3px 5px;
}
.select2-no-results {
  padding-left: 20px;
}
.select2-no-results:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f05a";
  margin-right: 5px;
}
/*
disabled look for disabled choices in the results dropdown
*/
.select2-results .select2-disabled.select2-highlighted {
  color: #666;
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
.select2-results .select2-disabled {
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
.select2-results .select2-selected {
  display: none;
}
.select2-more-results.select2-active {
  background: #f4f4f4 url('../../img/select2-spinner.gif') no-repeat 100%;
}
.select2-more-results {
  background: #f4f4f4;
  display: list-item;
}
/* disabled styles */
.select2-container.select2-container-disabled .select2-choice {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container.select2-container-disabled .select2-choice .select2-arrow {
  background-color: #f4f4f4;
  background-image: none;
  border-left: 0;
}
.select2-container.select2-container-disabled .select2-choice abbr {
  display: none;
}
/* multiselect */
.select2-container-multi .select2-choices {
  height: auto !important;
  height: 1%;
  margin: 0;
  padding: 0;
  position: relative;
  border: 1px solid #ccc;
  cursor: text;
  overflow: hidden;
  background-color: #fff;
}
.select2-locked {
  padding: 3px 5px 3px 5px !important;
}
.select2-container-multi .select2-choices {
  min-height: 26px;
}
.select2-container-multi.select2-container-active .select2-choices {
  border: 1px solid #5D98CC;
  outline: none;
}
.select2-container-multi .select2-choices li {
  float: left;
  list-style: none;
}
.select2-container-multi .select2-choices .select2-search-field {
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
.select2-container-multi .select2-choices .select2-search-field input {
  padding: 5px;
  margin: 1px 0;
  font-family: sans-serif;
  font-size: 100%;
  color: #666;
  outline: 0;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: transparent !important;
}
.select2-container-multi .select2-choices .select2-search-field input.select2-active {
  background: #ffffff url('../../img/select2-spinner.gif') no-repeat 100% !important;
}
.select2-default {
  color: #999 !important;
}
.select2-container-multi .select2-choices .select2-search-choice {
  padding: 1px 28px 1px 8px;
  margin: 4px 0 3px 5px;
  position: relative;
  line-height: 18px;
  color: #fff;
  cursor: default;
  border: 1px solid #2a6395;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #3276b1;
}
.select2-container-multi .select2-choices .select2-search-choice .select2-chosen {
  cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice-focus {
  opacity: .8;
}
.select2-search-choice-close {
  display: block;
  min-width: 21px;
  min-height: 20px;
  position: absolute;
  right: 3px;
  top: 3px;
  margin: 0;
  padding: 0;
  font-size: 15px;
  line-height: 12px;
  text-decoration: none!important;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.select2-search-choice-close:before {
  color: #ffffff;
  content: "\f057";
}
.select2-container-multi .select2-search-choice-close {
  display: block;
  top: 0;
  right: 0;
  padding: 3px 4px 3px 6px;
}
.select2-container-multi .select2-search-choice-close:hover {
  background: rgba(0, 0, 0, 0.3);
}
/*
.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close:hover {
  background-position: right -11px;
}
.select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close {
    background-position: right -11px;
}*/
/* disabled styles */
.select2-container-multi.select2-container-disabled .select2-choices {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
  padding: 3px 5px;
  border: 1px solid #4a90cc;
  background-image: none;
  background-color: #86b4dd;
  cursor: not-allowed;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
  display: none;
  background: none;
}
/* end multiselect */
.select2-result-selectable .select2-match,
.select2-result-unselectable .select2-match {
  text-decoration: underline;
}
.select2-offscreen,
.select2-offscreen:focus {
  clip: rect(0 0 0 0) !important;
  width: 1px !important;
  height: 1px !important;
  border: 0 !important;
  margin: 0 !important;
  padding: 0 !important;
  overflow: hidden !important;
  position: absolute !important;
  outline: 0 !important;
  left: 0px !important;
  top: 0px !important;
}
.select2-display-none {
  display: none;
}
.select2-measure-scrollbar {
  position: absolute;
  top: -10000px;
  left: -10000px;
  width: 100px;
  height: 100px;
  overflow: scroll;
}
/*
 * TODO's
 */
.todo-group-title {
  margin: 0;
  line-height: 31px;
  padding: 0 0 0 10px;
  background: #fafafa;
  border-bottom: 1px solid #e7e7e7;
  border-top: 1px solid #f4f4f4;
  color: #999999;
}
.todo {
  margin: 0;
  padding: 0;
  min-height: 5px;
  list-style: none;
}
.todo > li {
  display: block;
  position: relative;
  overflow: hidden;
  border-bottom: 1px solid #e7e7e7;
  margin: 0 5px;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAcAAAAQCAYAAADagWXwAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo0RkQ1OEY4NTM4NUIxMUUzQjdCMUMxQzJCQUE3MTMxOCIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo0RkQ1OEY4NjM4NUIxMUUzQjdCMUMxQzJCQUE3MTMxOCI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjRGRDU4RjgzMzg1QjExRTNCN0IxQzFDMkJBQTcxMzE4IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjRGRDU4Rjg0Mzg1QjExRTNCN0IxQzFDMkJBQTcxMzE4Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+pTD+wgAAACtJREFUeNpimDBhwn8gYABhdDYjiIELMDHgAUwTJ06Ea0VnjxpLO2MBAgwAGYZLegQbQ3UAAAAASUVORK5CYII=) 1px 11px no-repeat;
}
.todo > li:last-child,
.todo > li:only-child {
  border-bottom: none;
}
.todo > li > :first-child {
  display: block;
  border-right: 1px solid #FFE1EB;
  height: 100%;
  padding: 6px 11px 6px 18px;
  width: 20px;
  vertical-align: top;
  position: absolute;
}
.todo > li > :first-child:hover {
  cursor: move;
}
.todo > li.complete > :first-child:hover {
  cursor: default;
}
.todo > li.complete {
  background: none;
}
.todo > li > p {
  height: 100%;
  margin-left: 52px;
  border-left: 1px solid #FFE1EB;
  display: inline-block;
  padding: 8px 0px 6px 7px;
  margin-bottom: 0;
  min-height: 37px;
  line-height: normal;
  font-size: 14px;
  font-weight: 500;
  color: #333333;
}
.todo > li > p > span {
  display: block;
  line-height: 12px;
  font-size: 10px;
  font-weight: normal;
}
.todo > li > p > :first-child {
  margin-top: -5px;
  color: #999999;
  margin-bottom: 4px;
}
.todo > li > p > .date {
  color: #bfbfbf;
}
.todo > li.complete > * {
  text-decoration: line-through;
  font-style: italic;
}
/* drag */
.todo > li.ui-sortable-helper {
  border-top: 1px solid #eeeeee;
  background: rgba(113, 132, 63, 0.1);
}
/*
 * TIMELINE PAGE
 */
/* Timeline */
.smart-timeline {
  position: relative;
}
.smart-timeline-list {
  list-style: none;
  margin: 0;
  padding: 0;
}
.smart-timeline-list:after {
  content: " ";
  background-color: #eeeeee;
  position: absolute;
  display: block;
  width: 2px;
  top: 0;
  left: 95px;
  bottom: 0;
  z-index: 1;
}
.smart-timeline-list li {
  position: relative;
  margin: 0;
  padding: 15px 0;
}
.smart-timeline-list > li:hover {
  background-color: #f4f4f4;
}
.smart-timeline-hover li:hover {
  background-color: #f9f9f9;
}
.smart-timeline-icon {
  background: #3276b1;
  color: #ffffff;
  border-radius: 50%;
  position: absolute;
  width: 32px;
  height: 32px;
  line-height: 28px;
  font-size: 14px;
  text-align: center;
  left: 80px;
  top: 10px;
  z-index: 100;
  padding: 2px;
}
.smart-timeline-icon > img {
  height: 32px;
  width: 32px;
  border-radius: 50%;
  margin-top: -2px;
  margin-left: -2px;
  border: 2px solid #3276b1;
}
.smart-timeline-time {
  float: left;
  width: 70px;
  text-align: right;
}
.smart-timeline-time > small {
  font-style: italic;
}
.smart-timeline-content {
  margin-left: 123px;
}
/*
 * FORUM PAGE
 */
.table-forum thead tr {
  background: none !important;
}
.table-forum thead tr th {
  font-size: 17px;
  font-weight: normal;
  border-bottom-color: #F1F1F1;
}
.table-forum tr td {
  border-top-style: dashed !important;
  padding-top: 12px !important;
  padding-bottom: 12px !important;
}
.table-forum tr td h4 {
  font-size: 15px;
  font-weight: 700;
}
.table-forum tr td h4 small {
  font-size: 13px;
  display: block;
  margin-top: 2px;
}
.table-forum tr td > i {
  margin-top: 4px;
  padding-left: 10px;
}
.table-forum tr.locked h4 > a:before {
  display: inline-block;
  font-family: FontAwesome;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f023";
}
.table-forum tr.closed h4 > a {
  text-decoration: line-through;
  color: #848484;
  cursor: not-allowed;
}
.forum-attachment {
  margin-top: 20px;
  display: block;
}
html {
  margin: 0;
  padding: 0;
  height: 100%;
  overflow-x: hidden !important;
  /*- disabled for widget chrome bug */
  background: url('../../img/mybg.png') #ffffff;
}
body {
  margin: 0;
  padding: 0;
  height: 100%;
  overflow: hidden;
  /*- disabled for widget chrome bug */
  background: url('../../img/mybg.png') #ffffff;
  direction: ltr;
}
a:hover,
a:active,
a:focus,
button,
button:active,
button:focus,
object,
embed,
input::-moz-focus-inner {
  outline: 0;
}
h1,
h2,
h3,
h4 {
  margin: 0;
  font-family: "Open Sans", Arial, Helvetica, Sans-Serif;
  font-weight: 300;
}
.page-title {
  margin: 12px 0 28px;
}
.page-title span {
  font-size: 16px;
  color: #333333;
  display: inline-block;
  vertical-align: 1px;
}
label {
  font-weight: normal;
}
*:focus {
  outline: 0 !important;
}
/*
 * IE FIX for tap delay
 */
a,
input,
button {
  -ms-touch-action: none !important;
}
textarea:focus,
select:focus,
input[type="text"]:focus,
input[type="password"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="time"]:focus,
input[type="week"]:focus,
input[type="number"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
input[type="color"]:focus,
.uneditable-input:focus {
  outline: 0;
  outline: thin dotted \9;
  /* IE6-9 */
  -webkit-box-shadow: none !important;
  -moz-box-shadow: none !important;
  box-shadow: none !important;
}
.input-sm,
.input-lg,
.input-xs,
.form-control {
  border-radius: 0px !important;
  -webkit-border-radius: 0px !important;
  -moz-border-radius: 0px !important;
}
.input-xs {
  height: 24px;
  padding: 2px 10px;
  font-size: 11px;
  line-height: 1.5;
}
.btn-xs {
  padding: 1px 5px;
}
.btn-sm {
  padding: 6px 10px 5px;
}
.btn-lg {
  padding: 10px 16px;
}
.no-space {
  margin: 0;
}
.no-space > [class*="col-"] {
  margin: 0 !important;
  padding-right: 0;
  padding-left: 0;
}
#content {
  padding: 10px 14px;
  position: relative;
  left: 0px;
}
body.container {
  position: relative;
  padding: 0;
  border-left: 1px solid #bfbfbf;
  border-right: 1px solid #bfbfbf;
  box-shadow: 0 2px 70px rgba(0, 0, 0, 0.45);
}
.no-content-padding {
  margin: -10px -14px 0 -14px;
  /*used with content >:first-child */
}
.no-padding {
  padding: 0px !important;
}
.no-padding > pre {
  margin: 30px;
}
.no-padding  > table,
.no-padding .dataTables_wrapper table {
  border: none !important;
  margin-bottom: 0px !important;
  border-bottom-width: 0px !important;
}
.no-padding-bottom {
  padding-bottom: 0px !important;
}
.padding-5 {
  padding: 5px !important;
}
.padding-7 {
  padding: 7px !important;
}
.padding-10 {
  padding: 10px !important;
}
.padding-top-10 {
  padding-top: 10px !important;
}
.padding-bottom-10 {
  padding-bottom: 10px !important;
}
.no-padding  > table tr td:last-child,
.no-padding  > table tr th:last-child,
.no-padding .dataTables_wrapper table tr td:last-child,
.no-padding .dataTables_wrapper table tr th:last-child {
  border-right: none !important;
}
.no-padding  > table tr td:first-child,
.no-padding  > table tr th:first-child,
.no-padding .dataTables_wrapper table tr td:first-child,
.no-padding .dataTables_wrapper table tr th:first-child {
  border-left: none !important;
}
.no-padding .dataTables_wrapper table tbody tr:last-child td {
  border-bottom: 0;
}
/*
 * Headers
 */
h1 {
  letter-spacing: -1px;
  font-size: 24px;
  margin: 10px 0;
}
h1 small {
  font-size: 18px;
  font-weight: 300;
  letter-spacing: -1px;
}
.lead {
  font-size: 19px;
}
h2 {
  letter-spacing: -1px;
  font-size: 22px;
  margin: 20px 0;
  line-height: normal;
}
h3 {
  display: block;
  font-size: 19px;
  font-weight: 400;
  margin: 20px 0;
  line-height: normal;
}
h4 {
  line-height: normal;
}
h5 {
  font-size: 17px;
  font-weight: 300;
  margin: 10px 0;
  line-height: normal;
}
h6 {
  font-size: 15px;
  margin: 10px 0;
  font-weight: bold;
  line-height: normal;
}
.row-seperator-header {
  margin: 15px 14px 20px;
  border-bottom: none;
  display: block;
  color: #646464;
  font-size: 20px;
  font-weight: 400;
}
/*
 * Forced text alignments
 */
.text-align-center,
.text-center {
  text-align: center !important;
}
.text-align-left,
.text-left {
  text-align: left !important;
}
.text-align-right,
.text-right {
  text-align: right !important;
}
/*
 * Font Weights
 */
.semi-bold {
  font-weight: 400 !important;
}
.ultra-light {
  font-weight: 300 !important;
}
/*
 * Font Sizes
 */
.font-xs {
  font-size: 85% !important;
}
.font-sm {
  font-size: 95% !important;
}
.font-md {
  font-size: 130% !important;
}
.font-lg {
  font-size: 160% !important;
}
.font-xl {
  font-size: 200% !important;
}
.font-400 {
  font-size: 400% !important;
}
/*
 * Center Canvas
 */
.center-canvas,
.center-child-canvas > canvas {
  display: block !important;
  margin: 0 auto !important;
}
/*
 * Margins
 */
.no-margin {
  margin: 0px !important;
}
.margin-top-5 {
  margin-top: 5px !important;
}
.margin-top-10 {
  margin-top: 10px !important;
}
.margin-bottom-5 {
  margin-bottom: 5px !important;
}
.margin-bottom-10 {
  margin-bottom: 10px !important;
}
.margin-right-5 {
  margin-right: 5px !important;
}
/*
 * No border
 */
.no-border,
.well[class*=" bg-"].no-border {
  border-width: 0px !important;
}
.no-border-transparent {
  border-color: transparent !important;
}
.no-border-radius {
  border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-border-radius: 0px;
}
/*
 * Inlines
 */
.display-inline {
  display: inline-block !important;
}
.display-normal {
  display: inline !important;
}
/*
 * Images
 */
.hover-transparent {
  opacity: .5;
}
.hover-transparent:hover {
  opacity: 1;
}
/*
 * JUST A BORDER 
 */
.bordered {
  border: 1px solid rgba(0, 0, 0, 0.2);
}
.bordered:hover {
  border: 1px solid rgba(0, 0, 0, 0.4);
}
/*
 * CURSORS
 */
.cursor-pointer {
  cursor: pointer;
}
/*
 * ***************************************************
 * MAIN LAYOUT START
 * ***************************************************
 */
aside {
  display: block;
  overflow: hidden;
  background: #3a3633;
  background: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIxMDAlIiB5Mj0iMCUiPgogICAgPHN0b3Agb2Zmc2V0PSI5NyUiIHN0b3AtY29sb3I9IiMzYTM2MzMiIHN0b3Atb3BhY2l0eT0iMSIvPgogICAgPHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjMmEyNzI1IiBzdG9wLW9wYWNpdHk9IjEiLz4KICA8L2xpbmVhckdyYWRpZW50PgogIDxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxIiBoZWlnaHQ9IjEiIGZpbGw9InVybCgjZ3JhZC11Y2dnLWdlbmVyYXRlZCkiIC8+Cjwvc3ZnPg==");
  background: -moz-linear-gradient(left, #3a3633 93%, #2a2725 100%);
  background: -webkit-gradient(linear, left top, right top, color-stop(93%, #3a3633), color-stop(100%, #2a2725));
  background: -webkit-linear-gradient(left, #3a3633 93%, #2a2725 100%);
  background: -o-linear-gradient(left, #3a3633 93%, #2a2725 100%);
  background: -ms-linear-gradient(left, #3a3633 93%, #2a2725 100%);
  background: linear-gradient(to right, #3a3633 93%, #2a2725 100%);
  min-height: 100%;
}
/*
 * HEADER GROUP
 */
#header {
  display: block;
  height: 49px;
  position: relative;
  margin: 0;
  padding: 0 13px 0 0;
  background-color: #f3f3f3;
  background-image: -moz-linear-gradient(top, #f3f3f3, #e2e2e2);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f3f3f3), to(#e2e2e2));
  background-image: -webkit-linear-gradient(top, #f3f3f3, #e2e2e2);
  background-image: -o-linear-gradient(top, #f3f3f3, #e2e2e2);
  background-image: linear-gradient(to bottom, #f3f3f3, #e2e2e2);
  background-repeat: repeat-x;
}
#header > div {
  display: inline-block;
  vertical-align: middle;
  height: 49px;
  float: left;
}
#header > div.open {
  font-weight: bold;
}
.fixed-header #header {
  position: fixed;
  width: 100%;
  z-index: 1003;
  top: 0px;
  border-bottom: 2px solid #999999;
  border-bottom: 1px solid rgba(0, 0, 0, 0.3);
  box-shadow: -11px 12px 23px rgba(0, 0, 0, 0.1);
}
/* as per version 1.3 */
.fixed-header.fixed-ribbon #header {
  border-bottom: none;
  box-shadow: none;
}
.container.fixed-header #header {
  max-width: 1164px;
}
.fixed-header #header .ajax-dropdown {
  z-index: 1004;
}
.fixed-header #shortcut {
  position: fixed;
}
.fixed-header #main {
  margin-top: 49px;
}
#logo-group > span {
  display: inline-block;
  height: 39px;
  float: left;
}
#logo-group span#activity {
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  border-radius: 2px;
  cursor: default !important;
  display: inline-block;
  font-weight: bold;
  height: 24px;
  width: 24px;
  padding: 2px;
  text-align: center;
  text-decoration: none !important;
  -moz-user-select: none;
  -webkit-user-select: none;
  background-color: #f8f8f8;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
  border: 1px solid #bfbfbf;
  color: #c4bab6;
  font-size: 19px;
  margin: 10px 0 0 0;
  position: relative;
}
#logo-group span#activity:hover {
  border: 1px solid #bfbfbf;
  transition: all 0.0s;
  cursor: pointer !important;
  -webkit-box-shadow: inset 0px 0px 4px 1px rgba(0, 0, 0, 0.08);
  box-shadow: inset 0px 0px 4px 1px rgba(0, 0, 0, 0.08);
}
#logo {
  display: inline-block;
  width: 175px;
  margin-top: 13px;
  margin-left: 9px;
}
#logo img {
  width: 110px;
  height: auto;
  padding-left: 3px;
}
#logo-group > span .badge {
  position: absolute;
  top: -5px;
  right: -5px;
  cursor: pointer;
  background: #0091d9;
  display: inline-block;
  font-size: 10px;
  box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  color: #ffffff;
  font-weight: bold;
  border-radius: 50%;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
  padding: 2px 4px 3px 4px;
  text-align: center;
  line-height: normal;
}
#activity.active .badge {
  background: #006fa6 !important;
}
#project-context {
  display: inline-block;
  padding: 7px 13px 0;
  position: relative;
}
#project-context > span {
  display: block;
}
#project-context > :first-child {
  display: block;
  color: #bfbfbf;
  font-size: 10px;
  font-weight: bold;
  text-transform: uppercase;
  text-shadow: 0 0 1px white;
  padding-left: 0px;
  text-align: left;
}
#project-selector {
  max-width: 97%;
  white-space: nowrap;
  background: none;
  border: none;
  padding: 0;
  text-align: left;
  color: #555555;
  font-size: 14px;
  cursor: pointer;
}
#project-selector:hover {
  color: #333333;
}
.header-search {
  position: relative;
}
.header-search.pull-right {
  margin-left: 6px;
}
.header-search > input[type="text"] {
  display: block;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  min-width: 200px;
  width: 100%;
  height: 30px;
  padding: 0 10px;
  outline: none;
  border-width: 1px;
  border-style: solid;
  border-radius: 0;
  border-color: #bfbfbf;
  background: #ffffff;
  color: #404040;
  appearance: normal;
  -moz-appearance: none;
  -webkit-appearance: none;
  margin-top: 10px;
  line-height: normal;
}
.header-search > button {
  background: none;
  border: none;
  color: #6D6A69;
  font-size: 17px;
  height: 30px;
  line-height: 30px;
  margin: 0;
  padding: 0;
  position: absolute;
  right: 0px;
  top: 10px;
  width: 30px;
  z-index: 2;
}
#search-mobile {
  display: none;
}
#cancel-search-js {
  position: absolute;
  display: none;
  background: #a90329;
  z-index: 3;
  color: #ffffff;
  padding: 0;
  right: 10px;
  top: 10px;
  text-align: center;
  height: 29px;
  line-height: 29px;
  width: 30px;
  font-size: 17px;
  text-decoration: none !important;
}
#header > :first-child,
aside {
  width: 220px;
}
/*
 * LEFT PANEL
 */
#left-panel {
  position: absolute;
  top: 49px;
  left: 0px;
  z-index: 1002;
}
#main {
  display: block;
  margin-left: 220px;
  padding: 0;
  min-height: 500px;
}
/*
 * RIBBON
 */
#ribbon {
  min-height: 40px;
  background: #474544;
  padding: 0 13px;
  position: relative;
}
#ribbon .breadcrumb {
  display: inline-block;
  margin: 0;
  padding: 11px 34px 11px 0 !important;
  background: none;
  vertical-align: top;
}
#ribbon .breadcrumb a,
#ribbon .breadcrumb {
  color: #BBB !important;
  text-decoration: none !Important;
}
#ribbon .breadcrumb > .active,
#ribbon .breadcrumb li:last-child {
  color: #E4E4E4;
}
.fixed-ribbon #ribbon {
  position: fixed;
  right: 0;
  left: 220px;
  top: 49px;
  z-index: 999;
}
.container.fixed-ribbon #ribbon {
  width: 944px;
  left: 590px;
}
.fixed-ribbon #content {
  padding-top: 50px;
}
.minified.fixed-ribbon #ribbon {
  left: 45px;
}
.hidden-menu.fixed-ribbon #ribbon {
  left: 10px;
}
/*
 * NAV
 * Menu CSS is learnt from: http://experiments.wemakesites.net/css3-treeview.html
 */
.fixed-navigation #left-panel {
  position: fixed;
  z-index: 998;
}
/* All levels */
nav ul li a:active {
  background: #616161 !important;
}
/* All levels */
nav ul {
  width: 100%;
  padding: 40px 28px 25px 0;
  padding: 0;
  margin: 0;
  font-size: 13px;
  line-height: 0.5em;
  list-style: none;
  position: relative;
}
/* All levels */
nav ul .active > a {
  color: #fff !important;
  position: relative;
}
/* All levels */
nav ul li.active > a:before {
  content: "\f0d9";
  font-family: FontAwesome;
  display: block;
  height: 27px;
  line-height: normal;
  width: 27px;
  position: absolute;
  right: -21px;
  font-size: 20px;
  color: #eeeeee;
}
nav ul li.active.open > a:before {
  content: "";
}
nav > ul > li:last-child.open {
  border-bottom: 1px solid rgba(255, 255, 255, 0.15);
}
/* All levels */
nav ul li {
  overflow: hidden;
}
/* All levels */
nav ul li a {
  line-height: normal;
  font-size: 14px;
  padding: 10px 10px 10px 11px;
  color: #a8a8a8;
  display: block;
  font-weight: normal;
  text-decoration: none !important;
  position: relative;
}
/* Second level */
nav > ul > li > ul > li > a {
  padding-top: 7px;
  padding-bottom: 7px;
}
/* Third Level */
nav > ul > li > ul > li > ul > li > a {
  padding-top: 7px;
  padding-bottom: 7px;
}
/* All levels */
nav ul li a:focus {
  color: #c9c9c9;
}
/* All levels */
nav ul li a:hover {
  color: #ffffff;
  text-decoration: none;
}
/* All levels */
nav ul b {
  float: right;
  font-size: 14px;
  margin-top: -1px;
}
/* All levels */
nav ul span.menu-item-parent {
  display: inline-block;
  margin: 0;
  padding: 0;
}
/* First level: A, Second level: LI Open */
nav ul li.open > a,
nav ul li.open > a b {
  color: #fff !important;
}
/* First level: Icon */
nav > ul > li > a b {
  position: absolute !important;
  right: 10px;
  top: 10px;
}
nav > ul > li > a > i {
  /*font-size: 121%; fa-lg overrides this so..  */
  margin-right: 5px;
  width: 15px;
  display: inline-block;
  text-align: center;
  position: relative;
}
/* First level icon */
nav > ul > li > a > i > em {
  font-size: 9px;
  display: block;
  padding: 2px;
  position: absolute;
  top: -8px;
  right: -6px;
  text-decoration: none;
  font-style: normal;
  background: #ED1C24;
  color: #ffffff;
  min-width: 13px;
  border-radius: 50%;
  max-height: 13px;
  line-height: 8px;
  font-weight: bold;
  vertical-align: baseline;
  white-space: nowrap;
  text-align: center;
  border: 1px solid rgba(255, 255, 255, 0.1);
}
/* Second level switched to relative */
nav ul li li {
  border-bottom: none;
  position: relative;
}
/* Second level: UL */
nav > ul > li > ul::before {
  content: "";
  display: block;
  position: absolute;
  z-index: 1;
  left: 23px;
  top: 0;
  bottom: 0;
  border-left: 1px solid #7A7A7A;
}
/* Second level: UL LI */
nav > ul ul li::before {
  content: "";
  display: block;
  position: absolute;
  width: 8px;
  left: 23px;
  top: 16px;
  border-top: 1px solid #7A7A7A;
  z-index: 1;
}
/* Third level: UL LI */
nav > ul ul ul li::before {
  content: "";
  display: block;
  position: absolute;
  width: 18px;
  left: 10px;
  top: 17px;
  border-top: 1px solid transparent;
}
/* Second level and onwards > */
nav > ul ul li a i {
  font-size: 14px !important;
  width: 18px !important;
  text-align: center !important;
}
/* Second and Third level line color */
nav > ul > li:hover > ul::before,
nav > ul > li:hover > ul > li::before {
  border-color: #ACACAC !important;
}
/* Second Level: UL */
nav ul ul {
  margin: 0;
  padding: 0;
  display: none;
  background: rgba(69, 69, 69, 0.6);
}
nav ul ul {
  padding: 7px 0;
}
/* Third Level: UL */
nav ul ul ul {
  background: transparent;
  padding: 0;
}
/* Third Level: LI */
nav ul ul li {
  margin: 0;
  padding: 0;
}
/* Second Level: A */
nav ul ul li > a {
  padding-left: 42px;
  font-size: 14px;
  font-weight: normal;
  outline: 0;
}
/* Second Level: A:hover */
nav ul ul li > a:hover {
  background-color: rgba(69, 69, 69, 0.8);
  color: #ffffff;
}
/* Third Level: A */
nav ul ul ul li a {
  color: #bfbfbf;
  padding: 8px 10px 8px 70px;
  font-size: 14px;
}
/* Third Level: A:hover */
nav ul ul ul li a:hover {
  background-color: #4C4F53;
  color: #ffffff;
}
/* Fourth Level: A */
nav ul ul ul ul li a {
  padding-left: 90px;
}
/* Fifth Level: A */
nav ul ul ul ul ul li a {
  padding-left: 110px;
}
/* Sixth Level: A */
nav ul ul ul ul ul ul li a {
  padding-left: 130px;
}
/* Second level: B */
nav ul ul b {
  color: #B3B3B3;
}
/* Second level: LI:hover B */
nav ul ul > li:hover b {
  color: #D5D9E2;
}
/*
 * HEADER NAV DROPDOWN LIST
 */
.header-dropdown-list {
  list-style: none;
  float: right;
  position: relative;
  margin: 0;
}
.header-dropdown-list > li {
  display: inline-block;
  padding-right: 5px;
}
.header-dropdown-list > li > .dropdown-toggle {
  margin-top: 16px;
  display: inline;
  line-height: 30px;
}
/*
 * ***************************************************
 * MAIN LAYOUT END
 * ***************************************************
 */
/*
 * ACCORDIONS
 */
.smart-accordion-default.panel-group {
  margin-bottom: 0px;
}
.smart-accordion-default.panel-group .panel + .panel {
  margin-top: -1px;
}
.smart-accordion-default.panel-group .panel-heading {
  padding: 0px;
}
.smart-accordion-default.panel-group .panel-title a {
  display: block;
  padding: 10px 15px;
  text-decoration: none !important;
}
.smart-accordion-default .panel-heading,
.panel-group .panel {
  border-radius: 0px;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
}
.smart-accordion-default .panel-default > .panel-heading {
  background-color: #fcfcfc;
}
.smart-accordion-default .panel-default {
  border-color: #c3c3c3;
}
.smart-accordion-default .panel-title > a > :first-child {
  display: none;
}
.smart-accordion-default .panel-title > a.collapsed > .fa {
  display: none;
}
.smart-accordion-default .panel-title > a.collapsed > :first-child {
  display: inline-block;
}
.no-padding .smart-accordion-default > div {
  border-left: none !important;
  border-right: none !important;
}
.no-padding .smart-accordion-default > div:first-child {
  border-top: none !important;
}
.no-padding .smart-accordion-default > div:last-child {
  border-bottom: none !important;
}
/*
 * ON OFF SWITCHES
 */
/* http://proto.io/freebies/onoff/ */
.onoffswitch-container {
  margin-top: 4px;
  margin-left: 7px;
  display: inline-block;
}
.onoffswitch {
  position: relative;
  width: 50px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  margin-top: 3px;
  margin-bottom: 3px;
  margin-left: 5px;
  display: inline-block;
  vertical-align: middle;
}
.onoffswitch-checkbox {
  display: none;
}
.onoffswitch-label {
  display: block;
  overflow: hidden;
  cursor: pointer;
  border: 1px solid #626262;
  border-radius: 50px;
  border-color: #adadad #b3b3b3 #9e9e9e;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.onoffswitch-inner {
  width: 200%;
  margin-left: -100%;
  display: block;
}
.onoffswitch-inner:before,
.onoffswitch-inner:after {
  float: left;
  width: 50%;
  height: 15px;
  padding: 0;
  line-height: 15px;
  font-size: 10px;
  color: #ffffff;
  font-family: Trebuchet, Arial, sans-serif;
  font-weight: bold;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.onoffswitch-inner:before {
  content: attr(data-swchon-text);
  text-shadow: 0 -1px 0 #333333;
  padding-left: 7px;
  background-color: #3276b1;
  color: #ffffff;
  box-shadow: inset 0 2px 6px rgba(0, 0, 0, 0.5), 0 1px 2px rgba(0, 0, 0, 0.05);
  text-align: left;
}
.onoffswitch-inner:after {
  content: attr(data-swchoff-text);
  padding-right: 7px;
  text-shadow: 0 -1px 0 #ffffff;
  background-color: #ffffff;
  color: #555555;
  text-align: right;
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.onoffswitch-switch {
  width: 19px;
  height: 19px;
  margin: -2px;
  background: white;
  border: 1px solid #9a9a9a;
  border-radius: 50px;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 32px;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  background-color: #f4f4f4;
  background-image: -moz-linear-gradient(top, #ffffff, #eeeeee);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#eeeeee));
  background-image: -webkit-linear-gradient(top, #ffffff, #eeeeee);
  background-image: -o-linear-gradient(top, #ffffff, #eeeeee);
  background-image: linear-gradient(to bottom, #ffffff, #eeeeee);
  background-repeat: repeat-x;
  -webkit-box-shadow: 1px 1px 4px 0px rgba(0, 0, 0, 0.3);
  box-shadow: 1px 1px 4px 0px rgba(0, 0, 0, 0.3);
}
.onoffswitch-checkbox + .onoffswitch-label .onoffswitch-switch:before,
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch:before {
  content: "\f00d";
  color: #a90329;
  display: block;
  text-align: center;
  line-height: 19px;
  font-size: 10px;
  text-shadow: 0 -1px 0 #ffffff;
  font-weight: bold;
  font-family: FontAwesome;
}
/* checked */
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch:before {
  content: "\f00c";
  color: #57889c;
}
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-inner {
  margin-left: 0;
  display: block;
}
.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch {
  right: 0px;
}
.onoffswitch-switch:hover {
  background-color: #eeeeee;
}
.onoffswitch-switch:active {
  background-color: #eeeeee;
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
}
/*
 * Disabled state
 */
.onoffswitch-checkbox:disabled + .onoffswitch-label .onoffswitch-inner:after,
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-inner:before {
  text-shadow: 0 1px 0 #ffffff;
  background: #bfbfbf;
  color: #333333;
}
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-switch,
.onoffswitch-checkbox:disabled + .onoffswitch-label .onoffswitch-switch {
  background-color: #f4f4f4;
  background-image: -moz-linear-gradient(top, #bfbfbf, #f4f4f4);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#bfbfbf), to(#f4f4f4));
  background-image: -webkit-linear-gradient(top, #bfbfbf, #f4f4f4);
  background-image: -o-linear-gradient(top, #bfbfbf, #f4f4f4);
  background-image: linear-gradient(to bottom, #bfbfbf, #f4f4f4);
  box-shadow: none !important;
}
.onoffswitch-checkbox:disabled + .onoffswitch-label,
.onoffswitch-checkbox:checked:disabled + .onoffswitch-label .onoffswitch-label {
  border-color: #ababab #999999 #878787 !important;
}
.onoffswitch-checkbox:checked + .onoffswitch-label {
  border-color: #3276b1 #2a6395 #255681;
}
.onoffswitch + span,
.onoffswitch-title {
  display: inline-block;
  vertical-align: middle;
  margin-top: -5px;
}
/*
 * FORMS
 */
.form-control {
  box-shadow: none !important;
  -webkit-box-shadow: none !important;
  -moz-box-shadow: none !important;
}
.form hr {
  margin-left: -13px;
  margin-right: -13px;
  border-color: rgba(0, 0, 0, 0.1);
  margin-top: 20px;
  margin-bottom: 20px;
}
.form fieldset {
  display: block;
  border: none;
  background: rgba(255, 255, 255, 0.9);
  position: relative;
}
fieldset {
  position: relative;
}
.form-actions {
  display: block;
  padding: 13px 14px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(249, 249, 249, 0.9);
  margin-top: 25px;
  margin-left: -13px;
  margin-right: -13px;
  margin-bottom: -13px;
  text-align: right;
}
.well .form-actions {
  margin-left: -19px;
  margin-right: -19px;
  margin-bottom: -19px;
}
.well.well-lg .form-actions {
  margin-left: -24px;
  margin-right: -24px;
  margin-bottom: -24px;
}
.well.well-sm .form-actions {
  margin-left: -9px;
  margin-right: -9px;
  margin-bottom: -9px;
}
.popover-content .form-actions {
  margin: 0 -14px -9px;
  border-radius: 0 0 3px 3px;
  padding: 9px 14px;
}
.no-padding .form .form-actions {
  margin: 0;
  display: block;
  padding: 13px 14px 15px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
  text-align: right;
  margin-top: 25px;
}
.form header,
legend {
  display: block;
  padding: 8px 0;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.2);
  background: #ffffff;
  font-size: 16px;
  font-weight: 300;
  color: #222222;
  margin: 25px 0px 20px;
}
.no-padding .form header {
  margin: 25px 14px 0;
}
.form header:first-child {
  margin-top: 10px;
}
legend {
  font-weight: 400;
  margin-top: 0px;
  background: none;
}
.input-group-addon {
  padding: 6px 10px;
  border-radius: 0;
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
}
.input-group-addon {
  transition: border-color 0.3s;
  -o-transition: border-color 0.3s;
  -ms-transition: border-color 0.3s;
  -moz-transition: border-color 0.3s;
  -webkit-transition: border-color 0.3s;
  transition: background-color 0.3s;
  -o-transition: background-color 0.3s;
  -ms-transition: background-color 0.3s;
  -moz-transition: background-color 0.3s;
  -webkit-transition: background-color 0.3s;
}
.input-group-addon .fa {
  font-size: 14px;
}
.input-group-addon .fa-lg,
.input-group-addon .fa-2x {
  font-size: 2em;
}
.input-group-addon .fa-3x,
.input-group-addon .fa-4x,
.input-group-addon .fa-5x {
  font-size: 30px;
}
input[type="text"]:focus + .input-group-addon {
  border-color: #0091d9;
  background-color: #72a0ce;
  color: #ffffff;
}
.has-warning input[type="text"],
.has-warning input[type="text"] + .input-group-addon {
  border-color: #dbab57;
}
.has-warning input[type="text"] + .input-group-addon {
  background-color: #faf2cc;
  color: #c09853;
}
.has-warning input[type="text"]:focus,
.has-warning input[type="text"]:focus + .input-group-addon {
  border-color: #dbab57;
}
.has-warning input[type="text"]:focus + .input-group-addon {
  background-color: #e1c118;
  color: #ffffff;
}
.has-error .input-group-addon {
  border-color: #b94a48;
  background: #f2dede;
  color: #b94a48;
}
.has-error input[type="text"],
.has-error input[type="text"] + .input-group-addon {
  border-color: #b94a48;
}
.has-error input[type="text"] + .input-group-addon {
  background-color: #f2dede;
  color: #b94a48;
}
.has-error input[type="text"]:focus,
.has-error input[type="text"]:focus + .input-group-addon {
  border-color: #c05e5e;
}
.has-error input[type="text"]:focus + .input-group-addon {
  background-color: #c05e5e;
  color: #ffffff;
}
.has-success input[type="text"]:focus + .input-group-addon {
  border-color: #468847;
  background-color: #468847;
  color: #ffffff;
}
.form fieldset .form-group:last-child,
.form fieldset .form-group:last-child .note,
.form .form-group:last-child,
.form .form-group:last-child .note {
  margin-bottom: 0;
}
.note {
  margin-top: 6px;
  padding: 0 1px;
  font-size: 11px;
  line-height: 15px;
  color: #999999;
}
/*
	 * WITH ICON
	 */
.input-icon-right {
  position: relative;
}
.input-icon-right > i,
.input-icon-left > i {
  position: absolute;
  right: 10px;
  top: 30%;
  font-size: 16px;
  color: #bfbfbf;
}
.input-icon-left > i {
  right: auto;
  left: 24px;
}
.input-icon-right .form-control {
  padding-right: 27px;
}
.input-icon-left .form-control {
  padding-left: 29px;
}
input[type="text"].ui-autocomplete-loading,
input[type="password"].ui-autocomplete-loading,
input[type="datetime"].ui-autocomplete-loading,
input[type="datetime-local"].ui-autocomplete-loading,
input[type="date"].ui-autocomplete-loading,
input[type="month"].ui-autocomplete-loading,
input[type="time"].ui-autocomplete-loading,
input[type="week"].ui-autocomplete-loading,
input[type="number"].ui-autocomplete-loading,
input[type="email"].ui-autocomplete-loading,
input[type="url"].ui-autocomplete-loading,
input[type="search"].ui-autocomplete-loading,
input[type="tel"].ui-autocomplete-loading,
input[type="color"].ui-autocomplete-loading {
  background-image: url("../../img/select2-spinner.gif") !important;
  background-repeat: no-repeat;
  background-position: 99% 50%;
  padding-right: 27px;
}
.input-group-addon .checkbox,
.input-group-addon .radio {
  min-height: 0px;
  margin-right: 0px !important;
  padding-top: 0;
}
.input-group-addon label input[type="checkbox"].checkbox + span,
.input-group-addon label input[type="radio"].radiobox + span,
.input-group-addon label input[type="radio"].radiobox + span:before,
.input-group-addon label input[type="checkbox"].checkbox + span:before {
  margin-right: 0px;
}
.input-group-addon .onoffswitch,
.input-group-addon .onoffswitch-label {
  margin: 0;
}
/*
 * HR
 */
hr.simple {
  margin-top: 10px;
  margin-bottom: 10px;
  border-style: dashed;
}
/*
 * Timeline Seperator
 */
.timeline-seperator {
  display: block;
  text-align: center;
  color: #999999;
  margin: 20px 0 0;
}
.timeline-seperator > :first-child {
  padding: 4px 5px;
  border: 1px dashed rgba(0, 0, 0, 0.1);
  background: #ffffff;
  font-size: 11px;
  border-radius: 4px;
}
.timeline-seperator .btn,
.timeline-seperator .btn + .dropdown-menu {
  margin-right: 15px;
}
.timeline-seperator:after {
  display: block;
  content: " ";
  margin: 0 20px;
  border-bottom: 1px dashed rgba(0, 0, 0, 0.1);
  margin-top: -8px;
}
/*
 * Alerts
 */
.alert {
  margin-bottom: 20px;
  margin-top: 0px;
  padding: 5px 15px 5px 34px;
  color: #675100;
  border-width: 0px;
  border-left-width: 5px;
  padding: 10px;
  border-radius: 0px;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
}
.alert .close {
  top: 0px;
  right: -5px;
  line-height: 20px;
}
.alert-heading {
  font-weight: 600;
}
.alert-danger {
  border-color: #953b39;
  color: #ffffff;
  background: #c26565;
  text-shadow: none;
}
.alert-warning {
  border-color: #dfb56c;
  color: #826430;
  background: #efe1b3;
}
.alert-success {
  border-color: #8ac38b;
  color: #356635;
  background: #cde0c4;
}
.alert-info {
  border-color: #9cb4c5;
  color: #305d8c;
  background: #d6dde7;
}
/*
 * WELLS
 */
.well {
  background: #fbfbfb;
  border: 1px solid #dddddd;
  box-shadow: 0 1px 1px #ececec;
  -webkit-box-shadow: 0 1px 1px #ececec;
  -moz-box-shadow: 0 1px 1px #ececec;
  position: relative;
}
.well.well-clean {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  border-color: transparent;
}
.well.well-glass {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  border-color: transparent;
  background-color: rgba(255, 255, 255, 0.25);
  color: #ffffff;
}
.well.well-light {
  background: #ffffff;
  border: 1px solid #e2e2e2;
}
.widget-body .well {
  margin-bottom: 0px;
}
.well.transparent {
  border: none !important;
  background: none !important;
}
.jarviswidget.well.transparent > div,
.jarviswidget.well.transparent > div .widget-body {
  padding: 0px !important;
}
/* any wells with custom bg the border will be darkened */
.well[class^="bg-"],
.well[class*=" bg-"] {
  border: 1px solid #555555 !important;
}
/*
 * PROGRESS BARS
 */
.progress-micro {
  height: 3px !important;
  line-height: 3px !important;
}
.progress-xs {
  height: 7px !important;
  line-height: 7px !important;
}
.progress-sm {
  height: 14px !important;
  line-height: 14px !important;
}
.progress-lg {
  height: 30px !important;
  line-height: 30px !important;
}
.progress .progress-bar {
  position: absolute;
  overflow: hidden;
  line-height: 20px;
}
.progress .progressbar-back-text {
  position: absolute;
  width: 100%;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  text-align: center;
}
.progress .progressbar-front-text {
  display: block;
  width: 100%;
  font-size: 12px;
  line-height: 20px;
  text-align: center;
}
.progress.right .progress-bar {
  right: 0;
}
.progress.right .progressbar-front-text {
  position: absolute;
  right: 0;
}
.progress.vertical {
  width: 25px;
  height: 100%;
  min-height: 150px;
  margin-right: 20px;
  display: inline-block;
  margin-bottom: 0px;
}
.progress.wide-bar {
  width: 40px;
}
.progress.vertical.bottom {
  position: relative;
}
.progress.vertical.bottom .progressbar-front-text {
  position: absolute;
  bottom: 0;
}
.progress.vertical .progress-bar {
  width: 100%;
  height: 0;
  -webkit-transition: height 0.6s ease;
  transition: height 0.6s ease;
}
.progress.vertical.bottom .progress-bar {
  position: absolute;
  bottom: 0;
}
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-moz-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-o-keyframes progress-bar-stripes {
  from {
    background-position: 0 0;
  }
  to {
    background-position: 40px 0;
  }
}
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
.progress {
  position: relative;
  margin-bottom: 20px;
  overflow: hidden;
  height: 22px;
  background: #eeeeee;
  box-shadow: 0 1px 0 transparent, 0 0 0 1px #e3e3e3 inset;
  -webkit-box-shadow: 0 1px 0 transparent, 0 0 0 1px #e3e3e3 inset;
  -moz-box-shadow: 0 1px 0 transparent, 0 0 0 1px #e3e3e3 inset;
  border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-border-radius: 0px;
}
.progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 11px;
  color: #ffffff;
  text-align: center;
  background-color: #57889c;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  font-weight: bold;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-image: url('../../img/pattern/overlay-pattern.png');
}
.progress-striped .progress-bar {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px;
}
.progress.active .progress-bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -moz-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.progress-bar-danger {
  background-color: #a90329;
}
.progress-striped .progress-bar-danger {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-success {
  background-color: #739e73;
}
.progress-striped .progress-bar-success {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-warning {
  background-color: #c79121;
}
.progress-striped .progress-bar-warning {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-info {
  background-color: #57889c;
}
.progress-striped .progress-bar-info {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-info .bar,
.progress .bar-info {
  background: #57889c;
}
.vertical-bars {
  padding: 0;
  margin: 0;
}
.vertical-bars:after {
  content: "";
  display: block;
  height: 0;
  clear: both;
}
.vertical-bars li {
  padding: 14px 0;
  width: 25%;
  display: block;
  float: left;
  text-align: center;
}
.vertical-bars li:first-child {
  border-left: none;
}
.vertical-bars > li > .progress.vertical:first-child {
  margin-left: auto;
}
.vertical-bars > li > .progress.vertical {
  margin: 0 auto;
  float: none;
}
/*
 * BAR HOLDER
 */
.bar-holder:first-child {
  border-top: none;
}
.bar-holder {
  padding: 18px 15px;
}
.bar-holder .progress {
  margin: 0;
}
/*
 * TABS
 */
.nav-tabs > li > a .badge {
  font-size: 11px;
  padding: 3px 5px 3px 5px;
  opacity: .5;
  margin-left: 5px;
  min-width: 17px;
  font-weight: normal;
}
.nav-tabs > li > a > .fa {
  opacity: .5;
}
.tabs-left .nav-tabs > li > a .badge {
  margin-right: 5px;
  margin-left: 0px;
}
.nav-tabs > li > a .label {
  display: inline-block;
  font-size: 11px;
  margin-left: 5px;
  opacity: .5;
}
.nav-tabs > li.active > a .badge,
.nav-tabs > li.active > a .label,
.nav-tabs > li.active > a > .fa {
  opacity: 1;
}
.nav-tabs > li > a {
  border-radius: 0px;
  color: #333333;
}
.nav-tabs > li.active > a {
  -webkit-box-shadow: 0 -2px 0 #57889c;
  -moz-box-shadow: 0 -2px 0 #57889c;
  box-shadow: 0 -2px 0 #57889c;
  border-top-width: 0px !important;
  margin-top: 1px !important;
  font-weight: bold;
}
.tabs-left .nav-tabs > li.active > a {
  -webkit-box-shadow: -2px 0 0 #57889c;
  -moz-box-shadow: -2px 0 0 #57889c;
  box-shadow: -2px 0 0 #57889c;
  border-top-width: 1px !important;
  border-left: none !important;
  margin-left: 1px !important;
}
.tabs-left .nav-pills > li.active > a {
  border: none !important;
  box-shadow: none !important;
  -webkit-box-shadow: none !important;
  -moz-box-shadow: none !important;
}
.tabs-right .nav-tabs > li.active > a {
  -webkit-box-shadow: 2px 0 0 #57889c;
  -moz-box-shadow: 2px 0 0 #57889c;
  box-shadow: 2px 0 0 #57889c;
  border-top-width: 1px !important;
  border-right: none !important;
  margin-right: 1px !important;
}
.tabs-below .nav-tabs > li.active > a {
  -webkit-box-shadow: 0 2px 0 #57889c;
  -moz-box-shadow: 0 2px 0 #57889c;
  box-shadow: 0 2px 0 #57889c;
  border-bottom-width: 0px !important;
  border-top: none !important;
  margin-top: 0px !important;
}
.tabs-below > .nav-tabs,
.tabs-right > .nav-tabs,
.tabs-left > .nav-tabs {
  border-bottom: 0;
}
.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}
.tab-content > .active,
.pill-content > .active {
  display: block;
}
.tabs-below > .nav-tabs {
  border-top: 1px solid #dddddd;
}
.tabs-below > .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-left > .nav-tabs > li,
.tabs-right > .nav-tabs > li,
.tabs-left > .nav-pills > li,
.tabs-right > .nav-pills > li {
  float: none;
}
.tabs-left > .nav-tabs > li > a,
.tabs-right > .nav-tabs > li > a,
.tabs-left > .nav-pills > li > a,
.tabs-right > .nav-pills > li > a {
  min-width: 74px;
  margin-right: 0;
  margin-bottom: 3px;
}
.tabs-left > .nav-tabs,
.tabs-left > .nav-pills {
  float: left;
  margin-right: 19px;
  border-right: 1px solid #dddddd;
}
.tabs-left > .nav-pills {
  border-right: none;
}
.tabs-left > .nav-tabs > li > a {
  margin-right: -1px;
}
.tabs-left > .nav-tabs > li > a:hover,
.tabs-left > .nav-tabs > li > a:focus {
  border-color: #eeeeee #d5d5d5 #eeeeee #eeeeee;
}
.tabs-left > .nav-tabs .active > a,
.tabs-left > .nav-tabs .active > a:hover,
.tabs-left > .nav-tabs .active > a:focus {
  border-color: #d5d5d5 transparent #d5d5d5 #dddddd;
  *border-right-color: #ffffff;
}
.tabs-left > .tab-content {
  margin-left: 109px;
}
.tabs-right > .nav-tabs {
  float: right;
  margin-left: 19px;
  border-left: 1px solid #dddddd;
  /* DDD */
}
.tabs-right > .nav-tabs > li > a {
  margin-left: -1px;
}
.tabs-right > .nav-tabs > li > a:hover,
.tabs-right > .nav-tabs > li > a:focus {
  border-color: #eeeeee #eeeeee #eeeeee #dddddd;
}
.tabs-right > .nav-tabs .active > a,
.tabs-right > .nav-tabs .active > a:hover,
.tabs-right > .nav-tabs .active > a:focus {
  border-color: #dddddd #dddddd #dddddd transparent;
  *border-left-color: #ffffff;
}
.tabs-below > .nav-tabs,
.tabs-right > .nav-tabs,
.tabs-left > .nav-tabs {
  border-bottom: 0;
}
.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}
.tab-content > .active,
.pill-content > .active {
  display: block;
}
.tabs-below > .nav-tabs {
  border-top: 1px solid #dddddd;
}
.tabs-below > .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-below > .nav-tabs > li > a:hover,
.tabs-below > .nav-tabs > li > a:focus {
  border-top-color: #dddddd;
  border-bottom-color: transparent;
}
.tabs-below > .nav-tabs > .active > a,
.tabs-below > .nav-tabs > .active > a:hover,
.tabs-below > .nav-tabs > .active > a:focus {
  border-color: transparent #dddddd #dddddd #dddddd;
  /* tabs */
}
/* bordered tabs */
.nav-tabs.bordered {
  background: #ffffff;
  border: 1px solid #dddddd;
}
.nav-tabs.bordered > :first-child a {
  border-left-width: 0px !important;
}
.nav-tabs.bordered + .tab-content {
  border: 1px solid #dddddd;
  border-top: none;
}
/* bordered tabs top right */
.tabs-pull-right.nav-tabs > li,
.tabs-pull-right.nav-pills > li {
  float: right;
}
.tabs-pull-right.nav-tabs > li:first-child > a,
.tabs-pull-right.nav-pills > li:first-child > a {
  margin-right: 1px;
}
.tabs-pull-right.bordered.nav-tabs > li:first-child > a,
.tabs-pull-right.bordered.nav-pills > li:first-child > a {
  border-left-width: 1px !important;
  margin-right: 0px;
  border-right-width: 0px;
}
/* jarviswidget header first child is tab */
.jarviswidget > header > .nav-tabs.pull-left > li:first-child a {
  border-left-width: 0px !important;
}
/* 
 * WEBKIT IOS HIGHLIGHT COLOR
 * 
 */
a:link,
.btn,
button {
  -webkit-tap-highlight-color: rgba(169, 3, 41, 0.5);
}
.login-info,
.login-info *,
#logo-group *,
.minified .menu-item-parent {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
/*
 * BS2 useful classes
 * these classes and its importance was overlooked in BS3
 */
.hidden-desktop {
  display: none !important;
}
/*
 * DROPDOWN MENU
 */
.dropdown-menu-xs {
  min-width: 37px;
}
.dropdown-menu-xs > li > a {
  padding: 3px 10px;
}
.dropdown-menu-xs > li > a:hover i {
  color: #fff !important;
}
/* Dropdown menu extended */
.dropdown-submenu {
  position: relative;
}
.dropdown-submenu > .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -6px;
  margin-left: -1px;
}
.dropdown-submenu:hover > .dropdown-menu {
  display: block;
}
.dropdown-submenu > a:after {
  display: block;
  content: " ";
  float: right;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  border-left-color: #bfbfbf;
  margin-top: 5px;
  margin-right: -10px;
}
.dropdown-submenu:hover > a:after {
  border-left-color: #ffffff;
}
.dropdown-submenu.pull-left {
  float: none;
}
.dropdown-submenu.pull-left > .dropdown-menu {
  left: -100%;
  margin-left: 10px;
}
/*
 * Table
 */
.table.has-tickbox thead tr th:first-child {
  width: 18px;
}
.table.has-tickbox.smart-form thead tr th:first-child .radio,
.table.has-tickbox.smart-form thead tr th:first-child .checkbox,
.table.has-tickbox.smart-form tbody tr td:first-child .radio,
.table.has-tickbox.smart-form tbody tr td:first-child .checkbox {
  padding: 0px !important;
}
.table thead tr,
.fc-border-separate thead tr {
  background-color: #eeeeee;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f2f2f2), to(#fafafa));
  background-image: -webkit-linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  background-image: -moz-linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  background-image: -ms-linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  background-image: -o-linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  background-image: -linear-gradient(top, #f2f2f2 0, #fafafa 100%);
  font-size: 12px;
}
.fc-border-separate thead tr th {
  padding: 4px;
  line-height: 1.428571429;
}
.table-bordered > thead > tr > th,
.table-bordered > thead > tr > td {
  border-width: 1px;
}
.no-padding > .table-bordered {
  border: none !important;
}
.no-padding > .table-bordered thead tr th:first-child,
.no-padding > .table-bordered thead tr td:first-child,
.no-padding > .table-bordered tbody tr td:first-child {
  border-left-width: 0px !important;
}
.no-padding > .table-bordered thead tr th:last-child,
.no-padding > .table-bordered tbody tr td:last-child {
  border-right-width: 0px !important;
}
.no-padding > .table-bordered tbody tr:last-child td {
  border-bottom-width: 0px !important;
}
.no-padding .note-editable .table-bordered {
  border: 1px solid #dddddd !important;
}
.smart-form.table td .radio i,
.smart-form.table td .checkbox i,
.smart-form.table th .radio i,
.smart-form.table th .checkbox i {
  top: 0px !important;
}
/*
 * small stats
 */
.show-stats .progress {
  height: 7px;
  border-radius: 0;
  margin-top: 3px;
  margin-bottom: 15px;
}
.show-stats {
  padding-top: 6px !important;
}
.show-stat-buttons {
  float: left;
  width: 100%;
}
.show-stats .show-stat-buttons > :first-child {
  padding-right: 5px;
}
.show-stats .show-stat-buttons > :last-child {
  padding-left: 5px;
}
.show-stat-microcharts {
  margin-left: -10px;
  margin-right: -10px;
}
.show-stat-microcharts > div {
  border-right: 1px solid #DADADA !important;
  border-top: 1px solid #DADADA !important;
  margin-top: 10px !important;
  height: 65px;
  overflow: hidden;
  padding: 7px 9px;
}
.show-stat-microcharts > :last-child {
  border-right: none !important;
}
.show-stat-microcharts .sparkline {
  margin-top: 10px;
  margin-right: 8px;
  opacity: .7;
}
.show-stat-microcharts .sparkline:hover {
  opacity: 1;
}
.smaller-stat {
  margin: 0;
  padding: 0;
  list-style: none;
}
.smaller-stat li {
  margin-top: 3px;
  margin-right: 0px;
}
.smaller-stat li:first-child {
  margin-top: 8px;
}
.smaller-stat span.label {
  width: 40px;
  display: block;
  text-align: left;
  opacity: .5;
  cursor: default;
}
.smaller-stat span.label:hover {
  opacity: 1;
}
/*
 * Login info
 */
.login-info {
  border-bottom: 1px solid #D8D4D4;
  display: block;
  font-size: 12px;
  height: 39px;
  color: #ffffff;
  border: solid transparent;
  border-width: 1px 0px 1px 0px;
  box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  width: 100%;
  margin: 0px !important;
  border-bottom: 1px solid #525151;
}
.login-info a {
  text-decoration: none !important;
  color: #a8a8a8;
  display: inline-block;
  margin-top: 6px;
}
.login-info a span {
  text-transform: capitalize;
  font-size: 14px;
  /* 14px~ */
  display: inline-block;
  text-decoration: none;
  max-width: 150px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  vertical-align: middle;
}
.login-info a span + i {
  vertical-align: middle;
}
.login-info a:hover {
  color: #ffffff;
}
.login-info > span {
  height: 38px;
  display: block;
  padding: 0 10px;
  border-bottom: 1px solid #1A1817;
}
.login-info img {
  width: 25px;
  height: auto;
  display: inline-block;
  vertical-align: middle;
  margin-top: 1px;
  margin-right: 5px;
  margin-left: 0px;
  border-left: 3px solid #ffffff;
}
img.online,
img.busy,
img.offline,
img.away {
  border-left: 3px solid #fff;
}
img.online {
  border-left-color: #40ac2b !important;
}
img.busy {
  border-left-color: #ed1c24 !important;
}
img.offline {
  border-left-color: #dddddd !important;
}
img.away {
  border-left-color: #ffc40d !important;
}
/*
	 * Client page forms
	 */
.client-form header {
  padding: 15px 13px;
  margin: 0;
  border-bottom-style: solid;
  border-bottom-color: rgba(0, 0, 0, 0.1);
  background: rgba(248, 248, 248, 0.9);
}
/*
 * MINIFIED MENU
 */
.minified .inbox-badge {
  border-radius: 50%;
  font-size: 9px;
  padding: 2px;
  position: absolute;
  top: 6px;
  right: 6px;
  background: #ED1C24;
  min-width: 13px;
}
.minifyme {
  border-bottom: 1px solid #302F2F;
  background: #454545;
  color: #A8A8A8;
  text-align: center;
  padding: 0;
  width: 36px;
  height: 28px;
  display: block;
  position: absolute;
  right: -3px;
  border-radius: 5px 0px 0px 5px;
  cursor: pointer;
  margin-top: 5px;
  font-size: 19px;
  transition: all 0.1s linear 0s;
}
.minifyme:hover {
  background: #646464;
  color: #E4E4E4;
  right: 0px;
}
.minified .minifyme {
  right: 0px;
  color: #A8A8A8;
  position: relative;
  width: 100%;
  border-radius: 0px;
  margin: 0;
  height: 34px;
  font-size: 23px;
}
.minified .minifyme .fa:before {
  content: "\f0a9";
}
.minified .login-info a span,
.minified .login-info a i {
  display: none;
}
.minified .login-info span {
  padding: 0px 5px;
  text-align: center;
}
.minified .login-info img {
  margin: -2px 0 0;
  width: 30px;
}
.minified .login-info {
  height: 38px;
  border-bottom: 1px solid #181818;
}
.minified #left-panel {
  width: 45px;
}
.minified #main {
  margin-left: 45px;
}
/*
 * Minified NAV
 */
.minified #left-panel,
.minified nav > ul > li {
  overflow: visible;
}
.minified nav > ul > ul {
  min-height: 100px !important;
  max-height: 180px !important;
  overflow-y: scroll;
  overflow-x: hidden;
  background: #ed1c24 !important;
}
.minified nav > ul > li,
.minified nav > ul > li a {
  position: relative;
}
.minified nav ul > li > a {
  padding: 10px 11px;
  display: block;
}
.minified nav > ul > li > a .fa.fa-fw {
  display: block;
  width: auto;
  text-align: center;
  padding: 0;
}
.minified nav > ul > li > a > i {
  text-align: center;
  margin: 0;
  display: block;
}
.minified nav > ul > li.active > a::before {
  content: "\f0d9";
}
.minified nav ul ul li a {
  padding-left: 14px;
}
.minified nav ul ul li li a {
  padding-left: 25px;
}
.minified nav > ul ul li::before {
  left: 12px;
}
.minified nav > ul > li > ul::before {
  left: 12px;
}
.minified nav > ul > li > a .menu-item-parent,
.minified nav > ul > li > a > b {
  display: none;
}
.minified nav > ul > li > a > .menu-item-parent {
  display: none;
  position: absolute;
  left: 40px;
  top: -3px;
  width: 186px;
  height: 38px;
  line-height: 38px;
  background-color: whiteSmoke;
  color: #333333;
  z-index: 3;
  -webkit-box-shadow: 2px 1px 2px 0 rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 2px 1px 2px 0 rgba(0, 0, 0, 0.2);
  box-shadow: 2px 1px 2px 0 rgba(0, 0, 0, 0.2);
  border-left: 1px solid #bfbfbf;
  border-top: 1px solid #D8D4D4;
  border-bottom: 1px solid #ffffff;
  padding-left: 12px;
}
.minified nav > ul > li > ul {
  display: none !important;
  position: absolute;
  left: 40px;
  width: 200px;
  z-index: 5;
  border: 1px solid #bfbfbf;
  min-height: 180px;
  -webkit-box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
  box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
  background: #3A3633;
  margin-top: -3px;
}
.minified nav ul > li > ul > li > ul {
  position: relative;
  left: 13px;
  border: none;
  width: auto;
  margin-left: -12px;
  width: 197px;
}
.minified nav > ul > li:hover > a > .menu-item-parent,
.minified nav > ul > li:hover > ul {
  display: block !important;
}
.minified nav > ul > li > ul > li {
  background-color: rgba(69, 69, 69, 0.9);
}
.minified nav > ul > li > ul > li > ul > li {
  background-color: #484B50;
}
.minified nav > ul > li {
  border-bottom: 1px solid #1A1817;
  border-top: 1px solid #525151;
}
.minified nav > ul > li > ul::before {
  border-left: none;
}
.minified nav > ul ul li::before {
  border: none;
}
.slimScrollDiv,
.slimScrollDiv > :first-child {
  overflow: hidden;
}
.minified .slimScrollDiv,
.minified .slimScrollDiv > :first-child {
  overflow: visible !important;
}
.minified .slimScrollBar,
.minified .slimScrollRail {
  display: none;
}
.minified nav > ul > li > ul > li > a {
  padding-top: 7px;
  padding-bottom: 7px;
}
.minified nav > ul > li > ul > li > ul > li > a {
  padding-top: 7px;
  padding-bottom: 7px;
}
.minified nav > ul > li > ul > li > ul > li a {
  padding-top: 6px;
  padding-bottom: 6px;
}
/* Fourth Level: A */
.minified nav ul ul ul ul li a {
  padding-left: 45px;
}
/* Fifth Level: A */
.minified nav ul ul ul ul ul li a {
  padding-left: 62px;
}
/* Sixth Level: A */
.minified nav ul ul ul ul ul ul li a {
  padding-left: 82px;
}
/*
 * SHORT CUTS
 */
.pull-right {
  float: right !Important;
}
.pull-left {
  float: left !Important;
}
/*
 * ALTERNATIVE PAGING
 */
.pagination.pagination-alt > li > a {
  box-shadow: none;
  -moz-box-shadow: none;
  -webkit-box-shadow: none;
  border: none;
  margin-left: -1px;
}
.pagination.pagination-alt > li:first-child > a {
  padding-left: 0px;
}
/*
 * CUSTOM BUTTON
 */
.pagination > li > a,
.pagination > li > span {
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.disabled {
  color: #ffffff;
}
.btn-default.disabled {
  color: #999999;
}
.btn {
  border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
}
.btn:active {
  position: relative;
  top: 1px;
  left: 1px;
}
.btn.btn-ribbon {
  background-color: #707070;
  background-image: -moz-linear-gradient(top, #777777, #666666);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#777777), to(#666666));
  background-image: -webkit-linear-gradient(top, #777777, #666666);
  background-image: -o-linear-gradient(top, #777777, #666666);
  background-image: linear-gradient(to bottom, #777777, #666666);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff777777', endColorstr='#ff666666', GradientType=0);
  color: white;
  padding: 0 5px;
  line-height: 20px;
  vertical-align: middle;
  height: 20px;
  display: block;
  border: none;
  float: left;
  margin: 0 8px 0 0;
  cursor: pointer;
}
.btn.btn-ribbon > i {
  font-size: 111%;
}
.ribbon-button-alignment {
  padding-top: 10px;
  display: inline-block;
}
.ribbon-button-alignment.pull-right > .btn.btn-ribbon {
  margin: 0 0 0 8px;
}
/*
 * Panels
 */
.panel-purple {
  border-color: #6e587a;
}
.panel-purple > .panel-heading {
  color: #ffffff;
  background-color: #6e587a;
  border-color: #6e587a;
}
.panel-greenLight {
  border-color: #71843f;
}
.panel-greenLight > .panel-heading {
  color: #ffffff;
  background-color: #71843f;
  border-color: #71843f;
}
.panel-greenDark {
  border-color: #496949;
}
.panel-greenDark > .panel-heading {
  color: #ffffff;
  background-color: #496949;
  border-color: #496949;
}
.panel-darken {
  border-color: #333333;
}
.panel-darken > .panel-heading {
  color: #ffffff;
  background-color: #404040;
  border-color: #404040;
}
.panel-pink {
  border-color: #ac5287;
}
.panel-pink > .panel-heading {
  color: #ffffff;
  background-color: #ac5287;
  border-color: #ac5287;
}
.panel-green {
  border-color: #356e35;
}
.panel-green > .panel-heading {
  color: #ffffff;
  background-color: #356e35;
  border-color: #356e35;
}
.panel-blueLight {
  border-color: #92a2a8;
}
.panel-blueLight > .panel-heading {
  color: #ffffff;
  background-color: #92a2a8;
  border-color: #92a2a8;
}
.panel-pinkDark {
  border-color: #a8829f;
}
.panel-pinkDark > .panel-heading {
  color: #ffffff;
  background-color: #a8829f;
  border-color: #a8829f;
}
.panel-redLight {
  border-color: #a65858;
}
.panel-redLight > .panel-heading {
  color: #ffffff;
  background-color: #a65858;
  border-color: #a65858;
}
.panel-red {
  border-color: #a90329;
}
.panel-red > .panel-heading {
  color: #ffffff;
  background-color: #a90329;
  border-color: #a90329;
}
.panel-teal {
  border-color: #568a89;
}
.panel-teal > .panel-heading {
  color: #ffffff;
  background-color: #568a89;
  border-color: #568a89;
}
.panel-orange {
  border-color: #c79121;
}
.panel-orange > .panel-heading {
  color: #ffffff;
  background-color: #c79121;
  border-color: #c79121;
}
.panel-blueDark {
  border-color: #4c4f53;
}
.panel-blueDark > .panel-heading {
  color: #ffffff;
  background-color: #4c4f53;
  border-color: #4c4f53;
}
.panel-magenta {
  border-color: #6e3671;
}
.panel-magenta > .panel-heading {
  color: #ffffff;
  background-color: #6e3671;
  border-color: #6e3671;
}
.panel-blue {
  border-color: #57889c;
}
.panel-blue > .panel-heading {
  color: #ffffff;
  background-color: #57889c;
  border-color: #57889c;
}
.panel-footer > .btn-block {
  border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-border-radius: 0px;
  border-bottom: none;
  border-left: none;
  border-right: none;
}
/*
 * Circle Buttons
 */
.btn-circle {
  width: 30px;
  height: 30px;
  text-align: center;
  padding: 6px 0;
  font-size: 12px;
  line-height: 18px;
  border-radius: 50%;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
}
.btn-circle.btn-lg {
  width: 50px;
  height: 50px;
  padding: 10px 15px;
  font-size: 18px;
  line-height: 30px;
  border-radius: 50%;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
}
.btn-circle.btn-xl {
  width: 70px;
  height: 70px;
  padding: 10px 15px;
  font-size: 24px;
  line-height: 50px;
  border-radius: 50%;
  -moz-border-radius: 50%;
  -webkit-border-radius: 50%;
}
/*
 * Big Metro Buttons
 */
.btn-metro {
  margin: 0 0 20px;
  padding-top: 15px;
  padding-bottom: 15px;
}
.btn-metro > span {
  display: block;
  vertical-align: bottom;
  margin-top: 10px;
  text-transform: uppercase;
}
.btn-metro > span.label {
  position: absolute;
  top: 0px;
  right: 0px;
}
/*
 * buttons with labels
 */
.btn-label {
  position: relative;
  left: -12px;
  display: inline-block;
  padding: 6px 12px;
  background: rgba(0, 0, 0, 0.15);
  border-radius: 3px 0 0 3px;
}
.btn-labeled {
  padding-top: 0;
  padding-bottom: 0;
}
.btn-link {
  box-shadow: none;
  -webkit-box-shadow: none;
  font-size: 14px;
}
/*
 * ANIMATION
 */
#left-panel,
#content {
  -moz-transition: left 0.1s ease-out;
  -ms-transition: left 0.1s ease-out;
  -o-transition: left 0.1s ease-out;
  -webkit-transition: left 0.1s ease-out;
  transition: left 0.1s ease-out;
}
#main {
  -moz-transition: all 0.1s ease-out;
  -ms-transition: all 0.1s ease-out;
  -o-transition: all 0.1s ease-out;
  -webkit-transition: all 0.1s ease-out;
  transition: all 0.1s ease-out;
}
/*
 * CHARTS
 */
.chart-small {
  height: 100px;
  width: 100%;
}
.chart-large {
  height: 235px;
  width: 100%;
}
.chart-xl {
  height: 297px;
  width: 100%;
}
/*
 * Flot Tool tips 
 */
#flotTip {
  padding: 3px 5px;
  background-color: #ffffff;
  z-index: 9999;
  color: #333333;
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
  font-size: 14px;
  border: 1px solid #C1C1C1;
  -moz-border-radius: 4px;
  -khtml-border-radius: 4px;
  -webkit-border-radius: 4px;
  border-radius: 4px;
}
#flotTip span {
  color: #38812D;
  font-weight: bold;
}
.legendLabel span {
  display: block;
  margin: 0 5px;
}
.legendColorBox {
  padding-left: 10px;
  vertical-align: top;
  padding-top: 5px;
}
.legendColorBox div > div {
  width: 4px;
  height: 4px;
  border-radius: 50%;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
/*
 * Morris Charts 
 */
.morris-hover.morris-default-style {
  border-radius: 10px;
  padding: 6px;
  color: #666;
  background: rgba(255, 255, 255, 0.8);
  border: solid 2px rgba(230, 230, 230, 0.8);
  font-family: sans-serif;
  font-size: 12px;
  text-align: center;
}
.morris-hover.morris-default-style .morris-hover-row-label {
  font-weight: bold;
  margin: 0.25em 0;
}
.morris-hover.morris-default-style .morris-hover-point {
  white-space: nowrap;
  margin: 0.1em 0;
}
.morris-hover {
  position: absolute;
  z-index: 1001;
}
/*
 * Flot Chart 
 */
.chart {
  height: 220px;
  margin: 20px 5px 10px 10px;
}
.has-legend {
  margin-top: 30px !important;
}
.has-legend-unique {
  margin-top: 19px !important;
}
/*
 * EASY PIE CHART
 */
.easyPieChart {
  position: relative;
  text-align: center;
}
.easyPieChart canvas {
  position: absolute;
  top: 0;
  left: 0;
}
.easy-pie-chart {
  display: inline-block;
}
.easy-pie-chart .percent {
  color: #444;
  font-size: 12px;
  font-weight: bold;
}
.easy-pie-title {
  display: inline-block;
  margin: 10px 6px 0;
  font-size: 12px;
  font-weight: 400;
  text-transform: uppercase;
  width: 100px;
  height: 19px;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.easy-pie-title .icon-color-good,
.easy-pie-title .icon-color-bad {
  font-size: 18px;
}
/*
 * Carren colors
 */
.icon-color-good {
  color: #40ac2b;
}
.icon-color-bad {
  color: #ed1c24;
}
/*
 * SIGNS
 */
.percent-sign:after,
.degree-sign:after {
  content: " %";
  line-height: normal;
}
.degree-sign:after {
  content: " °F";
}
/*
 * HIDDEN MENU
 */
.hidden-menu #left-panel {
  left: -210px;
  z-index: 1002;
}
.hidden-menu #main {
  margin-left: 10px;
}
.hidden-menu #left-panel:hover {
  left: 0px;
}
.hidden-menu .minifyme {
  display: none;
}
.minified #hide-menu {
  display: none;
}
.btn-header.pull-right {
  margin-left: 6px;
}
.btn-header a > span {
  font-size: 13px;
  font-weight: normal;
  line-height: 20px;
  height: 30px;
  display: inline-block;
}
.btn-header > :first-child > a {
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  border-radius: 2px;
  cursor: default !important;
  display: inline-block;
  font-weight: bold;
  height: 30px;
  min-width: 30px;
  padding: 2px;
  text-align: center;
  text-decoration: none !important;
  -moz-user-select: none;
  -webkit-user-select: none;
  background-color: #f8f8f8;
  background-image: -webkit-gradient(linear, left top, left bottom, from(#f8f8f8), to(#f1f1f1));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
  background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
  border: 1px solid #bfbfbf;
  color: #6D6A69;
  font-size: 17px;
  margin: 10px 0 0 0;
}
.btn-header > :first-child > a:hover {
  border: 1px solid #bfbfbf;
  color: #222;
  transition: all 0.0s;
  cursor: pointer;
  -webkit-box-shadow: inset 0px 0px 4px 1px rgba(0, 0, 0, 0.08);
  box-shadow: inset 0px 0px 4px 1px rgba(0, 0, 0, 0.08);
}
.btn-header > :first-child > a:active {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #e8e8e8 0%, #ededed 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #e8e8e8), color-stop(100%, #ededed));
  background-image: -webkit-linear-gradient(top, #e8e8e8 0%, #ededed 100%);
  background-image: -o-linear-gradient(top, #e8e8e8 0%, #ededed 100%);
  background-image: -ms-linear-gradient(top, #e8e8e8 0%, #ededed 100%);
  background-image: linear-gradient(to bottom, #e8e8e8 0%, #ededed 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#e8e8e8', endColorstr='#ededed', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
}
.hidden-menu #hide-menu > :first-child > a {
  background-color: #e8e8e8;
  background-image: -moz-linear-gradient(top, #5a5a5a 0%, #686868 100%);
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #5a5a5a), color-stop(100%, #686868));
  background-image: -webkit-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -o-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: -ms-linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  background-image: linear-gradient(to bottom, #5a5a5a 0%, #686868 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5A5A5A', endColorstr='#686868', GradientType=0);
  -webkit-box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0px 0px 3px 1px rgba(0, 0, 0, 0.15);
  color: #ffffff;
  border-color: #494949;
}
.hidden-menu #hide-menu > :first-child > a:active,
.full-screen #fullscreen > :first-child > a:active {
  -webkit-box-shadow: inset 0px 0px 6px 1px rgba(0, 0, 0, 0.2);
  box-shadow: inset 0px 0px 6px 1px rgba(0, 0, 0, 0.2);
}
/*
 * AJAX DROPDOWN
 */
.ajax-dropdown > :first-child {
  margin: 0 0 3px 0;
  padding: 0 0 9px 0;
}
.ajax-dropdown {
  position: absolute;
  display: none;
  z-index: 1003;
  background: white;
  top: 48px;
  left: 16px;
  width: 344px;
  height: 435px;
  border-radius: 0px;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  -moz-box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  box-shadow: 0 2px 4px rgba(30, 30, 100, 0.25);
  padding: 10px;
  background: #ffffff;
  border: 1px solid #b3b3b3;
}
.ajax-dropdown:after,
.ajax-dropdown:before {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.ajax-dropdown:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #ffffff;
  border-width: 7px;
  left: 50%;
  margin-left: -7px;
}
.ajax-dropdown:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  left: 50%;
  margin-left: -8px;
}
.ajax-dropdown .btn-group .btn {
  font-weight: bold;
  text-transform: capitalize;
}
.ajax-dropdown .btn-group > :nth-child(2) {
  border-right-width: 0px;
  border-left-width: 0px;
}
.ajax-dropdown .btn-group .btn:active {
  top: 0px;
  left: 0px;
}
.ajax-notifications {
  height: 365px;
  display: block;
  overflow: auto;
  margin-right: -10px;
  margin-left: -10px;
  border-bottom: 1px solid #CECECE;
  border-top: 1px solid #CECECE;
  background: #E9E9E9;
}
.ajax-notifications > .alert.alert-transparent {
  background-color: transparent;
  border-color: transparent;
  color: #757575;
  margin: 13px 10px;
}
.ajax-notifications > .alert > :first-child {
  margin-bottom: 10px;
  font-weight: 400;
}
.ajax-dropdown > :last-child {
  font-size: 13px;
  display: block;
  padding: 5px 0;
  line-height: 22px;
  font-weight: 400;
}
.ajax-dropdown .fa-4x.fa-border {
  border-width: 3px;
  border-radius: 50%;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  display: block;
  margin: 0 auto;
  width: 46px;
  text-align: center;
  color: #D1D1D1;
  border-color: #D1D1D1;
}
/*
 * LARGE DROPDOWNS
 */
.dropdown-large {
  position: static !important;
}
.dropdown-menu-large {
  margin-left: 16px;
  margin-right: 16px;
  padding: 20px 0px;
}
.dropdown-menu-large > li > ul {
  padding: 0;
  margin: 0;
}
.dropdown-menu-large > li > ul > li {
  list-style: none;
}
.dropdown-menu-large > li > ul > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.428571429;
  color: #333333;
  white-space: normal;
}
.dropdown-menu-large > li ul > li > a:hover,
.dropdown-menu-large > li ul > li > a:focus {
  text-decoration: none;
  color: #262626;
  background-color: #f5f5f5;
}
.dropdown-menu-large .disabled > a,
.dropdown-menu-large .disabled > a:hover,
.dropdown-menu-large .disabled > a:focus {
  color: #999999;
}
.dropdown-menu-large .disabled > a:hover,
.dropdown-menu-large .disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
  cursor: not-allowed;
}
.dropdown-menu-large .dropdown-header {
  color: #428bca;
  font-size: 18px;
}
@media (max-width: 768px) {
  .dropdown-menu-large {
    margin-left: 0 ;
    margin-right: 0 ;
  }
  .dropdown-menu-large > li {
    margin-bottom: 30px;
  }
  .dropdown-menu-large > li:last-child {
    margin-bottom: 0;
  }
  .dropdown-menu-large .dropdown-header {
    padding: 3px 15px !important;
  }
}
/*
 * PAGING
 */
.pagination-xs > li > a,
.pagination-xs > li > span {
  padding: 4px 9px;
  font-size: 12px;
}
/*
 * NOTIFICATIONS : MAIL
 */
.notification-body *,
.notification-body:before *,
.notification-body:after * {
  box-sizing: border-box !important;
  -webkit-box-sizing: border-box !important;
  -moz-box-sizing: border-box !important;
}
.notification-body {
  padding: 0 0 0 3px;
  margin: 0;
  list-style: none;
}
.notification-body > li {
  border-bottom: 1px solid #E9E9E9;
  position: relative;
}
.notification-body > li > span {
  background: #ffffff;
  display: block;
  min-height: 25px;
  overflow: hidden;
  padding: 8px 10px 13px;
  white-space: normal;
}
.notification-body > li > span:hover {
  background: #F0F4F7 ;
  color: #667F8F;
}
.notification-body > li a.msg {
  padding-left: 50px !important;
}
.notification-body > li a,
.notification-body > li a:hover {
  text-decoration: none;
}
.notification-body > li a,
.notification-body > li a span {
  display: block;
  position: relative;
  overflow: hidden;
}
.notification-body > li a,
.notification-body > li a:hover {
  text-decoration: none;
}
.notification-body > li:hover .progress {
  background: #ffffff;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #a7a7a7 inset;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0), 0 0 0 1px #cccccc inset;
  -moz-box-shadow: 0 1px 0 transparent, 0 0 0 1px #ffffff inset;
}
.notification-body > li:hover .text-muted {
  color: #333333;
}
.notification-body .from {
  font-size: 14px;
  line-height: normal;
  color: #333333;
  font-weight: normal;
  margin-right: 60px;
  margin-bottom: 6px;
  height: 20px;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.notification-body .unread .from {
  font-weight: bold;
}
.notification-body .unread {
  background: #FFFFE0;
}
.notification-body time {
  position: absolute;
  top: 3px;
  right: 0;
  font-size: 11px;
  font-weight: normal;
  color: #058dc7;
}
.notification-body .msg-body,
.notification-body .subject {
  font-size: 13px;
  color: #A0A0A0;
  max-height: 35px;
  width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}
.notification-body .subject {
  font-size: 13px;
  color: #333333;
  max-height: 22px;
}
/*
 * WIZARDS
 */
.bootstrapWizard {
  display: block;
  list-style: none;
  padding: 0;
  position: relative;
  width: 100%;
}
.bootstrapWizard a:hover,
.bootstrapWizard a:active,
.bootstrapWizard a:focus {
  text-decoration: none;
}
.bootstrapWizard li {
  display: block;
  float: left;
  width: 25%;
  text-align: center;
  padding-left: 0;
}
.bootstrapWizard li:before {
  border-top: 3px solid #55606E;
  content: "";
  display: block;
  font-size: 0;
  overflow: hidden;
  position: relative;
  top: 11px;
  right: 1px;
  width: 100%;
  z-index: 1;
}
.bootstrapWizard li:first-child:before {
  left: 50%;
  max-width: 50%;
}
.bootstrapWizard li:last-child:before {
  max-width: 50%;
  width: 50%;
}
.bootstrapWizard li.complete .step {
  background: #0aa66e;
  padding: 1px 6px;
  border: 3px solid #55606E;
}
.bootstrapWizard li .step i {
  font-size: 10px;
  font-weight: normal;
  position: relative;
  top: -1.5px;
}
.bootstrapWizard li .step {
  background: #B2B5B9;
  color: #ffffff;
  display: inline;
  font-size: 15px;
  font-weight: bold;
  line-height: 12px;
  padding: 7px 13px;
  border: 3px solid transparent;
  border-radius: 50%;
  line-height: normal;
  position: relative;
  text-align: center;
  z-index: 2;
  transition: all 0.1s linear 0s;
}
.bootstrapWizard li.active .step,
.bootstrapWizard li.active.complete .step {
  background: #0091d9;
  color: #ffffff;
  font-weight: bold;
  padding: 7px 13px;
  font-size: 15px;
  border-radius: 50%;
  border: 3px solid #55606E;
}
.bootstrapWizard li.complete .title,
.bootstrapWizard li.active .title {
  color: #2B3D53;
}
.bootstrapWizard li .title {
  color: #bfbfbf;
  display: block;
  font-size: 13px;
  line-height: 15px;
  max-width: 100%;
  position: relative;
  table-layout: fixed;
  text-align: center;
  top: 20px;
  word-wrap: break-word;
  z-index: 104;
}
.wizard-actions {
  display: block;
  list-style: none;
  padding: 0;
  position: relative;
  width: 100%;
}
.wizard-actions li {
  display: inline;
}
.tab-content.transparent {
  background-color: transparent;
}
/*
 * FUELUX WIZARD
 */
.fuelux .wizard {
  position: relative;
  overflow: hidden;
  background-color: #f9f9f9;
  border: 1px solid #d4d4d4;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  *zoom: 1;
  -webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  -moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
}
.fuelux .wizard:before,
.fuelux .wizard:after {
  display: table;
  line-height: 0;
  content: "";
}
.fuelux .wizard:after {
  clear: both;
}
.fuelux .wizard ul {
  width: 4000px;
  padding: 0;
  margin: 0;
  list-style: none outside none;
}
.fuelux .wizard ul.previous-disabled li.complete {
  cursor: default;
}
.fuelux .wizard ul.previous-disabled li.complete:hover {
  color: #356e35;
  cursor: default;
  background: #f3f4f5;
}
.fuelux .wizard ul.previous-disabled li.complete:hover .chevron:before {
  border-left-color: #f3f4f5;
}
.fuelux .wizard ul li {
  position: relative;
  float: left;
  height: 46px;
  padding: 0 20px 0 30px;
  margin: 0;
  font-size: 16px;
  line-height: 46px;
  color: #999999;
  cursor: default;
  background: #ededed;
}
.fuelux .wizard ul li .chevron {
  position: absolute;
  top: 0;
  right: -14px;
  z-index: 1;
  display: block;
  border: 24px solid transparent;
  border-right: 0;
  border-left: 14px solid #d4d4d4;
}
.fuelux .wizard ul li .chevron:before {
  position: absolute;
  top: -24px;
  right: 1px;
  display: block;
  border: 24px solid transparent;
  border-right: 0;
  border-left: 14px solid #ededed;
  content: "";
}
.fuelux .wizard ul li.complete {
  color: #468847;
  background: #f3f4f5;
}
.fuelux .wizard ul li.complete:hover {
  cursor: pointer;
  background: #e7eff8;
}
.fuelux .wizard ul li.complete:hover .chevron:before {
  border-left: 14px solid #e7eff8;
}
.fuelux .wizard ul li.complete .chevron:before {
  border-left: 14px solid #f3f4f5;
}
.fuelux .wizard ul li.active {
  color: #3a87ad;
  background: #f1f6fc;
}
.fuelux .wizard ul li.active .chevron:before {
  border-left: 14px solid #f1f6fc;
}
.fuelux .wizard ul li .badge {
  margin-right: 8px;
}
.fuelux .wizard ul li:first-child {
  padding-left: 20px;
  border-radius: 4px 0 0 4px;
}
.fuelux .wizard .actions {
  position: absolute;
  right: 0;
  z-index: 2;
  float: right;
  padding-right: 15px;
  padding-left: 15px;
  line-height: 46px;
  vertical-align: middle;
  background-color: #eeeeee;
  border-left: 1px solid #d4d4d4;
}
.fuelux .wizard .actions a {
  margin-right: 8px;
  font-size: 12px;
  line-height: 45px;
}
.fuelux .wizard .actions .btn-prev i {
  margin-right: 5px;
}
.fuelux .wizard .actions .btn-next i {
  margin-left: 5px;
}
.fuelux .step-content .step-pane {
  display: none;
}
.fuelux .step-content .active {
  display: block;
}
.fuelux .step-content .active .btn-group .active {
  display: inline-block;
}
/*
 * jarvismetro TILE
 */
.jarvismetro-tile {
  float: left;
  display: block;
  background-color: #ffffff;
  width: 100px;
  height: 70px;
  cursor: pointer;
  box-shadow: inset 0px 0px 1px #FFFFCC;
  border: 1px dotted #C5C5C5;
  text-decoration: none;
  color: #ffffff;
  font-weight: 300;
  font-smooth: always;
  margin: 0 10px 20px 0;
  padding: 5px;
  position: relative;
}
.jarvismetro-tile:hover {
  z-index: 10;
  -webkit-transform: scale(1.07);
  -moz-transform: scale(1.07);
}
.jarvismetro-tile.big-cubes {
  width: 120px;
  height: 120px;
}
.jarvismetro-tile.double {
  width: 249px;
}
.jarvismetro-tile:active {
  top: 1px;
  left: 1px;
}
.jarvismetro-tile .iconbox {
  text-align: center;
}
.jarvismetro-tile .iconbox i {
  display: block;
  margin: 15px auto 0;
  height: 75px;
}
.jarvismetro-tile .iconbox span {
  display: block;
  text-align: left;
}
.jarvismetro-tile .iconbox span > span {
  position: absolute;
  right: -3px;
  bottom: -3px;
  border-radius: 50%;
  padding: 5px 5px;
  border: 1px solid #ffffff;
}
.selected {
  border: 1px solid #0091d9 !important;
}
.selected:before {
  display: block;
  position: absolute;
  content: "\f00c";
  color: #ffffff;
  right: 4px;
  font-family: FontAwesome;
  z-index: 2;
}
.selected:after {
  width: 0;
  height: 0;
  border-top: 35px solid #0091d9;
  border-left: 35px solid rgba(0, 0, 0, 0);
  position: absolute;
  display: block;
  right: 0;
  content: ".";
  top: 0;
  z-index: 1;
}
/*
 * SHORT CUT
 */
#shortcut {
  display: block;
  position: absolute;
  top: 0px;
  left: 0;
  height: auto;
  width: 100%;
  background-color: #33302F;
  background-color: rgba(0, 0, 0, 0.85);
  z-index: 1005;
  display: none;
  color: #ffffff;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#shortcut ul {
  padding: 15px 20px 10px;
  list-style: none;
  margin: 0;
  box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.3);
  border-bottom: 1px solid #423F3F;
}
#shortcut ul li {
  display: inline-block;
  width: auto;
}
#shortcut ul li .jarvismetro-tile {
  margin: 0px 3px 3px;
  border: none;
  border-radius: 0px;
  -moz-border-radius: 0px;
  -webkit-border-radius: 0px;
}
#shortcut ul li .jarvismetro-tile:hover {
  color: #ffffff;
  text-decoration: none;
}
#shortcut ul li .jarvismetro-tile:active,
#shortcut ul li .jarvismetro-tile:focus {
  left: 0;
  top: 0;
}
.shortcut-on #response-btn {
  display: none !important;
}
.shortcut-on #main .navbar,
.shortcut-on #left-bar .navbar {
  border: none !important;
}
/*
 * ARROW BOX
 */
.arrow-box-up:after,
.arrow-box-up:before {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.arrow-box-up:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #ffffff;
  border-width: 7px;
  left: 50%;
  margin-left: -7px;
}
.arrow-box-up:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  left: 50%;
  margin-left: -8px;
}
/*
	 * right
	 */
.arrow-box-up-right:after,
.arrow-box-up-right:before {
  bottom: 100%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}
.arrow-box-up-right:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #ffffff;
  border-width: 7px;
  right: 10px;
  margin-left: -7px;
}
.arrow-box-up-right:before {
  border-color: rgba(131, 131, 131, 0);
  border-bottom-color: #838383;
  border-width: 8px;
  right: 9px;
  margin-left: -8px;
}
/*
	 * BOOTSTRAP TOOLTIP
	 */
.tooltip-inner {
  padding: 5px 10px;
  font-size: 11px;
  font-family: Arial, Helvetica, sans-serif;
  font-weight: bold;
  border-radius: 0px;
}
/*
 * SPARKLINE
 */
.jqstooltip {
  padding: 7px !important;
  border-radius: 3px !important;
  -webkit-border-radius: 3px !important;
  -moz-border-radius: 3px !important;
  border: none !important;
  background-color: #000000 !important;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
.jqstooltip .jqsfield {
  font-family: "Segoe UI", "Open Sans", Calibri, Candara, Arial, sans-serif;
  font-size: 11px;
}
#sparks {
  display: block;
  list-style: none;
  margin: 10px 0 0;
  padding: 0;
  text-align: right;
}
#sparks li {
  display: inline-block;
  max-height: 47px;
  overflow: hidden;
  text-align: left;
  box-sizing: content-box;
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
}
#sparks li h5 {
  color: #555;
  float: left;
  font-size: 11px;
  font-weight: normal;
  margin: -3px 0 0 0;
  padding: 0;
  border: none;
  text-transform: uppercase;
}
#sparks li span {
  color: #636363;
  display: block;
}
#sparks li {
  border-left: 1px dotted #c7c7c7;
  padding: 0 10px;
}
#sparks li:last-child {
  padding-right: 0;
}
#sparks li:first-child {
  border-left: none;
  padding-left: 0;
}
.sparks-info {
  min-width: 70px;
}
.sparks-info span {
  font-size: 18px;
  line-height: 20px;
  margin: 0;
  text-transform: none;
}
.sparks-info .sparkline {
  display: block;
  float: right;
  margin: 3px 0 0 20px;
}
/*
 * WEBKIT SCROLLING CSS
 * Reference: http://stackoverflow.com/questions/10592657/scrollbar-stylesheet
 * GitHub Source: https://gist.github.com/jambu/2004633
 */
.desktop-detected .custom-scroll::-webkit-scrollbar {
  -webkit-overflow-scrolling: touch;
  height: 10px;
  width: 10px;
}
.desktop-detected .custom-scroll::-webkit-scrollbar:hover {
  background-color: #E9E9E9;
  border: 1px solid #dbdbdb;
}
.desktop-detected .custom-scroll::-webkit-scrollbar-button:start:decrement,
.scrollable::-webkit-scrollbar-button:end:increment {
  background: transparent;
  display: block;
  height: 0;
}
.desktop-detected .custom-scroll::-webkit-scrollbar-track {
  background-clip: padding-box;
  border-width: 0 0 0 4px;
  border: solid transparent;
}
.desktop-detected .custom-scroll::-webkit-scrollbar-track-piece {
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  -webkit-border-radius: 0;
  background-color: transparent;
  border-radius: 0;
}
.desktop-detected .custom-scroll::-webkit-scrollbar-thumb {
  -moz-box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  -webkit-box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
  background-clip: padding-box;
  background-color: rgba(0, 0, 0, 0.2);
  border-width: 0;
  border: none;
  box-shadow: inset 1px 1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 rgba(0, 0, 0, 0.07);
}
.desktop-detected .custom-scroll::-webkit-scrollbar-thumb:vertical,
.scrollable::-webkit-scrollbar-thumb:horizontal {
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  -webkit-border-radius: 0;
  background-color: #bfbfbf;
  border-radius: 0;
}
.desktop-detected .custom-scroll::-webkit-scrollbar-thumb:active {
  -moz-box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.33);
  -webkit-box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.33);
  background-color: rgba(0, 0, 0, 0.44);
  box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.33);
}
.desktop-detected .custom-scroll::-webkit-scrollbar-thumb:hover {
  background-color: #959595;
}
.mobile-detected .custom-scroll {
  -webkit-overflow-scrolling: touch;
}
/*
 * Air fields 
 * Description: absolute positioned objects
 */
.air {
  position: absolute;
  z-index: 5;
}
.air-bottom {
  bottom: 0px;
}
.air-top {
  top: 0px;
}
.air-top-right {
  top: 0px;
  right: 0px;
}
.air-top-left {
  top: 0px;
  left: 0px;
}
.air-bottom-left {
  bottom: 0px;
  left: 0px;
}
.air-bottom-right {
  bottom: 0px;
  right: 0px;
}
/*
 * Typehead
 */
.twitter-typeahead .tt-query,
.twitter-typeahead .tt-hint {
  margin-bottom: 0;
}
.tt-dropdown-menu {
  min-width: 160px;
  margin-top: 2px;
  padding: 5px 0;
  background-color: #ffffff;
  border: 1px solid #bfbfbf;
  border: 1px solid rgba(0, 0, 0, 0.2);
  *border-right-width: 2px;
  *border-bottom-width: 2px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
.tt-suggestion {
  display: block;
  padding: 3px 20px;
}
.tt-suggestion.tt-is-under-cursor {
  color: #ffffff;
  background-color: #0081c2;
}
.tt-suggestion.tt-is-under-cursor a {
  color: #ffffff;
}
.tt-suggestion p {
  margin: 0;
}
/*
 * Google Maps
 */
.google_maps {
  width: 100%;
  height: 350px;
  position: relative;
}
.google_maps * {
  box-sizing: content-box;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
}
.google_maps img {
  max-width: none;
  /* needed for google map popup*/
}
/*
 * Header btn
 */
.header-btn {
  margin-top: 5px;
}
/*
 * TREE
 */
.tree {
  min-height: 20px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.tree li {
  list-style-type: none;
  margin: 0;
  padding: 5px;
  position: relative;
}
.tree ul ul li:hover {
  background: rgba(0, 0, 0, 0.015);
}
.tree li:before,
.tree li:after {
  content: '';
  left: -20px;
  position: absolute;
  right: auto;
}
.tree li:before {
  border-left: 1px solid #999999;
  bottom: 50px;
  height: 100%;
  top: -11px;
  width: 1px;
  -webkit-transition: "border-color 0.1s ease 0.1s";
  -moz-transition: "border-color 0.1s ease 0.1s";
  -o-transition: "border-color 0.1s ease 0.1s";
  transition: "border-color 0.1s ease 0.1s";
}
.tree li:after {
  border-top: 1px solid #999999;
  height: 20px;
  top: 18px;
  width: 25px;
}
.tree li span {
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  border: 1px dotted #999999;
  border-radius: 5px;
  display: inline-block;
  padding: 3px 8px;
  text-decoration: none;
  -webkit-transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
  -moz-transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
  -o-transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
  transition: color 0.2s ease 0.1s, background-color 0.2s ease 0.1s, border-color 0.3s ease 0.2s;
}
.tree li.parent_li > span {
  cursor: pointer;
  padding: 7px;
}
.tree > ul > li:before,
.tree > ul > li::after {
  border: 0;
}
.tree li:last-child::before {
  height: 30px;
}
.tree li.parent_li > span:hover,
.tree li.parent_li > span:hover + ul li span {
  background: #eee;
  border: 1px solid #94a0b4;
  color: #000000;
}
.tree > ul {
  padding-left: 0px;
}
.tree ul ul {
  padding-left: 34px;
  padding-top: 10px;
}
.tree li.parent_li > span:hover {
  background-color: #DF8505;
  border: 1px solid #C67605;
  color: #ffffff;
}
.tree li.parent_li > span:hover + ul li::before {
  border-left-color: #F89406;
}
.tree li.parent_li > span:hover + ul li::after {
  border-top-color: #F89406;
}
.tree li.parent_li > span:hover + ul li span {
  background: #FDDFB3 !important;
  border: 1px solid #FAA937;
  color: #000;
}
/*
 * VECTOR MAP
 */
.jvectormap-label {
  position: absolute;
  display: none;
  border: solid 1px #CDCDCD;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  background: #292929;
  color: white;
  font-family: sans-serif, Verdana;
  font-size: smaller;
  padding: 3px;
}
.jvectormap-zoomin,
.jvectormap-zoomout {
  position: absolute;
  background: #292929;
  padding: 4px;
  width: 22px;
  height: 22px;
  cursor: pointer;
  line-height: 10px;
  text-align: center;
  font-size: 14px;
  border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  -webkit-box-shadow: inset 0 -2px 0 rgba(0, 0, 0, 0.05);
  background-color: #ffffff;
  border: 1px solid #bfbfbf;
}
.jvectormap-zoomin:hover,
.jvectormap-zoomout:hover {
  background: #eeeeee;
  border-color: #d9d9d9;
}
.jvectormap-zoomin {
  top: 0px;
}
.jvectormap-zoomout {
  top: 24px;
}
.vector-map {
  height: 300px;
  width: 100%;
  padding: 10px;
}
#heat-fill {
  display: block;
  position: relative;
  margin-bottom: 20px;
  background: #333333;
  height: 7px;
  width: 200px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgAAAABCAIAAAAU3Xa1AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDowMDE4MkZGMzMzOTgxMUUzODZBQUNFQUNFOTk0NEUxRiIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDowMDE4MkZGNDMzOTgxMUUzODZBQUNFQUNFOTk0NEUxRiI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjAwMTgyRkYxMzM5ODExRTM4NkFBQ0VBQ0U5OTQ0RTFGIiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjAwMTgyRkYyMzM5ODExRTM4NkFBQ0VBQ0U5OTQ0RTFGIi8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+rG8MDAAAAM5JREFUeNpUUtESwyAIg8ft9v8/W4ElBPWKV1AIiKEeEWVuVlWjINSVONBnirQDxukNgcuyTQsBzLHMDsLIQQw+nIL71JqNJ5GZJXApFNpmtlagQjfS2xGbkFA4Iwu+hu0sK3Wl3nOwNv7TvPrWk3X0eW9dK1pU9hK2eTuWb2ySJmlziutA3iBxmblPNvA5PNsuUpoDY80+Z0SW1IRpDEqwC58C14tsr1f8le8si0aojdADr/1UjaclsFashX8GGkL9wDxtRsV6ft/PX4ABADRzhOVIOJaAAAAAAElFTkSuQmCC);
}
.fill-a,
.fill-b {
  width: 20px;
  text-align: right;
  overflow: hidden;
  text-overflow: ellipsis;
  display: block;
  background: #ffffff;
  padding-right: 4px;
  position: absolute;
  left: 0px;
  margin-top: -7px;
  font-weight: bold;
}
.fill-b {
  text-align: left;
  position: absolute;
  right: 0px;
  left: auto;
  top: 0px;
  width: 60px;
  padding-left: 4px;
  padding-right: 0px;
}
/*
 * CKEDITOR
 */
.cke_top {
  background: rgba(248, 248, 248, 0.9) !important;
  background-image: none !important;
}
/*
 * PACE PROGRESS BAR
 */
.pace {
  -webkit-pointer-events: none;
  pointer-events: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
}
.pace-inactive {
  display: none;
}
.pace .pace-progress {
  background: #3276b1;
  position: fixed;
  z-index: 2000;
  top: 0;
  left: 0;
  height: 2px;
  -webkit-transition: width 1s;
  -moz-transition: width 1s;
  -o-transition: width 1s;
  transition: width 1s;
}
.pace .pace-progress-inner {
  display: block;
  position: absolute;
  right: 0px;
  width: 100px;
  height: 100%;
  box-shadow: 0 0 10px #29d, 0 0 5px #29d;
  opacity: 1.0;
  -webkit-transform: rotate(3deg) translate(0px, -4px);
  -moz-transform: rotate(3deg) translate(0px, -4px);
  -ms-transform: rotate(3deg) translate(0px, -4px);
  -o-transform: rotate(3deg) translate(0px, -4px);
  transform: rotate(3deg) translate(0px, -4px);
}
.pace .pace-activity {
  display: block;
  position: fixed;
  z-index: 2000;
  top: 63px;
  right: 40px;
  width: 14px;
  height: 14px;
  border: solid 2px transparent;
  border-top-color: #29d;
  border-left-color: #29d;
  border-radius: 10px;
  -webkit-animation: pace-spinner 400ms linear infinite;
  -moz-animation: pace-spinner 400ms linear infinite;
  -ms-animation: pace-spinner 400ms linear infinite;
  -o-animation: pace-spinner 400ms linear infinite;
  animation: pace-spinner 400ms linear infinite;
}
@-webkit-keyframes pace-spinner {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@-moz-keyframes pace-spinner {
  0% {
    -moz-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -moz-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@-o-keyframes pace-spinner {
  0% {
    -o-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -o-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@-ms-keyframes pace-spinner {
  0% {
    -ms-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes pace-spinner {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
/*
 * BS Multiselect
 * TODO:
 */
.multiselect-container {
  position: absolute;
  list-style-type: none;
  margin: 0;
  padding: 0;
}
.multiselect-container .input-group {
  margin: 5px;
}
.multiselect-container > li {
  padding: 0;
}
.multiselect-container > li > a.multiselect-all label {
  font-weight: bold;
}
.multiselect-container > li > label.multiselect-group {
  margin: 0;
  padding: 3px 20px 3px 20px;
  height: 100%;
  font-weight: bold;
}
.multiselect-container > li > a > label {
  margin: 0;
  height: 100%;
  cursor: pointer;
  font-weight: normal;
}
.multiselect-container > li > a > label.radio,
.multiselect-container > li > a > label.checkbox {
  margin: 0;
}
.multiselect-container > li > a > label > input[type="checkbox"] {
  margin-bottom: 5px;
}
.btn-group > .btn-group:nth-child(2) > .multiselect.btn {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
/*
 * FORMS: INPUT WITH ICONS
 */
.input-group .icon-addon .form-control {
  border-radius: 0;
}
.icon-addon {
  position: relative;
  color: #555;
  display: block;
}
.icon-addon:after,
.icon-addon:before {
  display: table;
  content: " ";
}
.icon-addon:after {
  clear: both;
}
.icon-addon.addon-md .glyphicon,
.icon-addon .glyphicon,
.icon-addon.addon-md .fa,
.icon-addon .fa {
  position: absolute;
  z-index: 2;
  left: 10px;
  width: 20px;
  margin-left: -2.5px;
  text-align: center;
  padding: 10px 0;
  top: 1px;
}
.icon-addon.addon-lg .form-control {
  line-height: 1.33;
  height: 46px;
  font-size: 18px;
  padding: 10px 16px 10px 40px;
}
.input-group-lg .icon-addon.addon-lg + .input-group-btn > .btn {
  height: 46px;
}
.icon-addon.addon-sm .form-control {
  height: 30px;
  padding: 5px 10px 5px 28px;
  font-size: 12px;
  line-height: 1.5;
}
.icon-addon.addon-lg .fa,
.icon-addon.addon-lg .glyphicon {
  font-size: 18px;
  margin-left: 0;
  left: 11px;
  top: 4px;
}
.icon-addon.addon-md .form-control,
.icon-addon .form-control {
  padding-left: 30px;
  float: left;
  font-weight: normal;
}
.icon-addon.addon-sm .fa,
.icon-addon.addon-sm .glyphicon {
  margin-left: 0;
  font-size: 12px;
  left: 5px;
  top: -1px;
}
.icon-addon .form-control:focus + .glyphicon,
.icon-addon:hover .glyphicon,
.icon-addon .form-control:focus + .fa,
.icon-addon:hover .fa {
  color: #2580db;
}
.icon-addon input:disabled + .glyphicon,
.icon-addon select:disabled + .glyphicon,
.icon-addon input:disabled + .fa,
.icon-addon select:disabled + .fa {
  color: #ccc;
}
/*
 * GENERAL MOBILE (Applies to all resolutions below 979px)
 */
@media (max-width: 979px) {
  /* Profile Page */
  .profile-pic > img {
    width: 110px;
  }
  /* Profile Page */
  .profile-pic {
    float: left;
  }
  .profile-pic > img {
    margin-right: 10px;
  }
  .profile-pic + div,
  .profile-pic + div + div {
    padding-left: 30px;
    padding-right: 30px;
  }
  /* added new class per version 1.3 
	html, body {
		overflow-x: hidden !important;
	}*/
  #fullscreen > :first-child > a {
    display: none !important;
  }
  body.container {
    border: none !important;
  }
  .inbox-data-message > :first-child {
    height: 50px;
    overflow: hidden;
  }
  .show-stats .show-stat-buttons > :first-child {
    padding-right: 13px;
  }
  .show-stats .show-stat-buttons > :last-child {
    padding-left: 13px;
  }
  .inbox-checkbox-triggered > .btn-group .btn {
    padding-left: 10px;
    padding-right: 10px;
  }
  .inbox-body .table-wrap {
    padding: 0px !important;
  }
  .inbox-nav-bar {
    padding-left: 5px;
    padding-right: 5px;
  }
  .inbox-data-message > :first-child > :first-child {
    display: block !important;
    font-size: 14px;
  }
  .inbox-table-icon > :first-child {
    margin-top: 12px;
  }
  #inbox-table .inbox-table-icon {
    padding-left: 10px !important;
  }
  /* search header */
  .header-search.pull-right {
    margin-left: 0px;
  }
  /* Visibility */
  .visible-tablet {
    display: inline-block !important;
  }
  .hidden-tablet,
  .display-inline.hidden-tablet {
    display: none !important;
  }
}
/* MOBILE LAYOUT STARTS HERE */
/*
 * IPAD HORIZONTAL
 */
@media (min-width: 768px) and (max-width: 979px) {
  #main::after {
    /*content: "IPAD HORIZONTAL";*/
  }
  #main {
    margin-left: 0;
  }
  #left-panel {
    left: -220px;
  }
  /* minified adjustment counter */
  .minified #left-panel {
    left: 0px;
  }
  /* responsive menu button */
  #hide-menu > :first-child > a {
    margin-top: 9px;
    width: 40px;
  }
  .btn-header a {
    margin-top: 9px !important;
    width: 40px !important;
  }
  #hide-menu i {
    color: #6D6A69;
    font-size: 100%;
  }
  .hidden-menu #hide-menu i {
    color: #ffffff;
  }
  #hide-menu i::before {
    content: "\f0c9";
  }
  .hidden-menu #left-panel {
    left: 0;
  }
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
  .fixed-ribbon #ribbon {
    left: 0px;
  }
  /*
	 * Header search
	 */
  .header-search > input[type="text"] {
    margin-top: 9px;
  }
}
/*
 * IPAD VERTICAL
 */
@media (min-width: 768px) and (max-width: 880px) {
  #main::after {
    /*content: "IPAD VERTICAL";*/
  }
  #main {
    margin-left: 0;
  }
  #left-panel {
    left: -220px;
  }
  .no-content-padding {
    margin: 0 -14px !important;
  }
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
  /* minified adjustment counter */
  .minified #left-panel {
    left: 0px;
  }
  /* responsive menu button */
  #hide-menu > :first-child > a,
  .btn-header a {
    margin-top: 5px !important;
    width: 40px !important;
    height: 39px !important;
    line-height: 38px !important;
  }
  #logo {
    margin-top: 10px;
  }
  #logo img {
    width: 127px;
  }
  /* transparent header button */
  .btn-header.transparent a {
    border: none !important;
    background: none;
    margin-left: 0;
    width: 25px !important;
    box-shadow: none !important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
  #hide-menu i {
    color: #6D6A69;
    font-size: 121%;
  }
  .hidden-menu #hide-menu i {
    color: #ffffff;
  }
  #hide-menu i::before {
    content: "\f0c9";
  }
  .hidden-menu #left-panel {
    left: 0px;
  }
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
  .fixed-ribbon #ribbon {
    left: 0px;
  }
  /*
	 * Header search
	 */
  .header-search > input[type="text"] {
    margin-top: 9px;
  }
}
/*
 * OTHER DEVICES
 */
@media (max-width: 767px) {
  /* Profile Page */
  .profile-pic > img {
    width: 100px;
  }
  #main::after {
    /*content: "OTHER DEVICES";*/
  }
  #main {
    margin-left: 0px;
  }
  #left-panel {
    left: -220px;
  }
  /* dashboard microcharts */
  .show-stat-microcharts > div {
    margin-top: 0px !important;
    border-right: none !important;
  }
  .show-stat-buttons {
    padding-left: 10px !important;
    padding-right: 10px !important;
  }
  /* padding adjustment */
  #content,
  #ribbon {
    padding-left: 5px;
    padding-right: 5px;
  }
  #header {
    padding-right: 5px;
  }
  #logo {
    margin-left: 4px;
  }
  .no-content-padding {
    margin: 0 -5px !important;
  }
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
  /* minified adjustment counter */
  .minified #left-panel {
    left: 0px;
  }
  /* transparent header button */
  .btn-header.transparent a {
    border: none !important;
    background: none;
    margin-left: 0;
    width: 25px !important;
    box-shadow: none !important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
  /* responsive menu button */
  #hide-menu > :first-child > a,
  .btn-header a {
    margin-top: 5px !important;
    width: 40px !important;
    height: 39px !important;
    line-height: 38px !important;
  }
  #hide-menu > :first-child > a {
    width: 50px !important;
  }
  #logo {
    margin-top: 10px;
  }
  #logo img {
    width: 127px;
  }
  #hide-menu i {
    color: #6D6A69;
    font-size: 121%;
  }
  .hidden-menu #hide-menu i {
    color: #ffffff;
  }
  #hide-menu i::before {
    content: "\f0c9";
  }
  .hidden-menu #left-panel {
    left: 0px;
  }
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
  .fixed-ribbon #ribbon {
    left: 0px;
  }
  .fixed-navigation #left-panel {
    position: absolute !important;
  }
  /*
	 * fixed ribbon
	 */
  .fixed-ribbon #content {
    padding-top: 52px;
  }
  /*
	 * header search
	 */
  .header-search {
    display: none;
  }
  #search-mobile {
    display: block;
  }
  .search-mobile .header-search {
    display: block;
    position: absolute;
    top: 0px;
    width: 100%;
    height: 49px;
    background: #333;
    padding: 0 2px;
    box-sizing: border-box;
    left: 0px;
  }
  .search-mobile .header-search > input[type="text"] {
    margin-top: 2px;
    height: 45px;
    border-color: #333;
    padding-right: 75px;
  }
  .search-mobile .header-search > button {
    height: 29px;
    line-height: 29px;
    background: #DDDDDD;
  }
  .search-mobile .header-search > button {
    right: 44px;
  }
  .search-mobile #search-mobile {
    display: none;
  }
  .search-mobile #cancel-search-js {
    display: block;
  }
  /* project info is not needed at this width */
  #project-context {
    display: none;
  }
}
/*
 * ANDROID
 */
@media only screen and (min-width: 0px) and (max-width: 679px) {
  /* Profile Page */
  .profile-pic > img {
    width: 90px;
  }
  #main::after {
    /*content: "ANDROID";*/
  }
  #main {
    margin-left: 0;
  }
  #left-panel {
    left: -220px;
  }
  /* dashboard microcharts */
  .show-stat-microcharts > div {
    margin-top: 0px !important;
    border-right: none !important;
  }
  .show-stat-buttons {
    padding-left: 10px !important;
    padding-right: 10px !important;
  }
  /* padding adjustment */
  #content,
  #ribbon {
    padding-left: 5px;
    padding-right: 5px;
  }
  #header {
    padding-right: 5px;
  }
  #logo {
    margin-left: 4px;
  }
  .no-content-padding {
    margin: 0 -5px !important;
  }
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
  /* minified adjustment counter */
  .minified #left-panel {
    left: 0px;
  }
  /* header color altered and adjusted for mobile view & contrast */
  #header {
    background: #ffffff;
  }
  #ribbon {
    border-bottom: 1px solid #CFCFCF;
    border-top: 1px solid #E6E6E6;
    background: #F5F5F5;
  }
  #ribbon .breadcrumb a,
  #ribbon .breadcrumb {
    color: #6D6C6C !important;
  }
  #ribbon .breadcrumb > .active,
  #ribbon .breadcrumb li:last-child {
    color: #333 !important;
  }
  /* responsive menu button */
  #hide-menu > :first-child > a,
  .btn-header a {
    margin-top: 5px !important;
    width: 40px !important;
    height: 39px !important;
    line-height: 38px !important;
  }
  #hide-menu > :first-child > a {
    width: 50px !important;
  }
  #logo {
    margin-top: 10px;
  }
  #logo img {
    width: 127px;
  }
  /* transparent header button */
  .btn-header.transparent a {
    border: none !important;
    background: none;
    margin-left: 0;
    width: 25px !important;
    box-shadow: none !important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
  /* menu btn cont... */
  #hide-menu i {
    color: #6D6A69;
    font-size: 121%;
  }
  .hidden-menu #hide-menu i {
    color: #ffffff;
  }
  #hide-menu i::before {
    content: "\f0c9";
  }
  .hidden-menu #left-panel {
    left: 0;
  }
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
  .fixed-ribbon #ribbon {
    left: 0px;
  }
  /*
	 * header search
	 */
  .header-search {
    display: none;
  }
  #search-mobile {
    display: block;
  }
  .search-mobile .header-search {
    display: block;
    position: absolute;
    top: 0px;
    width: 100%;
    height: 49px;
    background: #333;
    padding: 0 2px;
    box-sizing: border-box;
    left: 0px;
  }
  .search-mobile .header-search > input[type="text"] {
    margin-top: 2px;
    height: 45px;
    border-color: #333;
    padding-right: 75px;
  }
  .search-mobile .header-search > button {
    height: 29px;
    line-height: 29px;
    background: #DDDDDD;
  }
  .search-mobile .header-search > button {
    right: 44px;
  }
  .search-mobile #search-mobile {
    display: none;
  }
  .search-mobile #cancel-search-js {
    display: block;
  }
  /* project info is not needed at this width */
  #project-context {
    display: none !important;
  }
  .hidden-tablet {
    display: none !important;
  }
}
/*
 * IPHONE
 */
@media only screen and (min-width: 320px) and (max-width: 479px) {
  /* Profile Page */
  .profile-pic {
    text-align: left;
  }
  .profile-pic > img {
    width: 90px;
    margin-left: 0px;
    top: -25px;
    margin-right: 0px;
  }
  .profile-pic + div > h1 {
    font-size: 20px;
  }
  .profile-pic + div > h1 small {
    font-size: 16px;
  }
  .profile-carousel .carousel-indicators {
    top: 10px;
  }
  #main::after {
    /*content: "IPHONE";*/
  }
  #main {
    margin-left: 0;
  }
  #left-panel {
    left: -220px;
  }
  /* dashboard microcharts */
  .show-stat-microcharts > div {
    margin-top: 0px !important;
    border-right: none !important;
  }
  .show-stat-buttons {
    padding-left: 10px !important;
    padding-right: 10px !important;
  }
  /* padding adjustment */
  #content,
  #ribbon {
    padding-left: 5px;
    padding-right: 5px;
  }
  #header {
    padding-right: 5px;
  }
  #logo {
    margin-left: 4px;
  }
  .no-content-padding {
    margin: 0 -5px !important;
  }
  .inbox-nav-bar.no-content-padding {
    margin-top: -10px !important;
  }
  /* minified adjustment counter */
  .minified #left-panel {
    left: 0px;
  }
  /* header color altered and adjusted for mobile view & contrast */
  #header {
    background: #ffffff;
  }
  #ribbon {
    border-bottom: 1px solid #CFCFCF;
    border-top: 1px solid #E6E6E6;
    background: #F5F5F5;
  }
  #ribbon .breadcrumb a,
  #ribbon .breadcrumb {
    color: #6D6C6C !important;
  }
  #ribbon .breadcrumb > .active,
  #ribbon .breadcrumb li:last-child {
    color: #333 !important;
  }
  /* lego width adjustment */
  #logo {
    width: 135px;
  }
  #logo-group {
    width: 169px !important;
  }
  /* spark line top */
  #sparks {
    text-align: center;
    background: #E0E0E0;
    padding: 10px 0;
    margin-bottom: 15px;
  }
  #sparks li {
    padding: 0 10px 0 20px;
  }
  /* project content */
  #project-context {
    display: none !important;
  }
  /* responsive menu button */
  #hide-menu > :first-child > a,
  .btn-header a {
    margin-top: 5px !important;
    width: 40px !important;
    height: 39px !important;
    line-height: 38px !important;
  }
  #logo {
    margin-top: 10px;
  }
  #logo img {
    width: 127px;
  }
  /* transparent header button */
  .btn-header.transparent a {
    border: none !important;
    background: none;
    margin-left: 0;
    width: 25px !important;
    box-shadow: none !important;
  }
  .btn-header.transparent a:hover {
    color: #a90329;
  }
  #hide-menu > :first-child > a {
    width: 46px !important;
  }
  #hide-menu i {
    color: #6D6A69;
    font-size: 121%;
  }
  .hidden-menu #hide-menu i {
    color: #ffffff;
  }
  #hide-menu i::before {
    content: "\f0c9";
  }
  .hidden-menu #left-panel {
    left: 0px;
  }
  .hidden-menu #main {
    position: relative;
    left: 210px;
  }
  .hidden-menu.fixed-ribbon #ribbon {
    left: 220px;
  }
  .fixed-ribbon #ribbon {
    left: 0px;
  }
  /* project info is not needed at this width */
  #project-context {
    display: none;
  }
  /* #*$^& Bootstrap 3 ! */
  .hidden-mobile {
    display: none !important;
  }
  .visible-mobile {
    display: inline-block !important;
  }
  /* activity panel */
  .ajax-notifications {
    height: 250px;
  }
  .ajax-dropdown {
    width: 299px;
    height: 320px;
    left: 0;
    top: 49px;
  }
  .ajax-dropdown:before {
    margin-left: -14px;
  }
  .ajax-dropdown:after {
    margin-left: -13px;
  }
  /*
	 * header search
	 */
  .header-search {
    display: none;
  }
  #search-mobile {
    display: block;
    margin-left: 0;
  }
  .search-mobile .header-search {
    display: block;
    position: absolute;
    top: 0px;
    width: 100%;
    height: 49px;
    background: #333;
    padding: 0 2px;
    box-sizing: border-box;
    left: 0px;
  }
  .search-mobile .header-search > input[type="text"] {
    margin-top: 2px;
    height: 45px;
    border-color: #333;
    padding-right: 75px;
  }
  .search-mobile .header-search > button {
    height: 29px;
    line-height: 29px;
    background: #DDDDDD;
  }
  .search-mobile .header-search > button {
    right: 44px;
  }
  .search-mobile #search-mobile {
    display: none;
  }
  .search-mobile #cancel-search-js {
    display: block;
  }
  /* widget headers width */
  .jarviswidget header h2 {
    width: 135px;
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
  }
}
/*
 * ANIMATED
 */
/* Navigation icon first level 
.desktop-detected nav > ul > li > a:hover i {
	-webkit-animation-name: wobble;
	-moz-animation-name: wobble;
	-o-animation-name: wobble;
	animation-name: wobble;
}

.desktop-detected nav > ul > li > a:hover i {
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
}*/
/* All dropdowns */
.open > .dropdown-menu {
  -webkit-animation-name: flipInX;
  -moz-animation-name: flipInX;
  -o-animation-name: flipInX;
  animation-name: flipInX;
}
.open > .dropdown-menu {
  -webkit-animation-duration: .4s;
  -moz-animation-duration: .4s;
  -o-animation-duration: .4s;
  animation-duration: .4s;
  -webkit-animation-fill-mode: both;
  -moz-animation-fill-mode: both;
  -o-animation-fill-mode: both;
  animation-fill-mode: both;
}
.active + .ajax-dropdown {
  -webkit-animation-name: flipInY;
  -moz-animation-name: flipInY;
  -o-animation-name: flipInY;
  animation-name: flipInY;
  -webkit-animation-duration: .7s;
  -moz-animation-duration: .7s;
  -o-animation-duration: .7s;
  animation-duration: .7s;
  -webkit-animation-fill-mode: both;
  -moz-animation-fill-mode: both;
  -o-animation-fill-mode: both;
  animation-fill-mode: both;
}
